package cz.cuni.jagrlib;

/**
 * Binary operations used in set*() drawing methods. All 16 binary mappings are coded into
 * one integer ( [oldBit,newBit] -&gt; resultBit).
 *
 * @version 0.25 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
 * @since   0.02
 * @see     <a href="../../../../cz/cuni/jagrlib/BinaryOperation.java">BinaryOperation.java</a>
 * @see     cz.cuni.jagrlib.iface.BitMask interface BitMask
 * @see     cz.cuni.jagrlib.iface.RasterGraphics interface RasterGraphics
 */
public class BinaryOperation
{
  /* old  new   code
      0    0    bit0
      0    1    bit1
      1    0    bit2
      1    1    bit3
  */

  /**
   * Zero .. code = <tt>0000</tt>.
   */
  public final static int BIN_OP_ZERO     = 0x00;

  /**
   * Not(Or) .. code = <tt>1000</tt>.
   */
  public final static int BIN_OP_NOR      = 0x01;

  /**
   * Not(Old) &amp; New /= New subtract Old/ .. code = <tt>0100</tt>.
   */
  public final static int BIN_OP_0100     = 0x02;
  public final static int BIN_OP_SUB_INV  = 0x02;

  /**
   * Negate .. code = <tt>1100</tt>.
   */
  public final static int BIN_OP_NEGATE   = 0x03;

  /**
   * Old &amp; Not(New) /= Old subtract New/ .. code = <tt>0010</tt>.
   */
  public final static int BIN_OP_0010     = 0x04;
  public final static int BIN_OP_SUBTRACT = 0x04;

  /**
   * Not(Set) .. code = <tt>1010</tt>.
   */
  public final static int BIN_OP_NSET     = 0x05;

  /**
   * Xor .. code = <tt>0110</tt>.
   */
  public final static int BIN_OP_XOR      = 0x06;

  /**
   * Not(And) .. code = <tt>1110</tt>.
   */
  public final static int BIN_OP_NAND     = 0x07;

  /**
   * And .. code = <tt>0001</tt>.
   */
  public final static int BIN_OP_AND      = 0x08;

  /**
   * Equal .. code = <tt>1001</tt>.
   */
  public final static int BIN_OP_EQUAL    = 0x09;

  /**
   * Set .. code = <tt>0101</tt>.
   */
  public final static int BIN_OP_SET      = 0x0a;

  /**
   * Not(Old) | New .. code = <tt>1101</tt>.
   */
  public final static int BIN_OP_1101     = 0x0b;

  /**
   * Dummy .. code = <tt>0011</tt>.
   */
  public final static int BIN_OP_DUMMY    = 0x0c;

  /**
   * Old | Not(New) .. code = <tt>1011</tt>.
   */
  public final static int BIN_OP_1011     = 0x0d;

  /**
   * Or .. code = <tt>0111</tt>.
   */
  public final static int BIN_OP_OR       = 0x0e;

  /**
   * One .. code = <tt>1111</tt>.
   */
  public final static int BIN_OP_ONE      = 0x0f;

  /**
   * Returns the binary-op result.
   *
   * @param  op Binary operation code.
   * @param  canvas The original (canvas) boolean value.
   * @param  brush The drawn (brush) boolean value.
   * @return The result boolean value.
   */
  public final static boolean boolOp ( int op, boolean canvas, boolean brush )
  {
    return( ((canvas ? (op >> 2) : op) & (brush ? 2 : 1)) > 0 );
  }

  /**
   * Returns the <b>stationary closure</b> of a binary operation (<tt>0</tt> in <b>brush</b>
   * plane must not change anything).
   *
   * @param  op The binary operation.
   * @return The stationary closure of the operation.
   */
  public final static int stationaryOp ( int op )
  {
    return( (op & BIN_OP_OR) | BIN_OP_0010 );
  }

}
