package cz.cuni.jagrlib;

/**
 * Abstract {@link cz.cuni.jagrlib.iface.BitMask}-enumerator. Used for {@link cz.cuni.jagrlib.iface.BitMask} and
 * {@link cz.cuni.jagrlib.iface.AlphaMask} passing.
 *
 * @version 0.25 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
 * @since   0.03
 * @see     <a href="../../../../cz/cuni/jagrlib/BitMaskEnumerator.java">BitMaskEnumerator.java</a>
 * @see     cz.cuni.jagrlib.iface.BitMask interface BitMask
 * @see     cz.cuni.jagrlib.iface.AlphaMask interface AlphaMask
 */
public interface BitMaskEnumerator
{
  /** -Infinity marker. */
  int MINUS_INFINITY = Integer.MIN_VALUE;

  /** +Infinity marker. */
  int PLUS_INFINITY  = Integer.MAX_VALUE;

  /**
   * Return type for {@link BitMaskEnumerator} pixel.
   *
   * @version 0.25 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
   * @since   0.03
   * @see     BitMaskEnumerator.HLine
   */
  class Pixel
  {
    /**
     * X coordinate of the pixel. <br>For infinite scanlines two {@link Pixel}s
     * are returned (using {@link #MINUS_INFINITY} and/or {@link #PLUS_INFINITY}).
     */
    public int x;

    /** Y coordinate of the pixel. */
    public int y;

    /** Opacity of the pixel (should be &gt; <tt>0.0</tt>). */
    public double alpha;
  }

  /**
   * Return type for {@link BitMaskEnumerator} H-line.
   *
   * @version 0.25 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
   * @since   0.03
   * @see     BitMaskEnumerator.Pixel
   */
  class HLine
  {
    /**
     * Starting X coordinate of the H-line.
     * <br>Infinity markers can be used.
     */
    public int x1;

    /**
     * X coordinate after the end of of the H-line (x2 &gt; x1).
     * <br>Infinity markers can be used.
     */
    public int x2;

    /** Y coordinate of the H-line. */
    public int y;

    /** Opacity of the H-line (should be &gt; <tt>0.0</tt>). */
    public double alpha;
  }

  /**
   * (re-)initialization of the enumerator.
   */
  void reset ();

  /**
   * Returns the next {@link cz.cuni.jagrlib.iface.BitMask} ({@link cz.cuni.jagrlib.iface.AlphaMask}) pixel.
   *
   * @param  pre Pre-allocated {@link Pixel} instance (non-mandatory).
   * @return The next opaque {@link Pixel} or <tt>null</tt>.
   * @see    #nextHLine
   */
  Pixel nextPixel ( Pixel pre );

  /**
   * Returns the next {@link cz.cuni.jagrlib.iface.BitMask} ({@link cz.cuni.jagrlib.iface.AlphaMask}) H-line.
   *
   * @param  pre Pre-allocated {@link HLine} instance (non-mandatory).
   * @return The next opaque {@link HLine} or <tt>null</tt>.
   * @see    #nextPixel
   */
  HLine nextHLine ( HLine pre );

}
