package cz.cuni.jagrlib;

import java.util.*;

import cz.cuni.jagrlib.iface.Solid;

/**
 * Leaf node (holding elementary solid) of CSG scene representation.
 *
 * @version 0.26 $Rev: 460 $ $Date: 2007-05-21 17:21:31 +0200 (po, 21 V 2007) $ $Author: pepca $
 * @since   0.11
 * @see     <a href="../../../../cz/cuni/jagrlib/CSGLeaf.java">CSGLeaf.java</a>
 * @see     Solid
 * @see     CSGNode
 */
public class CSGLeaf extends CSGCommonNode
{
  /**
   * Solid which is assigned to this leaf-node.
   * One Solid instance can be shared among multiple {@link CSGLeaf}Nodes.
   */
  public Solid solid;

  /** Initializing constructor. */
  public CSGLeaf ( Solid _solid )
  {
    solid = _solid;
  }

  /**
   * Computes all intersections of the given ray with the solid.
   *
   * @param  P0 Ray origin ({@code double[3]} or {@code double[4]}).
   * @param  P1 Direction vector of the ray ({@code double[3]} or {@code double[4]}).
   * @return List of all intersections with the solid.
   */
  public List< MicroFacet > intersection ( double[] P0, double[] P1 )
  {
    if ( P0 == null || P0.length < 3 ||
         P1 == null || P1.length < 3 || solid == null ) return null;

    List< MicroFacet > inter = solid.intersection( P0, P1 );
    if ( inter != null )                  // complete the MicroFacet data
      for ( MicroFacet mf : inter )
      {
        mf.sceneNode = this;
        if ( mf.geometry == null )
          mf.geometry = solid;
      }

    return inter;
  }

}
