package cz.cuni.jagrlib;

import cz.cuni.jagrlib.iface.*;

/**
 * Default implementation of {@link BrepIterator} interface - using precomputed array.
 *
 * @version 0.25 $Rev: 401 $ $Date: 2007-03-11 13:15:07 +0100 (ne, 11 III 2007) $ $Author: pepca $
 * @see     <a href="../../../../cz/cuni/jagrlib/DefaultBrepIteratorArr.java">DefaultBrepIteratorArr.java</a>
 */
public abstract class DefaultBrepIteratorArr extends DefaultBrepIterator
{
  /** Next object's id. */
  protected int n;

  /** Precomputed array - {@link #reset} has to initialize it! */
  protected int[] arr;

  /**
   * Fills the provided array by all items (pre-allocated array could be {@code null}
   * or too small - in these cases new one will be created).
   * End of the data is marked using {@link Brep#NULL}.
   */
  @Override
  public int[] toArray ( int[] pre )
  {
    if ( arr == null ) return null;

    if ( pre == null ||
         pre.length < arr.length )
      pre = new int[ arr.length ];

    System.arraycopy( arr, 0, pre, 0, arr.length );
    if ( pre.length > arr.length )
      pre[ arr.length ] = Brep.NULL;

    return pre;
  }

  /**
   * Returns id of the next object.
   *
   * @return {@link Brep#NULL} if there is no next object available.
   */
  public int next ()
  {
    if ( arr != null &&
         n < arr.length )
      return arr[n++];

    return Brep.NULL;
  }

  /**
   * How many items remain in the set?.
   * Non-mandatory - must return {@link Brep#NULL} if not implemented.
   */
  @Override
  public int left ()
  {
    return( (arr == null) ? Brep.NULL : arr.length - n );
  }

}
