package cz.cuni.jagrlib;

import cz.cuni.jagrlib.iface.FunctionR2ToR2;

/**
 * Default implementation of {@link FunctionR2ToR2} interface.
 *
 * @version 0.24 $Rev: 270 $ $Date: 2006-05-24 02:50:03 +0200 (st, 24 V 2006) $ $Author: pepca $
 * @see     <a href="../../../../cz/cuni/jagrlib/DefaultFunctionR2ToR2.java">DefaultFunctionR2ToR2.java</a>
 */
public abstract class DefaultFunctionR2ToR2 extends Piece implements FunctionR2ToR2
{
  /**
   * Compute the mapping: <b>f(x,y)</b>.
   *
   * @param  x X coordinate (1st argument).
   * @param  y Y coordinate (2nd argument).
   * @param  res Result array (<tt>res[0]</tt> = U coordinate,
   *             <tt>res[1]</tt> = V coordinate).
   */
  public void f ( double x, double y, double[] res )
  {
    if ( res == null || res.length < 2 ) return;

    res[0] = x;
    res[1] = y;
  }

  /**
   * Compute partial derivatives: <b>du(x,y)/dx</b>, <b>du(x,y)/dy</b>, <b>dv(x,y)/dx</b> and
   * <b>dv(x,y)/dy</b>.
   *
   * @param  x X coordinate (1st argument).
   * @param  y Y coordinate (2nd argument).
   * @param  d Array to hold results (<tt>d[0]</tt> = du(x,y)/dx,
   *           <tt>d[1]</tt> = du(x,y)/dy, <tt>d[2]</tt> = dv(x,y)/dx,
   *           <tt>d[3]</tt> = dv(x,y)/dy).
   * @return <tt>true</tt> if this service is implemented.
   */
  public boolean df ( double x, double y, double d[] )
  {
    return false;
  }

  /**
   * Compute the inverse mapping: <b>f<sup>-1</sup>(u,v)</b>.
   *
   * @param  u U coordinate (1st argument).
   * @param  v V coordinate (2nd argument).
   * @param  res Result array (<tt>res[0]</tt> = X coordinate,
   *             <tt>res[1]</tt> = Y coordinate).
   * @return <tt>true</tt> if this service is implemented.
   */
  public boolean fInv ( double u, double v, double[] res )
  {
    if ( res == null || res.length < 2 ) return false;

    res[0] = u;
    res[1] = v;
    return true;
  }

  /**
   * Compute partial derivatives of inverse mapping: <b>dx(u,v)/du</b>, <b>dx(u,v)/dv</b>,
   * <b>dy(u,v)/du</b> and <b>dy(u,v)/dv</b>.
   *
   * @param  u U coordinate (1st argument).
   * @param  v V coordinate (2nd argument).
   * @param  d Array to hold results (<tt>d[0]</tt> = dx(u,v)/du,
   *           <tt>d[1]</tt> = dx(u,v)/dv, <tt>d[2]</tt> = dy(u,v)/du,
   *           <tt>d[3]</tt> = dy(u,v)/dv).
   * @return <tt>true</tt> if this service is implemented.
   */
  public boolean dfInv ( double u, double v, double d[] )
  {
    return false;
  }

  /**
   * Returns domain of the mapping.
   *
   * @param  dom Domain array (<tt>dom[0]</tt> = Xmin, <tt>dom[1]</tt> = Xmax,
   *             <tt>dom[2]</tt> = Ymin, <tt>dom[3]</tt> = Ymax).
   * @return <tt>true</tt> if this service is implemented.
   */
  public boolean getDomain ( double[] dom )
  {
    return false;
  }

  /**
   * Returns range of the mapping.
   *
   * @param  rng Range array (<tt>rng[0]</tt> = Umin, <tt>rng[1]</tt> = Umax,
   *             <tt>rng[2]</tt> = Vmin, <tt>rng[3]</tt> = Vmax).
   * @return <tt>true</tt> if this service is implemented.
   */
  public boolean getRange ( double[] rng )
  {
    return false;
  }

}
