package cz.cuni.jagrlib;

import cz.cuni.jagrlib.iface.IntFunction;

/**
 * Default implementation of {@link IntFunction} interface.
 *
 * @version 0.25 $Rev: 294 $ $Date: 2006-07-06 00:50:34 +0200 (čt, 06 VII 2006) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../cz/cuni/jagrlib/DefaultIntFunction.java">DefaultIntFunction.java</a>
 */
public abstract class DefaultIntFunction extends Piece implements IntFunction
{
  /**
   * Compute the mapping: {@code double -> int}.
   */
  public int g ( double x )
  {
    return g( x, 0.0 );
  }

  /**
   * Compute the mapping: {@code int -> int}.
   */
  public int g ( int x )
  {
    return g( (double)x );
  }

  /**
   * Compute the mapping: {@code double[2] -> int}.
   */
  public int g ( double x, double y )
  {
    return g( x, y, 0.0 );
  }

  /**
   * Compute the mapping: {@code int[2] -> int}.
   */
  public int g ( int x, int y )
  {
    return g( (double)x, (double)y );
  }

  /**
   * Compute the mapping: {@code double[3] -> int}.
   */
  public int g ( double x, double y, double z )
  {
    double[] arg = { x, y, z };
    return g( arg );
  }

  /**
   * Compute the mapping: {@code int[3] -> int}.
   */
  public int g ( int x, int y, int z )
  {
    return g( (double)x, (double)y, (double)z );
  }

  /**
   * Compute the mapping: {@code double[] -> int}.
   */
  public int g ( double[] arg )
  {
    return 0;
  }

  /**
   * Compute the mapping: {@code int[] -> int}.
   */
  public int g ( int[] arg )
  {
    return 0;
  }

  /**
   * Returns domain of the mapping.
   *
   * @param  dom Domain array (<tt>dom[0]</tt> = Xmin, <tt>dom[1]</tt> = Xmax, etc.).
   * @return <tt>null</tt> if this service is not implemented.
   */
  public double[] getDomain ( double[] dom )
  {
    return null;
  }

  /**
   * Returns domain of the mapping.
   *
   * @param  dom Domain array (<tt>dom[0]</tt> = Xmin, <tt>dom[1]</tt> = Xmax, etc.).
   * @return <tt>null</tt> if this service is not implemented.
   */
  public int[] getDomain ( int[] dom )
  {
    return null;
  }

}
