package cz.cuni.jagrlib;

import java.util.List;

/**
 * Default implementation of scene node.
 * Doesn't implement hierarchy-related methods.
 *
 * @version 0.26 $Rev: 462 $ $Date: 2007-05-24 10:40:53 +0200 (čt, 24 V 2007) $ $Author: pepca $
 * @since   0.25
 * @see     <a href="../../../../cz/cuni/jagrlib/DefaultSceneNode.java">DefaultSceneNode.java</a>
 */
public abstract class DefaultSceneNode implements SceneNode
{
  //==========================================================================
  //  Data:

  /** Serial number used in intersection testing. */
  protected int serial = -1;

  //==========================================================================
  //  Interface SceneNode:

  /**
   * Returns the given attribute (defined in this {@link SceneNode} or inherited from
   * some parent node).
   * <p>Returned object can be an <b>original</b> data object and must not be altered
   * outside this {@link SceneNode} instance.
   *
   * @param  key Key-string.
   * @return Attribute object or {@code null}. Must not be altered!
   * @see    #getAttributes
   * @see    #setAttribute
   * @see    #selfAttribute
   */
  public Object getAttribute ( String key )
  {
    return null;
  }

  /**
   * Is the given attribute defined in the node itself or is it inherited?
   *
   * @param  key Key-string.
   * @return {@code true} if the node defines the given attribute.
   * @see    #getAttribute
   * @see    #setAttribute
   * @see    #getAttributes
   */
  public boolean selfAttribute ( String key )
  {
    return false;
  }

  /**
   * Defines the given attribute (key-value pair) in the node.
   *
   * @param  key Key-string.
   * @param  value Attribute value (arbitrary type).
   * @return The old attribute value (defined in the node itself&excl;) or
   *         {@code null}.
   * @see    #getAttribute
   * @see    #selfAttribute
   * @see    #getAttributes
   */
  public Object setAttribute ( String key, Object value )
  {
    return null;
  }

  /**
   * Returns the whole inherence-sequence for the given attribute.
   *
   * @param  key Key-string.
   * @return List of attribute values: {@code result[0]} .. definition in the node itself,
   *         {@code result[1]} .. definition in parent node,
   *         {@code result[2]} .. definition in "grand-parent" node, etc.
   * @see    #getAttribute
   * @see    #setAttribute
   * @see    #selfAttribute
   */
  public List< Object > getAttributes ( String key )
  {
    return null;
  }

  /**
   * Returns number of child nodes.
   *
   * @return Number of child nodes (= {@code 0} for this node).
   * @see    #getChild
   * @see    #getChildMatrix
   * @see    #getChildMatrixInv
   */
  public int children ()
  {
    return 0;
  }

  /**
   * Returns the given child node.
   *
   * @param  i Order of the requested node (from {@code 0} to {@code children()-1}).
   * @return The requested node or {@code null}.
   * @see    #children
   * @see    #getChildMatrix
   * @see    #getChildMatrixInv
   */
  public SceneNode getChild ( int i )
  {
    return null;
  }

  /**
   * Returns transformation matrix for the given child node.
   *
   * @param  i Order of the child node.
   * @return Transformation matrix from the child's coordinate system to this node's one.
   *         {@code null} stands for <b>identity</b>.
   * @see    #children
   * @see    #getChild
   * @see    #getChildMatrixInv
   */
  public TrMatrix getChildMatrix ( int i )
  {
    return null;
  }

  /**
   * Returns inverse transformation matrix for the given child node.
   *
   * @param  i Order of the child node.
   * @return Transformation matrix from this node's coordinate system to child's one.
   *         {@code null} stands for <b>identity</b>.
   * @see    #children
   * @see    #getChild
   * @see    #getChildMatrix
   */
  public TrMatrix getChildMatrixInv ( int i )
  {
    return null;
  }

  /**
   * Inserts a new child node.
   *
   * @param  child The new child node.
   * @param  m Transformation matrix for the new child node (transformation from child's
   *           coordinate system to this node's one). Can be {@code null}, even
   *           for non-trivial {@code mInv}.
   * @param  mInv Inverse transformation matrix for the new child node (transformation from
   *              this node's coordinate system to child's one). Can be {@code null}, even
   *              for non-trivial {@code m}.
   * @return Order of the inserted child node (or {@code -1} in case of failure).
   * @see    #removeChild
   * @see    #children
   */
  public int insertChild ( SceneNode child, TrMatrix m, TrMatrix mInv )
  {
    return -1;
  }

  /**
   * Removes the given child node.
   *
   * @param  i Order of the child node to be removed.
   * @return Number of child nodes after the remove-operation.
   * @see    #insertChild
   * @see    #children
   */
  public int removeChild ( int i )
  {
    return 0;
  }

  /**
   * Returns the parent of this node.
   *
   * @return The parend node or {@code null} for scene-root.
   * @see    #setParent
   * @see    #getOrder
   * @see    #children
   * @see    #getChild
   */
  public SceneNode getParent ()
  {
    return null;
  }

  /**
   * Sets handle to the parent node.
   *
   * @param  par Parent node (or {@code null}).
   * @see    #getParent
   */
  public void setParent ( SceneNode par )
  {
  }

  /**
   * Returns order of this {@link SceneNode} in its parent.
   *
   * @return Order of this node as a child (or {@code -1} for scene-root).
   * @see    #setOrder
   * @see    #getParent
   */
  public int getOrder ()
  {
    return -1;
  }

  /**
   * Sets order of this {@link SceneNode} in its parent.
   *
   * @param  ord The new order.
   * @see    #getOrder
   */
  public void setOrder ( int ord )
  {
  }

  /**
   * Returns {@code true} if this node is root of object (component) hierarchy.
   *
   * @see    #setObjectRoot
   */
  public boolean isObjectRoot ()
  {
    return false;
  }

  /**
   * Sets this node as root for the object (component).
   *
   * @param  root Should this node be treated as root?
   * @see    #isObjectRoot
   */
  public void setObjectRoot ( boolean root )
  {
  }

  /**
   * Sets serial number of the current test.
   * Used in intersection testing.
   */
  public int getSerial ()
  {
    return serial;
  }

  /**
   * Returns serial number assigned to the node.
   */
  public void setSerial ( int serial )
  {
    this.serial = serial;
  }

  /**
   * Computes all intersections of the given ray with the sub-scene.
   *
   * @param  P0 Ray origin ({@code double[3]} or {@code double[4]}).
   * @param  P1 Direction vector of the ray ({@code double[3]} or {@code double[4]}).
   * @return List of all ray vs. sub-scene intersections.
   */
  public List< MicroFacet > intersection ( double[] P0, double[] P1 )
  {
    return null;
  }

  /**
   * Asserts validity of the given intersection-attributes.
   * Doesn't resolve anything.
   *
   * @param  mf The checked intersection.
   * @param  tmp Non-mandatory object holding state-information for deferred computations.
   * @param  attributes Attribute mask (required attributes - see
   *                    {@code MicroFacet.VALID_*}).
   * @return Attributes which were not computed.
   */
  public int assertAttributes ( MicroFacet mf, Object tmp, int attributes )
  {
    return attributes;
  }

}
