package cz.cuni.jagrlib;

import cz.cuni.jagrlib.iface.*;

/**
 * Default implementation of {@link Solid}.
 * Defines non-mandatory members for convenience.
 *
 * @version 0.26 $Rev: 473 $ $Date: 2007-05-31 21:16:42 +0200 (čt, 31 V 2007) $ $Author: pepca $
 * @see     <a href="../../../../cz/cuni/jagrlib/DefaultSolid.java">DefaultSolid.java</a>
 */
public abstract class DefaultSolid extends Piece implements Solid
{
  //==========================================================================
  //  Interface Solid:

  /**
   * Creates polyhedral representation of the solid (non-mandatory method).
   *
   * @param  b Global B-rep data structure.
   * @param  smoothness Quality-factor of an approximation ({@code 0.0} for default
   *                    approximation).
   * @return Handle of the created solid (or {@link Brep#NULL} if the method is not
   *         implemented).
   * @see    Brep#NULL
   */
  public int createPolyhedr ( Brep b, double smoothness )
  {
    return Brep.NULL;
  }

  /**
   * Asserts validity of the given intersection-attributes.
   * Resolves:
   * {@link MicroFacet#VALID_TANGENT VALID_TANGENT},
   * {@link MicroFacet#VALID_TEX_COORD VALID_TEX_COORD}.
   *
   * @param  mf The checked intersection.
   * @param  tmp Non-mandatory object holding state-information for deferred computations.
   * @param  attributes Attribute mask (required attributes - see
   *                    {@code MicroFacet.VALID_*}).
   * @return Attributes which were not computed.
   */
  public int assertAttributes ( MicroFacet mf, Object tmp, int attributes )
  {
    return attributes;
  }

  /**
   * Returns bounding volume of the solid (non-mandatory method).
   *
   * @param  toWorld Transform from local (solid) coordinates to world coordinates
   *         (where bounding volume will live).
   * @return Bounding volume of the solid or {@code null} if method is not implemented.
   * @see    #intersection
   */
  public BoundingVolume getBoundingVolume ( TrMatrix toWorld )
  {
    return null;
  }

  /**
   * Point vs. solid test ("inside-test").
   *
   * @param  point Coordinates of the 3D point ({@code double[3]} or
   *               {@code double[4]}).
   * @return {@code true} if the given point lies inside the solid.
   */
  public boolean isInside ( double[] point )
  {
    return false;
  }

  //==========================================================================
  //  Module registration:

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "Solid";

  /** Object category. */
  protected final static String CATEGORY = C_3D + '.' + C_SOLID;
}
