package cz.cuni.jagrlib;

import java.io.*;

import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.piece.*;

/**
 * Main program for audio de-humming (five consecutive notch filters).
 *
 * @version 0.25 $Rev: 301 $ $Date: 2006-07-20 09:08:30 +0200 (čt, 20 VII 2006) $ $Author: pepca $
 * @since   0.25
 * @see     <a href="../../../../cz/cuni/jagrlib/MainDehumming.java">MainDehumming.java</a>
 */
public class MainDehumming
{
  static String inputFileName  = "grab.wav";
  static String outputFileName = "out.wav";

  static double[]  f = {   50.0,  150.0,  250.0,  350.0,  450.0 };
  static double[]  e = { 0.9990, 0.9992, 0.9994, 0.9996, 0.9998 };
  static int filters = 5;

  /** Main routine. */
  public static void main ( String[] args )
  {
      // arguments:
    Main.commandLineParams( args );

    int i;
    for ( i = 0; i < args.length; i++ )
      if ( args[i].charAt( 0 ) == '-' )
        switch ( args[i].charAt( 1 ) )
        {
          case 'i':
            if ( ++i < args.length )
              inputFileName = args[i];
            break;

          case 'o':
            if ( ++i < args.length )
              outputFileName = args[i];
            break;

          case '1':
            if ( ++i + 1 < args.length )
            {
              filters = 1;
              f[0] = Double.parseDouble( args[i] );
              e[0] = Double.parseDouble( args[++i] );
            }
            break;

          case '2':
            if ( ++i + 1 < args.length )
            {
              if ( filters < 2 ) filters = 2;
              f[1] = Double.parseDouble( args[i] );
              e[1] = Double.parseDouble( args[++i] );
            }
            break;

          case '3':
            if ( ++i + 1 < args.length )
            {
              if ( filters < 3 ) filters = 3;
              f[2] = Double.parseDouble( args[i] );
              e[2] = Double.parseDouble( args[++i] );
            }
            break;

          case '4':
            if ( ++i + 1 < args.length )
            {
              if ( filters < 4 ) filters = 4;
              f[3] = Double.parseDouble( args[i] );
              e[3] = Double.parseDouble( args[++i] );
            }
            break;

          case '5':
            if ( ++i + 1 < args.length )
            {
              if ( filters < 5 ) filters = 5;
              f[4] = Double.parseDouble( args[i] );
              e[4] = Double.parseDouble( args[++i] );
            }
            break;

          default:
            System.out.println( "Unknown argument!" );
        }

      // 1. input line:
    BufferedBitStream   iStr = new BufferedBitStream();
    WAVFileFormatMapped iF   = new WAVFileFormatMapped();
    iStr.set( BitStream.STREAM_NAME, inputFileName );

      // 2. output line:
    BufferedBitStream   oStr = new BufferedBitStream();
    WAVFileFormatMapped oF   = new WAVFileFormatMapped();
    oStr.set( BitStream.STREAM_NAME, outputFileName );

      // 3. filter system:
    AudioFilter filter  = new AudioFilter();
    Filter1DNotch[] fil = new Filter1DNotch[ filters ];

    for ( i = 0; i < filters; i++ )
    {
      fil[i] = new Filter1DNotch();
      fil[i].set( Filter1DNotch.FREQUENCY, f[i] );
      fil[i].set( Filter1DNotch.UNITY, e[i] );
    }

      // connect the modules:
    try
    {
      iF.connect(     Piece.PL_STREAM, iStr, Piece.PL_INPUT );
      oF.connect(     Piece.PL_STREAM, oStr, Piece.PL_INPUT );
      filter.connect( "audio1",        iF,   Piece.PL_INPUT );
      filter.connect( "audio2",        oF,   Piece.PL_INPUT );
      for ( i = 0; i < filters; i++ )
        filter.connect( "filter" + (i+1), fil[i], Piece.PL_INPUT );
    }
    catch ( BadInterfaceException e )
    {
      LogFile.error( "Bad Interface in connecting-time!" );
      LogFile.exception( e );
      return;
    }

      // load source audio file:
    try
    {
      iF.loadFile( (String)null, "r" ); // read-only mode
    }
    catch ( IOException e )
    {
      LogFile.exception( "Error reading audio file!", e );
    }

      // open target audio file for writting:
    try
    {
      oF.loadFile( (String)null, "rw" ); // read/write mode
    }
    catch ( IOException e )
    {
      LogFile.exception( "Error creating audio file!", e );
    }

      // filtering:
    try
    {
      filter.fire( 0 );
    }
    catch ( JaGrLibException e )
    {
      LogFile.exception( e );
    }

      // save the output audio file:
    try
    {
      iF.closeFile();
      if ( oF != null )
        oF.closeFile();
    }
    catch ( IOException e )
    {
      LogFile.exception( "Error closing audio file(s)!", e );
    }
  }

}
