package cz.cuni.jagrlib;

/**
 * Abstract <tt>Piece</tt>-referencing interface. Can be used for 1D and 2D
 * <tt>Piece</tt>-arrays, too.
 *
 * @version 0.25 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
 * @since   0.11
 * @see     <a href="../../../../cz/cuni/jagrlib/PieceReference.java">PieceReference.java</a>
 * @see     Piece
 */
public interface PieceReference
{
  /**
   * Simple <tt>Piece</tt> de-referencing.
   *
   * @param  iface Fully-qualified interface name or <tt>null</tt> if no checking
   *               is necessary.
   * @return The requested <tt>Piece</tt>-reference.
   * @throws BadInterfaceException If the <tt>Piece</tt> doesn't implemented the requested
   *                               interface.
   * @see    #getPiece(String,int)
   * @see    #getPiece(String,int,int)
   */
  Piece getPiece ( String iface )
  throws BadInterfaceException;

  /**
   * 1D <tt>Piece</tt>-array fetching.
   *
   * @param  iface Fully-qualified interface name or <tt>null</tt> if no checking
   *               is necessary.
   * @param  i <tt>Piece</tt>-index.
   * @return The requested <tt>Piece</tt>-reference.
   * @throws BadInterfaceException If the <tt>Piece</tt> doesn't implemented the requested
   *                               interface.
   * @see    #getPiece(String)
   * @see    #getPiece(String,int,int)
   */
  Piece getPiece ( String iface, int i )
  throws BadInterfaceException;

  /**
   * 2D <tt>Piece</tt>-array fetching.
   *
   * @param  iface Fully-qualified interface name or <tt>null</tt> if no checking
   *               is necessary.
   * @param  i Primary <tt>Piece</tt>-index.
   * @param  j Secondary <tt>Piece</tt>-index.
   * @return The requested <tt>Piece</tt>-reference.
   * @throws BadInterfaceException If the <tt>Piece</tt> doesn't implemented the requested
   *                               interface.
   * @see    #getPiece(String)
   * @see    #getPiece(String,int)
   */
  Piece getPiece ( String iface, int i, int j )
  throws BadInterfaceException;

}
