package cz.cuni.jagrlib;

import java.util.Locale;

import cz.cuni.jagrlib.iface.*;

/**
 * Object able to process progress messages and compute a little more complex results.
 *
 * @version 0.26 $Rev: 470 $ $Date: 2007-05-27 07:43:43 +0200 (ne, 27 V 2007) $ $Author: pepca $
 * @see     <a href="../../../../cz/cuni/jagrlib/ProgressCounter.java">ProgressCounter.java</a>
 */
public class ProgressCounter implements ProgressListener
{
  //==========================================================================
  //  Data:

  /** Starting time in milliseconds. */
  protected long timeStart;

  /** Actual time in milliseconds. */
  protected long timeAct;

  /** Starting progress. */
  protected double progressStart = 1.0;

  /** Actual progress. */
  protected double progressAct;

  /** Progress multiplier. */
  protected double progressMul = 1.0;

  /** Progress origin. */
  protected double progressAdd = 0.0;

  //==========================================================================
  //  Interface ProgressListener:

  /** Sets progress state ({@code 0 &lt;= state &lt;= total}). */
  public synchronized void progress ( long state, long total )
  {
    timeAct     = System.currentTimeMillis();
    progressAct = state * progressMul / total + progressAdd;
    if ( progressAct < progressStart )
    {
      progressStart = progressAct;
      timeStart     = timeAct;
    }
  }

  /** Repaint progress indicator (if applicable). */
  public void repaint ()
  {
  }

  //==========================================================================
  //  Public service:

  /** Sets actual progress-interval (domain of both parameters is {@code < 0.0, 1.0 >}). */
  public synchronized void setInterval ( double mul, double add )
  {
    progressMul = mul;
    progressAdd = add;
  }

  /** Total time in seconds. */
  public synchronized double totalTime ()
  {
    return( 0.001 * (timeAct - timeStart) );
  }

  /** Estimates remaining time in seconds. */
  public synchronized double remainingTime ()
  {
    if ( progressAct + Geometry.EPSILON < progressStart )
      return 0.0;

    return( 0.001 * (timeAct - timeStart) * (1.0 - progressAct) / (progressAct - progressStart) );
  }

  /** Estimates remaining time and returns its HH:MM:SS representation. */
  public String remainingString ()
  {
    return Formula.timeHMS( remainingTime() );
  }

  /** Assembles more complex "Finished.." message. */
  public synchronized String message ()
  {
    return String.format( Locale.US, "%3.0f%% (%s)", (100.0 * progressAct), remainingString() );
  }
}
