package cz.cuni.jagrlib;

/**
 * Simple rank implementation using histogram array.
 *
 * @version 0.25 $Rev: 392 $ $Date: 2007-01-21 17:37:56 +0100 (ne, 21 I 2007) $ $Author: pepca $
 * @since   0.25
 * @see     <a href="../../../../../cz/cuni/jagrlib/RankHistogram.java">RankHistogram.java</a>
 */
public class RankHistogram implements Rank
{
  /** Actual maximal value. */
  protected int maxV;

  /** Actual histogram. */
  protected int[] h;

  /** Actual index of minimum value. */
  protected int hMin;

  /** Actual index of maximum value. */
  protected int hMax;

  /** Histogram cardinality. */
  protected int card;

  /** Initializes the rank. */
  public void init ( int maxValue )
  {
    if ( h    == null ||
         maxV != maxValue )
      h = new int[ (maxV = maxValue) + 1 ];
    else
      while ( hMin <= hMax )
        h[ hMin++ ] = 0;

    hMin = maxV;
    hMax = 0;
    card = 0;
  }

  /** Adds new pixel value. */
  public void add ( int value )
  {
    if ( value < 0 ||
         value > maxV ) return;

    h[ value ]++;
    if ( value < hMin ) hMin = value;
    if ( value > hMax ) hMax = value;
    card++;
  }

  /**
   * Computes the given rank-value (min, median, max, ..).
   * Can be destructive - should be called once after each {@link #init} call.
   */
  public int result ( RankType type )
  {
    switch ( type )
    {
      case MIN:
        return hMin;

      case MAX:
        return hMax;

      case MIDDLE:
        return (hMin + hMax + 1) >> 1;

      default:                            // compute median
      {
        int steps = card >> 1;            // will find (steps+1)-th least value..
        while ( steps-- > 0 )
        {
          if ( --h[ hMin ] == 0 )
            while ( h[ ++hMin ] == 0 ) ;
        }
        return hMin;
      }
    }
  }
}
