package cz.cuni.jagrlib;

/**
 * Template for {@link Piece} class - abstract specimen for data-flow node.
 *
 * <p>Instances of {@link Template} object are used as <b>nodes</b> in graph of execution
 * while instances of {@link Channel} object are connecting them as graph <b>edges</b>.
 *
 * @version 0.26 $Rev: 797 $ $Date: 2008-09-05 23:36:51 +0200 (pá, 05 IX 2008) $ $Author: Tomas $
 * @since   0.23
 * @see     <a href="../../../../cz/cuni/jagrlib/Template.java">Template.java</a>
 */
public interface Template
{
  //==========================================================================
  //  General constants:

  /** Base JaGrLib package. */
  String JAGRLIB = "cz.cuni.jagrlib";

  /** Base JaGrLib package with trailing dot. */
  String JAGRLIB2 = JAGRLIB + '.';

  /** Interface prefix = {@value}. */
  String IFACE = JAGRLIB2 + "iface.";

  /** Generic string initializer. */
  String EMPTY = "-empty-";

  //==========================================================================
  //  Plug constants:

  /** Connect all plugs (for {@link Piece#setTemplateDynamic}). */
  int ALL_PLUGS = -1;

  /** Generic input {@link Plug} identifier. */
  String PL_INPUT = "input";

  /** Generic output {@link Plug} identifier. */
  String PL_OUTPUT = "output";

  /** Window {@link Plug} identifier. */
  String PL_WINDOW = "window";

  /** Bit-mask {@link Plug} identifier. */
  String PL_BITMASK = "bitmask";

  /** Alpha-mask {@link Plug} identifier. */
  String PL_ALPHAMASK = "alphamask";

  /** Trigger {@link Plug} identifier. */
  String PL_TRIGGER = "trigger";

  /** Property {@link Plug} identifier. */
  String PL_PROPERTY = "property";

  /** Direct {@link Plug} identifier. */
  String PL_DIRECT = "direct";

  /** Raster image {@link Plug} identifier. */
  String PL_RASTER = "raster";

  /** Raster image {@link Plug} identifier. */
  String PL_IMAGE = "image";

  /** Palette {@link Plug} identifier. */
  String PL_PALETTE = "palette";

  /** Colormap {@link Plug} identifier. */
  String PL_COLORMAP = "colormap";

  /** Compare {@link Plug} identifier. */
  String PL_COMPARE = "compare";

  /** Editor {@link Plug} identifier. */
  String PL_EDITOR = "editor";

  /** Order {@link Plug} identifier. */
  String PL_ORDER = "order";

  /** Data {@link Plug} identifier. */
  String PL_DATA = "data";

  /** Filter {@link Plug} identifier. */
  String PL_FILTER = "filter";

  /** Intersectable {@link Plug} identifier. */
  String PL_INTERSECTION = "intersection";

  /** [Bit-]stream {@link Plug} identifier. */
  String PL_STREAM = "stream";

  /** Function {@link Plug} identifier. */
  String PL_FUNCTION = "function";

  /** Light-source {@link Plug} identifier. */
  String PL_LIGHTSOURCE = "lightsource";

  /** Transform {@link Plug} identifier. */
  String PL_TRANSFORM = "transform";

  /** Quantizer {@link Plug} identifier. */
  String PL_QUANTIZER = "quantizer";

  /** Codec {@link Plug} identifier. */
  String PL_CODEC = "codec";

  /** Import {@link Plug} identifier. */
  String PL_IMPORT = "import";

  /** Render {@link Plug} identifier. */
  String PL_RENDER = "render";

  /** Photon map {@link Plug} identifier. */
  String PL_PHOTON = "photonmap";

  /** Caustic map {@link Plug} identifier. */
  String PL_CAUSTIC = "causticmap";

  /** Shadow map {@link Plug} identifier. */
  String PL_SHADOW = "shadowmap";

  /** Volume map {@link Plug} identifier. */
  String PL_VOLUME = "volumemap";

  //==========================================================================
  //  Name constants:

  /** Undefined category name. */
  String CAT_EMPTY = "undefined";

  //==========================================================================
  //  Category constants:

  /** category string: worker */
  String C_WORKER = "worker";

  /** category string: 1D */
  String C_1D = "1D";

  /** category string: 2D */
  String C_2D = "2D";

  /** category string: 3D */
  String C_3D = "3D";

  /** category string: io */
  String C_IO = "io";

  /** category string: draw */
  String C_DRAW = "draw";

  /** category string: clip */
  String C_CLIP = "clip";

  /** category string: data */
  String C_DATA = "data";

  /** category string: line */
  String C_LINE = "line";

  /** category string: fill */
  String C_FILL = "fill";

  /** category string: circle */
  String C_CIRCLE = "circle";

  /** category string: ellipse */
  String C_ELLIPSE = "ellipse";

  /** category string: line */
  String C_CURVE = "curve";

  /** category string: polygon */
  String C_POLYGON = "polygon";

  /** category string: text */
  String C_TEXT = "text";

  /** category string: image */
  String C_IMAGE = "image";

  /** category string: filter */
  String C_FILTER = "filter";

  /** category string: sample */
  String C_SAMPLE = "sample";

  /** category string: integer */
  String C_INTEGER = "integer";

  /** category string: float */
  String C_FLOAT = "float";

  /** category string: raster */
  String C_RASTER = "raster";

  /** category string: vector */
  String C_VECTOR = "vector";

  /** category string: brep */
  String C_BREP = "brep";

  /** category string: set */
  String C_SET = "set";

  /** category string: function */
  String C_FUNCTION = "function";

  /** category string: transform */
  String C_TRANSFORM = "transform";

  /** category string: projection */
  String C_PROJECTION = "projection";

  /** category string: metric */
  String C_METRIC = "metric";

  /** category string: render */
  String C_RENDER = "render";

  /** category string: radiosity */
  String C_RADIOSITY = "radiosity";

  /** category string: alpha */
  String C_ALPHA = "alpha";

  /** category string: scene */
  String C_SCENE = "scene";

  /** category string: solid */
  String C_SOLID = "solid";

  /** category string: camera */
  String C_CAMERA = "camera";

  /** category string: light */
  String C_LIGHT = "light";

  /** category string: viewer */
  String C_VIEWER = "viewer";

  /** category string: binary */
  String C_BINARY = "binary";

  /** category string: compression */
  String C_COMPRESSION = "compression";

  /** category string: editor */
  String C_EDITOR = "editor";

  /**
   * Connects a new {@link Plug}. General routine.
   *
   * @param  key New plug's key.
   * @param  _mandatory Is that plug mandatory (has to be connected)?
   * @param  _multi Can that plug be used in multi-channels?
   * @param  _cloneable Is that plug "cloneable" (=generic)? If yes,
   *                    ordinal numbers (starting from 0) will be appended to its name.
   * @param  _inputInterface Fully qualified identifier of input (implemented)
   *                         {@code interface}.
   * @param  _outputInterface Fully qualified identifier of output (required)
   *                          {@code interface}.
   */
  void newPlug ( String key, boolean _mandatory, boolean _multi, boolean _cloneable,
                 String _inputInterface, String _outputInterface );

  /**
   * Connects a new input {@link Plug}. Common-use routine: creates <b>optional</b>,
   * <b>non-cloneable</b>, <b>multi</b> plug.
   *
   * @param  key New plug's key.
   * @param  _inputInterface Fully qualified identifier of input (implemented)
   *                         {@code interface}.
   */
  void newInputPlug ( String key, String _inputInterface );

  /**
   * Connects a new output {@link Plug}. Common-use routine: creates <b>mandatory</b>,
   * <b>non-cloneable</b>, <b>multi</b> plug.
   *
   * @param  key New plug's key.
   * @param  _outputInterface Fully qualified identifier of output (required)
   *                          {@code interface}.
   */
  void newOutputPlug ( String key, String _outputInterface );

  /**
   * Connects a new optional output {@link Plug}. Common-use routine: creates <b>optional</b>,
   * <b>non-cloneable</b>, <b>multi</b> plug.
   *
   * @param  key New plug's key.
   * @param  _outputInterface Fully qualified identifier of output (required)
   *                          {@code interface}.
   */
  void newOptOutputPlug ( String key, String _outputInterface );

  /**
   * Sets registration strings for the module.
   */
  void setRegStrings ( String _name, String _template, String _category, String _description );

  //==========================================================================
  //  Property registration:

  String TYPE_INTEGER     = "java.lang.Integer";

  String TYPE_LONG        = "java.lang.Long";

  String TYPE_STRING      = "java.lang.String";

  String TYPE_DOUBLE      = "java.lang.Double";

  String TYPE_FLOAT       = "java.lang.Float";

  String TYPE_BOOLEAN     = "java.lang.Boolean";

  String TYPE_OBJECT      = "java.lang.Object";

  /** Default manipulator (single edit line, checkbox, ..). */
  int MANIPULATOR_DEFAULT   = 0;

  /** Custom manipulator specified by its class name. */
  int MANIPULATOR_CUSTOM    = 1;

  /** List-box manipulator (for integer values only). */
  int MANIPULATOR_COMBO     = 2;

  /** Multi-line text area (for strings only). */
  int MANIPULATOR_MULTILINE = 3;

  /**
   * Starts definition of single property.
   *
   * @param  name String identifier (unique inside one module class).
   * @param  type Value type - full Java class identifier.
   * @param  descr Brief textual description (for human eyes only).
   * @param  visual Should be this property represented visually in GUI?
   * @see    #propEnd
   */
  void propBegin ( String name, String type, String descr, boolean visual );

  /**
   * Default value (non-mandatory).
   */
  void propDefault ( Object value );

  /**
   * Minimum and maximum allowed values (for comparable types only, non-mandatory).
   */
  void propBounds ( Object min, Object max );

  /**
   * Sets visual manipulator for GUI editing of the property.
   * For predefined manipulators.
   */
  void propManipulator ( int manipulatorType );

  /**
   * Sets visual manipulator for GUI editing of the property.
   * For user-defined manipulators.
   *
   * @param  className Class name (either fully-qualified or local in {@code package cz.cuni.jagrlib.gui}).
   */
  void propManipulator ( String className );

  /**
   * Adds next enum label (for list-box GUI).
   *
   * @param  label Textual label to appear in the listbox.
   * @param  value Associated property value (real-value).
   * @param  descr Optional item's description (for human eyes only).
   */
  void propEnum ( String label, Object value, String descr );

  /**
   * Finishes definition of the property.
   * Every property-definition segment started by {@link #propBegin} must
   * be properly closed by {@link #propEnd}.
   *
   * @see    #propBegin
   */
  void propEnd ();

}