package cz.cuni.jagrlib;

import java.io.*;
import java.awt.geom.*;

import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.BadInterfaceException;

/**
 * Abstract {@link VectorGraphics} command - represents one atomic command which
 * is consumed by vector graphics interpreters.
 *
 * @version 0.25 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
 * @since   0.02
 * @see     <a href="../../../../cz/cuni/jagrlib/VectorCommand.java">VectorCommand.java</a>
 * @see     cz.cuni.jagrlib.iface.VectorGraphics interface VectorGraphics
 */
public abstract class VectorCommand implements Serializable
{
  /** Dummy line style (no drawing is actually done). */
  public final int LINE_DUMMY     = 0;

  /**
   * Callback line style.
   *
   * @see    VCommand.SetLineStyle
   * @see    cz.cuni.jagrlib.iface.VectorGraphics#setLineCallback
   */
  public final int LINE_CALLBACK  = 1;

  /** Solid line style (continuous line). */
  public final int LINE_SOLID     = 2;

  /** Dashed line style (length(dash) = length(gap)). */
  public final int LINE_DASH      = 3;

  /** Dotted line style (length(dot) = length(gap)/4). */
  public final int LINE_DOT       = 4;

  /** Dash-dotted line style ("dot-gap-dash-gap" pattern). */
  public final int LINE_DASHDOT   = 5;

  /** Dummy fill style (no drawing is actually done). */
  public final int FILL_DUMMY     = 0;

  /**
   * Callback fill style.
   *
   * @see    VCommand.SetFillStyle
   * @see    cz.cuni.jagrlib.iface.VectorGraphics#setFillCallback
   */
  public final int FILL_CALLBACK  = 1;

  /** Solid fill style. */
  public final int FILL_SOLID     = 2;

  /** /-Hatched fill style (angle = 45 degrees). */
  public final int FILL_HATCHR    = 3;

  /** \-Hatched fill style (angle = -45 degrees). */
  public final int FILL_HATCHL    = 4;

  /**
   * Transforms the command using the given <tt>AffineTransform</tt>.
   *
   * @param  t Affine transformation (3x2 matrix of doubles) or <tt>null</tt>.
   */
  public void transform ( AffineTransform t )
  {}

  /**
   * Executes the command on the given {@link VectorGraphics} interface.
   *
   * @param  out Output vector interface.
   * @throws BadInterfaceException
   * @see    VectorGraphics
   */
  public void execute ( VectorGraphics out )
  throws BadInterfaceException
  {}

}
