package cz.cuni.jagrlib;

import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.piece.*;
import cz.cuni.jagrlib.testing.*;
import cz.cuni.jagrlib.worker.*;
import cz.cuni.jagrlib.obscure.*;
import cz.cuni.jagrlib.eval.*;
import cz.cuni.jagrlib.reg.*;
import cz.cuni.jagrlib.gui.*;
import cz.cuni.jagrlib.xml.*;

/**
 * Version information for the JaGrLib project.
 * This file should be updated <u>every time</u> any SVN change is commited
 * (otherwise version numbers in the application won't be updated).
 * <br />Older technical notes are placed in
 * <a href="../../../../news.html">news.html</a> file.
 *
 * <p>23.11.2003 PE:
 * <ul>
 *   <li>SVN keyword experiments: Date, Rev and Author.
 *   <li>new file: Version.java.
 *   <li>AboutDialog: versioning info, icon, layout.
 *   <li>LogFile moved to package jagrlib.
 * </ul>
 * <p>26.11.2003 Kostlivy:
 * <ul>
 *   <li>Fix: bug with ModuleGUI.moduleHeight=0, ModuleGUI.moduleWidth=0,
 *       constants have now private declaration.
 *   <li>Rename: "Zoom Window" changed to "Outline".
 * </ul>
 * <p>27.11.2003 Kostlivy:
 * <ul>
 *   <li>Editing of Groups.
 *   <li>InfoGroup, HashMapChannels, HashMapModules: ActionListener added.
 * </ul>
 * <p>28.11.2003 Kostlivy:
 * <ul>
 *   <li>CompositionGUI: new methods moveToFront(ModuleGUI), moveToBack(ModuleGUI).
 *   <li>Selected module is moved to front of composition.
 * </ul>
 * <p>2.12.2003 Kostlivy:
 * <ul>
 *   <li>New: 'Select All' to main menu.
 *   <li>Set minimum size of dialogs.
 * </ul>
 * <p>3.12.2003 Kostlivy:
 * <ul>
 *   <li>Set location of About dialog in the middle of screen.
 *   <li>Fix: bug in RegModulesDialog (Reg Files).
 *   <li>New: saving location and size of dialogs: RegGroupDialog, RegModulesDialog.
 * </ul>
 * <p>4.12.2003 PE:
 * <ul>
 *   <li>Improved: compile.bat script (runs much more faster).
 *   <li>newPiece() method was removed from Piece and all inherited classes.
 * </ul>
 * <p>5.12.2003 PE:
 * <ul>
 *   <li>New packages: worker, private, testing. Three workers were moved to 'worker'.
 *   <li>SVN attributes for all package.html files.
 *   <li>Changed: several dialogue legends, ClassNotFoundException error handling.
 * </ul>
 * <p>5.12.2003 Kostlivy:
 * <ul>
 *   <li>Rename Obsluha to Manipulator and modeshow to mode in xml files.
 * </ul>
 * <p>23.12.2003 PE:
 * <ul>
 *   <li>HashMapPlugs: simplified, getKeysArray() usage converted to Iterator
 *       pattern in most cases.
 *   <li>InfoState: constants for plug check/status (replacement for
 *       InfoPlug.[NOT]CONNECT* constants).
 * </ul>
 * <p>5.-6.3.2004 PE:
 * <ul>
 *   <li>JaGrLibException and JaGrLibCause changes (encapsulating JaGrLibCause into
 *       RuntimeException).
 *   <li>Removing BadInterfaceException from common interfaces.
 *   <li>Consequent changes in all source files.
 * </ul>
 * <p>7.3.2004 PE:
 * <ul>
 *   <li>RegTables changed to "interface".
 *   <li>RegTables and RegTablesXML changes: return values (AbstractTableModel),
 *       renames: registry* -> register*.
 *   <li>Internal data structures: preparing for the Big-bang.
 * </ul>
 * <p>7.-14.3.2004 PE:
 * <ul>
 *   <li>Updated commit.bat
 *   <li>class RegPiece: registration info was separated into this class, removed from InfoModule.
 *   <li>name, description, category, etc. were removed from Piece.
 *   <li>Template changed to interface, methods moved to Piece (temporarily).
 *   <li>Template.setRegStrings() (temporary solution).
 *   <li>all Piece descendants were altered.
 * </ul>
 * <p>14.-21.3.2004 PE:
 * <ul>
 *   <li>new registration framework for modules: setTemplate(), reg, reg[], getReg(), etc.
 *   <li>LogFile.debug(), debugLogs (for debug prints).
 *   <li>Piece.execute() was removed.
 *   <li>Piece diagnostics.
 * </ul>
 * <p>21.3.2004 PE:
 * <ul>
 *   <li>interface ParamPiece removed.
 *   <li>interface Property reduced.
 *   <li>Piece implements Property by default.
 *   <li>initPiece() removed (replaced by "set(Map)").
 *   <li>StaticCSGScene.SCENE, several other cosmetic changes.
 *   <li>all Piece descendants changed.
 * </ul>
 * <p>21.3.2004 PE:
 * <ul>
 *   <li>Registration of properties (old "Params") reworked.
 *   <li>LineBresenham: Listbox-manipulated integer property.
 * </ul>
 * <p>28.3.2004 PE:
 * <ul>
 *   <li>Cloneable interface implemented in HashMapPlugs and InfoPlug (deep-copy).
 *   <li>RegPiece will copy plugs into each InfoModule instance.
 *   <li>Interface identifiers used in RegPiece should be local:
 *       normalizeInterfaceName() helper.
 *   <li>indexOf, lastIndexOf: chars shall be used instead of one-character strings.
 * </ul>
 * <p>29.-30.3.2004 PE:
 * <ul>
 *   <li>Worker extends Runnable (progress() method added).
 *   <li>all Worker descendants updated (progress, error messages).
 *   <li>understands() method removed from Piece descendants.
 *   <li>LogFile.exception(s,ex).
 *   <li>Template.propManipulator(String) for user-defined manipulators.
 *   <li>Template.propBounds, .propDefault implemented.
 *   <li>Rev.69.
 *   <li>kucharka.html updated.
 *   <li>several JavaDoc errors.
 *   <li>Rev.70.
 *   <li>kucharka.html is up-to-date.
 *   <li>removed obsolete classes: Mesh, TemplateChannel.
 * </ul>
 * <p>31.3.-3.4.2004 PE:
 * <ul>
 *   <li>zapocty.html: many fixes, reorganization.
 *   <li>index.html updated.
 *   <li>public tag 0.23, version number changed to 0.24.
 * </ul>
 * <p>5.4.2004 PE:
 * <ul>
 *   <li>0.23 version published on the WWW (list.cgi sctripts repaired).
 *   <li>Missing default value shall not log a warning.
 *   <li>Piece: improved diagnostics.
 *   <li>pack.bat updated.
 *   <li>index.html fix (new2.gif).
 * </ul>
 * <p>10.-12.4.2004 PE:
 * <ul>
 *   <li>package "private" changed to "obscure".
 *   <li>zapocty.html: small fixes, assignment 74.
 *   <li>RayGenerator interface: added hidden-sampling support, consequent change in StaticCamera.
 *   <li>Crc32: module adopted from other project.
 *   <li>RandomJames: module adopted from "jbench" project.
 *   <li>obscure.Enigma: text scrambling class, can hide Java source file.
 *   <li>scripts: compile-obscure, encryption/decryption.
 *   <li>svn attributes: svn:ignore, file "ignored", svn:eol-style "native".
 *   <li>Enigma class - 1st encrypted source into SVN.
 * </ul>
 * <p>25.4.2004 PE:
 * <ul>
 *   <li>JavaBitStream: fixed readBuffer().
 *   <li>Repository migrated to SVN version 1.0.1.
 *   <li>XTransitionList: fixed setList(List,int,int,int).
 * </ul>
 * <p>11.5.2004 PE:
 * <ul>
 *   <li>RayTracing, RayCasting: fixed sampling propagation (for distibuted-RT).
 * </ul>
 * <p>8.9.2004 PE:
 * <ul>
 *   <li>VEFDS fixup: used[CONTEXT] shall not be used.
 *   <li>Brep.setAttribute() added.
 *   <li>commit.bat: strict comment.txt checking.
 * </ul>
 * <p>9.9.2004 PE:
 * <ul>
 *   <li>VEFDS fix: Object[] isn't compatible with primitive_type[].
 * </ul>
 * <p>12.9.2004 PE:
 * <ul>
 *   <li>VEFDS: added getAllFaces() method.
 * </ul>
 * <p>16.9.2004 PE:
 * <ul>
 *   <li>PhongModel: reverse faces are handled correctly.
 *   <li>RasterImage: put* and get* methods.
 *   <li>StaticCSGScene: getCamera() fixed (bad typecast).
 *   <li>VEFDS: fixed working with SOLID attributes..
 * </ul>
 * <p>12.10.2004 PE:
 * <ul>
 *   <li>Compatibility fixes for JDK 1.5.0 release.
 * </ul>
 * <p>18.-23.10.2004 PE:
 * <ul>
 *   <li>WWW pages update (zapocty.html, labNN.html).
 * </ul>
 * <p>18.-23.10.2005 PE:
 * <ul>
 *   <li>New interfaces: LineRenderAnti, PolygonStrokeRender.
 * </ul>
 * <p>25.10.2005 PE:
 * <ul>
 *   <li>Line-clipping workspace.
 *   <li>LineWorkerStar worker.
 *   <li>BezierWorker worker.
 * </ul>
 * <p>27.10.2005 PE:
 * <ul>
 *   <li>JavaBitStream fixes.
 *   <li>VEFDS fixes.
 * </ul>
 * <p>31.10.2005 PE:
 * <ul>
 *   <li>PNG, GIF, BMP formats (PNGFileFormat, GIFFileFormat).
 *   <li>Flood-fill modules (FloodFillPoint, OverwriteClassificator).
 *   <li>Flood-fill worker (FloodFillWorker) and workspace.
 *   <li>Cubic Bezier curve: pilot modules (BezierCurve, BezierRegular).
 * </ul>
 * <p>1.-3.11.2005 PE:
 * <ul>
 *   <li>All "deprecated" warnings fixed.
 *   <li>Eclipse porting (generics, warnings, folder refactorization..).
 * </ul>
 * <p>4.11.2005 PE:
 * <ul>
 *   <li>Eclipse porting (compile scripts fixed).
 * </ul>
 * <p>5.11.2005 PE:
 * <ul>
 *   <li>Fix: source directory ('View Code' command) is now computed correctly.
 *   <li>Fix: plug compatibility was improved (isAssignableFrom).
 *   <li>New: sys-options-orig.txt (holding versioned default values).
 *   <li>New: option item for source hierarchy.
 *   <li>New: LineClipAntiWorker module (LineClipping is universal pilot implementation).
 * </ul>
 * <p>7.11.2005 PE:
 * <ul>
 *   <li>New: loading composition from command-line (not finished yet).
 *   <li>New: modules ImageFilterWorker, Pixelize, workspace sImageFilter.
 *   <li>Fix: default folders in Module Registration Dialog.
 *   <li>New: putPixel() methods into RasterGraphics and RasterImage.
 * </ul>
 * <p>8.-10.11.2005 PE:
 * <ul>
 *   <li>New: RasterGraphics.putImage() methods, the same for RasterImage.
 *   <li>Another two stages of Eclipse refactorisation.
 * </ul>
 * <p>14.-15.11.2005 PE:
 * <ul>
 *   <li>New: Color conversion/reduction template.
 *   <li>New: Colormaps, ColorReduce, sColorReduce.xml.
 *   <li>Fix: another small bug in source-base folder.
 *   <li>Fix: allowing '-' in WholeFieldNumber.
 *   <li>Fix: number of color bands for BufferedImage.TYPE_CUSTOM.
 * </ul>
 * <p>16.11.2005 PE:
 * <ul>
 *   <li>New: Double module parameters (ParamDouble class etc.).
 *   <li>New: PolylineAntialias, PolylineAntiWorker modules.
 *   <li>Fix: Numerical values increment is now 0.1 (Value class).
 *   <li>Fix: Random color setting in several workers.
 *   <li>Fix: double -&gt; int conversion now uses correct rounding (several modules).
 * </ul>
 * <p>18.-19.11.2005 PE:
 * <ul>
 *   <li>Fix: RGBA, Gray color modes in RasterImage.
 *   <li>Improved: PNG output format in several workspaces.
 * </ul>
 * <p>20.-21.11.2005 PE:
 * <ul>
 *   <li>Improved: optional black background in RasterImagePreview Window.
 *   <li>Improved: interface EntropyCodec.
 *   <li>New: LZWCodec, CompressedFormatBW, ImageCompressionWorker.
 *   <li>Fix: LineClipWorker (double coordinates), some other small fixes..
 * </ul>
 * <p>23.-24.11.2005 PE:
 * <ul>
 *   <li>Improved: deterministic line generator in LineAntiWorker.
 *   <li>Improved: reset() parameter checking in RandomJames.
 *   <li>Fix: unchecked warnings in Eclipse..
 * </ul>
 * <p>27.11.2005 PE:
 * <ul>
 *   <li>New: MainEval (reading XML scripts).
 *   <li>New: cz.cuni.jagrlib.eval package for evaluation plugins.
 *   <li>New: DefaultPlugin class, first eval script.
 * </ul>
 * <p>28.11.2005 PE:
 * <ul>
 *   <li>Updated: BW image decoding (CompressedFormatBW), consequent changes (workspace, worker).
 *   <li>New: RGB image codec (CompressedFormatRGB), test RGB image.
 *   <li>New: ZLIBCodec class (using built-in Java classes).
 *   <li>New: Pal image codec (CompressedFormatPal), test Pal image.
 *   <li>Fix: in LZWCodec - setContext() should call flush().
 *   <li>Fix: colormap handling in RasterGraphics &amp; RasterImage:
 *       getColormap() and setColormap() methods, first tests in CompressedFormatPal..
 *   <li>Fix: JavaDoc comments.
 * </ul>
 * <p>29.-30.11.2005 PE:
 * <ul>
 *   <li>Updated: refactorisation of "iface" package (general descendant Property,
 *       all *XRender interfaces were removed, CubicCurveRender -> CurveRender),
 *       consequent changes (BezierWorker, BezierCurve, BezierRegular).
 *   <li>Improved: new "strategy" parameter for ZLIB library (ZLIBCodec).
 *   <li>Improved: ColorReduce template now uses MODE_COLORMAP in output image.
 * </ul>
 * <p>4.-5.12.2005 PE:
 * <ul>
 *   <li>Improved: simple instance statistics into MainEval.
 *   <li>Updated: 1st eval script.
 *   <li>Fix: loading gray PNG/GIF images (should be marked as MODE_COLORMAP).
 *   <li>New: getRGB(), getGray() methods to RasterGraphics, RasterImage.
 *   <li>New: CompressedFormatOrder, sCompressionOrder.xml.
 *   <li>New: OrderSerpentine template class.
 *   <li>New: Function interface, FunctionDefault default implementation.
 *   <li>New: ImageCompare class (w/o filtering so far).
 *   <li>Updated: ImageCompressionWorker class (able to print image comparison error).
 * </ul>
 * <p>6.12.2005 PE:
 * <ul>
 *   <li>Improved: randomize parameter into ColorReduce module.
 *   <li>New: Formula class holding common support math.
 *   <li>Improved: psychovisual color-component coefficients into ImageCompare (optional).
 *   <li>New: optional "compare" plug in ImageFilterWorker.
 * </ul>
 * <p>7.12.2005 PE:
 * <ul>
 *   <li>Updated: REPEAT and SEED keys lifted to Worker interface.
 *   <li>Improved: PolylineAntiWorker (random generator).
 *   <li>Improved: statistics in MainEval (failed test instances).
 *   <li>Improved: RandomJames into LineClipWorker, LineClipAntiWorker.
 *   <li>Improved: LineClipping (everything should be computed using double arithmetics).
 * </ul>
 * <p>9.-11.12.2005 PE:
 * <ul>
 *   <li>Fix: several fixes in RasterImage (accuracy in communication with BufferedImage,
 *       getRGB).
 *   <li>New: ImageConvert class, sImageConvert.xml.
 *   <li>Fix: RasterImage.getRGB() in MODE_BAND format.
 *   <li>Updated: several Property keys (WIDTH, HEIGHT, ..) lifted to apropriate interfaces..
 *   <li>New: LineAntialiasReal class (exact line anti-aliasing using box filter).
 *   <li>Improved: MainEval procedure, EvalPlugin, DefaultPlugin, ..
 *   <li>New: eval plugins: Ex2005_01_b (antialias-line comparison),
 *       Ex2005_02_a (simple test for lines with real-coordinates),
 *       Ex2005_02_c (simple test for lines with real-coordinates and antialiasing).
 *   <li>Improved: eval folder reorganization.
 * </ul>
 * <p>13.12.2005 PE:
 * <ul>
 *   <li>Improved: evaluation plugins will check their output directory (and eventually create one).
 *   <li>Improved: script 2005_02_a can optionally check random lines and allows only ones
 *       which don't pass through pixel mid-points.
 *   <li>Improved: script 2005_02_c can use either integer- or double- variants of original
 *       (not clipped) line.
 *   <li>New: MainEval command-line parameter -Dparam=value (has priority over script settings).
 *   <li>Updated: repository re-organization for Eclipse ("src" folder, "class" folder,
 *       "eclipse" folder for source files).
 * </ul>
 * <p>14.12.2005 PE:
 * <ul>
 *   <li>New: two missing Ex2005_02 test plugins are finished.
 *   <li>Improved: small improvements of test system.
 * </ul>
 * <p>17.12.2005 PE:
 * <ul>
 *   <li>Improved: Ex2005_02_b (more tolerant setLineWidth() calling).
 *   <li>New: Colormap332, ColorReduceRound and ColorReduceWorker.
 *   <li>New: sColorReduceSplit.xml - template for 2-step color reduce algorithms.
 *   <li>Improved: RasterImage -&gt; Raster Graphics (all registration templates and compositions).
 *   <li>Improved: sBezier.xml uses LineAntialiasReal module.
 *   <li>Improved: better index-checking in Colormaps module.
 * </ul>
 * <p>19.-20.12.2005 PE:
 * <ul>
 *   <li>Improved: Flood-fill animation support (FloodFillPoint, FloodFillWorker).
 *   <li>Fix: ImageCompare (overflow in denominator - MAE, RMSE).
 *   <li>Fix: overflow in ColorReduce.
 *   <li>Improved: conical and cylindrical filters in ImageCompare.
 *   <li>New: DefaultFileFormat (common routines for all raster file formats).
 * </ul>
 * <p>21.-22.12.2005 PE:
 * <ul>
 *   <li>Improved: completed filtering in ImageCompare (floating point).
 *   <li>Improved: ColorReduceWorker is using floating point comparison (also in sColorReduce.xml).
 *   <li>New: ParamColor (color manipulator).
 *   <li>Improved: source formatting in some modules.
 * </ul>
 * <p>3.-4.1.2006 PE:
 * <ul>
 *   <li>Improved: EntropyHistogram interface (setContext added).
 *   <li>Fix: PL_STREAM plug in all modules derived from DefaultFileFormat..
 *       (MainNN.java, eval plugins)
 * </ul>
 * <p>8.-9.1.2006 PE:
 * <ul>
 *   <li>New: Ex2005_07_a plugin, 2005_07_a.xml script.
 *   <li>Improved: minor changes in evaluation mechanism.
 *   <li>Fix: TrMatrix.append() and ..prepend() - missing last column in one of arguments.
 *   <li>New: Ex2005_06_a plugin (image filters), 2005_06_a.xml script (partial).
 *   <li>Improved: new DefaultProperty class can be used as universal ancestor for
 *       classes implementing Property interface (several handy support routines).
 *   <li>Improved: thank to DefaultProperty - all property values can be read from String instances, etc.
 * </ul>
 * <p>11.1.2006 PE:
 * <ul>
 *   <li>New: InputListener interface, default implementation (DefaultInputListener).
 *   <li>Improved: run.bat (JVM can use more heap memory).
 * </ul>
 * <p>23.-24.1.2006 PE:
 * <ul>
 *   <li>Fix: LZWCodec code-table expansion.
 *   <li>Fix: small fixes in ZLIBCodec and LZWCodec.
 *   <li>Improved: RasterImagePreview window-title handling.
 * </ul>
 * <p>27.1.2006 PE:
 * <ul>
 *   <li>New: Formula.clamp() methods.
 *   <li>New: interface Render3D, constants in Render.
 *   <li>New: modules FunctionSamples, GraphR2ToR, worker Render3DWorker.
 *   <li>Fix: all property key strings should be declared public.
 *   <li>Fix: parameter descriptions are correctly handled in registration.
 *   <li>Fix: registration database ({@literal Description <-> Category}).
 *   <li>Fix: parameter order in Piece.setRegStrings().
 * </ul>
 * <p>28.1.2006 PE:
 * <ul>
 *   <li>Fix: indentation in registration database (regdata.xml).
 *   <li>Improved: source formatting and cleanup in cz.cuni.jagrlib.xml.
 *   <li>Improved: source formatting in cz.cuni.jagrlib.gui, Piece.java, etc.
 *   <li>Improved: eliminating usage of Array.getLength().
 *   <li>Improved: params - default, min, max values don't need to be String instances.
 * </ul>
 * <p>29.1.2006 PE:
 * <ul>
 *   <li>Fix: double registrated template of SolidColorBrush (in the database only).
 *   <li>Improved: java.lang.reflect.* is no longer imported in most sources.
 *   <li>Improved: XML output format.
 *   <li>Improved: all compositions (but sBresenham-G.xml) were re-saved in new style.
 *   <li>New: AWTGraphics interface (Graphics/Graphics2D output producer).
 *   <li>Updated: SampleData interface (preserves mapping-mode access).
 *   <li>New: Render3D.setProjection(view,up,lookAt,zoom) non-mandatory method.
 * </ul>
 * <p>30.-31.1.2006 PE:
 * <ul>
 *   <li>New: InputListener.setWindowSize() method.
 *   <li>New: AWTWindow module - window receiving AWT graphics output.
 *   <li>New: DrawAxes module - simple 3D axes drawing (to visualize projection matrix).
 *   <li>New: InteractiveProjection module - sample implementation of asignment #12 (projection
 *       matrix synthesis from interactive input).
 *   <li>New: ProjectionWorker module, sProjection.xml composition, asignment #12.
 * </ul>
 * <p>2.2.2006 PE:
 * <ul>
 *   <li>Improved: ProjectionWorker - auto-redraw feature.
 *   <li>New: keyboard events in AWTWindow.
 * </ul>
 * <p>3.-4.2.2006 PE:
 * <ul>
 *   <li>Updated: some methods in SampleData interface.
 *   <li>New: DataMatrix module (SampleData implementation).
 *   <li>Updated: small changes in all Worker modules.
 * </ul>
 * <p>5.2.2006 PE:
 * <ul>
 *   <li>New: AntCity module (not debugged yet).
 *   <li>New: {@code <Visible/>} tag added to XML Param description (changes in relevant source files
 *       and XML database).
 *   <li>Fix: preview.repaintAll() is called again in worker modules.
 *   <li>New: InputListener support in RasterImagePreview.
 *   <li>Fix: empty set of InputListener objects in AWTWindow is now handled correctly.
 * </ul>
 * <p>6.-7.2.2006 PE:
 * <ul>
 *   <li>New: AntCityWorker module; keyboard is used for navigation.
 *   <li>New: both GraphicsViewer modules got InputListener plugs for easy connection of listeners.
 *       Change in sProjection.xml composition.
 *   <li>Fix: JavaDoc comments were updated ("///" comments were converted to "/**").
 *   <li>New: sAntCity.xml composition.
 *   <li>Fix: data array initialization in DataMatrix.
 *   <li>Fix: keyboard handling in RasterImagePreview.
 * </ul>
 * <p>8.2.2006 PE:
 * <ul>
 *   <li>Improved: continuous zoom-factor in pilot implementation of AntCity.
 *   <li>Improved: all version and application-related strings moved to Version.java.
 * </ul>
 * <p>12.2.2006 PE:
 * <ul>
 *   <li>Improved: Render3DWorker contains azimuth- and elevation- angles of the orthogonal projection.
 *   <li>New: branches.txt (information about repository branches - particularly about merging).
 * </ul>
 * <p>20.2.2006 PE:
 * <ul>
 *   <li>Fix: KeyboardListener registration in AWTWindow module.
 *   <li>New: branches/log.txt (version log for all branches - until they are merged into trunk).
 * </ul>
 * <p>6.4.2006 PE:
 * <ul>
 *   <li>New: BlueScreen module, sBlueScreen.xml composition (exercise #20).
 *   <li>New: 2 new modules: Deformations, WarpEngine, sWarpingEngine.xml composition (exercise #21),
 *   <li>Fix: additional small fixes.
 *   <li>Improved: Deformations - angles should be entered in degrees.
 *   <li>New: Deformations - "Cubic twist", "Round twist", "Magnifying glass" were added.
 *   <li>Improved: WarpEngine is now able to do quincunx interpolation in input space.
 * </ul>
 * <p>11.-12.4.2006 PE:
 * <ul>
 *   <li>New: interface Features - data store for features (feature-based warping/morphing).
 *   <li>New: two specimen Solids - SolidSpecimen.java, Revolution.java.
 *   <li>New: Cylinder, Cone, Cube modules (CSG Solids).
 *   <li>New: Main04, Main05 (special Ray-tracing scenes, Main05 scene is generated procedurally
         - a la fractal).
 * </ul>
 * <p>16.4.2006 PE:
 * <ul>
 *   <li>Improved: Brep constants for {@code float}-based data types, float methods.
 *   <li>Improved: Brep-induced changes in VEFDS class, Javadoc comments, cosmetics.
 *   <li>Improved: cosmetics in TrMatrix.
 *   <li>Improved: cosmetics and float-constants in Geometry.
 *   <li>New: float-methods in TrMatrix.
 *   <li>New: Brep.setCoordTypes() method (called before init()).
 *   <li>New: new methods/switch-branches relating to float type in VEFDS.
 * </ul>
 * <p>17.4.2006 PE:
 * <ul>
 *   <li>New: modules TriangleWarpingWorker, TriMeshDeformation, sTriMeshWarping composition.
 *   <li>Improved: properties in VEFDS module (primary coordinate types).
 *   <li>Improved: cosmetics - Property, Deformations.
 * </ul>
 * <p>18.4.2006 PE:
 * <ul>
 *   <li>Improved: interface Feature renamed to FeatureStore (and improved).
 *   <li>New: Features module (implementation of FeatureStore interface).
 *   <li>New: Formula.cloneArray() methods.
 *   <li>Improved: TimeDependent (cosmetics).
 * </ul>
 * <p>19.4.2006 PE:
 * <ul>
 *   <li>New: FeatureDeformation module (empty implementation of feature-based warping).
 *   <li>Improved: small optimization in module Deformations.
 *   <li>New: Geometry.pointSegment2D() and Geometry.pointSegment3D().
 *   <li>Improved: StaticPointLightSource (cosmetics, {@code ArrayList<double[]>} used in set/get).
 *   <li>Fix: final distance computation in Geometry.pointSegment2D() and Geometry.pointSegment3D().
 *   <li>Improved: Eclipse warnings.
 *   <li>New: test implementation of FeatureDeformation, FeatureWarpingWorker module, sFeatureWarping.xml.
 * </ul>
 * <p>20.-21.4.2006 PE:
 * <ul>
 *   <li>New: DefaultGeometrySearch class (convenience).
 *   <li>New: UniformGrid module (not tested yet, only centerPass() is implemented..).
 *   <li>New: Geometry.pointBox2D().
 *   <li>Improved: cosmetics in some other files..
 *   <li>New: Search2DWorker module, sSearch2D.xml.
 *   <li>New: Formula.colorRamp().
 *   <li>Improved: UniformGrid - consider maximal search radius.
 *   <li>Improved: more effective processing of homogeneous coordinates in Geometry.
 *   <li>Fix: functional fixes in UniformGrid.
 * </ul>
 * <p>23.4.2006 PE:
 * <ul>
 *   <li>New: GeometrySearch.getStatistics() method (various counters).
 *   <li>New: statistics in DefaultGeometrySearch, UniformGrid.
 *   <li>Improved: statistics in Search2DWorker, MAX_DISTANCE attribute.
 *   <li>Improved: DecimalField, WholeNumberField (FormattedDocument is no longer used).
 *   <li>Removed: FormattedDocument.java.
 *   <li>Improved: DecimalField renamed to DoubleNumberField, WholeNumberField renamed to IntNumberField.
 *   <li>New: two alternatives of point-set generation in Search2DWorker: uniform, Lorentz [x,z].
 * </ul>
 * <p>26.4.2006 PE:
 * <ul>
 *   <li>New: HashFunction module (Arash Partow).
 *   <li>Improved: Function interface was renamed to RealFunction and merged
 *       with FunctionR2ToR (FunctionR2ToR no longer exists).
 * </ul>
 * <p>27.4.2006 PE:
 * <ul>
 *   <li>New: SimpleNoise module (only trivial function yet), sNoise2D composition.
 *   <li>New: double-version of Formula.colorRamp().
 *   <li>Fix: small bug in DefaultRealFunction.
 *   <li>Improved: SimpleSynthesizer is now able to use RealFunction input.
 *   <li>Improved: CastingWorker module was renamed to SampleRenderWorker,
 *       strict CSG-dependencies were removed.
 *   <li>New: methods for convenient parameter-fetching from Property instances.
 *   <li>Improved: SampleRenderWorker can read image size (from RasterGraphics or ImageSynthesizer).
 *   <li>Improved: cosmetics in many modules.
 *   <li>Improved: Formula.colorRamp() methods (better colors).
 * </ul>
 * <p>28.4.2006 PE:
 * <ul>
 *   <li>New: RandomStatic class (simple stateless pseudo-random generators).
 *   <li>Improved: cubic B-spline interpolated noise (2D and 3D).
 *   <li>New: HashFunction - LCG-based hash function.
 *   <li>Improved: better coordinate hashing in HashFunction.
 * </ul>
 * <p>29.4.2006 PE:
 * <ul>
 *   <li>Improved: interface EntropyHistogram (changes proposed by Jan Kadlec).
 *   <li>New: IntervalArray module (cummulative frequency interval tree).
 * </ul>
 * <p>30.4.-1.5.2006 PE:
 * <ul>
 *   <li>New: interface DiscreteTransform, module DefaultDiscreteTransform.
 *   <li>New: collection class IntMap, support class IntTuple.
 *   <li>New: Formula.findPrime(), Formula.getSmallPrime() methods.
 *   <li>Fix: DEF_MAGNI_GLASS inverse function in Deformations.
 *   <li>Improved: cosmetics, javadoc - Template, LZWCodec, Deformations,
 *       EntropyHistogram, EntropyCodec, Formula, DefaultRealFunction,
 *       DefaultFileFormat
 *   <li>Fix: IntMap.TupleIterator must not have &lt;T&gt; parameter.
 *   <li>New: ArithmeticCodec module (dynamic arithmetic coding).
 * </ul>
 * <p>2.5.2006 PE:
 * <ul>
 *   <li>Changed: context Id changed to {@code integer} in EntropyCodec, EntropyHistogram.
 *   <li>Changed: context-related changes in all codec/histogram implementations.
 *   <li>New: Formula.vlc() method (logically equivalent to JPEG's VLC).
 *   <li>Improved: cosmetics, javadoc - IntMap, all testing.CompressedFormat* modules.
 *   <li>Fix: two bit-shifts in ArithmeticCodec.
 *   <li>Improved: STATISTICS universal property into Property.
 *   <li>Improved: STATISTICS implementation into IntervalArray, ArithmeticCodec
 *       (via LogFile), ImageCompressionWorker.
 *   <li>New: Formula.percent().
 *   <li>Improved: Main &amp; MainEval are now initializing the log-file time correctly.
 *   <li>Fix: Formula.findPrime().
 *   <li>Fix: EntropyCodec.CTX_DEFAULT must not interfere with IntMap.NULL_KEY &amp; IntMap.REMOVED_KEY.
 *   <li>Fix: several fixes in IntMap, collision statistics added.
 *   <li>New: interface IntFunction, class DefaultIntFunction, module ImagePredictor (not tested yet).
 * </ul>
 * <p>2.-3.5.2006 PE:
 * <ul>
 *   <li>Changed: ImagePredictor moved to package jagrlib.piece.
 *   <li>New: ImagePredictor - complete set of 8 predictors from JPEG, new property: precinct size.
 *   <li>Improved: explicit instantiation of wrapper classes (Integer, Double, ..) out.
 *   <li>Improved: cosmetics/javadoc in many source files.
 *   <li>Improved: ImagePredictor.clamp() - clamps predictions to the allowed range.
 *   <li>New: Formula.vlcInv() - inverse of Formula.vlc().
 *   <li>New: CompressedFormatGray module, sCompressionGray.xml composition.
 *   <li>Fix: fixes in Formula.vlc(), ArithmeticCodec..
 * </ul>
 * <p>4.5.2006 PE:
 * <ul>
 *   <li>Changed: EntropyHistogram.CTX_DEFAULT was removed. Minor changes in EntropyHistogram API.
 *   <li>Improved: hash-number in Search2DWorker (to compare results).
 *   <li>Improved: Search2DWorker asks data structure for textual description (logging),
 *       time-measurements.
 *   <li>New: universal text description Property.TEXT_DESCRIPTION (used in UniformGrid).
 *   <li>Improved: cosmetics/javadoc in some files.
 *   <li>Improved: VEFDS.GRANUL was increased due to effectivity.
 *   <li>New: separator strings into LogFile.
 * </ul>
 * <p>5.5.2006 PE:
 * <ul>
 *   <li>Improved: explicit instantiation of wrapper classes (Integer, Double, ..) out - finished.
 *   <li>New: class DefaultFunctionR2ToR2.
 *   <li>Improved: N.Nd double literals out from regdata.xml.
 *   <li>Fix: gui.ParamColor - color editing & persistance.
 *   <li>New: Formula.parseColor(), DefaultProperty.colorProperty().
 *   <li>Improved: cosmetics/javadoc/@Overrides in some files.
 *   <li>Fix: ImageCompare.f(int) returns values from <0.0,255.0> range. Fix in 2 callers.
 * </ul>
 * <p>6.5.2006 PE:
 * <ul>
 *   <li>Fix: Skel application startup (using invokeLater()). Makes possible to load default
 *       composition from command-line. At last!
 *   <li>Improved: cosmetics/javadoc/@Overrides in some files.
 *   <li>Fix: DEF_MAGNI_GLASS inverse function in Deformations (hoping this is the final fix?).
 *   <li>New: interface PersistentParamsBinary (parameter persistence in binary file).
 *   <li>New: interface BlockQuantizer (block quantization/dequantization).
 *   <li>New: abstract class DefaultBlockQuantizer (trivial implementation via redirection).
 *   <li>public tag 0.24, version number changed to 0.25.
 * </ul>
 * <p>7.5.2006 PE:
 * <ul>
 *   <li>New: interface BlockCodec (block coding/decoding).
 *   <li>Improved: cosmetics/javadoc/@Overrides in many files.
 *   <li>New: Geometry.pointSegment2D(double,double,double,double,double,double).
 *   <li>Improved: geometric algorithms in ChannelGUIImproved.
 *   <li>Fix: results farther than maxRadius should be discarded (UniformGrid &amp; Search2DWorker).
 * </ul>
 * <p>8.5.2006 PE:
 * <ul>
 *   <li>Improved: ValueTransferFunction interface (inverse mappings were added).
 *   <li>New: DefaultValueTransferFunction (prototype of pixel transfer function).
 *   <li>New: Formula.rgbToGray(double,double,double).
 *   <li>Improved: IntervalArray and ArithmeticCodec (all frequencies are reset after change of maxSymbol).
 *       Temporary precaution.
 *   <li>New: support methods in DefaultFileFormat: readUnsigned16(), writeUnsigned16(),
 *       readParameters(), writeParameters().
 *   <li>Improved: cosmetics/javadoc/@Overrides in some files.
 *   <li>New: CompressedFormatTransform module (prototype of lossy block transform coding).
 *   <li>New: DCT module (Discrete Cosine Transform).
 * </ul>
 * <p>9.5.2006 PE:
 * <ul>
 *   <li>Fix: DefaultDiscreteTransform methods, inverse transforms added.
 *   <li>New: int Formula.round( double ).
 *   <li>New: CheckerTexture module (used in Main03.java).
 *   <li>Improved: sanity check code in IntervalArray.
 * </ul>
 * <p>10.5.2006 PE:
 * <ul>
 *   <li>New: complete set of {@code double[] <-> int[]} conversion methods in DefaultDiscreteTransform class.
 *   <li>New: BlockQuantizer.setData() method (direct qtable setup).
 *   <li>Improved: small improvements in DefaultBlockQuantizer.
 *   <li>New: JPEGQuantizer module (slightly generalized JPEG1 quantizer).
 *   <li>Fix: Template.PL_CODEC constant.
 *   <li>New: CompressedFormatTransform.quality property (quantizer is set from it).
 * </ul>
 * <p>11.5.2006 PE:
 * <ul>
 *   <li>New: ZigZagCodec module (zig-zag integer matrix encoding a la JPEG).
 *   <li>New: BlockCodec.init() method, IOException handling in methods using underlying EntropyCodec.
 *   <li>Improved: small changes in CompressedFormatTransform.
 *   <li>Improved: IntervalArray: usage of methods from Arrays class.
 *   <li>Improved: cosmetics/javadoc/@Overrides in some files.
 *   <li>Fix: IntervalArray.CFTree.newSize() - member "m" has to be re-initialized.
 *   <li>Improved: decimation and increment defaults/bounds in ArithmeticCodec.
 * </ul>
 * <p>13.5.2006 PE:
 * <ul>
 *   <li>Improved: inter-block prediction in BlockCodec interface, CompressedFormatTransform and
 *       ZigZagCodec modules..
 *   <li>Improved: cosmetics/javadoc/@Overrides in many files.
 *   <li>Improved: changes in interface SceneNode, class CSGCommonNode (concerning root-node attribute and
 *       getAttributes() method).
 *   <li>New: MicroFacet.objCoord, MicroFacet.locCoord, MicroFacet.toObject, .. improved coord-assertion logic.
 * </ul>
 * <p>14.5.2006 PE:
 * <ul>
 *   <li>Improved: some javadoc fixes.
 *   <li>Fix: {@link IntervalArray} sanity check fixed to "s/log2(s) + min * s" (s = |alphabet|).
 *   <li>Improved: {@link LightModel#getOrigColor} instaed of {@code getColor()}, changes in
 *       {@link MicroFacet}, {@link PhongModel}, ...
 *   <li>New: {@link SpotTexture} module (3D texture specimen).
 *   <li>Updated: {@link Main03} class (now using both pilot textures).
 *   <li>Fix: default constructor {@link CheckerTexture#CheckerTexture} is needed by registration.
 * </ul>
 * <p>15.5.2006 PE:
 * <ul>
 *   <li>New: implementation of {@link VEFDS#setTriangleVertices}.
 *   <li>New: implementation of {@link VEFDS#setVertexCoords(int,int,float[])},
 *       {@link VEFDS#getVertexCoords(int,int,float[])}.
 *   <li>New: implementation of {@link VEFDS#getAttribute(int,int,float[])}.
 * </ul>
 * <p>16.5.2006 PE:
 * <ul>
 *   <li>New: universal {@link Property#LOGGING} property (set .. switch on/off, get .. log text).
 *   <li>Improved: {@link ZigZagCodec} logging.
 * </ul>
 * <p>17.5.2006 PE:
 * <ul>
 *   <li>Updated: WWW documents, arrangements for WWW refactorization.
 *   <li>Fix: pack.bat fixed &amp; improved.
 *   <li>WWW refactorization for real HTTP serving (ping-pong of several commits).
 * </ul>
 * <p>19.5.2006 PE:
 * <ul>
 *   <li>New: {@link JitteringSynthesizer} module, sRayTracingJitter.xml.
 *   <li>Improved: {@link Main05} is now using {@link JitteringSynthesizer}, camera FOV was reduced.
 *   <li>Improved: in {@link JitteringSynthesizer}, supersampling-propagating
 *       {@link ImageFunction#getSample} variant is used.
 * </ul>
 * <p>20.5.2006 PE:
 * <ul>
 *   <li>New: random permutation in {@link RandomJames}, javadoc/cosmetics.
 *   <li>New: random point in triangle - {@link RandomJames#randomPointFromTriangle}.
 *   <li>Updated: {@link ImageSynthesizer#SUPERSAMPLING} property, semantics
 *       has been changed in {@link JitteringSynthesizer}.
 *   <li>New: {@link RedrawTimer} class (used in {@link Main02} to {@link Main05}, {@link ProjectionWorker},
 *       {@link SampleRenderWorker}).
 *   <li>New: super-sampling support into {@link LightSource} &amp; {@link LightModel} interfaces.
 *   <li>New: {@link DefaultLightSource} class, used in {@link StaticPointLightSource},
 *       {@link AmbientLightSource}.
 *   <li>New: {@link Geometry#dotProduct3D} solves homogen. coordinates.
 *   <li>New: super-sampling support into {@link RTScene} interface
 *       (and {@link StaticCSGScene} implementation).
 * </ul>
 * <p>21.5.2006 PE:
 * <ul>
 *   <li>Improved: {@link Enigma} cosmetics, encoding/decoding scripts.
 *   <li>New: two obscure modules: {@link DepthOfFieldCamera} &amp; {@link RectangleLightSource}.
 *   <li>New: two main classes: {@link Main06} &amp; {@link Main07} (using obscure modules).
 * </ul>
 * <p>23.5.2006 PE:
 * <ul>
 *   <li>Fix: pixel value normalisation in {@link CompressedFormatTransform}.
 *   <li>Improved: Main0X cosmetics, {@link Main07} will use both DoF camera and area light source.
 *   <li>Improved: error display in {@link ImageCompressionWorker} &amp; {@link ImageFilterWorker}
 *       (accuracy set to 2 fract. digits).
 *   <li>New: {@link DefaultRasterGraphics} class ({@link RasterImage} is the descendant of it).
 *   <li>Improved: cosmetics/javadoc in some files.
 * </ul>
 * <p>25.5.2006 PE:
 * <ul>
 *   <li>New: {@link HDRImage} module (first untested implementation).
 *   <li>Fix: obscure package moved outside the "src" hierarchy (for Eclipse).
 * </ul>
 * <p>26.5.2006 PE:
 * <ul>
 *   <li>New: jai_codec package included into repository (as JAR file).
 *   <li>Fix: {@link HDRImage} (uses jai_codec classes, another fixes).
 *   <li>New: {@link PFMFileFormat} module (Portable Float Map "PF 'width' 'height' 'scale'").
 *   <li>Improved: {@link LineWorker} uses {@link RandomJames} (random seed can be entered in GUI).
 *   <li>New: sBresenhamHDR.xml composition (very slow in the 1st version - probably
 *       due to bitmap conversion in preview window).
 * </ul>
 * <p>27.5.2006 PE:
 * <ul>
 *   <li>Fix: {@link DefaultRasterGraphics#BACKGROUND_D} has to be used together with
 *       {@code double[]} color representation.
 *   <li>Improved: javadoc links in {@link Version}-log.
 *   <li>Improved: doc.bat script (classes included in {@code lib/*.jar} archives).
 *   <li>Improved: {@link Formula#round} and {@link Math#round(float)} usage in some files.
 * </ul>
 * <p>28.5.2006 PE:
 * <ul>
 *   <li>New: {@link Formula#ldexp} and {@link Formula#frexp} methods (C[++] portability).
 *   <li>New: {@link Formula#RGBToRGBe} and {@link Formula#RGBeToRGB} methods
 *       (supporting Radiance's HDR color format).
 *   <li>New: {@link HDRMap} module, {@code sPFMview.xml} composition for converting PFM image to LDR format.
 *   <li>New: {@link HDRFileFormat} module, {@code sHDRview.xml} composition for reading HDR images.
 * </ul>
 * <p>29.5.2006 PE:
 * <ul>
 *   <li>Fix: {@link HDRFileFormat} load method - conversions in {@link Formula} ({@code byte <-> int}).
 *   <li>Improved: gamma-correction in {@link HDRMap} module.
 *   <li>Fix: JAI archive included into Eclipse's classpath.
 * </ul>
 * <p>31.5.2006 PE:
 * <ul>
 *   <li>Improved: {@link RayCasting}/{@link RayTracing} - background/black color depends
         on Camera result (invalid ray {@literal =>} black).
 *   <li>New: {@link LogFile#probe} property-map and associated methods.
 *   <li>Changed: in {@link LogFile}, {@code debugLogs -> debugging}.
 *   <li>New: {@link LogFile#tracing} flag.
 *   <li>New: command-line parameter "{@code -p <probe-file>}" for selective runtime logging.
 *   <li>Improved: {@link RayCasting}/{@link RayTracing} shouldn't check color overflow.
 *   <li>Fix: result color has to be initialized in {@link PhongModel#color} methods.
 *   <li>Improved: {@link SimpleSynthesizer} shall either do gamma-correction or not do
 *       result clamping. The same stands for {@link JitteringSynthesizer}.
 *   <li>Changed: {@link Geometry#SCENE_EPSILON} raised to 10<sup>-4</sup>, {@link StaticCSGScene#intersection}
 *       improved a little bit (real intersection-origin distance).
 * </ul>
 * <p>1.6.2006 PE:
 * <ul>
 *   <li>Fix: saving file in {@link HDRFileFormat}.
 *   <li>Changed: gamma-correction should be set to {@code 1/2.2}, data changes in scene definition,
 *       light source and background defaults. Light source attenuation default was set.
 *   <li>Changed: sequential changes in Main0X classes..
 *   <li>New: {@code sRayTracingHDR.xml} composition is saving result image in HDR format.
 *   <li>Changed: basic property-names moved to {@link Texture} interface.
 *   <li>Changed: "Date Rev Author" unification ({@code svn:keywords} file property).
 *   <li>New: {@link DefaultProperty#enumProperty} - universal enum constructor from
 *       {@link String}, {@link Integer} (both carrying ordinal number). Acknowledgement to Mirek Ruzicka.
 * </ul>
 * <p>3.6.2006 PE:
 * <ul>
 *   <li>New: {@link Geometry#pointInTriangle2D} method (computes barycentric coordinates after that).
 *   <li>Improved: {@link TriMeshDeformation} implementation (computes real deformation).
 * </ul>
 * <p>4.-5.6.2006 PE:
 * <ul>
 *   <li>New: {@link LogFile#memoryStatistics} methods - memory heap usage, garbage collection,
 *       sequential changes in {@link Search2DWorker}.
 *   <li>Improved: {@link LogFile} output: US locale is used in time formatting,
 *       operating system &amp; JVM details.
 *   <li>Improved: more robust pixel reading in {@link CompressedFormatGray}.
 * </ul>
 * <p>6.-7.6.2006 PE:
 * <ul>
 *   <li>New: {@link Formula#permutationsWithRepetition} method.
 *   <li>Changed: basic property-names moved to {@link RealFunction} interface.
 *   <li>New: {@link MainNoise} main program (3D noise functions).
 *   <li>Improved: derivatives shall be computed in {@link DefaultRealFunction}.
 * </ul>
 * <p>9.-10.6.2006 PE:
 * <ul>
 *   <li>New: log-images in {@link LogFile} class.
 *   <li>New: {@link Main#commandLineParams} method for common cmd-line parsing.
 *   <li>Changed: changes in main routines: {@link MainNoise}, {@link Main03}, {@link Main07}.
 *   <li>Fix: light-sources will be considered in {@link RayCasting}, {@link RayTracing} classes.
 *   <li>New: {@link AdaptiveJitteringSynthesizer} module (obscure).
 * </ul>
 * <p>12.-17.6.2006 PE:
 * <ul>
 *   <li>Improved: {@link AdaptiveJitteringSynthesizer} module (obscure).
 *   <li>Improved: reconstruction error is logged in {@link ImageCompressionWorker} module.
 *   <li>Improved: 1st RLE packet (before DC) was removed in {@link ZigZagCodec} module.
 *   <li>Changed: another property-names were moved to {@link RealFunction} interface.
 * </ul>
 * <p>20.6.2006 PE:
 * <ul>
 *   <li>Fix: Park-Miller LCG in {@link RandomStatic} module (thank to M. Ruzicka).
 * </ul>
 * <p>24.6.2006 PE:
 * <ul>
 *   <li>New: {@link TestImageFunctions} module - test image functions for sampling.
 *   <li>New: sSamplingTest.xml composition.
 * </ul>
 * <p>24.6.2006 PE:
 * <ul>
 *   <li>New: {@link MainSampling} - main program for adaptive sampling tests.
 *   <li>Fix: minor sampling artefacts in {@link AdaptiveJitteringSynthesizer}.
 *   <li>New: {@link GraphicsViewer#destroy} method - destroys the actual window completely.
 *            Consequent changes in {@link RasterImagePreview} and {@link AWTWindow}.
 *   <li>Improved: {@link LogFile#createImage} can embed image number into file-name.
 * </ul>
 * <p>27.6.2006 PE:
 * <ul>
 *   <li>Improved: {@link Main06} and {@link Main07} main routines (depth-of-field camera,
 *       area light source).
 * </ul>
 * <p>2.7.2006 PE:
 * <ul>
 *   <li>New: {@link StarFlare} module - pilot implementation of HDR-exposition with
 *       overflow handling.
 * </ul>
 * <p>3.7.2006 PE:
 * <ul>
 *   <li>Improved: variable number of rays in {@link StarFlare} module.
 * </ul>
 * <p>4.-5.7.2006 PE:
 * <ul>
 *   <li>Improved: preparation for bounding volumes, object ids, speedup R-T methods (1st phase).
 *   <li>Improved: {@code BoundingBox} interface renamed to {@link BoundingVolume}.
 *   <li>New: {@link BoundingSphere} class (not tested yet).
 *   <li>Improved: refactorisation of 3D scene stuff (1st phase): {@link RTScene} interface,
 *       {@link SceneNode} class, {@link DefaultSceneNode} class,
 *       {@link CSGNode} class, {@link CSGCommonNode} class,
 *       {@link Solid} interface, {@link StaticCSGScene} module, all consequent changes.
 *   <li>New: {@link Geometry#pointBox3D} method.
 *   <li>New: {@link GeometrySearch#finishedSegment} method.
 * </ul>
 * <p>12.-13.7.2006 PE:
 * <ul>
 *   <li>Improved: {@link Solid#getBoundingVolume}.
 *   <li>New: {@link BitStream#seek} method, consequences.
 *   <li>New: {@link BufferedBitStream} module (not tested yet).
 *   <li>Improved: property names moved between {@link BitStream} and {@link JavaBitStream}.
 * </ul>
 * <p>14.-16.7.2006 PE:
 * <ul>
 *   <li>Improved: support I/O routines moved to {@link DefaultFileFormat}.
 *   <li>New: {@link WAVFileFormatMapped} module, not tested yet.
 *   <li>New: {@link Formula#swapBytes} method.
 *   <li>New: support for disk-mapped data formats: {@link DataFileFormat#closeFile} method.
 *   <li>Fix: integer sample type in registration of {@link DataMatrix} module.
 * </ul>
 * <p>17.7.2006 PE:
 * <ul>
 *   <li>New: {@link AudioReplay} module (not tested yet).
 *   <li>Improved: cosmetics, javadoc.
 *   <li>New: geometry methods in {@link WAVFileFormatMapped}.
 * </ul>
 * <p>18.7.2006 PE:
 * <ul>
 *   <li>Fix: initial testing/debugging of {@link BufferedBitStream},
 *       {@link WAVFileFormatMapped} and {@link AudioReplay}.
 *   <li>New: {@link AudioFilterWorker} worker module (with optional data filtering and
 *       sound replay), sAudioFilter.xml composition.
 * </ul>
 * <p>19.7.2006 PE:
 * <ul>
 *   <li>New: {@link Filter1D} interface.
 *   <li>New: {@link AudioFilter} module (framework for consecutive 1D filtering).
 *   <li>New: {@link Filter1DNotch} module (simple 1D notch filter).
 *   <li>New: sAudioReplay.xml and sAudioFilter.xml compositions.
 *   <li>Improved: small changes in {@link SampleData} interface (number of read samples
 *       is returned from some methods), consequent changes in {@link DataMatrix}.
 *   <li>Improved: bug fixes and improvements in {@link AudioReplay} module (stream pausing,
 *       positioning etc.).
 *   <li>Fix: several bug fixes in {@link BufferedBitStream}.
 *   <li>Improved: {@link WAVFileFormatMapped} - support for {@code double[]} exchange buffers.
 *   <li>Fix: {@link AudioFilterWorker} should create output audio stream itself.
 *   <li>New: standalone {@link MainDehumming} program.
 * </ul>
 * <p>21.7.2006 PE:
 * <ul>
 *   <li>Fix: {@link WAVFileFormatMapped} can handle files {@code >2GB}.
 * </ul>
 * <p>30.9.2006 PE:
 * <ul>
 *   <li>New: {@link RankFilter} module - 1st version.
 * </ul>
 * <p>15.10.2006 PE:
 * <ul>
 *   <li>New: "eclipse3.1" project for old version of Eclipse (3.1). Current version will use "eclipse".
 *   <li>New: {@link DefaultImageSynthesizer} module and its usage ({@link SimpleSynthesizer}).
 *   <li>New: {@link FractalCircles} module, sFractal.xml composition.
 *   <li>Fix: javadoc comments in {@link RankFilter}.
 *   <li>New: {@link SampleColormap} module, sFractalPalette.xml composition.
 *   <li>Improved: tilted ellipse support in the {@link EllipseRender} interface.
 *   <li>New: {@link Ellipse}, {@link EllipseWorker} modules, sEllipse.xml composition.
 *   <li>New: sFloodFill8.xml composition (for assignment No.44).
 * </ul>
 * <p>21.10.2006 PE:
 * <ul>
 *   <li>New: {@link Complex} class - operations on complex numbers (1st version).
 *   <li>New: {@link Mandelbrot} obscure class - test module for {@link Complex}.
 * </ul>
 * <p>22.10.2006 PE:
 * <ul>
 *   <li>Improved: changes in class {@link Composition} - every {@link Worker} can reject
 *       invocation of the {@link Worker#run run()} method ({@link Worker#REJECT} property).
 *   <li>Improved: {@link Mandelbrot} module now can use arbitrary complex exponent.
 *   <li>New: {@link Geometry#isZero(double)} method.
 *   <li>Improved: {@link SampleRenderWorker} will be able to act in meta-worker scenario.
 * </ul>
 * <p>23.10.2006 PE:
 * <ul>
 *   <li>New: {@link DefaultProperty#stringProperty} method.
 *   <li>New: {@link AnimationWorker} module - meta-worker for animation rendering.
 *   <li>New: sFractalMandel.xml, sFractalMandelAnim.xml (animation of Mandelbrot set).
 * </ul>
 * <p>25.10.2006 PE:
 * <ul>
 *   <li>Fix: "cannot not parse" message.
 *   <li>Improved: "Single pass" switch in {@link SampleRenderWorker}.
 *   <li>New: long property type, many changes including new {@link ParamLong} class.
 * </ul>
 * <p>27.10.2006 PE:
 * <ul>
 *   <li>New: {@link PolygonFill} module (fake implementation of integer polygon fill).
 *   <li>New: {@link PolygonFillWorker} worker and xPolygon.xml.
 *   <li>New: {@link PolygonFillAnti} module (fake implementation of polygon fill with antialiasing).
 *   <li>New: {@link PolygonFillAntiWorker} worker and xPolygonAnti.xml.
 *   <li>Deleted: obsolete batches commit.bat and setvars.bat.
 *   <li>Improved: pack* batches - verbose listing mode removed from "jar" calls.
 * </ul>
 * <p>28.10.2006 PE:
 * <ul>
 *   <li>New: external library <a href="http://www.singularsys.com/jep/">JEP</a>.
 *   <li>New: {@link Formula#initExpression} prepares arithmetic expression for repetitive evaluation.
 *   <li>New: common parameter files for compiling and JavaDoc generation.
 *   <li>New: <a href="http://ant.apache.org/">Ant</a> build file - build.xml.
 *   <li>Improved: general expressions in {@link AnimationWorker} module.
 * </ul>
 * <p>29.10.2006 PE:
 * <ul>
 *   <li>Improved: Eclipse cleanup (new external libraries, unused variables/packages).
 *   <li>New: a couple of new HOWTO sections, Ant build system, ffmpeg encoding, ..
 *   <li>New: {@link cz.cuni.jagrlib.iface.GraphicsViewer.PreviewThread} inner class
 *       for preview threads (+ consequent changes).
 *   <li>Improved: source cleanup in worker package and in Main* classes.
 *   <li>Fix: new external libraries should be exported in update.sh script.
 *   <li>New: {@link ImageCompositionWorker} worker class (multiple source images will be used
 *       in computing target image).
 * </ul>
 * <p>30.10.2006 PE:
 * <ul>
 *   <li>New: {@link ParamText} parameter editor for multi-line strings.
 *   <li>New: 1st version of {@link ImageCompute} module - will use multi-line expressions
 *       for output raster image definition.
 *   <li>Improved: source cleanup and tiny refactorisation in {@link cz.cuni.jagrlib.gui} package.
 *   <li>Improved: {@link InfoParam#visibleLines} method is used in new module height estimation.
 * </ul>
 * <p>1.11.2006 PE:
 * <ul>
 *   <li>Fix: Param*.setValue(Object) must accept any reasonable value (any numeric and string type..).
 *   <li>Fix: syntactic error in makefile.jmk.
 *   <li>Improved: input redirection in {@link PolygonFill}.
 *   <li>Improved: three varying properties in {@link AnimationWorker}.
 *   <li>Improved: integer variable {@link AnimationWorker#frame}.
 *   <li>New: {@link Formula#isIntFormat} function.
 * </ul>
 * <p>2.11.2006 PE:
 * <ul>
 *   <li>Fix: font size in {@link ParamText}.
 *   <li>New: eval/avi.bat (uses ffmpeg to create AVI animation from sequence of pictures).
 *   <li>New: {@link ImageCompute} module is now working properly.
 * </ul>
 * <p>3.11.2006 PE:
 * <ul>
 *   <li>Improved: two public input constants (x, y) in {@link ImageCompute}.
 * </ul>
 * <p>4.11.2006 PE:
 * <ul>
 *   <li>New: {@link ImageTransition} module and sImageBlend.xml.
 *   <li>Improved: descendant of {@link Piece} (descendant of Default*) needs not define its
 *       own {@link Piece#reg} and {@link Piece#setTemplate} members.
 *   <li>Fix: pixel array size in {@link ImageTransition}.
 *   <li>Improved: frame offset property into {@link AnimationWorker}.
 * </ul>
 * <p>6.11.2006 PE:
 * <ul>
 *   <li>New: {@link PolygonClip} module, {@link PolygonClipWorker} and sClipPolygon.xml.
 *   <li>New: UNIX shell scripts (compile.sh, run.sh, ..).
 *   <li>New: {@link ImageCrop} module and sCropSequence.xml.
 * </ul>
 * <p>8.11.2006 PE:
 * <ul>
 *   <li>Improved: {@link ImageCrop} module - scaling with resampling (round and bilinear).
 *   <li>New: sImageCrop.xml.
 *   <li>Improved: Javadoc cleanup.
 * </ul>
 * <p>9.11.2006 PE:
 * <ul>
 *   <li>New: {@code RGB <-> HSV} conversion routines into {@link Formula}.
 * </ul>
 * <p>10.11.2006 PE:
 * <ul>
 *   <li>Improved: {@link RasterImagePreview} is using custom subclassed {@link javax.swing.JComponent}
 *       instead of {@link javax.swing.JLabel}.
 *   <li>New: {@link DefaultGraphicsViewer} class - common parts of both viewers ({@link AWTWindow},
 *       {@link RasterImagePreview}).
 *   <li>New: HUD methods into {@link GraphicsViewer} interface, 1st implementation in {@link RasterImagePreview}.
 *   <li>New: {@link MouseFrame} module to test HUD interface of {@link RasterImagePreview}.
 *       Used in sImageCrop.xml.
 *   <li>New: HUD methods in {@link AWTWindow}, not tested yet.
 * </ul>
 * <p>11.11.2006 PE:
 * <ul>
 *   <li>New: {@link Formula#granularity} method.
 *   <li>New: {@link JavaText} and {@link TextWorker} modules, sText.xml.
 *   <li>Improved: {@link GraphicsViewer#repaintAll} method is called in all workers.
 *   <li>Improved: antialiasing in {@link JavaText} (+ consequent changes: {@link TextWorker}..).
 *   <li>Improved: text extent implementation in {@link JavaText} (+ consequent changes).
 * </ul>
 * <p>12.11.2006 PE:
 * <ul>
 *   <li>New: {@link TestGamma} module, sGamma.xml.
 *   <li>Improved: antialiasing in {@link JavaText} can be switched on/off externally.
 * </ul>
 * <p>17.11.2006 PE:
 * <ul>
 *   <li>Improved: composition frame closing (able to cancel the close action),
 *       main application window closing can be vetoed by unsaved composition.
 *   <li>Improved: {@code comp} property into build.xml script (auto-loaded composition filename),
 *       {@code debug} property for {@link LogFile#debugging}.
 *   <li>New: {@link OrderedDither} module, used in sDither.xml.
 *   <li>Fix: {@link ImageCrop} scaling.
 *   <li>Improved: entropy codec parameter persistence in {@link CompressedFormatRGB}.
 * </ul>
 * <p>18.11.2006 PE:
 * <ul>
 *   <li>Improved: common loading code moved to {@link DefaultFileFormat}.
 *   <li>Improved: JPEG I/O filter ({@link JFIFFileFormat}) now uses javax.imageio.
 *   <li>Fix: two output bitmasks are needed in {@link FloodFillPoint}.
 *   <li>Add: "SaveInterval" parameter in {@link FloodFillPoint}.
 *   <li>Improved: Eclipse code cleanup.
 * </ul>
 * <p>19.11.2006 PE:
 * <ul>
 *   <li>New: {@link TestImageLaser} module (1st version) and {@link GridRenderWorker},
 *       composition for laser-printer test image: sLaser.xml.
 *   <li>Improved: code cleanup.
 * </ul>
 * <p>17.12.2006 PE:
 * <ul>
 *   <li>New: {@link WarpingSpecimen} module, {@link WarpingWorker}, and {@code sImageWarping.xml}.
 *   <li>Improved: small fixes in HOWTO.
 *   <li>New: {@link InputListener#windowClose windowClose()} method and
 *       BUTTON constants in {@link InputListener}). All consequent changes.
 *   <li>Improved: all JaGrLib threads now have their names (debugging).
 *   <li>Improved: code cleanup in {@link Composition}.
 * </ul>
 * <p>23.12.2006 PE:
 * <ul>
 *   <li>Improved: {@code HashMapPlugs} class was removed, consequent changes,
 *       new for-loop format, further refactorisation.
 *   <li>Fix: "Replace Piece" command is now able to match plugs properly.
 * </ul>
 * <p>24.12.2006 PE:
 * <ul>
 *   <li>Improved: {@code HashMapParams} class was removed, consequent changes.
 *   <li>Fix: filtering in module selection dialog (compatible, matching module).
 *   <li>Improved: list-box is used in module-selection dialog (plug interface).
 *   <li>New: {@link RegPiece#fullClassName()} method (+ usage).
 *   <li>New: {@link RegTables#getInterfaces()} method (collects all used module interfaces).
 *   <li>Improved: {@link SelectFilter} and {@link SelectFilterBasic} refactorisation.
 *   <li>Improved: list-box (package) used in registration dialog.
 * </ul>
 * <p>25.12.2006 PE:
 * <ul>
 *   <li>Improved: reg and gui - code cleanup.
 *   <li>Improved: won't need {@code PlafMacros} class any more.
 *   <li>Improved: XML format cleanup (boolean flags, Input/Output type of a plug).
 *   <li>Improved: code cleanup (opozite, JavaDoc commants,..).
 *   <li>Improved: further XML format cleanup (plug: {@code type/name -> iface/id}).
 *   <li>Improved: composition save - modules and channels are sorted by their keys.
 *   <li>Improved: registry - module plugs keep their ordering (according to source code).
 * </ul>
 * <p>27.12.2006-2.1.2007 PE:
 * <ul>
 *   <li>Fix: default parameter values in module registration.
 *   <li>Fix: intial plug position cannot be changed until its owner (module) is resized.
 *   <li>New: {@link AdditiveNoise} module, sImageNoise.xml composition.
 *   <li>New: {@link BitMaskCore} interface was severed from {@link BitMask}.
 *   <li>Fix: registration of multi-template modules.
 *   <li>New: {@link PolygonScanline} module, w/o antialiasing yet.
 * </ul>
 * <p>2.1.2007 PE:
 * <ul>
 *   <li>New: {@link EmptyBitMaskEnumerator} class - for modules w/o read capability.
 *   <li>Improved: anti-aliasing (super-sampling) added to {@link PolygonScanline} module.
 *   <li>Improved: build.xml should prefere the {@code class} directory over JAR files.
 * </ul>
 * <p>3.1.2007 PE:
 * <ul>
 *   <li>New: {@link DefaultPlugin#booleanParam} method.
 *   <li>New: eval-plugin class {@link Ex2006_45_a}, eval-scripts for exercises 45, 46.
 * </ul>
 * <p>6.1.2007 PE:
 * <ul>
 *   <li>Fix: improved edge uniqueness in {@link PolygonScanline} (using {@link Object#hashCode()}).
 *   <li>New: eval-plugin class {@link Ex2006_48_a}, eval-script for exercise 48.
 *   <li>Improved: toolbar panel shows number of running composition threads.
 *   <li>Improved: exceptions - {@code NotExecutableException} and {@code JaGrLibCause} dumped,
 *       GUI exception reporting, all Worker-modules revisited.
 *   <li>Improved: {@link AboutDialog} improvements: memory usage, OS details.
 *   <li>Improved: code cleanup (String.valueOf, JavaDoc).
 * </ul>
 * <p>7.1.2007 PE:
 * <ul>
 *   <li>New: entropy codec {@link HuffmanCodec} - adaptive Huffman codec (thank to Ondrej Starek).
 * </ul>
 * <p>8.1.2007 PE:
 * <ul>
 *   <li>Improved: refactorization of the {@link VEFDS} module.
 *   <li>Improved: "int-coords" changed to "projected-coords" in the {@link Brep} interface.
 *   <li>Improved: {@link Render3DWorker} - able to call 3D-scene-initialization first.
 *   <li>Improved: {@link VEFDS#getFaceVertices} - returns real face size even if the provided array is smaller.
 *   <li>New: {@link Test3DScene} and {@link RenderWireframe} modules, sRender3D.xml composition.
 * </ul>
 * <p>9.1.2007 PE:
 * <ul>
 *   <li>New: standard attribute names in {@link Brep} ({@link Brep#COLOR}, etc.).
 *   <li>New: color ramp producing {@code float[3]} RGB format.
 *   <li>Fix: {@link VEFDS#getAttributeId} now works with concrete context Id even if the attribute is shared.
 *   <li>Improved: JavaDoc in some source-files.
 *   <li>New: color and normal attributes in {@link Test3DScene} and {@link RenderWireframe}.
 * </ul>
 * <p>10.-19.1.2007 PE:
 * <ul>
 *   <li>Improved: {@link TrMatrix} refactorisation (vector coordinates will use {@code w=0.0} in homogenous format,
 *       {@code int[]} source coordinate vectors won't be used), consecutive changes in {@link VEFDS}.
 *   <li>New: property "Draw normals" in {@link RenderWireframe}.
 *   <li>Fix: JPEG encoding quality settings in all relevant Main classes ({@code 0.95f -> 95.0f}).
 *   <li>Improved: 3D noise generation {@link SimpleNoise}, {@link MainNoise} main class shows all builtin noise variants.
 *   <li>New: handy version of translation-construction method: {@link TrMatrix#translate3D(double,double,double,TrMatrix)}.
 *   <li>New: {@link Formula#vectorToString(int[])} and {@link TrMatrix#log} methods for debugging purposes.
 *   <li>Improved: re-entrancy in {@link Cube}.
 * </ul>
 * <p>21.1.2007 PE:
 * <ul>
 *   <li>New: {@link RankFilter} refactorisation - new interfaces/enums/classes: {@link RankType}, {@link Rank},
 *       {@link RankHistogram}, {@link WindowShape}.
 * </ul>
 * <p>22.1.2007 PE:
 * <ul>
 *   <li>Improved: many small improvements/fixes in {@link Geometry} and {@link TrMatrix}.
 *   <li>New: OpenGL-like methods - {@link TrMatrix#lookAt}, {@link TrMatrix#frustum}, {@link TrMatrix#perspective},
 *       {@link TrMatrix#ortho}, {@link TrMatrix#viewport}.
 *   <li>New: perspective camera in {@link Render3DWorker}.
 * </ul>
 * <p>23.1.2007 PE:
 * <ul>
 *   <li>New: {@link Brep#setFaceVertices} for more convenient scene generation.
 *   <li>New: random generator support functions - {@link RandomJames#randomInteger}, {@link RandomJames#randomDouble},
 *       {@link RandomJames#randomFloat} and {@link RandomJames#uniformDirection}.
 *   <li>Improved: vector methods in {@link Geometry}, new {@link Geometry#getAxes} method computes mutually
 *       perpendicular vectors.
 *   <li>Improved: intersection computations for all solids, time measurement in {@link Main03}.
 *   <li>New: {@link Test3DScene} can generate random fans.
 *   <li>New: {@link DefaultRender3D} module and its usage.
 *   <li>New: {@link RenderDepthBuffer} - test depth-buffer implementation.
 *   <li>New: {@link Render3D#setDepthComparison} and applicable constants.
 *   <li>Improved: {@link Render3DWorker} can be used in animated compositions, sRenderAnim.xml test.
 * </ul>
 * <p>24.-26.1.2007 PE:
 * <ul>
 *   <li>New: {@link DefaultImageFunction} + all applications.
 *   <li>New: {@link TextureFunctions} - simple procedural textures.
 *   <li>New: {@link Formula#remainder} - periodic remainder (unlike the zero-symmetric {@link Math#IEEEremainder}).
 *   <li>Improved: RGB color property can be returned in {@code double[]} format, too.
 *   <li>New: first (incorrect) texture interpolation in {@link RenderDepthBuffer}, texture
 *       coordinates are generated in {@link Test3DScene}.
 * </ul>
 * <p>27.1.2007 PE:
 * <ul>
 *   <li>Fix: reject mechanism for {@link AnimationWorker} - new {@link Piece#isConnected} method has to
 *       be used instead of {@link Piece#getInterface(String)}.
 *   <li>New: perspective-correct texture interpolation in {@link RenderDepthBuffer}.
 * </ul>
 * <p>4.2.2007 PE:
 * <ul>
 *   <li>Improved: resources (icons, default configuratino file) are now duplicated in {@code jagrlib.jar}
 *       in order to run Skel independently (only this single JAR is necessary).
 *   <li>New: {@link GuiConstants} class, consequent changes.
 *   <li>Fix: one minor GUI issue, resource retrieving via URL (class-loader).
 * </ul>
 * <p>12.2.2007 PE:
 * <ul>
 *   <li>New: {@link DefaultRasterFileFormat} class - ancestor for 2D raster image formats,
 *       consequent changes.
 * </ul>
 * <p>26.2.-1.3.2007 PE:
 * <ul>
 *   <li>New: {@link BrepIterator} interface (instead of {@code IteratorData}) + consequent changes.
 *   <li>New: default classes {@link DefaultBrepIterator}, {@link DefaultBrepIteratorOrd},
 *       {@link DefaultBrepIteratorArr}.
 * </ul>
 * <p>4.-9.3.2007 PE:
 * <ul>
 *   <li>Improved: interface {@link FaceRender} was simplified - additional parameters will be set using {@link Property}
 *       interface..
 *   <li>Improved: property names into {@link BrepIterator} - for depth-order.
 *   <li>New: {@link FaceRenderFlat}, {@link RenderPainter} and {@link DepthSort} modules, sRenderPainter.xml.
 * </ul>
 * <p>22.-23.3.2007 PE:
 * <ul>
 *   <li>Improved: {@link Test3DScene} is able to generate non-penetrating faces
 *       and transparent colors.
 *   <li>Fix: transparent color processing in all modules related to {@link Test3DScene}.
 * </ul>
 * <p>24.3.2007 PE:
 * <ul>
 *   <li>Improved: registration-warnings in {@link RegPiece}.
 *   <li>Fix: point mapping in {@link TriMeshDeformation}.
 *   <li>New: optional interactive-editing module can be called from {@link TriangleWarpingWorker}.
 *   <li>New: triangle-mesh editing specimen {@link TriMeshEditor}, sTriMeshEditor.xml composition.
 *   <li>Improved: originator reference added to all {@link InputListener} calls + consequent changes.
 * </ul>
 * <p>25.3.2007 PE:
 * <ul>
 *   <li>Improved: simplification of {@link FeatureStore} interface, consequent changes.
 *   <li>public tag 0.25, version number changed to 0.26.
 * </ul>
 * <p>26.3.2007 PE:
 * <ul>
 *   <li>Fix: alpha-channel generation in {@link Test3DScene}.
 * </ul>
 * <p>3.4.2007 PE:
 * <ul>
 *   <li>Fix: non-penetrating fans in {@link Test3DScene}.
 * </ul>
 * <p>12.4.2007 PE:
 * <ul>
 *   <li>Improved: {@link UniformGrid} is able to store 2D edges and perform ray-pass.
 *   <li>New: sRay2D.xml composition.
 *   <li>New: {@link DefaultRasterGraphics#drawLine}, its usage.
 *   <li>Fix: {@link UniformGrid} passes for line segments.
 * </ul>
 * <p>14.-15.4.2007 PE:
 * <ul>
 *   <li>Fix: inverse magni-glass in {@link Deformations}.
 *   <li>New: {@link Geometry#rayBox} method, its usage in {@link UniformGrid}.
 *   <li>Improved: {@link Search2DWorker} - result logging, graphics output banning.
 *   <li>Improved: speed of {@link VEFDS#adjustAttributes} (called in every *create() method).
 * </ul>
 * <p>16.4.2007 PE:
 * <ul>
 *   <li>Improved: {@link StaticCSGScene} - scene hierarchy, camera and lights are defined externally
 *       (ready to read them from XML script in future).
 *   <li>Improved: {@code ParamCSGScene} - camera and lights are defined here (read from XML script in future).
 *   <li>Improved: {@link SampleRenderWorker}, {@link GridRenderWorker} - no connected {@link LightSource}s.
 *   <li>Todo: all compositions using {@link SampleRenderWorker} have to be fixed!
 * </ul>
 * <p>17.4.2007 PE:
 * <ul>
 *   <li>Fix: all compositions using {@link SampleRenderWorker} were fixed.
 *   <li>Improved: refactorization of the {@link ParamGUI} system, 1st step: internal/String values.
 * </ul>
 * <p>18.4.2007 PE:
 * <ul>
 *   <li>New: {@link JGLScript} module (not finished yet).
 *   <li>New: {@link Formula#vectorToString(double[])} function (diagnostics).
 * </ul>
 * <p>20.4.2007 PE:
 * <ul>
 *   <li>Fix: array parsing in {@link JGLScript}, method invokation.
 *   <li>Improved: Eclipse warnings.
 * </ul>
 * <p>21.4.2007 PE:
 * <ul>
 *   <li>New: {@link Formula#parseStringList} function.
 *   <li>Improved: {@link JGLScript} module (1st version, not attached yet).
 * </ul>
 * <p>22.4.2007 PE:
 * <ul>
 *   <li>Improved: {@link StaticCSGScene} is able to interpret JGL script defining 3D scene.
 *   <li>New: {@link Formula#relativePath} function (limited so far).
 *   <li>Fix: dialog-box coordinates read from options are recomputed according to actual screen size.
 *   <li>New: two JGL scene files.
 *   <li>Improved: string representation should not be editable in {@link ParamSpec}.
 *   <li>Improved: {@code ParamCSGScene} renamed to {@link ParamJGLScript}, will be used for all .JGL script files.
 *   <li>Deleted: {@code ParamAmbientLightSource}, {@code ParamStaticCamera} and {@code ParamStaticPointLightSource}.
 *   <li>Improved: JGL script returns {@code Map< String, Object >} for convenience.
 *   <li>Improved: JGL scripting support added to five other modules (light sources, ray-generators).
 * </ul>
 * <p>23.-24.4.2007 PE:
 * <ul>
 *   <li>New: {@code scenerot.jgl} scene definition (for assignment #24).
 *   <li>New: {@code scripting.html} manual, changes in Ray-tracing HOWTO ({@code rt.html}).
 * </ul>
 * <p>28.4.2007 PE:
 * <ul>
 *   <li>New: time measurement into {@link Render3DWorker}.
 *   <li>New: {@link Formula#colorToString} and {@link Formula#stringValue} functions.
 *   <li>Fix: correct storage of {@link java.awt.Color} parameter value ({@link InputOutputXML}),
 *       affected XML files were fixed too.
 *   <li>Improved: error messages generated in {@link RegPiece}.
 *   <li>Fix: default values of all parameter types are now used in initialization time ({@link ParamGUI},
 *       {@link ParamSpec}, {@link ParamCombo}).
 * </ul>
 * <p>29.4.2007 PE:
 * <ul>
 *   <li>Improved: input plugs shouldn't be mandatory, changes in {@link Template}, {@link RegPiece}, ..
 *   <li>Improved: property tooltips will contain description strings.
 *   <li>Improved: transparency in {@link RayTracing} (not tested yet).
 * </ul>
 * <p>30.4.2007 PE:
 * <ul>
 *   <li>New: {@link MicroFacet#front}: from the {@link Solid}'s point of view.
 *   <li>Improved: small fixes for transparency in {@link RayTracing} system
 *       (not finished yet, but non-transparent stuff still works).
 * </ul>
 * <p>1.5.2007 PE:
 * <ul>
 *   <li>Fix: many transparency-related fixes ({@link StaticPointLightSource}, {@link PhongModel},
 *       {@link RayTracing}, {@link RayCasting}).
 *   <li>Fix: light sources should be bound to the R-T scene (shadow-computing in {@link LightSource#lights}).
 *   <li>Fix: total reflection ({@link Geometry#specularReflection}).
 *   <li>New: Schlick-like adjustments in {@link PhongModel}.
 *   <li>New: {@link RTScene#getBackground} method; background color should be included in scene definition.
 *   <li>New: background color can be defined in JGL script (R-T scene).
 *   <li>Improved: scene accelerators in {@link RayCasting} and {@link RayTracing}.
 * </ul>
 * <p>2.-3.5.2007 PE:
 * <ul>
 *   <li>Improved: {@link RayCasting}, {@link RayTracing}: algorithms' restrictions are now available via {@link Property}.
 *   <li>Fix: {@link StaticPointLightSource} is able to use accelerated ray vs. scene intersections.
 *   <li>Improved: key string definition in {@code <set>} command is now more general ({@link JGLScript}).
 *   <li>Improved: {@link RayTracing} - switching off the "shading" is now more meaningful.
 *   <li>New: {@code data/scenedof.jgl} scene definition (for area-light and/or depth-of-field camera testing).
 * </ul>
 * <p>4.5.2007 PE:
 * <ul>
 *   <li>Fix: image-bounds are handled correctly in {@link JitteringSynthesizer} and {@link AdaptiveJitteringSynthesizer}.
 *   <li>Deleted: obsolete branch {@code compression-src}.
 *   <li>New: 3D scene for Phong-Schlick light model test.
 *   <li>Improved: minor changes in HTML pages (links to Image Gallery, XHTML compliance, ..).
 * </ul>
 * <p>5.5.2007 PE:
 * <ul>
 *   <li>New: branch {@code piece-new} for module candidates.
 *   <li>Improved: {@link UniformGrid} can have only one big cell.
 *   <li>Improved: short class identifiers allowed in {@link Template#propManipulator(java.lang.String)}.
 *   <li>New: package constants {@link Template#JAGRLIB} and {@link Template#JAGRLIB2}.
 *   <li>Improved: short class identifiers in {@link JGLScript}: {@code <class>} element.
 *   <li>Improved: {@link JGLScript} - key string can be defined as a XML attribute ({@code <set key="xx">}).
 *   <li>New: {@code <def>} element in {@link JGLScript} - named literal object (a la {@code #define}).
 *   <li>Fix: {@link JGLScript} - named {@code <object>} should act as immediate value as well.
 *   <li>New: {@link RayGenerator#setAspectRatio} method for later camera setup, many consequent changes.
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 438 - 443.
 *   <li>Improved: {@code phongTest.xml} was enhanced - checker texture was added to the gray ball.
 * </ul>
 * <p>6.5.2007 PE:
 * <ul>
 *   <li>Improved: "clamp" switch into {@link ImageCompute}.
 *   <li>Improved: jittering amplitude into {@link JitteringSynthesizer}, able to set regular
 *       supersampling and semi-jittering.
 * </ul>
 * <p>7.-8.5.2007 PE:
 * <ul>
 *   <li>New: {@link RasterSearch} interface.
 *   <li>Improved: {@code Pixelize} module was renamed to {@link EffectPixelize} (starting a new convention).
 *   <li>Improved: {@link EffectPixelize} moved to package {@code piece}.
 *   <li>New: {@link EffectBlur} module.
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 443 - 449.
 *   <li>Improved: {@code update.sh} script for automatic WWW synchronization.
 * </ul>
 * <p>9.5.2007 PE:
 * <ul>
 *   <li>New: {@link BitStream#canRead} method - determines if the read-mode is set.
 *   <li>New: {@link Piece#init} method - module initialization (multiple phases), has to be run after
 *       property-values setup but before any {@link Runnable#run Worker.run()}.
 *   <li>Improved: consequent changes in many workers, modules and compositions (auto-init-capable modules so far:
 *       ancestors of {@link DefaultGraphicsViewer}, {@link DefaultRasterFileFormat}).
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 449 - 451.
 * </ul>
 * <p>14.5.2007 PE:
 * <ul>
 *   <li>New: interface {@link Breakable} - added to all potentially time-consuming interfaces.
 *   <li>New: user-break mechanism into {@link MainWindow} (two stages: mild and "brute-force").
 *   <li>Improved: composition cleanup after all workers finish their jobs..
 *   <li>Improved: safer user-break (triple mouse click on the "stop" button).
 * </ul>
 * <p>15.5.2007 PE:
 * <ul>
 *   <li>Improved: {@link MainWindow} - brute-force break logging, closing {@link LogFile} stream
 *       after finished composition run.
 * </ul>
 * <p>18.-19.5.2007 PE:
 * <ul>
 *   <li>New: interface {@link ScalarQuantizer}.
 *   <li>New: {@link LinearQuantizer} and {@link FractalCompressionQtree} modules (the later one
 *       is not finished yet).
 *   <li>Improved: {@link Complex#invert}, integer-exponent power functions added to {@link Complex} class.
 *   <li>New: {@link DeadZoneQuantizer} and {@link SampleRasterSearch} modules.
 *   <li>New: {@link HDRImage} constructor using source image resampling.
 * </ul>
 * <p>20.5.2007 PE:
 * <ul>
 *   <li>New: {@link Formula#bits} function (log_2(long) rounded up to the nearest integer).
 *   <li>Improved: {@link FractalCompressionQtree} code is finished but not tested at all (postponing).
 *   <li>Improved: {@link SampleRasterSearch} - convenience of future extensions.
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 451 - 458.
 * </ul>
 * <p>21.5.2007 PE:
 * <ul>
 *   <li>New: {@link IntersectionAttributes} interface and its usage.
 *   <li>Improved: tiny ray-tracing refactorisation (object ids, intersection attributes).
 *   <li>New: {@link Geometry#rayTriangle3D} routine (a la Tomas Moller).
 *   <li>New: {@link BrepSolid} class - B-rep connector for Ray-tracing scenes, not tested yet.
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 458 - 460.
 * </ul>
 * <p>23.-24.5.2007 PE:
 * <ul>
 *   <li>New: {@link DefaultRasterGraphics#drawFrame} method.
 *   <li>Fix: many fixes in fractal-compression system ({@link FractalCompressionQtree},
 *       {@link SampleRasterSearch}, {@link HDRImage}).
 *   <li>Improved: {@link Breakable} interface into {@link DataFileFormat} and {@link ImageCompressionWorker}.
 *   <li>Improved: input object-map can be passed to {@link JGLScript} interpretation routine.
 *   <li>Improved: {@link StaticCSGScene} - {@link Brep} object (optional) can be passed to scene-definition script.
 *   <li>New: test B-rep scene for Ray-tracing.
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 460 - 463.
 * </ul>
 * <p>25.5.2007 PE:
 * <ul>
 *   <li>Improved: {@link AdaptiveJitteringSynthesizer} - super-sampling logging mode converted to property.
 *   <li>New: {@link MicroFacet#epsilon} constant - can be customized by individual {@link Solid}s
 *       ({@link MicroFacet#setEpsilon(double)}).
 *   <li>New: {@link MicroFacet#near} and {@link MicroFacet#far} methods, usage.
 *   <li>Improved: visibility tests in both light-sources (using {@link MicroFacet#far}).
 *   <li>Improved: {@link Breakable} implementation into {@link AudioFilterWorker}.
 *   <li>New: {@link ProgressListener} interface and {@link Breakable#setProgressListener} method, usage.
 *   <li>Improved: progress-indication in all relevant modules &amp; workers..
 *   <li>Improved: {@link RedrawTimer} is able to set preview-window's title.
 * </ul>
 * <p>26.5.2007 PE:
 * <ul>
 *   <li>Improved: {@link CSGNode} uses {@link java.util.ArrayList ArrayList} to store child-node references.
 *   <li>New: {@link Formula#storeFloat}, {@link Formula#loadFloat}, etc. + usage.
 *   <li>Fix: loading list-box values from composition file ({@link ParamCombo}).
 *   <li>New: {@link Formula#timeHMS} function - human-readable time formatting.
 *   <li>New: {@link ProgressCounter} object can compute useful progress results (remaining time) + usage.
 * </ul>
 * <p>30.-31.5.2007 PE:
 * <ul>
 *   <li>Fix: reflected and refracted rays should take only {@code Ks} and {@code Kt} into account
 *       (changes in interface {@link LightModel} and {@link PhongModel} module).
 *   <li>Improved: normal vector handling in {@link BrepSolid} (smooth and shell switches).
 *   <li>Improved: texture coordinates shall be read from B-rep database ({@link BrepSolid}).
 *   <li>Improved: boolean is a new implicit parameter type in JGL script ({@code <val>}).
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 463 - 471.
 *   <li>New: {@link DefaultSolid} ancestor class (convenience) + usage.
 *   <li>New: {@link Plane} CSG solid: infinite plane.
 *   <li>Fix: set operator in {@link MicroFacet} should consider infinite segments.
 * </ul>
 * <p>1.6.2007 PE:
 * <ul>
 *   <li>Improved: {@link Double#MAX_VALUE} etc. replaced by {@link Double#POSITIVE_INFINITY} and
 *       {@link Double#NEGATIVE_INFINITY}.
 *   <li>Improved: generalization of {@link Plane} - will be able to represent rectangle and triangle, too.
 * </ul>
 * <p>2.6.2007 PE:
 * <ul>
 *   <li>New: {@link IntMap#iterator} returns regular iterator, the class implements
 *       the {@link java.util.Collection} interface.
 *   <li>Improved: refactorisation of {@link Brep} and {@link VEFDS} - attributes are stored
 *       in one big array, one common map will accelerate access to them..
 *   <li>New: {@link Geometry#isZero(float)} predicate + usage.
 *   <li>Improved: {@link LightModel} - material constants names (will be used in Wavefront material parsing).
 *   <li>New: {@link PhongMaterial} data object was separated from {@link PhongModel}.
 *   <li>New: {@link DefaultBrepFileFormat} ancestor class.
 *   <li>New: {@link DefaultFileFormat#readLine} method for text file-formats.
 *   <li>New: {@link OBJFileFormat} module (will read Wavefront .OBJ format), not finished yet.
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 471 - 476.
 * </ul>
 * <p>3.6.2007 PE:
 * <ul>
 *   <li>Improved: {@link JavaBitStream} can use underlying {@link java.util.zip.GZIPInputStream GZIPInputStream}
 *       - optional GZIP decompression on-the-fly.
 *   <li>Improved: {@link OBJFileFormat} is finished but some functionality is still missing.
 *   <li>Improved: {@link Piece#init} overridable was moved to {@link DefaultFileFormat} (to be inherited by all
 *       file-format modules).
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 476 - 479.
 * </ul>
 * <p>4.6.2007 PE:
 * <ul>
 *   <li>Improved: {@link JGLScript} - {@code <function>} element is allowed on global level.
 *   <li>Improved: {@link JGLScript} - {@code "null"} value is parsed in the {@code <val>} element.
 *   <li>Improved: {@link VEFDS} - coordinate-type 'set's won't force database re-initialization if not necessary.
 *   <li>Improved: {@link StaticCSGScene} - reference to {@link DataFileFormat} is passed to JGL script (so scripts
 *       can load 3D scene files themselves..).
 *   <li>New: {@code sRayTracingObj.xml} and {@code sceneTeapot.jgl} data files.
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 479 - 483.
 *   <li>Improved: efficiency and generality of {@link UniformGrid}.
 * </ul>
 * <p>5.-6.6.2007 PE:
 * <ul>
 *   <li>Improved: {@link VEFDS} optimization.
 *   <li>Improved: {@link UniformGrid} optimization, two alternative ray-pass iterators.
 * </ul>
 * <p>29.6.2007 PE:
 * <ul>
 *   <li>Merge: from {@code trunk} to {@code opengl} - revisions 303 - 487.
 * </ul>
 * <p>29.6.2007 [opengl] PE:
 * <ul>
 *   <li>Improved: minor changes in {@link Brep} and {@link VEFDS} concerning the
 *       {@link Brep#setSolidFaces} method.
 * </ul>
 * <p>2.7.2007 PE:
 * <ul>
 *   <li>Improved: 3D ray pass in {@link UniformGrid}, pilot version.
 * </ul>
 * <p>6.7.2007 [opengl] PE:
 * <ul>
 *   <li>Fix: ANT build system - JavaDoc, run target (OpenGL branch).
 *   <li>Improved: minor update of the README-opengl.txt.
 *   <li>Improved: ignore list of the "lib" subdirectory.
 *   <li>Fix: JavaDoc warnings in the OpenGL branch + some cosmetics.
 *   <li>Fix: svn:* properties of the new OpenGL files.
 * </ul>
 * <p>22.7.2007 PE:
 * <ul>
 *   <li>Improved: better diagnostic messages in {@link JGLScript}.
 *   <li>Fix: 3D ray pass in {@link UniformGrid}.
 * </ul>
 * <p>23.7.2007 PE:
 * <ul>
 *   <li>Fix: shell mode in {@link BrepSolid}.
 *   <li>New: 3D scene with three teapots ({@code sceneTeapot3.jgl}).
 * </ul>
 * <p>16.8.2007 PE, Tomas:
 * <ul>
 *   <li>New: interfaces for radiosity methods, including systems of linear equations.
 *   <li>New: branch {@code radiosity} for radiosity computations (Tomas will be the main developer)
 * </ul>
 * <p>18.8.2007 [radiosity] Tomas:
 * <ul>
 *   <li>New: modules for pilot radiosity implementation.
 *   <li>Improved: SLE* interfaces.
 *   <li>Improved: {@code GaussSeidel} is generalized in {@code RelaxationMethods}.
 * </ul>
 * <p>18.8.2007 [radiosity] PE:
 * <ul>
 *   <li>Fix: SLE* interfaces, logic of {@code result[]} argument, plug names, SVN attributes.
 *   <li>Fix: solution vector shall be indexed by the {@code col} in {@link SLEData} and {@link SLESolver}.
 *   <li>Fix: last argument of {@link SLEDataStore#setCoeff}.
 *   <li>New: {@link MainSLE} main routine for testing SLE solvers.
 *   <li>New: {@link SimpleSLEDataStore} module - dumb data object storing full rectangular matrix.
 * </ul>
 * <p>20.8.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: Gauss-Seidel solving - solve(), refine()
 * </ul>
 * <p>21.8.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: Gauss-Seidel method - convergence.
 *   <li>Fix: few changes in terminology (better and more strict names).
 *   <li>New: solving by Southwell method {@code RelaxationMethods.southwell()}.
 *   <li>New: pseudocode for progressive method {@code RelaxationMethods.progressive()}.
 * </ul>
 * <p>23.8.2007 [radiosity] Tomas:
 * <ul>
 *   <li>New: pseudocode of hemicube method for F-F computing (constant basis).
 *   <li>New: preprocess for hemicube method.
 *   <li>New: functions operating with basis functions (interface {@link RadiosityBasisFunctions}).
 *   <li>New: implement some get*() methods in {@link RadiosityEquations} module (copied from
 *       {@link SimpleSLEDataStore}).
 *   <li>Improved: progressive refinement.
 * </ul>
 * <p>24.8.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: Gauss-Seidel: using residual of previous step in solving at current
 *       step (faster solving).
 *   <li>Fix: Gauss-Seidel: one step updates only one entry of result (not whole
 *       vector just last time).
 *   <li>Fix: {@link MainSLE} is modified for testing Gauss-Seidel iteration.
 *   <li>Fix: residual computing in Southwell method.
 *   <li>Improved: Gauss-Seidel method moved to individual module.
 * </ul>
 * <p>25.8.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: convergence in Gauss-Seidel and other relaxation methods.
 *   <li>Testing Gauss-Seidel and Southwell iterative methods.
 * </ul>
 * <p>26.8.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: resetting solution in Gauss-Seidel and Southwell method.
 *   <li>Fix: source code repeating in Gauss-Seidel and Southwell method.
 *   <li>Fix: work with data in solving system of linear equations.
 * </ul>
 * <p>27.8.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: getSolution() methods in {@code GaussSeidelIteration}.
 *   <li>Fix: {@code RelaxationMethods.reset()} function.
 *   <li>Fix: implicit constructor in {@code GaussSeidelIteration}.
 *   <li>Fix: source code repeating in {@code GaussSeidelIteration}.
 *   <li>Fix: {@code RelaxationMethods.update()} function.
 *   <li>Fix: getSolution() methods in {@code RelaxationMethods}.
 *   <li>New: Monte Carlo methods for F-F computing.
 * </ul>
 * <p>28.8.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@code RelaxationMethods.update()} and {@code GaussSeidelIteration.update()} function
 *   <li>Fix: {@code RelaxationMethods.reset()} function.
 *   <li>Fix: solving by Southwell method in {@code RelaxationMethods}.
 *   <li>Fix: repeating source code in Southwell solving method in {@code RelaxationMethods}.
 * </ul>
 * <p>29.8.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@code GaussSeidelIteration.getSolution()} and {@code RelaxationMethods.getSolution()}.
 *   <li>Fix: conversion element to coeficients {@code MonteCarloDiffAA.coefficientsFromElement()}.
 *   <li>Improved: module {@link MonteCarloFF} has renamed to {@code MonteCarloDiffAA}.
 *   <li>New: pseudocode for Monte Carlo area-to-area for F-F computing.
 *   <li>New: Monte-Carlo Area-to-Area moved to individual module.
 * </ul>
 * <p>3.9.2007 [radiosity] Tomas:
 * <ul>
 *   <li>New: supported sample collections for Monte Carlo methods.
 *   <li>New: implemented uniform random hemisphere sampling.
 *   <li>New: implemented systematic hemisphere sampling.
 *   <li>New: implemented stratified hemisphere sampling.
 * </ul>
 * <p>5.9.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@code RadiosityFunctions.getOrder()} is generalized (returns value
 *       in dependence on brep).
 *   <li>Improved: computing F-F by Monte Carlo hesmisphere sampling
 *       {@code MonteCarloDiffAA}.
 *   <li>Improved: get*() functions in {@link RadiosityEquations}.
 *   <li>Improved: {@link RadiosityEquations#getRight}.
 *   <li>Improved: {@link RadiosityEquations#getSolution}.
 *   <li>Improved: {@link RadiosityEquations#setSolution}.
 * </ul>
 * <p>10.9.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: attention of output modules {@link RadiosityEquations#getRows}.
 *   <li>Improved: attention of output modules {@code RadiosityEquations.getCols()}.
 *   <li>Improved: {@link RadiosityEquations#getCoeff} is now support
 *       non-constant basis.
 *   <li>Improved: {@link RadiosityEquations#getRow} is now support
 *       non-constant basis.
 *   <li>Improved: {@link RadiosityEquations#getColumn} is now support
 *       non-constant basis.
 *   <li>Improved: {@link RadiosityEquations#getMatrix} is now support
 *       non-constant basis.
 *   <li>Improved: protected methods for getting single coefficients.
 *   <li>Improved: overall security for attention of output modules.
 *   <li>Improved: accelerator - output interfaces are now stored in
 *       {@link RadiosityEquations}.
 *   <li>New: protected method {@code RadiosityEquations.initializeE()} for create
 *       new attribute (emission) in Brep.
 *   <li>New: protected method {@code RadiosityEquations.initializeB()} for create
 *       new attribute (result) in Brep.
 * </ul>
 * <p>13.9.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: module registration in {@link RadiosityEquations}.
 *   <li>Fix: initialization of array elements in {@code RadiosityEquations.getP()}.
 *   <li>Fix: {@code RadiosityEquations.getP()} was totally reworked.
 *   <li>Fix: copying arrays in {@code GaussSeidelIteration}.
 *   <li>Improved: {@code RadiosityEquations.getM()} is now support non-constant basis too.
 *   <li>Improved: security of methods (getting interfaces) in {@code GaussSeidelIteration}.
 * </ul>
 * <p>15.9.2007 [radiosity] Tomas:
 * <ul>
 *   <li>{@link MonteCarloFF} and {@code MonteCarloDiffFF} are merged into
 *       {@link MonteCarloFF}.
 *   <li>Improved: uniform sampling method.
 *   <li>New: Malley's method.
 * </ul>
 * <p>17.9.2007 [radiosity] Tomas:
 * <ul>
 *   <li>New: scene illumination computation {@link Radiosity#illuminate}.
 *   <li>Improved: illumination computation (timer).
 * </ul>
 * <p>22.9.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: SLE solving methods.
 * </ul>
 * <p>23.9.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: initializing variables (system of linear equations) in SLE solver.
 *   <li>Improved: Progressive refinement for SLE solving.
 *   <li>New: overshooting method for SLE solving.
 *   <li>New: new module for Super-Shoot-Gather method (SLE solving).
 * </ul>
 * <p>24.9.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: convergence and computing in {@link SuperShootGather}.
 * </ul>
 * <p>25.9.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: log file.
 *   <li>Fix: bugs in SLE loading and getting.
 *   <li>New: saving into database in {@link Radiosity}.
 * </ul>
 * <p>30.9.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: comments in {@code RelaxationMethods}, {@link Radiosity},
 *                 {@link SuperShootGather}, {@code GaussSeidelIteration},
 *                 {@link MonteCarloFF} and {@link RadiosityEquations}.
 *   <li>New: worker for global illumination methods.
 *   <li>New: interface property for {@link GlobalIlluminationWorker}.
 *   <li>Fix: maximal time.
 * </ul>
 * <p>1.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: some bugs in {@link GlobalIlluminationWorker}.
 *   <li>Fix: Interface Property in {@link MonteCarloFF}.
 *   <li>New: module registration {@link GlobalIlluminationWorker},
 *            {@link MonteCarloFF}, {@link RadiosityEquations},
 *            {@code GaussSeidelIteration}, {@link Radiosity}.
 *   <li>New: .xml file for pilot radiosity application.
 *   <li>Improved: .xml file for pilot radiosity application.
 * </ul>
 * <p>2.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: "coeff->element" and "element->coeff" transform methods in {@link MonteCarloFF}.
 *   <li>Improved: rays generating in {@link MonteCarloFF}.
 *   <li>Improved: intersection of ray a scene in {@link MonteCarloFF}.
 *   <li>Improved: .xml file for pilot radiosity implementation.
 *   <li>New: module for intersection computing (ray x B-rep) with acceleration by geometric search structures.
 * </ul>
 * <p>4.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: using {@link Piece#getInterface}.
 *   <li>Fix: ray generating in {@link MonteCarloFF}.
 * </ul>
 * <p>6.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: generating rays in {@link MonteCarloFF}.
 *   <li>Fix: generating numbers in {@link MonteCarloFF}.
 *   <li>Fix: sampling on the triangle in {@code MonteCarloFF.generateRaysForShooting()}.
 * </ul>
 * <p>7.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: intersection computing (ray x B-Rep) in {@link MonteCarloFF}.
 *   <li>Improved: .xml file for pilot radiosity implementation.
 *   <li>Improved: saving and solving system of linear equations in {@code GaussSeidelIteration}.
 * </ul>
 * <p>7.10.2007 PE:
 * <ul>
 *   <li>New: {@link BrepSolidDirectory} module (supported by general {@link GeometrySearch}).
 *   <li>Improved: {@link RenderWireframe} - new drawing mode (vertices only).
 *   <li>Improved: {@link BitStream} semantics - {@link BitStream#position} can be used even after
 *       output-stream close.
 *   <li>Improved: {@link OBJFileFormat} can save B-rep mesh (only "v", "vn", "vt" and "f" lines
 *       are supported, not tested yet).
 * </ul>
 * <p>8.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: convergence in {@code GaussSeidelIteration.gaussSeidel()},
 *            {@code GaussSeidelIteration.gathering()},
 *            {@code GaussSeidelIteration.southwell()}
 *   <li>Fix: initializing SLE in {@code GaussSeidelIteration}.
 *   <li>Improved: MainSLE for testing SLE solving.
 *   <li>New: gathering method for SLE solving in {@code GaussSeidelIteration}.
 * </ul>
 * <p>8.10.2007 PE:
 * <ul>
 *   <li>Fix: both {@link BitStream#position} implementations (should be more universal).
 *   <li>New: {@link CompressionWorker} - universal worker for data compression
 *       (preprocessing/encoding/reconstruction/save) with reconstruction-error measurement
 *       capability and graphic data preview.
 * </ul>
 * <p>9.10.2007 PE:
 * <ul>
 *   <li>New: {@link MicroFacet#face} - face Id for {@link Brep}-intersections.
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 483 - 548.
 * </ul>
 * <p>9.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: few bugs in SLE solving in {@code GaussSeidelIteration}.
 *   <li>Improved: MainSLE is return to previous form (only with few differences).
 *   <li>New: Handle of face, which is intersected by ray in {@link MicroFacet}.
 *   <li>New: few rows for debugging in {@code GaussSeidelIteration}.
 * </ul>
 * <p>10.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: computing residual in {@code GaussSeidelIteration}.
 *   <li>Fix: plugs in {@link Radiosity}.
 *   <li>Fix: .xml file for pilot radiosity implementation.
 *   <li>Fix: some other things in module communication (in radiosity application).
 * </ul>
 * <p>13.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: MicroFacet - handle removed (replaced by face).
 *   <li>Fix: many bugs in radiosity implementation.
 * </ul>
 * <p>14.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: sampling of planar triangle.
 *   <li>Fix: sampling of hemisphere.
 * </ul>
 * <p>15.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: using B-rep in {@link MonteCarloFF}.
 *   <li>Fix: triangle sampling in {@link MonteCarloFF}.
 * </ul>
 * <p>16.10.2007 PE:
 * <ul>
 *   <li>New: {@link Lissajous} module (drawing specimen), sDraw.xml.
 * </ul>
 * <p>17.10.2007 PE:
 * <ul>
 *   <li>New: {@link LineAntialias} module (the old {@code LineAntialiasReal} will
 *       be renamed to {@link LineAntialiasSimple}).
 *   <li>Deleted: {@code cz.cuni.jagrlib.testing.LineAntialias} module (obsolete specimen).
 *   <li>Fix: all {@code LineAntialias*} modules, their usage, consequent changes.
 *   <li>Improved: arrangements for "piece-new" merge (registration of new modules,..)
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 548 - 559.
 * </ul>
 * <p>18.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: Southwell iteration in {@code GaussSeidelIteration}.
 *   <li>Improved: Gauss-Seidel iteration {@code GaussSeidelIteration}.
 *   <li>Improved: gathering algorithm {@code GaussSeidelIteration}.
 *   <li>Improved: initializing in {@code GaussSeidelIteration}.
 *   <li>New: solving SLE by {@link SuperShootGather}.
 *   <li>New: solving SLE by shooting.
 *   <li>Fix: solving in {@link SuperShootGather}.
 * </ul>
 * <p>18.10.2007 PE:
 * <ul>
 *   <li>Improved: most Java 1.6 warnings were resolved.
 *   <li>Deleted: Eclipse 3.1 workspace (3.2 workspace is retained).
 * </ul>
 * <p>19.10.2007 PE:
 * <ul>
 *   <li>New: {@link OrderSFC} module (only two methods are implemented so far: Morton, Hilbert).
 * </ul>
 * <p>20.10.2007 PE:
 * <ul>
 *   <li>Fix: epilogue coding in {@link MeshCompressionRLE}, arbitrary image size was tested.
 *   <li>New: meandred Peano curve in {@link OrderSFC}.
 *   <li>New: plain Peano curve in {@link OrderSFC}.
 * </ul>
 * <p>21.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: getting reflectance from Brep in {@code RadiosityEquations.getP()}.
 *   <li>Fix: SLE solving bug in {@link Radiosity}.
 *   <li>Improved: convergence in SLE solving methods.
 *   <li>Improved: setting residual.
 *   <li>Improved: MainSLE and {@link GlobalIlluminationWorker}.
 *   <li>New: user can limit total max iterations in SLE solving.
 * </ul>
 * <p>21.10.2007 PE:
 * <ul>
 *   <li>Improved: line drawing using internal support modules in {@link Lissajous}.
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 559 - 567.
 *   <li>Improved: {@link FloodFillWorker} is now more robust, consequent changes.
 *   <li>Improved: {@link ImageFilterWorker} can be animated.
 *   <li>New: animated composition sDrawAnim.xml.
 * </ul>
 * <p>22.10.2007 PE:
 * <ul>
 *   <li>Improved: {@link Ellipse} module moved to the {@code piece} package, tilted ellipses
 *       supplemented by a variant of Bond's algorithm (adapted from Bohdan Kolecek's code).
 * </ul>
 * <p>23.10.2007 PE:
 * <ul>
 *   <li>Fix: image initialization in {@link Lissajous}.
 *   <li>Improved: default animation in sDrawAnim.xml.
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 567 - 572.
 *   <li>Improved: {@link Solid#intersection} JavaDoc documentation.
 * </ul>
 * <p>24.10.2007 PE:
 * <ul>
 *   <li>New: {@link KDTree} interface (discrete K-D-tree).
 *   <li>Improved: less complicated Eclipse-howto section (using Ant buildfile).
 *   <li>New: {@link ImageKDTree} module - discrete implementation of K-D-tree for raster image
 *       data representation (only space-balanced construction, not tested yet).
 * </ul>
 * <p>24.10.2007 PE:
 * <ul>
 *   <li>Improved: {@link CompressedFormatPal} is now more robust in handling non-palette images.
 * </ul>
 * <p>28.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: register of total max iterations.
 *   <li>Fix: {@link MonteCarloFF} in sRadiosity.xml.
 *   <li>New: {@link MainFormFactors} for form factors debugging.
 *   <li>New: {@code HierarchicalRadiosity} for hierarchical radiosity computing.
 * </ul>
 * <p>31.10.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link MainFormFactors} - connection of modules.
 *   <li>Fix: sampling on the triangle (y was always set on value 10) in {@link MonteCarloFF}.
 * </ul>
 * <p>2.11.2007 PE:
 * <ul>
 *   <li>Improved: Swing-related cleanup in Skel: part 1 (plug drawing, paintComponent() instead
 *       of paint(), module selection).
 *   <li>Improved: Swing-related cleanup in Skel: part 2 (updateUI() changed to repaint() or
 *       validate()).
 *   <li>Improved: interactive repainting (channels, plugs).
 *   <li>Improved: interactive repainting (module dragging).
 *   <li>Fix: SelectAll command (redraw).
 *   <li>New: keyboard accelerators in {@link MainWindow}.
 *   <li>New: window close command ({@link MainWindow}).
 *   <li>Improved: changes in keyboard accelerators.
 * </ul>
 * <p>3.11.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link RandomJames#randomPointFromTriangle} is used again.
 *   <li>Fix: {@link MainFormFactors} - connection of modules.
 *   <li>Improved: {@link MainFormFactors} - computing form factors.
 *   <li>Improved: {@link RadiosityEquations} - syntax of variables.
 *   <li>New: transformation direction from tangent space to world space.
 * </ul>
 * <p>3.11.2007 PE:
 * <ul>
 *   <li>Improved: ParameterHeight option defines the height of GUI parameter edit-line.
 *   <li>Fix: {@link Options#getInteger} usage.
 *   <li>Fix: {@code Replace Piece} command: mapping compatible but differently named plugs.
 *   <li>Improved: some image-compression compositions are using {@link CompressionWorker} now.
 *   <li>New: Gouraud color interpolation in {@link RenderDepthBuffer} (not debugged yet).
 * </ul>
 * <p>4.11.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: transformation directions from tangent space to world space.
 *   <li>Fix: computing F-F in {@link MonteCarloFF}.
 *   <li>Improved: test program for F-F computing - {@link MainFormFactors}.
 *   <li>Fix: computing F-F in {@link MainFormFactors}.
 *   <li>Improved: computing F-F {@link MainFormFactors}.
 * </ul>
 * <p>4.11.2007 PE:
 * <ul>
 *   <li>Improved: color multiplier property to {@link Test3DScene} + consequent changes.
 *   <li>Fix: {@link Formula#remainder} and its usage.
 *   <li>Fix: Gouraud interpolation in {@link RenderDepthBuffer}.
 *   <li>Improved: vertex-color mapping in {@link Test3DScene}.
 * </ul>
 * <p>5.11.2007 PE:
 * <ul>
 *   <li>Improved: less saturated default color for selected module border.
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 572 - 597.
 *   <li>Merge: from {@code trunk} to {@code radiosity} - revisions 550 - 598.
 * </ul>
 * <p>5.11.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: few bugs in radiosity application.
 *   <li>New: solver for hierarchical radiosity {@code HierarchicalRadiositySolver}.
 * </ul>
 * <p>7.11.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: some bugs in if ().
 * </ul>
 * <p>7.11.2007 PE:
 * <ul>
 *   <li>Improved: {@link Piece#userBreak} is used in {@link OrderedDither}.
 *   <li>Improved: simulated gamma-exponent in {@link OrderedDither}.
 *   <li>Fix: two bad format-strings (in user-break messages).
 *   <li>Improved: {@link Piece#userBreak} is used in {@link Lissajous}.
 *   <li>New: {@link SFCDither} module and sDitherSFC.xml.
 *   <li>Improved: blue-noise option (random threshold perturbation) in {@link SFCDither}.
 * </ul>
 * <p>11.11.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: module RayIntersector was unregistered.
 *   <li>Improved: {@link RadiosityEquations#getRight}.
 *   <li>New: sRadiosityPilot.xml for pilot radiosity implementation (use {@link BrepSolid} instead {@link BrepSolidDirectory}).
 * </ul>
 * <p>12.11.2007 PE:
 * <ul>
 *   <li>Improved: getting rid of non-UNICODE accented characters (Czech comments..).
 * </ul>
 * <p>13.11.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: RayIntersector was removed from regdata.xml.
 *   <li>New: module for generating Cornell Box - {@code CornellBoxGenerator}.
 *   <li>New: {@code CornellBoxGenerator} registered (but not completed and tested yet).
 *   <li>New: new radiosity application with scene, which is generated by {@code CornellBoxGenerator}.
 * </ul>
 * <p>19.11.2007 PE:
 * <ul>
 *   <li>Improved: tiny things in {@link Colormap332}.
 * </ul>
 * <p>20.11.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@code CornellBoxGenerator} now only dividing scene (input
 *            geometry must be loaded by usual way) -> name of this module should be changed.
 *   <li>Fix: {@code CornellBoxGenerator} re-registered.
 *   <li>Fix: sRadiosityGen.xml.
 *   <li>Fix: bug in dividing scene.
 * </ul>
 * <p>21.11.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: dividing scene by {@code CornellBoxGenerator}.
 *   <li>New: sRender3DDividing.xml.
 * </ul>
 * <p>22.11.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: {@link RadiosityEquations} now work with emission term correctly.
 *   <li>Improved: sRender3DDividing.xml and sRadiosityGen.xml.
 *   <li>Improved: property of {@code CornellBoxGenerator} - emission term can be disabled.
 *   <li>New: emission term in {@code CornellBoxGenerator}.
 * </ul>
 * <p>25.11.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: Jacobi and Southwell iteration methods in {@code GaussSeidelIteration}.
 * </ul>
 * <p>25.11.2007 PE:
 * <ul>
 *   <li>Fix: compression contexts in dictionary methods {@link LZWCodec} and {@link ZLIBCodec}
 *       (separate internal compressors cannot be used).
 *   <li>Improved: limits, constants in arithmetic coding.
 * </ul>
 * <p>27.11.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: few bugs in {@code CornellBoxGenerator}.
 *   <li>Improved: sRender3DDividing.xml and sRadiosityGen.xml.
 *   <li>Improved: {@link SuperShootGather} (but still doesn't work correctly).
 *   <li>New: in {@code CornellBoxGenerator} is now supported only tesselation
 *       which compute center of the triangle and create 3 new vertices.
 * </ul>
 * <p>1.12.2007 PE:
 * <ul>
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 597 - 622.
 * </ul>
 * <p>2.12.2007 PE:
 * <ul>
 *   <li>New: {@link WheelOfFortune} interface - static precursor of {@link EntropyHistogram}.
 *   <li>Improved: all entropy-codecs are able to use static {@link WheelOfFortune} for
 *       encoding/decoding.
 *   <li>New: {@link StraightRoulette} module - simple set of equal intervals.
 * </ul>
 * <p>2.12.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@code CornellBoxGenerator} was renamed to {@code SceneDivider}.
 *   <li>Fix: few bugs in {@code SceneDivider}.
 *   <li>New: new {@code CornellBoxGenerator} was added and now really creating Cornell box.
 * </ul>
 * <p>3.12.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@code GaussSeidelIteration} was renamed to {@code IterationMethods}.
 *   <li>Fix: {@code IterationMethods} - solving method gathering was removed.
 *   <li>Fix: {@code RelaxationMethods} - solving method shooting was removed.
 *   <li>Fix: few bugs in {@code RelaxationMethods}, {@code IterationMethods}
 *       and {@link SuperShootGather}.
 *   <li>Fix: {@code Hemicube} and {@code SinglePlaneMethod} was removed.
 *   <li>Fix: {@code SceneDivider} was renamed to {@code SceneSubdivision}.
 *   <li>Fix: {@code CornellBoxGenerator} was renamed to {@link CornellBox}.
 *   <li>Fix: {@code GaussSeidelIteration} and {@code CornellBoxGenerator} was
 *       unregistered because they doesn't exist.
 *   <li>Fix: sRadiosityGen.xml and sRender3DDividing.xml applications.
 *   <li>Improved: property of {@link CornellBox}.
 *   <li>New: {@code GaussSeidelIteration} was renamed to {@code IterationMethods}.
 * </ul>
 * <p>7.12.2007 PE:
 * <ul>
 *   <li>Improved: log-file format of branches/log.txt.
 *   <li>Merge: from {@code trunk} to {@code opengl} - revisions 487 - 633.
 * </ul>
 * <p>7.12.2007 [opengl] PE:
 * <ul>
 *   <li>Improved: JOGL library update (1.1.1-rc6).
 * </ul>
 * <p>8.12.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: {@link CornellBox} can create any quadrilateral.
 *   <li>Improved: vertices in {@link CornellBox} are now same as in original Cornell Box.
 *   <li>Improved: property of {@link CornellBox}.
 *   <li>New: variety of interiors in {@link CornellBox}.
 * </ul>
 * <p>8.12.2007 [opengl] PE:
 * <ul>
 *   <li>Deleted: {@code GLTestWorker} worker (redundant with {@code GLBrepWorker}).
 *   <li>Improved: coding style &amp; cosmetics mostly in the "opengl" branch.
 *   <li>Improved: code reuse in {@code GLBrepWorker}.
 *   <li>Improved: {@code GLBrepWorker} renamed to {@link GLWorker}.
 *   <li>New: FPS-estimate in {@link GLWindow}.
 *   <li>Changed: {@code GLBrepScene} renamed to {@link GLBrepRender}.
 *   <li>Improved: {@link Brep} attributes are used in {@link GLBrepRender} shading.
 *   <li>Improved: coding style, comments and little improvements in {@link SimpleGLGraphics}.
 * </ul>
 * <p>8.12.2007 stuchl:
 * <ul>
 *   <li>Merge: from {@code opengl} to {@code trunk} - revisions 642 - 642 (both HEAD).
 * </ul>
 * <p>9.12.2007 PE:
 * <ul>
 *   <li>Synchronization point between {@code trunk} and {@code opengl} (rev. 645).
 *   <li>Merge: from {@code piece-new} to {@code trunk} - revisions 622 - 645.
 *   <li>Synchronization point between {@code trunk} and {@code piece-new} (rev. 647).
 * </ul>
 * <p>9.12.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: quadrilateral creating in {@link CornellBox}.
 *   <li>Fix: data in {@link CornellBox}.
 *   <li>Fix: vertex computing in {@link CornellBox}.
 *   <li>Improved: property of {@link CornellBox}.
 * </ul>
 * <p>10.12.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: data in {@link CornellBox}.
 *   <li>Removed: few items in property in {@link CornellBox}.
 *   <li>New: algorithm for creating quad in {@link CornellBox}.
 * </ul>
 * <p>10.12.2007 [radiosity] PE:
 * <ul>
 *   <li>Improved: {@link CornellBox} - coding-style, reduced data redundancy,
 *       color attributes,..
 * </ul>
 * <p>11.12.2007 [radiosity] Tomas:
 * <ul>
 *   <li>New: {@link CornellBox} - automatic tesselation ...
 * </ul>
 * <p>11.12.2007 PE:
 * <ul>
 *   <li>New: {@link WheelOfFortune}-access methods into the {@link EntropyCodec} interface.
 *   <li>Improved: interactive projection refactorization ({@link InteractiveProjection},
 *       {@link ProjectionWorker}).
 *   <li>New: additional view-transform settings to {@link Render3D} - inspired by <b>OpenGL</b> +
 *       some consequent changes (not finished yet).
 *   <li>New: API changes implemented in {@link DefaultRender3D}.
 *   <li>Improved: {@link Render3D} interface added to {@link GLBrepRender}, the interactive
 *       projection setup is not finished yet..
 * </ul>
 * <p>12.12.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: {@link CornellBox} - coding-style, number of cells computing...
 *   <li>Removed: {@code GaussSeidelIteration}
 *   <li>Improved: {@link CornellBox} - data of CornellBox (emission ...)
 * </ul>
 * <p>12.12.2007 [radiosity] PE:
 * <ul>
 *   <li>Improved: automatic tesselation in {@link CornellBox}.
 * </ul>
 * <p>13.12.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link Radiosity} - interpolation into vertices, ..
 *   <li>Improved:  {@link GlobalIlluminationWorker} - property, ..
 *   <li>Removed: {@code IterationMethods}, {@code RelaxationMethods} and {@link SuperShootGather}
 *                - maxIter (total maximal number of iterations).
 * </ul>
 * <p>15.12.2007 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: {@link CornellBox} array col renamed to colors.
 *   <li>Improved: {@link Radiosity} - clamp(), comments, ..
 *   <li>New: {@link Radiosity} - saving results without Gouraud interpolation.
 *   <li>Fix: {@link GlobalIlluminationWorker} - variable maxTime..
 *   <li>{@link GlobalIlluminationWorker}, {@link Radiosity} - re-registered
 *   <li>Improved: {@link GlobalIlluminationWorker} - selectable view, ..
 *   <li>Improved: sRadiosityGen.xml - camera position ..
 *   <li>Fix: {@link Radiosity} - code duplication, ..
 *   <li>Fix: {@link GlobalIlluminationWorker} - code duplication, ..
 * </ul>
 * <p>16.12.2007 [radiosity] Tomas:
 * <ul>
 *   <li>{@code sRadiosityGen} was renamed to {@code sRadiosity}
 *   <li>Improved: {@code sRadiosity} - now using {@link BrepSolidDirectory}
 *       instead {@link BrepSolid}
 *   <li>Fix: {@link Radiosity} - light emission, ..
 *   <li>Improved: {@link GlobalIlluminationWorker} - coding-style, property, ..
 *   <li>Improved: {@link MonteCarloFF} - coding-style, bugs ..
 *   <li>Improved: {@link Radiosity} - accuracy, property, ..
 *   <li>Improved: {@link MonteCarloFF} - hemisphere sampling, lucidity of code, ..
 * </ul>
 * <p>16.12.2007 PE:
 * <ul>
 *   <li>Improved: OpenGL changes related to Eclipse (Eclipse project, warnings..).
 * </ul>
 * <p>18.12.2007 [radiosity] Tomas:
 *   <li>Improved: {@link GlobalIlluminationWorker} - time counting, ..
 *   <li>Improved: {@link CornellBox} - light emission, ..
 * </ul>
 * <p>17.12.2007 PE:
 * <ul>
 *   <li>Fix: run script for UNIX (OpenGL support).
 *   <li>Improved: {@link TrMatrix}-to-array conversions.
 *   <li>Fix: projection system in {@link TrMatrix} (should be compatible with OpenGL),
 *       consequent changes in many modules.
 *   <li>Fix: field-of-view is now defined by a total angle in degrees ({@link TrMatrix},
 *       many data files).
 *   <li>Improved: three-phase projection in {@link RenderWireframe},
 *       {@link InteractiveProjection}.
 *   <li>New: {@link DefaultRender3D#checkMatrix} for SW rendering - emulates OpenGL
 *       projection system.
 *   <li>New: interactivity in {@code sGLobjInt.xml}, {@code sProjectionGL.xml},
 *       {@code sGLbrep.xml}.
 * </ul>
 * <p>2.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: {@link MonteCarloFF} - solving of whole column ..
 *   <li>Deleted: {@code HierarchicalRadiosity} and {@code HierarchicalRadiositySolver}
 * </ul>
 * <p>3.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: {@link MainFormFactors} - supports for eazy method switching,
 *       now using Cornell box instead loading *.obj ..
 *   <li>Improved: {@code RelaxationMethods} - now supports overshooting and hyper-relaxation
 *   <li>New: {@code SinglePlaneMethod} - for FF solving ..
 *   <li>New: {@code Hemicube} - for FF solving ..
 * </ul>
 * <p>5.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link MonteCarloFF} - column computation ..
 *   <li>Improved: {@code SinglePlaneMethod} and {@code Hemicube} - computing of FF
 *   <li>Improved: {@code RelaxationMethods} - all methods are now in one procedure ..
 *   <li>New: {@code RelaxationMethods} - now supports overshooting with ambient term
 *   <li>New: {@code IterationMethods} - now supports hyperrelaxation
 *   <li>Fix: {@code RelaxationMethods} - solving by overshooting and overshooting with ambient term
 *   <li>Fix: {@code IterationMethods} - solving by hyperrelaxation, property ..
 *   <li>Fix: few bugs in {@code IterationMethods}.
 * </ul>
 * <p>6.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>{@code IterationMethods}->{@link SLERelaxation} - property, bug-fix
 *   <li>{@code RelaxationMethods} - property, simplification of code ..
 * </ul>
 * <p>7.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@code RelaxationMethods} - GaussSeidel, Jacobi algorithm ..
 *   <li>Fix: {@code RelaxationMethods} - Jacobi, Southwell algorithm ..
 *   <li>Fix: {@code RelaxationMethods} - bugs
 *   <li>Fix: {@code RelaxationMethods} - Southwell
 *   <li>Improved: {@link MainSLE} - better testing of SLE, easier switching, smarter saving, ..
 * </ul>
 * <p>7.1.2008 [radiosity] PE:
 * <ul>
 *   <li>Fix: interfaces {@link SLEData} and {@link SLESolver} should inherit from {@link Property}.
 *   <li>Fix: access methods in {@link SLERelaxation}.
 *   <li>Fix: iteration initialization (reset) in {@link SLERelaxation}.
 *   <li>Improved: registration and properties in SLE solving: invisible {@code Steps}, etc.
 *   <li>Improved: {@link MainSLE} - command-line parameters, logging, flexibility, ..
 *   <li>Fix: SVN properties.
 * </ul>
 * <p>8.1.2008 [radiosity] PE:
 * <ul>
 *   <li>Fix: Jacobi iteration in {@link SLERelaxation} (2nd residual vector does the trick).
 * </ul>
 * <p>8.1.2008 PE:
 * <ul>
 *   <li>Fix: false {@code @Override-s} in {@link GLWindow}.
 *   <li>New: winged-edge capabilities added to {@link Brep} and {@link VEFDS}
 *       (no implementation yet).
 *   <li>New: winged-edge implementation in {@link VEFDS}.
 *   <li>Updated: the {@link EulerOperators} interface (only 1st six simple operators).
 * </ul>
 * <p>10.1.2008 PE:
 * <ul>
 *   <li>Updated: eval-plugin {@link Ex2005_07_a} to meet assignment #67 conditions,
 *       relevant evaluation script was added.
 *   <li>Updated: the rest of {@link EulerOperators} interface (1st version).
 * </ul>
 * <p>12.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: {@code RelaxationMethods} renamed to {@link SLEProgressive}.
 *   <li>Improved: {@link SLEProgressive} - comments, property, ambient term, ..
 *   <li>Improved: {@link SLEData} - support for weight and reflectance ..
 *   <li>Improved: {@link RadiosityEquations} - support for weight and reflectance ..
 * </ul>
 * <p>15.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link MonteCarloFF}, {@link RadiosityEquations} - computing of size of element (triangle).
 *   <li>Improved: {@link Radiosity} - property, logging of information, ..
 *   <li>Improved: {@link MainSLE} - few little changes ..
 *   <li>Improved: modules are re-registered
 *   <li>Improved: {@link SuperShootGather} - property, comments, ..
 *   <li>New: sRadiosityRelax.xml, sRadiosityRelaxAcc.xml, sRadiosityProg.xml,
 *            sRadiosityProgAcc.xml, sRadiositySSG.xml, sRadiositySSGAcc.xml
 *   <li>Removed: sRadiosity.xml
 *   <li>Fix: {@link RadiosityEquations} - few bugs
 *   <li>New: sRadiosityOBJ.xml, sRadiosityOBJAcc.xml
 *   <li>Deleted: sRadiosityPilot.xml
 *   <li>Deleted: {@code SceneSubdivision} - useless module
 * </ul>
 * <p>16.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link SLERelaxation} - dividing of zero ..
 *   <li>Improved: {@link MainSLE} - easier of FF testing
 *   <li>Improved: {@link Radiosity} - swap of epsilon and accuracy (now
 *                 have got same sence as in SLE solvers)
 * </ul>
 * <p>19.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link MonteCarloFF} - generating of directions
 *   <li>Improved: {@link SLEDataStore} - set() function for weights and reflectances
 *   <li>Improved: {@link SimpleSLEDataStore} - set() function for weights and reflectances
 *   <li>Fix: {@link MonteCarloFF} - generating of directions
 * </ul>
 * <p>20.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link MonteCarloFF} - transform to TBN, ..
 * </ul>
 * <p>21.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link MonteCarloFF} - transform to TBN (tested), ..
 *   <li>Fix: {@link CornellBox} - now using original emission spectrum
 *   <li>New: {@link SLEData} - new property identifier (total residual)
 *   <li>New: {@link SLERelaxation} and {@link SLEProgressive} - total residual
 * </ul>
 * <p>23.1.2008 PE:
 * <ul>
 *   <li>Merge: from {@code trunk} to {@code radiosity} - revisions 598 - 700.
 * </ul>
 * <p>26.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link CornellBox} - light was put a little below (incorrect rendering)
 *   <li>Fix: {@link GlobalIlluminationWorker} - projection (like in {@link Render3DWorker})
 *   <li>Fix: {@link SLEProgressive} - ambient term (2nd result vector does the trick)
 * </ul>
 * <p>27.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link CornellBox} - size of light source, light emission spectrum, ..
 *   <li>Fix: {@link MonteCarloFF} - caching of form factors
 *   <li>Removed: {@link MonteCarloFF} - basis types (constant, linear, quadratic)
 * </ul>
 * <p>29.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link MonteCarloFF} - input of functions
 *   <li>Fix: {@link SLEProgressive} - total residual count
 *   <li>New: {@link MonteCarloFF} - new types of sampling (not complete yet)
 * </ul>
 * <p>31.1.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: restore of old build.xml
 * </ul>
 * <p>2.2.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link SuperShootGather} - solving
 *   <li>Fix: {@link RadiosityEquations} - bug in {@link RadiosityEquations#getRight}
 *   <li>Improved: {@link SLEProgressive} - variable declaring
 *   <li>New: {@link SuperShootGather} - ambient term
 * </ul>
 * <p>3.2.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: {@link SuperShootGather} - usage of memory
 * </ul>
 * <p>4.2.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: {@link MonteCarloFF} - caching of form factors (now
 *       are cached only rows, colums are computed by reciprocity rule)
 * </ul>
 * <p>10.-11.2.2008 PE:
 * <ul>
 *   <li>Improved: modification-time needs to be preserved in {@link Enigma}.
 * </ul>
 * <p>14.2.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Deleted: not accelerated radiosity application (e.g. sRadiosityRelax)
 *   <li>Renamed: accelerated application are renamed (e.g. sRadiosityRelaxAccel - sRadiosityRelax)
 *   <li>Improved: {@link GlobalIlluminationWorker} - computation of modelview matrix
 *   <li>Improved: {@code sRadiosityRelax}, {@code sRadiosityProg.xml} and
 *       {@code sRadiositySSG} - viewpoint change
 * </ul>
 * <p>1.3.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Deleted: modules Hemicube and SinglePlaneMethod
 *   <li>Improved: {@link SuperShootGather} - memory control (occupying a less memory)
 *   <li>Improved: {@link SLEData} - support of multiple SLEs ('mode' does the trick)
 *   <li>Improved: {@link RadiosityEquations} - support for RGB (not tested yet)
 *   <li>Improved: {@link Radiosity} - support for RGB (not tested yet)
 * </ul>
 * <p>2.3.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link RadiosityEquations}, {@link Radiosity} - few bugs
 *   <li>Improved: {@link RadiosityEquations} - accelerated
 * </ul>
 * <p>3.3.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link Radiosity} - support of RGB (individual color cases: RED_GRAY, RED, RGB ..)
 *   <li>Fix: {@link MonteCarloFF} - bug in caching
 *   <li>New: {@code SLEHierarchical} - solver for multi-level hierarchical radiosity
 * </ul>
 * <p>10.3.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: {@code SLEHierarchical} - form factor estimate
 * </ul>
 * <p>12.3.2008 [radiosity] Tomas:
 * <ul>
 *   <li>New: {@link MonteCarloFF} - computing of form factors by area-to-area
 * </ul>
 * <p>21.3.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: bugs in the {@link MonteCarloFF#formFactor}
 *   <li>Fix: bugs in the {@code SLEHierarchical}
 *   <li>Improved: subdividing in the {@code SLEHierarchical}
 *   <li>Fix: bugs in the {@link MonteCarloFF#formFactor}
 *   <li>Fix: bugs in the {@code SLEHierarchical}
 *   <li>Improved: {@link MainFormFactors} - simplification of testing
 *                 (some unuseful possibilities were removed)
 *   <li>New: {@code RadiosityHierarch} - main module for the hierarchical radiosity
 * </ul>
 * <p>25.3.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix & Improved: {@code SLEHierarchical} - solving and preprocessing
 *   <li>Fix: ambient term in {@link SLEProgressive} and {@link SuperShootGather}
 * </ul>
 * <p>26.3.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@link SuperShootGather#reset} - variable 'steps' must be set to the null
 *   <li>Improved: logging in {@link Radiosity} and {@code RadiosityHierarch}
 *   <li>Improved: support of RGB in a {@code RadiosityHierarch}, {@code SLEHierarchical}
 *   <li>Improved: {@link SLESolver} - support of multiple modes
 *   <li>Fix: {@link SLERelaxation}, {@link SLEProgressive}, {@link SuperShootGather} -
 *            mode functions
 *   <li>Improved: {@code sRadiosityRelax}, {@code sRadiosityProg} and
 *       {@code sRadiositySSG} - created standard values
 * </ul>
 * <p>3.4.2008 [radiosity] Tomas:
 * <ul>
 *   <li>New: {@code PhotonMapping} - photons, photon maps including irradiance
 *            estimate, locationg of photons, .. (not finished yet)
 * </ul>
 * <p>7.4.2008 [radiosity] Tomas:
 * <ul>
 *   <li>New: {@code PhotonMapping} - manipulation with KD-tree
 * </ul>
 * <p>9.4.2008 [radiosity] Tomas:
 * <ul>
 *   <li>New: {@code PhotonMapping} - emitting of photons
 * </ul>
 * <p>10.4.2008 [radiosity] Tomas:
 * <ul>
 *   <li>New: {@code PhotonMapping} - photon tracing (not finished yet)
 * </ul>
 * <p>14.4.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: {@code PhotonMapping} - photon tracing (not finished yet)
 *   <li>New: photon mapping application (sPhotonMapping.xml)
 *   <li>New: {@code PhotonMapping} - visualizing of photon maps (still on the beginning)
 *   <li>New: jgl. files - camera and scene-properties for Cornell box
 * </ul>
 * <p>17.4.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@code PhotonMapping} - few bugs in creating of photon map
 *   <li>Improved: {@code PhotonMapping} - visualising of photon maps, photon tracing
 * </ul>
 * <p>27.4.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@code PhotonMapping} - balancing of KD-tree
 *   <li>Fix: {@code PhotonMapping} - now is not connected with B-rep
 * </ul>
 * <p>29.4.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Improved: {@code PhotonMapping} - getting of property of materials,
 *                                         temporary light(s) for testing
 * </ul>
 * <p>1.5.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@code PhotonMapping} - some bugs in photon map creating, property, ..
 *   <li>New: new application of PhotonMapping
 * </ul>
 * <p>4.5.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@code PhotonMapping} - new variables in property, saving photons,
 *            generating photons leaving point light
 * </ul>
 * <p>8.5.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@code PhotonMapping} - bug in KD-tree balacing
 *   <li>Improved: {@code PhotonMapping} - photon map
 *   <li>New: scene for testing - "a la" Cornel box
 * </ul>
 * <p>10.5.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Fix: {@code PhotonMapping} - little bug in making heap from kd-tree
 *       (photon mapping now works properly with diffuse illumination)
 *   <li>Fix: CBEmpty - now have properly material properties
 *   <li>New: {@link SimpleSLEDataStore} - add methods {@code SimpleSLEDataStore.getType()}
 *       and {@code SimpleSLEDataStore.setType()} which are defined in interface {@link SLEData}
 * </ul>
 * <p>11.5.2008 [radiosity] Tomas:
 * <ul>
 *   <li>New: {@code PhotonMapping} - caustics, russian roulette in rendering,
 *       shadow map, map for participating media
 *   <li>Improved: {@code PhotonMapping} - property (new variables)
 * </ul>
 * <p>16.5.2008 PE:
 * <ul>
 *   <li>Merge: from {@code trunk} to {@code radiosity} - revisions 700 - 744.
 * </ul>
 * <p>17.5.2008 [radiosity] PE:
 * <ul>
 *   <li>Improved: {@link CornellBox} and {@link MonteCarloFF} moved to {@code piece}.
 *   <li>Improved: {@link MainFormFactors} - command-line arguments, more compact and readable code..
 *   <li>Improved: {@link MainSLE} - cosmetics, minor changes.
 *   <li>Improved: {@link MonteCarloFF} - cosmetics, comments (this module needs much more work!).
 *   <li>New: another main contributors into {@link AboutDialog}.
 *   <li>Fix: {@link MonteCarloFF} remake - efficiency (sampling will be checked next).
 *   <li>Improved: {@link MainFormFactors} is able to print element areas.
 *   <li>Fix: Javadoc syntax.
 *   <li>Improved: program version is now logged in {@link LogFile}.
 *   <li>Fix: corrected hemisphere sampling in {@link MonteCarloFF},
 *       cosine emitter is finished and tested.
 *   <li>Fix: {@link MonteCarloFF#formFactorsFrom} (back-face elimination).
 *   <li>Fix: FF array initialization in {@link MonteCarloFF}.
 *   <li>Fix: FF columns in {@link MainFormFactors}.
 *   <li>Fix: {@link MonteCarloFF#formFactor} (denominator, ..).
 *   <li>Improved: {@link MonteCarloFF#elementArea}, {@code MonteCarloFF.getNormal()}.
 * </ul>
 * <p>18.5.2008 [radiosity] PE:
 * <ul>
 *   <li>Improved: {@code MonteCarloFFSolving} renamed to {@link MonteCarloFF}, minor
 *       changes in registration..
 *   <li>Fix: {@link MonteCarloFF#init} - infinite recursion.
 *   <li>Improved: {@link Radiosity} moved to {@code piece}.
 *   <li>Improved: {@link Radiosity} - some minor changes, cosmetics, logging, registration..
 *   <li>Improved: {@link RadiosityEquations} moved to {@code piece}.
 *   <li>Improved: some changes/fixes in {@link RadiosityEquations} - cosmetics, efficiency, registration..
 *   <li>New: {@link Geometry#triangleArea}.
 *   <li>Improved: {@link SLEProgressive} moved to {@code piece}.
 *   <li>Improved: minor changes in {@link SLEProgressive} - cosmetics, efficiency, registration..
 *   <li>Improved: {@link SLERelaxation} moved to {@code piece}.
 *   <li>Improved: brighter white light in {@link CornellBox} (temporary solution,
 *       needs user-defined light color).
 *   <li>New: interface {@link GlobalIllumination} will entend {@link Property} and {@link Breakable}.
 *   <li>Improved: {@link Radiosity} implements user break.
 *   <li>Improved: {@link GlobalIlluminationWorker} - cosmetics, registration, user break..
 *   <li>Improved: {@link SuperShootGather} moved to {@code piece}.
 *   <li>Improved: {@link SuperShootGather} - cosmetics, efficiency, registration..
 *   <li>Fix: ambient term in {@link SLEProgressive}.
 *   <li>New: associative LRU cache {@link LRUCache}.
 *   <li>Improved: dual caching mechanism in {@link MonteCarloFF}.
 *   <li>New: {@link Geometry#triangleNormal}.
 *   <li>Improved: optimized world-&gt;tangent transform in {@link MonteCarloFF}.
 *   <li>Improved: last cosmetic changes before merge..
 * </ul>
 * <p>18.5.2008 [radiosity] Tomas:
 * <ul>
 *   <li>Merge: from {@code radiosity} to {@code trunk} - revisions 757 - 757 (both HEAD).
 * </ul>
 * <p>19.5.2008 PE:
 * <ul>
 *   <li>Fix: log-files ({@code branches.txt}, {@link Version}).
 *   <li>Fix: class name of {@link GlobalIlluminationWorker} (double l).
 * </ul>
 *
 * @author  PE
 * @version 0.26 $Rev: 760 $ $Date: 2008-05-19 04:05:39 +0200 (po, 19 V 2008) $ $Author: pepca $
 * @since   0.23
 * @see     <a href="../../../../cz/cuni/jagrlib/Version.java">Version.java</a>
 */
public class Version
{
  /** Global JaGrLib version (also used in Skel application): {@value} */
  public final static String VERSION        = "0.26";

  /**
   * SVN revision number: {@value}
   *
   * @see <a href="http://subversion.tigris.org/">Subversion Tigris</a>
   */
  public final static String SVN_REVISION   = "$Rev: 760 $";

  /** SVN last modification date: {@value} */
  public final static String SVN_DATE       = "$Date: 2008-05-19 04:05:39 +0200 (po, 19 V 2008) $";

  /** SVN author of recent modification: {@value} */
  public final static String SVN_AUTHOR     = "$Author: pepca $";

  /** URL (home-page) of JaGrLib. */
  public final static String JAGRLIB_URL    = "http://cgg.ms.mff.cuni.cz/JaGrLib/";

  /** Skel copyright notice. */
  public final static String SKEL_COPYRIGHT = "Copyright \u00A9 2000-2008";

  /** Skel application name. */
  public final static String SKEL_NAME      = "Skel";

  /** Skel authors. */
  public final static String SKEL_AUTHOR    = "Josef Pelik\u00E1n, Jan Kostliv\u00FD,";

  /** JaGrLib other main contributors. */
  public final static String SKEL_CONTRIB   = "Tom\u00E1s Sv\u00E1b, Jan Stuchl";

  /** JaGrLib information displayed in Skel application. */
  public final static String SKEL_JAGRLIB   = "JaGrLib project leader: Josef Pelik\u00E1n";

  /** Assembles nice version string. */
  public static String niceVersion ()
  {
    String svn = SVN_REVISION.substring( 1, SVN_REVISION.length() - 2 ) + ',';
    int pos1   = SVN_DATE.indexOf( ':' );
    int pos2   = SVN_DATE.indexOf( '(' );
    return( VERSION + " (" + svn + SVN_DATE.substring( pos1 + 1, pos2 - 1 ) + ')' );
  }

}
