package cz.cuni.jagrlib.eval;

import java.util.Map;
import java.io.PrintStream;

import cz.cuni.jagrlib.LogFile;

/**
 * Default evaluation plugin for MainEval.
 *
 * @version 0.25 $Rev: 383 $ $Date: 2007-01-04 01:02:18 +0100 (čt, 04 I 2007) $ $Author: pepca $
 * @since   0.24
 * @see     cz.cuni.jagrlib.MainEval
 * @see     <a href="../../../../../cz/cuni/jagrlib/eval/DefaultPlugin.java">DefaultPlugin.java</a>
 */
public class DefaultPlugin implements EvalPlugin
{
  //==========================================================================
  //  XML params:

  /** Generate HTML output? */
  public final static String HTML   = "htmlOut";

  /**
   * Runs one instance of the test (simple variant, w/o global result storage).
   *
   * @param env Environment map (global params).
   * @param param Individual params.
   * @param out Text stream for output messages.
   * @return True if test was successful, false in case of fatal error (instantiation, e.g.).
   */
  public boolean runTest ( Map< String, String > env, Map< String, String > param,
                           PrintStream out )
  {
    return true;
  }

  /**
   * Create result object (whatever it is).
   */
  public Object createResults ()
  {
    return null;
  }

  /**
   * Runs one instance of the test (results are stored in the given result object).
   *
   * @param env Environment map (global params).
   * @param param Individual params.
   * @param results Object for collecting results.
   * @return True if test was successful, false in case of fatal error (instantiation, e.g.).
   */
  public boolean runTest ( Map< String, String > env, Map< String, String > param,
                           Object results )
  {
    return true;
  }

  /**
   * Interpret the result object.
   *
   * @param env Environment map (global params).
   * @param results Object with collected results.
   * @param out Text stream for output messages.
   */
  public void interpretResults ( Map< String, String > env, Object results, PrintStream out )
  {
  }

  /**
   * Read integer value from param maps.
   *
   * @param env Environment map (global params).
   * @param param Individual params.
   * @param name Parameter name.
   * @param defaultValue Returned in case of failure.
   * @return Value of the given integer parameter.
   */
  protected static int integerParam ( Map< String, String > env, Map< String, String > param,
                                      String name, int defaultValue )
  {
    String tmp = null;
    if ( param != null )
      tmp = param.get( name );
    if ( tmp == null )
      tmp = env.get( name );

    if ( tmp == null )
      return defaultValue;

    int result = defaultValue;
    try
    {
      result = Integer.parseInt( tmp );
    }
    catch ( Exception e )
    {
      LogFile.error( "Bad integer number (" + name + "): " + tmp );
    }
    return result;
  }

  /**
   * Read double value from param maps.
   *
   * @param env Environment map (global params).
   * @param param Individual params.
   * @param name Parameter name.
   * @param defaultValue Returned in case of failure.
   * @return Value of the given double parameter.
   */
  protected static double doubleParam ( Map< String, String > env, Map< String, String > param,
                                        String name, double defaultValue )
  {
    String tmp = null;
    if ( param != null )
      tmp = param.get( name );
    if ( tmp == null )
      tmp = env.get( name );

    if ( tmp == null )
      return defaultValue;

    double result = defaultValue;
    try
    {
      result = Double.parseDouble( tmp );
    }
    catch ( Exception e )
    {
      LogFile.error( "Bad double number (" + name + "): " + tmp );
    }
    return result;
  }

  /**
   * Read string value from param maps.
   *
   * @param env Environment map (global params).
   * @param param Individual params.
   * @param name Parameter name.
   * @param defaultValue Returned in case of failure.
   * @return Value of the given string parameter.
   */
  protected static String stringParam ( Map< String, String > env, Map< String, String > param,
                                        String name, String defaultValue )
  {
    String tmp = null;
    if ( param != null )
      tmp = param.get( name );
    if ( tmp == null )
      tmp = env.get( name );

    return( tmp == null ? defaultValue : tmp );
  }

  /**
   * Read boolean value from param maps.
   *
   * @param env Environment map (global params).
   * @param param Individual params.
   * @param name Parameter name.
   * @param defaultValue Returned in case of failure.
   * @return Value of the given boolean parameter.
   */
  protected static boolean booleanParam ( Map< String, String > env, Map< String, String > param,
                                          String name, boolean defaultValue )
  {
    String tmp = null;
    if ( param != null )
      tmp = param.get( name );
    if ( tmp == null )
      tmp = env.get( name );

    return( tmp == null ? defaultValue : tmp.equalsIgnoreCase( "true" ) );
  }

}
