package cz.cuni.jagrlib.eval;

import java.util.Map;
import java.io.PrintStream;

/**
 * Evaluation plugin for MainEval.
 *
 * @version 0.26 $Rev: 439 $ $Date: 2007-05-05 12:29:50 +0200 (so, 05 V 2007) $ $Author: pepca $
 * @since   0.24
 * @see     cz.cuni.jagrlib.MainEval
 * @see     <a href="../../../../../cz/cuni/jagrlib/eval/EvalPlugin.java">EvalPlugin.java</a>
 */
public interface EvalPlugin
{
  /** Standard key for parameter-maps: class name. */
  String CLASS_NAME = "class";

  /** Standard key for parameter-maps: output file name. */
  String OUTPUT_FILE_NAME = "output";

  /** Standard key for parameter-maps: output folder. */
  String BASE = "base";

  /**
   * Runs one instance of the test (simple variant, w/o global result storage).
   *
   * @param env Environment map (global params).
   * @param param Individual params.
   * @param out Text stream for output messages.
   * @return True if test was successful, false in case of fatal error (instantiation, e.g.).
   */
  boolean runTest ( Map< String, String > env, Map< String, String > param,
                    PrintStream out );

  /**
   * Create result object (whatever it is).
   */
  Object createResults ();

  /**
   * Runs one instance of the test (results are stored in the given result object).
   *
   * @param env Environment map (global params).
   * @param param Individual params.
   * @param results Object for collecting results.
   * @return True if test was successful, false in case of fatal error (instantiation, e.g.).
   */
  boolean runTest ( Map< String, String > env, Map< String, String > param,
                    Object results );

  /**
   * Interpret the result object.
   *
   * @param env Environment map (global params).
   * @param results Object with collected results.
   * @param out Text stream for output messages.
   */
  void interpretResults ( Map< String, String > env, Object results, PrintStream out );

}
