package cz.cuni.jagrlib.eval;

import java.util.*;
import java.io.PrintStream;
import java.io.File;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.piece.*;

class Ex2005_01_bEntry
{
  public String name;

  public double time;

  public double error;
}

class Ex2005_01_bComparator implements Comparator< Ex2005_01_bEntry >
{
  /** Returns -1 if {@code a < b}, 0 if they are equal and 1 if {@code a > b}. */
  public int compare ( Ex2005_01_bEntry a, Ex2005_01_bEntry b )
  {
    if ( a.error < b.error ) return -1;
    if ( a.error > b.error ) return  1;
    if ( a.time  < b.time  ) return -1;
    if ( a.time  > b.time  ) return  1;
    return a.name.compareTo( b.name );
  }
}

/**
 * Evaluation plugin for MainEval: exercise 01, comparison with exact drawing.
 *
 * @version 0.26 $Rev: 439 $ $Date: 2007-05-05 12:29:50 +0200 (so, 05 V 2007) $ $Author: pepca $
 * @since   0.24
 * @see     MainEval
 * @see     <a href="../../../../../cz/cuni/jagrlib/eval/Ex2005_01_b.java">Ex2005_01_b.java</a>
 */
public class Ex2005_01_b extends DefaultPlugin
{
  //==========================================================================
  //  XML params:

  /** Number of items to draw. */
  public final static String REPEAT = "repeat";
  /** Random seed (for RandomJames). */
  public final static String SEED1  = "seed1";
  public final static String SEED2  = "seed2";
  /** Use integer coordinates? */
  public final static String INT    = "int";

  /** Etalon file-name. */
  public final static String ETALON = "etalon";
  /** Save the result as etalon? */
  public final static String SAVE   = "save";

  //==========================================================================
  //  Data:

  /** Use integer coordinates? */
  protected boolean integer;

  /** Pseudo-random generator. */
  protected RandomJames rnd;

  //==========================================================================
  //  Support:

  /** Generates one random point on the given line. */
  protected void generate ( double[] p, int line )
  {
    double random = rnd.uniformNumber() * 511.0;
    if ( integer )
      random = Math.round( random );
    p[0] = p[1] = random;

    switch ( line )
    {
      case 0:
        p[0] =   0.0;
        break;
      case 1:
        p[0] = 256.0;
        break;
      case 2:
        p[0] = 511.0;
        break;
      case 3:
        p[1] =   0.0;
        break;
      case 4:
        p[1] = 256.0;
        break;
      default:
        p[1] = 511.0;
    }
  }

  /** Internal test routine. */
  protected boolean internalTest ( Map< String, String > env, Map< String, String > param,
                                   PrintStream out, SortedSet< Ex2005_01_bEntry > results )
  {
      // class name:
    String shortName = param.get( CLASS_NAME );
    if ( shortName == null )
    {
      if ( out != null )
        out.println( "Cannot find the '" + CLASS_NAME + "' test argument!" );
      return false;
    }
    String className = Template.JAGRLIB2 + shortName;

      // picture file-name:
    String shortFileName = param.get( OUTPUT_FILE_NAME );
    if ( shortFileName == null )
      shortFileName = "output.png";
    String tmp = env.get( BASE );
    String outputFileName;
    if ( tmp == null )
      outputFileName = shortFileName;
    else
    {
      File baseDir = new File( tmp );
      baseDir.mkdirs();
      outputFileName = tmp.concat( shortFileName );
    }

      // repeat:
    int repeat = integerParam( env, param, REPEAT, 200 );

      // random seeds:
    int seed1 = integerParam( env, param, SEED1,  0 );
    int seed2 = integerParam( env, param, SEED2, 12 );

      // use integer coordinates?
    integer = integerParam( env, param, INT, 0 ) != 0;

      // etalon file-name:
    String etalonFileName = tmp.concat( stringParam( env, param, ETALON, "0etalon.png" ) );

    boolean saveEtalon = integerParam( env, param, SAVE, 0 ) != 0;

      // create Piece objects:
    Piece line;
    try
    {
      line = (Piece)(Class.forName( className ).newInstance());
    }
    catch ( Exception e )
    {
      if ( out != null )
        out.println( "Cannot instantiate the '" + shortName + "' class!" );
      return false;
    }
    if ( !(line instanceof LineRenderAnti) )
    {
      if ( out != null )
        out.println( "The " + shortName + " class doesn't implement LineRenderAnti interface!" );
      return false;
    }
    AlphaMatrix     alpha   = new AlphaMatrix();
    SolidColorBrush brush   = new SolidColorBrush();
    RasterImage     image   = new RasterImage();
    PNGFileFormat   png     = new PNGFileFormat();
    JavaBitStream   output  = new JavaBitStream();
    RasterImage     etalon  = new RasterImage();
    PNGFileFormat   pngEta  = new PNGFileFormat();
    JavaBitStream   input   = new JavaBitStream();
    ImageCompare    compare = new ImageCompare();
    output.set(  JavaBitStream.STREAM_NAME, saveEtalon ? etalonFileName : outputFileName );
    input.set(   JavaBitStream.STREAM_NAME, etalonFileName );
    compare.set( ImageCompare.METRIC_TYPE,  3 );

      // connect them by channels:
    try
    {
      line.connect(    Piece.PL_OUTPUT,    alpha,  Piece.PL_INPUT );
      brush.connect(   Piece.PL_ALPHAMASK, alpha,  Piece.PL_INPUT );
      brush.connect(   Piece.PL_OUTPUT,    image,  Piece.PL_INPUT );
      png.connect(     Piece.PL_RASTER,    image,  Piece.PL_INPUT );
      png.connect(     Piece.PL_STREAM,    output, Piece.PL_INPUT );
      pngEta.connect(  Piece.PL_RASTER,    etalon, Piece.PL_INPUT );
      pngEta.connect(  Piece.PL_STREAM,    input,  Piece.PL_INPUT );
      compare.connect( "image1",           etalon, Piece.PL_INPUT );
      compare.connect( "image2",           image,  Piece.PL_INPUT );
    }
    catch ( BadInterfaceException e )
    {
      out.println( "Error connecting the '" + shortName + "' module!" );
      LogFile.exception( "Bad Interface in connecting-time!", e );
      return false;
    }

      // set Pieces' parameters:
    image.init( 512, 512, RasterGraphics.MODE_RGBA, 0 );
    alpha.init( 512, 512 );

    int[] color = new int[ 4 ];
    color[3] = 255;

      // random generator:
    rnd = new RandomJames( seed1, seed2 );
    LineRenderAnti l = (LineRenderAnti)line;

      // time measurement:
    long startTime = System.currentTimeMillis();

      // draw random lines:
    double[] p0 = new double[ 2 ];
    double[] p1 = new double[ 2 ];

    try
    {
      for ( int i = 0; i++ < repeat; )
      {
          // random line:
        int beg = rnd.randomInteger( 0, 5 );
        int end;
        do
          end = rnd.randomInteger( 0, 5 );
        while ( end == beg );
        generate( p0, beg );
        generate( p1, end );
        l.drawLine( p0[0], p0[1], p1[0], p1[1], rnd.randomDouble( 0.5, 3.5 ) );

          // stroke it:
        if ( (i & 15) == 0 )
        {
            // set random color:
          color[0] = rnd.randomInteger( 154, 255 );
          color[1] = rnd.randomInteger( 154, 255 );
          color[2] = rnd.randomInteger( 154, 255 );
          brush.setColor( color );
          brush.fill();
        }
      }
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }

      // set random color:
    color[0] = rnd.randomInteger( 154, 255 );
    color[1] = rnd.randomInteger( 154, 255 );
    color[2] = rnd.randomInteger( 154, 255 );
    brush.setColor( color );
    brush.fill();

      // stop time:
    double elapsed = 1.e-3 * (System.currentTimeMillis() - startTime);

      // clear line ending points:
    image.setAlpha( 1.0 );
    image.setRectangle(   0,   0, 512,   4, RasterImage.INIT_COLOR );
    image.setRectangle(   0, 253, 512, 260, RasterImage.INIT_COLOR );
    image.setRectangle(   0, 508, 512, 512, RasterImage.INIT_COLOR );
    image.setRectangle(   0,   0,   4, 512, RasterImage.INIT_COLOR );
    image.setRectangle( 253,   0, 260, 512, RasterImage.INIT_COLOR );
    image.setRectangle( 508,   0, 512, 512, RasterImage.INIT_COLOR );

      // AE error:
    double err = 0;

    if ( !saveEtalon )
    {                                     // compare result with the etalon
        // load the etalon:
      try
      {
        pngEta.loadFile( (String)null, null );
        err = compare.f( 0 );
      }
      catch ( Exception e )
      {
        LogFile.error( "Error loading '" + etalonFileName + "' image!" );
      }
    }

      // save the result:
    try
    {
      png.saveFile( (String)null, null );
    }
    catch ( Exception e )
    {
      LogFile.error( "Error writting '" + outputFileName + "' image!" );
    }

    if ( out != null )
      out.println( String.format( Locale.US, "OK (%6.3fs), err =%10.f  %s", elapsed, err, shortName ) );
    else
    if ( results != null &&
         !saveEtalon )
    {
      Ex2005_01_bEntry entry = new Ex2005_01_bEntry();
        // instance name:
      int pos = shortFileName.lastIndexOf( '.' );
      if ( pos <= 0 )
        entry.name = shortFileName;
      else
        entry.name = shortFileName.substring( 0, pos );
        // instance error:
      entry.error = err;
        // instance computing time:
      entry.time = elapsed;
        // insert the new result into the result collection:
      results.add( entry );
    }

    return true;
  }

  //==========================================================================
  //  Interface EvalPlugin:

  /**
   * Runs one instance of the test (simple variant, w/o global result storage).
   */
  @Override
  public boolean runTest ( Map< String, String > env, Map< String, String > param, PrintStream out )
  {
    return internalTest( env, param, out, null );
  }

  /**
   * Create result object (whatever it is).
   */
  @Override
  public Object createResults ()
  {
    return new TreeSet< Ex2005_01_bEntry >( new Ex2005_01_bComparator() );
  }

  /**
   * Runs one instance of the test (results are stored in the given result object).
   *
   * @param env Environment map (global params).
   * @param param Individual params.
   * @param results Object for collecting results.
   * @return True if another test instance sould be eecuted, false in case of fatal error.
   */
  @SuppressWarnings("unchecked")
  @Override
  public boolean runTest ( Map< String, String > env, Map< String, String > param,
                           Object results )
  {
    return internalTest( env, param, null, (SortedSet< Ex2005_01_bEntry >)results );
  }

  /**
   * Interpret the result object.
   *
   * @param env Environment map (global params).
   * @param results Object with collected results.
   * @param out Text stream for output messages.
   */
  @SuppressWarnings("unchecked")
  @Override
  public void interpretResults ( Map< String, String > env, Object results, PrintStream out )
  {
    if ( results == null || out == null ) return;

    SortedSet< Ex2005_01_bEntry > res = (SortedSet< Ex2005_01_bEntry >)results;
    boolean htmlOut = integerParam( env, null, HTML, 0 ) != 0;
    Iterator< Ex2005_01_bEntry > it = res.iterator();
    int ord = 0;
    if ( htmlOut )
    {
      // !!! TODO: HTML table output !!!
    }
    else
    {
      out.println( "Rank     Error       Name                Time" );
      out.println( "-----------------------------------------------" );
      while ( it.hasNext() )
      {
        Ex2005_01_bEntry entry = it.next();
        ord++;
        out.format( Locale.US, "%3d. %10d  %-20s %7.3fs\n",
                    ord, entry.error, entry.name, entry.time );
      }
      out.println( "-----------------------------------------------" );
    }
  }

}
