package cz.cuni.jagrlib.eval;

import java.util.*;
import java.io.PrintStream;
import java.io.File;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.piece.*;

/**
 * Evaluation plugin for MainEval: exercise 02, clipped lines with non-integer coordinates, with antialiasing.
 *
 * @version 0.26 $Rev: 439 $ $Date: 2007-05-05 12:29:50 +0200 (so, 05 V 2007) $ $Author: pepca $
 * @since   0.24
 * @see     MainEval
 * @see     <a href="../../../../../cz/cuni/jagrlib/eval/Ex2005_02_b.java">Ex2005_02_b.java</a>
 */
public class Ex2005_02_b extends DefaultPlugin
{
  //==========================================================================
  //  XML params:

  /** Clipping class name. */
  protected final static String CLIP   = "clip";
  /** Number of items to draw. */
  protected final static String REPEAT = "repeat";
  /** Random seed (for RandomJames). */
  protected final static String SEED1  = "seed1";
  protected final static String SEED2  = "seed2";
  /** Use integer coordinates? */
  protected final static String INT    = "int";

  /**
   * Runs one instance of the test (simple variant, w/o global result storage).
   */
  @Override
  public boolean runTest ( Map< String, String > env, Map< String, String > param, PrintStream out )
  {
      // class name - line drawing:
    String shortName = param.get( CLASS_NAME );
    if ( shortName == null )
    {
      out.println( "Cannot find the '" + CLASS_NAME + "' test argument!" );
      return false;
    }
    String className = Template.JAGRLIB2 + shortName;

      // class name - line clipping:
    String shortNameClip = param.get( CLIP );
    if ( shortNameClip == null )
    {
      out.println( "Cannot find the '" + CLIP + "' test argument!" );
      return false;
    }
    String classNameClip = Template.JAGRLIB2 + shortNameClip;

      // picture file-name:
    String outputFileName = param.get( OUTPUT_FILE_NAME );
    if ( outputFileName == null )
      outputFileName = "output.png";
    String tmp = env.get( BASE );
    if ( tmp != null )
    {
      File baseDir = new File( tmp );
      baseDir.mkdirs();
      outputFileName = tmp.concat( outputFileName );
    }

      // repeat:
    int repeat = integerParam( env, param, REPEAT, 200 );

      // random seeds:
    int seed1 = integerParam( env, param, SEED1,  0 );
    int seed2 = integerParam( env, param, SEED2, 12 );

      // use integer coordinates?
    boolean integer = integerParam( env, param, INT, 1 ) != 0;

      // create Piece objects:
    Piece line;
    try
    {
      line = (Piece)(Class.forName( className ).newInstance());
    }
    catch ( Exception e )
    {
      out.println( "Cannot instantiate the '" + shortName + "' class!" );
      return false;
    }
    if ( !(line instanceof LineRenderAnti) )
    {
      out.println( "The '" + shortName + "' class doesn't implement LineRenderAnti interface!" );
      return false;
    }
    Piece clip;
    try
    {
      clip = (Piece)(Class.forName( classNameClip ).newInstance());
    }
    catch ( Exception e )
    {
      out.println( "Cannot instantiate the '" + shortNameClip + "' class!" );
      return false;
    }
    if ( !(clip instanceof LineRender) ||
         !(clip instanceof RectangleWindow) )
    {
      out.println( "The '" + shortNameClip + "' class doesn't implement LineRender and RectangleWindow interfaces!" );
      return false;
    }
    AlphaMatrix     mask   = new AlphaMatrix();
    SolidColorBrush brush  = new SolidColorBrush();
    RasterImage     image  = new RasterImage();
    PNGFileFormat   png    = new PNGFileFormat();
    JavaBitStream   output = new JavaBitStream();
    output.set( JavaBitStream.STREAM_NAME, outputFileName );

      // connect them by channels:
    try
    {
      line.connect(  Piece.PL_OUTPUT,    mask,   Piece.PL_INPUT );
      clip.connect(  Piece.PL_OUTPUT,    line,   Piece.PL_INPUT );
      brush.connect( Piece.PL_ALPHAMASK, mask,   Piece.PL_INPUT );
      brush.connect( Piece.PL_OUTPUT,    image,  Piece.PL_INPUT );
      png.connect(   Piece.PL_RASTER,    image,  Piece.PL_INPUT );
      png.connect(   Piece.PL_STREAM,    output, Piece.PL_INPUT );
    }
    catch ( BadInterfaceException e )
    {
      out.println( "Error connecting the '" + shortName + "' or '" + shortNameClip + "' module!" );
      LogFile.exception( "Bad Interface in connecting-time!", e );
      return false;
    }

      // set Pieces' parameters:
    image.init( 512, 512, RasterGraphics.MODE_RGBA, 0 );
    mask.init(  512, 512 );

    int[] color1 = { 255, 255, 192, 255 };
    int[] color2 = {   0,   0,  96, 255 };

      // random generator:
    RandomJames rnd     = new RandomJames( seed1, seed2 );
    LineRenderAnti l    = (LineRenderAnti)line;
    LineRender cl       = (LineRender)clip;
    RectangleWindow win = (RectangleWindow)clip;

      // time measurement:
    long startTime = System.currentTimeMillis();

      // draw random lines and clipped ones:
    try
    {
      win.rectangleWindow( 78, 453, 62, 469 );
      for ( int i = 0; i++ < repeat; )
      {
          // random line coordinates:
        int x1 = rnd.randomInteger( 0, 511 );
        int y1 = rnd.randomInteger( 0, 511 );
        int x2 = rnd.randomInteger( 0, 511 );
        int y2 = rnd.randomInteger( 0, 511 );
        double width = rnd.randomDouble( 0.5, 3.5 );

          // set line width:
        if ( cl instanceof LineRenderAnti )
          ((LineRenderAnti)cl).setWidth( width );
        else
          l.setWidth( width );

          // original (exact) line:
        if ( integer )
          l.drawLine( x1, y1, x2, y2 );
        else
          l.drawLine( (double)x1, (double)y1, (double)x2, (double)y2 );
        brush.setColor( color1 );
        brush.fill();

          // clipped line (using overwrite-color):
        if ( integer )
          cl.drawLine( x1, y1, x2, y2 );
        else
          cl.drawLine( (double)x1, (double)y1, (double)x2, (double)y2 );
        brush.setColor( color2 );
        brush.fill();
      }
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }

      // stop time:
    long stopTime = System.currentTimeMillis();

      // save the result:
    try
    {
      png.saveFile( (String)null, null );
    }
    catch ( Exception e )
    {
      LogFile.error( "Error writting '" + outputFileName + "' image!" );
    }

    out.println( String.format( Locale.US, "OK (%5.3fs) %s %s", 1.e-3 * (stopTime - startTime), shortNameClip, shortName ) );
    return true;
  }

}
