package cz.cuni.jagrlib.eval;

import java.util.*;
import java.io.PrintStream;
import java.io.File;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.piece.*;

/**
 * Evaluation plugin for MainEval: exercise 02, clipped lines with non-integer coordinates, w/o antialiasing.
 *
 * @version 0.26 $Rev: 439 $ $Date: 2007-05-05 12:29:50 +0200 (so, 05 V 2007) $ $Author: pepca $
 * @since   0.24
 * @see     MainEval
 * @see     <a href="../../../../../cz/cuni/jagrlib/eval/Ex2005_02_d.java">Ex2005_02_d.java</a>
 */
public class Ex2005_02_d extends DefaultPlugin
{
  //==========================================================================
  //  XML params:

  /** Clipping class name. */
  protected final static String CLIP   = "clip";
  /** Number of items to draw. */
  protected final static String REPEAT = "repeat";
  /** Random seed (for RandomJames). */
  protected final static String SEED1  = "seed1";
  protected final static String SEED2  = "seed2";
  /** Allow lines going exactly through half-points? */
  protected final static String HALF   = "half";

  /**
   * Runs one instance of the test (simple variant, w/o global result storage).
   */
  @Override
  public boolean runTest ( Map< String, String > env, Map< String, String > param, PrintStream out )
  {
      // class name - line drawing:
    String shortName = param.get( CLASS_NAME );
    if ( shortName == null )
    {
      out.println( "Cannot find the '" + CLASS_NAME + "' test argument!" );
      return false;
    }
    String className = Template.JAGRLIB2 + shortName;

      // class name - line clipping:
    String shortNameClip = param.get( CLIP );
    if ( shortNameClip == null )
    {
      out.println( "Cannot find the '" + CLIP + "' test argument!" );
      return false;
    }
    String classNameClip = Template.JAGRLIB2 + shortNameClip;

      // picture file-name:
    String outputFileName = param.get( OUTPUT_FILE_NAME );
    if ( outputFileName == null )
      outputFileName = "output.png";
    String tmp = env.get( BASE );
    if ( tmp != null )
    {
      File baseDir = new File( tmp );
      baseDir.mkdirs();
      outputFileName = tmp.concat( outputFileName );
    }

      // repeat:
    int repeat = integerParam( env, param, REPEAT, 200 );

      // random seeds:
    int seed1 = integerParam( env, param, SEED1,  0 );
    int seed2 = integerParam( env, param, SEED2, 12 );

      // allow half-pixels?
    boolean half = integerParam( env, param, HALF, 0 ) != 0;

      // create Piece objects:
    Piece line;
    try
    {
      line = (Piece)(Class.forName( className ).newInstance());
    }
    catch ( Exception e )
    {
      out.println( "Cannot instantiate the '" + shortName + "' class!" );
      return false;
    }
    if ( !(line instanceof LineRender) )
    {
      out.println( "The '" + shortName + "' class doesn't implement LineRender interface!" );
      return false;
    }
    Piece clip;
    try
    {
      clip = (Piece)(Class.forName( classNameClip ).newInstance());
    }
    catch ( Exception e )
    {
      out.println( "Cannot instantiate the '" + shortNameClip + "' class!" );
      return false;
    }
    if ( !(clip instanceof LineRender) ||
         !(clip instanceof RectangleWindow) )
    {
      out.println( "The '" + shortNameClip + "' class doesn't implement LineRender and RectangleWindow interfaces!" );
      return false;
    }
    XTransitionList mask   = new XTransitionList();
    SolidColorPen   pen    = new SolidColorPen();
    RasterImage     image  = new RasterImage();
    PNGFileFormat   png    = new PNGFileFormat();
    JavaBitStream   output = new JavaBitStream();
    output.set( JavaBitStream.STREAM_NAME, outputFileName );

      // connect them by channels:
    try
    {
      line.connect( Piece.PL_OUTPUT,  mask,   Piece.PL_INPUT );
      clip.connect( Piece.PL_OUTPUT,  line,   Piece.PL_INPUT );
      pen.connect(  Piece.PL_BITMASK, mask,   Piece.PL_INPUT );
      pen.connect(  Piece.PL_OUTPUT,  image,  Piece.PL_INPUT );
      png.connect(  Piece.PL_RASTER,  image,  Piece.PL_INPUT );
      png.connect(  Piece.PL_STREAM,  output, Piece.PL_INPUT );
    }
    catch ( BadInterfaceException e )
    {
      out.println( "Error connecting the '" + shortName + "' or '" + shortNameClip + "' module!" );
      LogFile.exception( "Bad Interface in connecting-time!", e );
      return false;
    }

      // set Pieces' parameters:
    image.init( 512, 512, RasterGraphics.MODE_RGB, 0 );
    mask.init(  512, 512 );

    int[] color1 = { 255, 255, 192 };
    int[] color2 = {   0,   0,  96 };

      // random generator:
    RandomJames rnd     = new RandomJames( seed1, seed2 );
    LineRender l        = (LineRender)line;
    LineRender cl       = (LineRender)clip;
    RectangleWindow win = (RectangleWindow)clip;

      // time measurement:
    long startTime = System.currentTimeMillis();

      // draw random lines and clipped ones:
    try
    {
      win.rectangleWindow( 100, 400, 92, 420 );
      for ( int i = 0; i++ < repeat; )
      {
          // random line coordinates:
        int x1, y1, x2, y2;
        int dx, dy;
        do
        {
          x1 = rnd.randomInteger( 0, 511 );
          y1 = rnd.randomInteger( 0, 511 );
          x2 = rnd.randomInteger( 0, 511 );
          y2 = rnd.randomInteger( 0, 511 );
          if ( half ) break;
          dx = Math.abs( x2 - x1 );
          dy = Math.abs( y2 - y1 );
          if ( dx > dy ) dy += dy;
          else
          if ( dy > dx ) dx += dx;
        } while ( Formula.gcd( dx, dy ) > 1 );

          // original (exact) line:
        l.drawLine( x1, y1, x2, y2 );
        pen.setColor( color1 );
        pen.stroke();

          // clipped line (using overwrite-color):
        cl.drawLine( x1, y1, x2, y2 );
        pen.setColor( color2 );
        pen.stroke();
      }
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }

      // stop time:
    long stopTime = System.currentTimeMillis();

      // save the result:
    try
    {
      png.saveFile( (String)null, null );
    }
    catch ( Exception e )
    {
      LogFile.error( "Error writting '" + outputFileName + "' image!" );
    }

    out.println( String.format( Locale.US, "OK (%5.3fs) %s %s", 1.e-3 * (stopTime - startTime), shortNameClip, shortName ) );
    return true;
  }

}
