package cz.cuni.jagrlib.eval;

import java.util.*;
import java.io.PrintStream;
import java.io.File;
import java.io.IOException;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.piece.*;

/**
 * Evaluation plugin for MainEval: exercise 06, general image filter testing.
 *
 * @version 0.26 $Rev: 439 $ $Date: 2007-05-05 12:29:50 +0200 (so, 05 V 2007) $ $Author: pepca $
 * @since   0.24
 * @see     MainEval
 * @see     <a href="../../../../../cz/cuni/jagrlib/eval/Ex2005_06_a.java">Ex2005_06_a.java</a>
 */
public class Ex2005_06_a extends DefaultPlugin
{
  //==========================================================================
  //  XML params:

  /** Input image file-name. */
  protected final static String IMAGE          = "image";
  /** General parameter name. */
  protected final static String PARAM_TEMPLATE = "par%02d";
  /** General parameter value. */
  protected final static String VALUE_TEMPLATE = "val%02d";

  /**
   * Runs one instance of the test (simple variant, w/o global result storage).
   */
  @Override
  public boolean runTest ( Map< String, String > env, Map< String, String > param, PrintStream out )
  {
      // class name:
    String shortName = param.get( CLASS_NAME );
    if ( shortName == null )
    {
      out.println( "Cannot find the '" + CLASS_NAME + "' test argument!" );
      return false;
    }
    String className = Template.JAGRLIB2 + shortName;

      // output picture file-name:
    String outputName = param.get( OUTPUT_FILE_NAME );
    if ( outputName == null )
      outputName = "output.png";
    String tmp = env.get( BASE );
    String outputFileName = outputName;
    if ( tmp != null )
    {
      File baseDir = new File( tmp );
      baseDir.mkdirs();
      outputFileName = tmp.concat( outputName );
    }

      // input picture file-name:
    String inputFileName = param.get( IMAGE );
    if ( inputFileName == null )
      inputFileName = env.get( IMAGE );
    if ( inputFileName == null )
    {
      out.println( "No input image specified!" );
      return true;
    }

      // create filter object:
    Piece pFilter;
    try
    {
      pFilter = (Piece)(Class.forName( className ).newInstance());
    }
    catch ( Exception e )
    {
      out.println( "Cannot instantiate the '" + shortName + "' class!" );
      return false;
    }
    if ( !(pFilter instanceof Trigger) )
    {
      out.println( "The '" + shortName + "' class doesn't implement Trigger interface!" );
      return true;
    }
    Trigger       filter = (Trigger)pFilter;
      // create other modules:
    JavaBitStream input  = new JavaBitStream();
    PNGFileFormat pngIn  = new PNGFileFormat();
    RasterImage   imIn   = new RasterImage();
    RasterImage   imOut  = new RasterImage();
    JavaBitStream output = new JavaBitStream();
    PNGFileFormat pngOut = new PNGFileFormat();
    input.set(  JavaBitStream.STREAM_NAME, inputFileName );
    output.set( JavaBitStream.STREAM_NAME, outputFileName );

      // connect them by channels:
    try
    {
      pngIn.connect(   Piece.PL_STREAM, input,  Piece.PL_INPUT );
      pngIn.connect(   Piece.PL_RASTER, imIn,   Piece.PL_INPUT );
      pFilter.connect( "image1",        imIn,   Piece.PL_INPUT );
      pFilter.connect( "image2",        imOut,  Piece.PL_INPUT );
      pngOut.connect(  Piece.PL_STREAM, output, Piece.PL_INPUT );
      pngOut.connect(  Piece.PL_RASTER, imOut,  Piece.PL_INPUT );
    }
    catch ( BadInterfaceException e )
    {
      out.println( "Error connecting the '" + shortName + "' module!" );
      LogFile.exception( "Bad Interface in connecting-time!", e );
      return false;
    }

      // set Pieces' parameters:
    int i = 1;
    do                                    // try one parameter
    {
      String paramTag = String.format( PARAM_TEMPLATE, i );
      String paramKey = param.get( paramTag );
      if ( paramKey == null ) break;
      paramTag = String.format( VALUE_TEMPLATE, i );
      String paramVal = param.get( paramTag );
      if ( paramVal != null )
        filter.set( paramKey, paramVal );
      i++;
    } while ( true );

      // 1. read the input image:
    try
    {
      pngIn.loadFile( (String)null, null );
    }
    catch ( IOException e )
    {
      LogFile.exception( "Error reading image '" + inputFileName + "'!", e );
      return true;
    }

      // time measurement:
    long startTime = System.currentTimeMillis();

      // 2. run the filter:
    try
    {
      filter.fire( 0 );
    }
    catch ( Exception e )
    {
      LogFile.exception( "Error filtering image (" + shortName + ')', e );
      return true;
    }

      // stop time:
    double elapsed = 1.e-3 * (System.currentTimeMillis() - startTime);

      // 3. save the result image:
    try
    {
      pngOut.saveFile( (String)null, null );
    }
    catch ( Exception e )
    {
      LogFile.error( "Error writting '" + outputName + "' image!" );
    }

    out.println( String.format( Locale.US, "%5.1fs, %s -> %s", elapsed, shortName, outputName ) );
    return true;
  }

}
