package cz.cuni.jagrlib.eval;

import java.util.*;
import java.io.PrintStream;
import java.io.File;
import java.io.IOException;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.piece.*;

class Ex2005_07_aEntry
{
  /** Author's name. */
  public String name;

  /** Image name. */
  public String image;

  /** Computation time in seconds. */
  public double time;

  /** MAE error of reconstructed (colormap-reduced) image. */
  public double error;
}

class Ex2005_07_aComparator implements Comparator< Ex2005_07_aEntry >
{
  /** Returns -1 if a &lt; b, 0 if they are equal and 1 if a &gt; b. */
  public int compare ( Ex2005_07_aEntry a, Ex2005_07_aEntry b )
  {
    if ( a.error < b.error ) return -1;
    if ( a.error > b.error ) return  1;
    if ( a.time  < b.time  ) return -1;
    if ( a.time  > b.time  ) return  1;
    return a.name.compareTo( b.name );
  }
}

/**
 * Evaluation plugin for MainEval: exercise 07, color reduction using one or two modules.
 *
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @since   0.24
 * @see     MainEval
 * @see     <a href="../../../../../cz/cuni/jagrlib/eval/Ex2005_07_a.java">Ex2005_07_a.java</a>
 */
public class Ex2005_07_a extends DefaultPlugin
{
  //==========================================================================
  //  XML params:

  /** Template for test image name tags. */
  protected final static String IMAGE_TEMPLATE = "image%02d";
  /** Colormap generator class name. */
  protected final static String CMAP           = "cmap";

  //==========================================================================
  //  Support:

  /** Internal test routine. */
  protected boolean internalTest ( Map< String, String > env, Map< String, String > param,
                                   PrintStream out, SortedSet< Ex2005_07_aEntry > results )
  {
      // colormap generator class name (optional):
    String shortNameCmap = param.get( CMAP );
    String classNameCmap = (shortNameCmap == null) ? null:
                           Template.JAGRLIB2 + shortNameCmap;

      // mapper class name:
    String shortNameMapper = param.get( CLASS_NAME );
    if ( shortNameMapper == null )
    {
      if ( out != null )
        out.println( "Cannot find the '" + CLASS_NAME + "' test argument!" );
      return false;
    }
    String classNameMapper = Template.JAGRLIB2 + shortNameMapper;

      // base directory for output images:
    String baseDir = env.get( BASE );
    if ( baseDir == null )
      baseDir = "eval/";
    File baseDirectory = new File( baseDir );
    baseDirectory.mkdirs();

      // output file-name suffix:
    String outputFileName = param.get( OUTPUT_FILE_NAME );
    if ( outputFileName == null )
      outputFileName = "output.png";

      // module objects:
    Piece         pCmap;
    Trigger       cmapGen;
    Piece         pMapper;
    Trigger       mapper;
    JavaBitStream input;
    PNGFileFormat pngIn;
    RasterImage   imIn;
    Colormaps     cmap;
    RasterImage   imOut;
    JavaBitStream output;
    PNGFileFormat pngOut;
    ImageCompare  cmp;

    int i = 1;
    do                                    // process one input image
    {
        // input/output parameters:
      String tag = String.format( IMAGE_TEMPLATE, i );
      String imageName = env.get( tag );
      if ( imageName == null ) return true;

        // create module instances:
      pCmap   = null;
      cmapGen = null;
      if ( shortNameCmap != null )
      {
        try
        {
          pCmap = (Piece)(Class.forName( classNameCmap ).newInstance());
        }
        catch ( Exception e )
        {
          if ( out != null )
            out.println( "Cannot instantiate the '" + shortNameCmap + "' class!" );
          return false;
        }
        if ( !(pCmap instanceof Trigger) )
        {
          if ( out != null )
            out.println( "The '" + shortNameCmap + "' class doesn't implement Trigger interface!" );
          return true;
        }
        cmapGen = (Trigger)pCmap;
      }

      try
      {
        pMapper = (Piece)(Class.forName( classNameMapper ).newInstance());
      }
      catch ( Exception e )
      {
        if ( out != null )
          out.println( "Cannot instantiate the '" + shortNameMapper + "' class!" );
        return false;
      }
      if ( !(pMapper instanceof Trigger) )
      {
        if ( out != null )
          out.println( "The '" + shortNameMapper + "' class doesn't implement Trigger interface!" );
        return true;
      }
      mapper = (Trigger)pMapper;

      input  = new JavaBitStream();
      pngIn  = new PNGFileFormat();
      imIn   = new RasterImage();
      cmap   = new Colormaps();
      imOut  = new RasterImage();
      output = new JavaBitStream();
      pngOut = new PNGFileFormat();
      cmp    = new ImageCompare();
      //cmp.set( ImageCompare.FILTER_PRECINCT, 2 );     // conic filter
      //cmp.set( ImageCompare.FILTER_RADIUS,   4.0 );   // filter radius = 4 pixels
      //cmp.set( ImageCompare.METRIC_TYPE,     2 );     // MAE = Mean Absolute Error
      cmp.set( ImageCompare.FILTER_PRECINCT, 0 );     // no filter
      cmp.set( ImageCompare.METRIC_TYPE,     1 );     // RMSE = Root Mean Square Error
      cmp.set( ImageCompare.PSYCHOVISUAL,    false );
        // connect them by channels:
      try
      {
        pngIn.connect(   Piece.PL_STREAM,  input,  Piece.PL_INPUT );
        pngIn.connect(   Piece.PL_RASTER,  imIn,   Piece.PL_INPUT );
        if ( pCmap != null )
        {
          pCmap.connect( Piece.PL_IMAGE,   imIn,   Piece.PL_INPUT );
          pCmap.connect( Piece.PL_PALETTE, cmap,   Piece.PL_INPUT );
        }
        pMapper.connect( "image1",         imIn,   Piece.PL_INPUT );
        pMapper.connect( Piece.PL_PALETTE, cmap,   Piece.PL_INPUT );
        pMapper.connect( "image2",         imOut,  Piece.PL_INPUT );
        pngOut.connect(  Piece.PL_STREAM,  output, Piece.PL_INPUT );
        pngOut.connect(  Piece.PL_RASTER,  imOut,  Piece.PL_INPUT );
        cmp.connect(     "image1",         imIn,   Piece.PL_INPUT );
        cmp.connect(     "image2",         imOut,  Piece.PL_INPUT );
      }
      catch ( BadInterfaceException e )
      {
        if ( out != null )
          out.println( "Error connecting the '" + shortNameMapper + "' module!" );
        LogFile.exception( "Bad Interface in connecting-time!", e );
        return false;
      }

        // inputName .. image file-name
      input.set( JavaBitStream.STREAM_NAME, imageName );
      String outputName = baseDir + imageName + '.' + outputFileName;
      output.set( JavaBitStream.STREAM_NAME, outputName );

        // 1. read the input image:
      try
      {
        pngIn.loadFile( (String)null, null );
      }
      catch ( IOException e )
      {
        LogFile.exception( "Error reading image '" + imageName + "'!", e );
        return false;
      }

        // time measurement:
      long startTime = System.currentTimeMillis();

        // 2. create the palette:
      if ( cmapGen != null )
      {
        try
        {
          cmapGen.fire( 0 );
        }
        catch ( Exception e )
        {
          LogFile.exception( "Error mapping image (" + shortNameCmap + ')', e );
          return true;
        }
      }

        // 3. remap the image:
      try
      {
        mapper.fire( 0 );
      }
      catch ( Exception e )
      {
        LogFile.exception( "Error mapping image (" + shortNameMapper + ')', e );
        return true;
      }

        // stop time:
      double elapsed = 1.e-3 * (System.currentTimeMillis() - startTime);

        // 4. compare both images:
      double error = cmp.f( 0 );

        // 5. save the result image:
      try
      {
        pngOut.saveFile( (String)null, null );
      }
      catch ( Exception e )
      {
        LogFile.error( "Error writting '" + outputName + "' image!" );
      }

      if ( out != null )
        out.println( String.format( Locale.US, "Err:%6.2f,%6.2fs, %s, %s", error, elapsed, shortNameMapper, imageName ) );
      else
      if ( results != null )
      {
        Ex2005_07_aEntry entry = new Ex2005_07_aEntry();
          // instance name:
        int pos = outputFileName.lastIndexOf( '.' );
        if ( pos <= 0 )
          entry.name = outputFileName;
        else
          entry.name = outputFileName.substring( 0, pos );
          // instance error:
        entry.error = error;
          // instance computing time:
        entry.time = elapsed;
          // image name:
        entry.image = imageName;
          // insert the new result into the result collection:
        results.add( entry );
      }

      i++;

    } while ( true );
  }

  //==========================================================================
  //  Interface EvalPlugin:

  /**
   * Runs one instance of the test (simple variant, w/o global result storage).
   */
  @Override
  public boolean runTest ( Map< String, String > env, Map< String, String > param, PrintStream out )
  {
    return internalTest( env, param, out, null );
  }

  /**
   * Create result object (whatever it is).
   */
  @Override
  public Object createResults ()
  {
    return new TreeSet< Ex2005_07_aEntry >( new Ex2005_07_aComparator() );
  }

  /**
   * Runs one instance of the test (results are stored in the given result object).
   *
   * @param env Environment map (global params).
   * @param param Individual params.
   * @param results Object for collecting results.
   * @return True if another test instance sould be eecuted, false in case of fatal error.
   */
  @SuppressWarnings("unchecked")
  @Override
  public boolean runTest ( Map< String, String > env, Map< String, String > param,
                           Object results )
  {
    return internalTest( env, param, null, (SortedSet< Ex2005_07_aEntry >)results );
  }

  /**
   * Interpret the result object.
   *
   * @param env Environment map (global params).
   * @param results Object with collected results.
   * @param out Text stream for output messages.
   */
  @SuppressWarnings("unchecked")
  @Override
  public void interpretResults ( Map< String, String > env, Object results, PrintStream out )
  {
    if ( results == null || out == null ) return;

    SortedSet<Ex2005_07_aEntry> res = (SortedSet< Ex2005_07_aEntry >)results;
    boolean htmlOut = integerParam( env, null, HTML, 0 ) != 0;
    Iterator< Ex2005_07_aEntry > it = res.iterator();
    int ord = 0;
    if ( htmlOut )
    {
      // !!! TODO: HTML table output !!!
    }
    else
    {
      out.println( "Rank   Error   Time    Name                 Image" );
      out.println( "---------------------------------------------------------------" );
      while ( it.hasNext() )
      {
        Ex2005_07_aEntry entry = it.next();
        ord++;
        out.format( Locale.US, "%3d.%8.2f%7.1fs %-20s %-15s\n",
                    ord, entry.error, entry.time, entry.name, entry.image );
      }
      out.println( "---------------------------------------------------------------" );
    }
  }

}
