package cz.cuni.jagrlib.eval;

import java.util.*;
import java.io.PrintStream;
import java.io.File;
import java.awt.geom.Point2D;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.piece.*;
import cz.cuni.jagrlib.obscure.*;

/**
 * Evaluation plugin for {@link MainEval}: exercise 48, general polygon clipping.
 *
 * @version 0.26 $Rev: 439 $ $Date: 2007-05-05 12:29:50 +0200 (so, 05 V 2007) $ $Author: pepca $
 * @since   0.25
 * @see     MainEval
 * @see     <a href="../../../../../cz/cuni/jagrlib/eval/Ex2006_48_a.java">Ex2006_48_a.java</a>
 */
public class Ex2006_48_a extends DefaultPlugin
{
  //==========================================================================
  //  XML params:

  /** Use anti-aliasing? */
  protected final static String ANTI_ALIAS  = "antiAlias";

  /** Random seed (for RandomJames). */
  protected final static String SEED1       = "seed1";
  protected final static String SEED2       = "seed2";

  /** Image resolution. */
  protected final static String RESOLUTION  = "resolution";

  /** I - big star parameters. */
  protected final static String STAR_NUMBER = "starNumber";

  /** II - big fan parameters. */
  protected final static String FAN_NUMBER  = "fanNumber";

  /** III - arrows parameters. */
  protected final static String ARR_RADIUS  = "arrRadius";
  protected final static String ARR_NUMBER  = "arrNumber";

  //==========================================================================
  //  Support:

  /** Polygon array. */
  Point2D.Double[] p;

  /** Polygon array backup. */
  Point2D.Double[] q;

  /** Global random generator. */
  RandomJames rnd;

  /** Polygonal window - relative coordinates. */
  final double[][] win =
  {
    { 0.20, 0.20 }, { 0.25, 0.20 }, { 0.30, 0.40 }, { 0.40, 0.90 },
    { 0.50, 0.10 }, { 0.60, 0.20 }, { 0.70, 0.70 }, { 0.80, 0.20 },
    { 0.90, 0.20 }, { 1.00, 0.80 }, { 1.10, 0.20 }, { 1.15, 0.20 },
    { 1.25, 0.90 }, { 1.30, 0.20 }, { 1.35, 0.40 }, { 1.45, 0.50 },
    { 1.50, 0.95 }, { 1.60, 0.15 }, { 1.65, 0.20 }, { 1.80, 0.20 },
    { 1.80, 1.00 }, { 1.10, 1.05 }, { 1.70, 1.20 }, { 1.80, 1.25 },
    { 1.80, 1.30 }, { 1.20, 1.34 }, { 1.80, 1.40 }, { 1.80, 1.80 },
    { 1.60, 1.80 }, { 1.60, 1.45 }, { 1.30, 1.45 }, { 1.30, 1.70 },
    { 1.31, 1.70 }, { 1.50, 1.70 }, { 1.50, 1.55 }, { 1.36, 1.55 },
    { 1.36, 1.56 }, { 1.49, 1.56 }, { 1.49, 1.69 }, { 1.31, 1.69 },
    { 1.31, 1.47 }, { 1.57, 1.47 }, { 1.57, 1.80 }, { 1.10, 1.80 },
    { 1.05, 0.90 }, { 0.80, 1.80 }, { 0.60, 1.80 }, { 0.60, 1.40 },
    { 0.50, 1.40 }, { 0.50, 1.80 }, { 0.20, 1.80 }, { 0.20, 1.30 },
    { 0.85, 1.28 }, { 0.20, 1.27 }, { 0.20, 1.10 }, { 0.80, 1.10 },
    { 0.60, 1.00 }, { 0.90, 0.95 }, { 0.20, 0.92 },
  };

  /** Creates star with non-uniformly distributed tips. */
  protected void makeStar ( double x0, double y0, double r1, double r2, double angle0, double exp, int n )
  {
    double dAngle = 1.0 / n;
    double angle  = 0.0;
    int i;
    for ( i = 0; i < n; i++, angle += dAngle )
    {
      double alph = (Math.pow( angle, exp ) + angle0) * 2.0 * Math.PI;
      double rad  = ((i & 1) == 0) ? r2 : r1;
      p[i]  = new Point2D.Double( x0 + rad * Math.sin( alph ),
                                  y0 - rad * Math.cos( alph ) );
      q[i]  = new Point2D.Double( x0 + rad * Math.sin( alph ),
                                  y0 - rad * Math.cos( alph ) );
    }
    p[i] = null;
    q[i] = null;
  }

  /** Creates fan with given number of tips. */
  protected void makeFan ( double x0, double y0, double r1, double r2, int n )
  {
    int i, j;
    for ( i = j = 0; j++ < n; )
    {
      double alph = rnd.uniformNumber() * 2.0 * Math.PI;
      double rad  = rnd.randomDouble( r1, r2 );
      double fan  = rnd.randomDouble( 0.01, 0.11 );
      p[i  ] = new Point2D.Double( x0, y0 );
      q[i++] = new Point2D.Double( x0, y0 );
      p[i  ] = new Point2D.Double( x0 + rad * Math.sin( alph ),
                                   y0 - rad * Math.cos( alph ) );
      q[i++] = new Point2D.Double( x0 + rad * Math.sin( alph ),
                                   y0 - rad * Math.cos( alph ) );
      alph += fan;
      p[i  ] = new Point2D.Double( x0 + rad * Math.sin( alph ),
                                   y0 - rad * Math.cos( alph ) );
      q[i++] = new Point2D.Double( x0 + rad * Math.sin( alph ),
                                   y0 - rad * Math.cos( alph ) );
    }
    p[i] = null;
    q[i] = null;
  }

  /**
   * Runs one instance of the test (simple variant, w/o global result storage).
   */
  @Override
  public boolean runTest ( Map< String, String > env, Map< String, String > param, PrintStream out )
  {
      // class name:
    String shortName = param.get( CLASS_NAME );
    if ( shortName == null )
    {
      out.println( "Cannot find the '<" + CLASS_NAME + ">' test argument!" );
      return false;
    }
    String className = Template.JAGRLIB2 + shortName;

      // picture file-name:
    String outputFileName = param.get( OUTPUT_FILE_NAME );
    if ( outputFileName == null )
      outputFileName = "output.png";
    String tmp = env.get( BASE );
    if ( tmp != null )
    {
      File baseDir = new File( tmp );
      baseDir.mkdirs();
      outputFileName = tmp.concat( outputFileName );
    }

      // antialiasing flag:
    final boolean antiAlias = booleanParam( env, param, ANTI_ALIAS, false );

      // random seeds:
    final int seed1         = integerParam( env, param, SEED1,        0 );
    final int seed2         = integerParam( env, param, SEED2,       12 );

      // big stars:
    final int starNumber    = integerParam( env, param, STAR_NUMBER, 10 );

      // big fans:
    final int fanNumber     = integerParam( env, param, FAN_NUMBER,  10 );

      // random arrows:
    final double arrRadius  = doubleParam(  env, param, ARR_RADIUS,  30.0 );
    final int arrNumber     = integerParam( env, param, ARR_NUMBER,  10 );

      // image resolution in pixels:
    final int resolution    = integerParam( env, param, RESOLUTION, 600 );

    final int maxPoly       = 600;

      // create Piece objects:
    Piece clipping;
    try
    {
      clipping = (Piece)(Class.forName( className ).newInstance());
    }
    catch ( Exception e )
    {
      out.println( "Cannot instantiate the '" + shortName + "' class!" );
      return false;
    }
    if ( !(clipping instanceof PolygonFillRender) ||
         !(clipping instanceof PolygonWindow) )
    {
      out.println( "The '" + shortName + "' class doesn't implement PolygonFillRender and PolygonWindow interfaces!" );
      return true;
    }

    final PolygonScanline poly   = new PolygonScanline();
    final XTransitionList mask   = new XTransitionList();
    final AlphaMatrix     alpha  = new AlphaMatrix();
    final SolidColorBrush brush  = new SolidColorBrush();
    final RasterImage     image  = new RasterImage();
    final PNGFileFormat   png    = new PNGFileFormat();
    final JavaBitStream   output = new JavaBitStream();
    output.set( JavaBitStream.STREAM_NAME, outputFileName );

      // connect them by channels:
    try
    {
      clipping.connect( Piece.PL_OUTPUT, poly, Piece.PL_INPUT );
      if ( antiAlias )
      {
        poly.connect(  Piece.PL_ALPHAMASK, alpha, Piece.PL_INPUT );
        brush.connect( Piece.PL_ALPHAMASK, alpha, Piece.PL_INPUT );
      }
      else
      {
        poly.connect(  Piece.PL_BITMASK, mask, Piece.PL_INPUT );
        brush.connect( Piece.PL_BITMASK, mask, Piece.PL_INPUT );
      }
      brush.connect( Piece.PL_OUTPUT, image,  Piece.PL_INPUT );
      png.connect(   Piece.PL_RASTER, image,  Piece.PL_INPUT );
      png.connect(   Piece.PL_STREAM, output, Piece.PL_INPUT );
    }
    catch ( BadInterfaceException e )
    {
      out.println( "Error connecting the '" + shortName + "' module!" );
      LogFile.exception( "Bad Interface in connecting-time!", e );
      return false;
    }

      // set Pieces' parameters:
    if ( antiAlias )
    {
      image.init( resolution, resolution, RasterGraphics.MODE_RGBA, 0 );
      alpha.init( resolution, resolution );
    }
    else
    {
      image.init( resolution, resolution, RasterGraphics.MODE_RGB, 0 );
      mask.init(  resolution, resolution );
    }
    poly.set( PolygonRender.POLY_INSIDE, PolygonRender.POLY_INSIDE_PARITY );

    double[] color = { 1.0, 1.0, 0.85, 1.0 };
    double[] clear = { 0.1, 0.1, 0.15, 1.0 };

      // random generator:
    rnd = new RandomJames( seed1, seed2 );

      // support variables:
    final PolygonFillRender clip = (PolygonFillRender)clipping;
    final PolygonWindow window   = (PolygonWindow)clipping;
    final double half = resolution * 0.5;
    p = new Point2D.Double[ maxPoly ];
    q = new Point2D.Double[ maxPoly ];
    double x0, y0;
    int i;

      // time measurement:
    long startTime = System.currentTimeMillis();

    try
    {
      i = 0;
      for ( double[] d : win )
        p[i++] = new Point2D.Double( d[0] * half, d[1] * half );
      p[i] = null;
      window.polygonWindow( p );

        // I - big stars:
      for ( i = 0; i++ < starNumber; )
      {
        double r1 = rnd.randomDouble( 10.0,  60.0 );
        double r2 = rnd.randomDouble( 90.0, 190.0 );
        x0        = rnd.randomDouble( r2, resolution - r2 );
        y0        = rnd.randomDouble( r2, resolution - r2 );

        makeStar( x0, y0, r1, r2, rnd.uniformNumber(), 4.0,
                  Formula.round( rnd.randomDouble( 20.0, 170.0 ) ) );

        poly.fillPolygon( p );
        color[0] = rnd.randomDouble( 0.3, 1.0 );
        color[1] = rnd.randomDouble( 0.3, 1.0 );
        color[2] = rnd.randomDouble( 0.3, 1.0 );
        brush.setColor( color );
        brush.fill();
        clip.fillPolygon( q );
        brush.setColor( clear );
        brush.fill();
      }

        // II - big fans:
      for ( i = 0; i++ < fanNumber; )
      {
        double r1 = rnd.randomDouble( 10.0,  50.0 );
        double r2 = rnd.randomDouble( 80.0, 200.0 );
        x0        = rnd.randomDouble( r2, resolution - r2 );
        y0        = rnd.randomDouble( r2, resolution - r2 );

        makeFan( x0, y0, r1, r2,
                 Formula.round( rnd.randomDouble( 20.0, 140.0 ) ) );

        poly.fillPolygon( p );
        color[0] = rnd.randomDouble( 0.3, 1.0 );
        color[1] = rnd.randomDouble( 0.3, 1.0 );
        color[2] = rnd.randomDouble( 0.3, 1.0 );
        brush.setColor( color );
        brush.fill();
        clip.fillPolygon( q );
        brush.setColor( clear );
        brush.fill();
      }

        // III - arrows:
      double x, y;

      for ( i = 0; i++ < arrNumber; )
      {
        x0           = rnd.randomDouble( arrRadius, resolution - arrRadius );
        y0           = rnd.randomDouble( arrRadius, resolution - arrRadius );
        double angle = rnd.uniformNumber() * 2.0 * Math.PI;
        double sina  = Math.sin( angle );
        double cosa  = Math.cos( angle );

        double tailX = arrRadius *       rnd.randomDouble( 0.2, 1.0 );
        double tailY = arrRadius * 0.2 * rnd.uniformNumber();
        double tipY  = arrRadius *       rnd.randomDouble( 0.2, 0.7 );
        double tip2Y = tipY      *       rnd.randomDouble( 0.2, 0.5 );
        double spike = arrRadius *       rnd.randomDouble( 0.4, 1.0 );
        double tip2X = spike     * 0.2 * rnd.uniformNumber();

        x    = -tailX;
        y    =  tailY;
        p[0] = new Point2D.Double( x0 + x * cosa + y * sina,
                                   y0 - x * sina + y * cosa );
        q[0] = new Point2D.Double( x0 + x * cosa + y * sina,
                                   y0 - x * sina + y * cosa );
        y    = -tailY;
        p[1] = new Point2D.Double( x0 + x * cosa + y * sina,
                                   y0 - x * sina + y * cosa );
        q[1] = new Point2D.Double( x0 + x * cosa + y * sina,
                                   y0 - x * sina + y * cosa );
        x    =  tip2X;
        y    = -tip2Y;
        p[2] = new Point2D.Double( x0 + x * cosa + y * sina,
                                   y0 - x * sina + y * cosa );
        q[2] = new Point2D.Double( x0 + x * cosa + y * sina,
                                   y0 - x * sina + y * cosa );
        x    =  0.0;
        y    = -tipY;
        p[3] = new Point2D.Double( x0 + x * cosa + y * sina,
                                   y0 - x * sina + y * cosa );
        q[3] = new Point2D.Double( x0 + x * cosa + y * sina,
                                   y0 - x * sina + y * cosa );
        x    =  spike;
        y    =  0.0;
        p[4] = new Point2D.Double( x0 + x * cosa + y * sina,
                                   y0 - x * sina + y * cosa );
        q[4] = new Point2D.Double( x0 + x * cosa + y * sina,
                                   y0 - x * sina + y * cosa );
        x    =  0.0;
        y    =  tipY;
        p[5] = new Point2D.Double( x0 + x * cosa + y * sina,
                                   y0 - x * sina + y * cosa );
        q[5] = new Point2D.Double( x0 + x * cosa + y * sina,
                                   y0 - x * sina + y * cosa );
        x    =  tip2X;
        y    =  tip2Y;
        p[6] = new Point2D.Double( x0 + x * cosa + y * sina,
                                   y0 - x * sina + y * cosa );
        q[6] = new Point2D.Double( x0 + x * cosa + y * sina,
                                   y0 - x * sina + y * cosa );
        p[7] = null;
        q[7] = null;

        poly.fillPolygon( p );
        color[0] = rnd.randomDouble( 0.3, 1.0 );
        color[1] = rnd.randomDouble( 0.3, 1.0 );
        color[2] = rnd.randomDouble( 0.3, 1.0 );
        brush.setColor( color );
        brush.fill();
        clip.fillPolygon( q );
        brush.setColor( clear );
        brush.fill();
      }
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }

      // stop time:
    long stopTime = System.currentTimeMillis();

      // save the result:
    try
    {
      png.saveFile( (String)null, null );
    }
    catch ( Exception e )
    {
      LogFile.error( "Error writting '" + outputFileName + "' image!" );
    }

    out.println( String.format( Locale.US, "OK (%5.3fs) %s", 1.e-3 * (stopTime - startTime), shortName ) );
    return true;
  }

}
