package cz.cuni.jagrlib.gui;

import java.util.*;
import java.awt.*;
import javax.swing.*;
import java.lang.management.*;

import cz.cuni.jagrlib.*;

/**
 * About dialog for the Skel application.
 *
 * @author  PE, Jan Kostlivy
 * @version 0.26 $Rev: 746 $ $Date: 2008-05-17 11:20:49 +0200 (so, 17 V 2008) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/AboutDialog.java">AboutDialog.java</a>
 */
public class AboutDialog extends JDialog
{
  private static final long serialVersionUID = 1L;

  //==========================================================================
  //  Methods:

  /**
   * Creates new Options dialog.
   *
   * @param frame Owner frame.
   */
  public AboutDialog ( Frame frame )
  {
    super( frame, "About Skel", true );
    try
    {
      init();
      pack();
      setLocation();
    }
    catch ( Exception ex )
    {
      LogFile.exception( ex );
    }
  }

  /**
   * Initialization of all dialog components.
   */
  private void init ()
  throws Exception
  {
      // panel:
    JPanel panel     = new JPanel( new GridBagLayout() );

      // icon:
    JLabel icon      = new JLabel( Options.getIcon( "logo64.gif" ) );
      // name:
    JLabel name      = new JLabel( Version.SKEL_NAME );
    name.setFont( new Font( "Dialog", 1, 32 ) );
      // version:
    JLabel version   = new JLabel( "Ver: " + Version.niceVersion() );
      // copyright:
    JLabel copyright = new JLabel( Version.SKEL_COPYRIGHT + " " + Version.SKEL_AUTHOR );
      // main contributors:
    JLabel contrib   = new JLabel( Version.SKEL_CONTRIB );
      // JaGrLib:
    JLabel jagrlib   = new JLabel( Version.SKEL_JAGRLIB );
      // URL:
    JLabel seeURL    = new JLabel( "Visit: " + Version.JAGRLIB_URL );

      // memory & OS statistics:
    MemoryMXBean mxb = ManagementFactory.getMemoryMXBean();
    MemoryUsage   mu = mxb.getHeapMemoryUsage();
    RuntimeMXBean rt = ManagementFactory.getRuntimeMXBean();
    OperatingSystemMXBean os = ManagementFactory.getOperatingSystemMXBean();
    JLabel mem1      = new JLabel( String.format( Locale.US, "Mem: init = %.1fM, max = %.1fM",
                                                  Formula.toMega( mu.getInit() ),
                                                  Formula.toMega( mu.getMax() ) ) );
    JLabel mem2      = new JLabel( String.format( Locale.US, "Mem: used = %.1fM, comm = %.1fM",
                                                  Formula.toMega( mu.getUsed() ),
                                                  Formula.toMega( mu.getCommitted() ) ) );
    JLabel os1       = new JLabel( rt.getVmName() + " (" + rt.getVmVersion() + ')' );
    JLabel os2       = new JLabel( "Arch: " + os.getArch() + ", " + os.getName() +
                                   " (" + os.getVersion() + "), cores: " + os.getAvailableProcessors() );

      // insert all components to the dialog pane:
    getContentPane().add( panel, BorderLayout.CENTER );
    GridBagConstraints c = new GridBagConstraints();
    c.insets    = new Insets( 15, 60, 15,  0 );
    panel.add( icon, c );
    c.insets    = GuiConstants.INSETS_0;
    panel.add( name, c );
    c.gridwidth = 2;                      // all the rest will spread to both columns
    c.gridx     = 0;                      // 2nd row
    c.gridy     = GridBagConstraints.RELATIVE; // all the rest will be y-relative
    c.insets    = new Insets(  0, 15,  2, 15 );
    panel.add( version,   c );
    panel.add( copyright, c );
    panel.add( contrib,   c );
    panel.add( jagrlib,   c );
    panel.add( seeURL,    c );
    c.insets    = new Insets( 10, 15,  1, 15 );
    c.anchor    = GridBagConstraints.WEST;
    panel.add( mem1,      c );
    c.insets    = new Insets(  0, 15,  1, 15 );
    panel.add( mem2,      c );
    panel.add( os1,       c );
    c.insets    = new Insets(  0, 15, 12, 15 );
    panel.add( os2,       c );
  }

  /** Set dialog location: middle of the screen. */
  protected void setLocation ()
  {
    Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
    setLocation( screenSize.width/2  - getWidth()/2,
                 screenSize.height/2 - getHeight()/2 );
    setResizable( false );
  }

}
