package cz.cuni.jagrlib.gui;

import java.util.*;
import java.awt.*;
import java.awt.event.*;

/**
 * Undo / Redo object.
 *
 * @author  Jan Kostlivy
 * @version 0.25 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/ActionsUndo.java">ActionsUndo.java</a>
 */
public class ActionsUndo
{
  /**
   * Tests, if list is at the beginning.
   *
   * @return true or false
   */
  public boolean isOnStart ()
  {
    return ( actualPosition == 0 );
  }

  /**
   * Tests, if list is at the end.
   *
   * @return true or false
   */
  public boolean isOnEnd ()
  {
    return ( actualPosition == action.size() );
  }

  /** Flag, if composition was changed. */
  private boolean changedComposition = false;

  private Vector<ActionsUndoReg> action = new Vector<ActionsUndoReg>();
  private int actualPosition = 0;

  /** Flag for permition to adding new actions. */
  public boolean dont = false;

  /** Delete all actions from list. */
  public void clear ()
  {
    action.clear();
    actualPosition     = 0;
    changedComposition = false;
  }

  /**
   * Test, if composition was changed.
   *
   * @return true or false
   */
  public boolean changed ()
  {
    return changedComposition;
  }

  /**
   * Registry action to list.
   *
   * @param _action Akce
   */
  public void registry ( ActionsUndoReg _action )
  {
    if ( dont ) return;

    action.add( actualPosition, _action );
    actualPosition++;
    changedComposition = true;
    registryPerformed( _action );
  }

  /** Returns last action.*/
  public void undo ()
  {
    if ( actualPosition == 0 ) return;

    actualPosition--;
    ActionsUndoReg a = action.get( actualPosition );
    a.objectReg.undo( a );
  }

  /** Returns last undoed action.*/
  public void redo ()
  {
    if ( actualPosition == action.size() ) return;

    ActionsUndoReg a = action.get( actualPosition );
    actualPosition++;
    a.objectReg.redo( a );
  }

  transient ActionListener actionListener;

  /** Filter change. */
  public void registryPerformed ( ActionsUndoReg _action )
  {
    ActionEvent e = new ActionEvent( _action, 0, null );
    processActionEvent( e );
  }

  /**
   * Adds the specified action listener to receive action events from
   * this object. Action events occur when any action is registred.
   * If l is null, no exception is thrown and no action is performed.
   *
   * @param         l the action listener
   * @see           #removeActionListener
   * @see           java.awt.event.ActionListener
   */
  public synchronized void addActionListener ( ActionListener l )
  {
    if ( l != null )
      actionListener = AWTEventMulticaster.add( actionListener, l );
  }

  /**
   * Removes the specified action listener so that it no longer
   * receives action events from this object.
   * If l is null, no exception is thrown and no action is performed.
   *
   * @param  l the action listener
   * @see    #addActionListener
   * @see    java.awt.event.ActionListener
   */
  public synchronized void removeActionListener ( ActionListener l )
  {
    if ( l != null )
      actionListener = AWTEventMulticaster.remove( actionListener, l );
  }

  /**
   * Processes action events occurring on this object
   * by dispatching them to any registered
   * <tt>ActionListener</tt> objects.
   *
   * <p>This method is not called unless action events are
   * enabled for this object. Action events are enabled
   * when one of the following occurs:
   * <ul>
   * <li>An <tt>ActionListener</tt> object is registered
   * via <tt>addActionListener</tt>.
   * <li>Action events are enabled via <tt>enableEvents</tt>.
   * </ul>
   *
   * <p>Note that if the event parameter is <tt>null</tt>
   * the behavior is unspecified and may result in an
   * exception.
   *
   * @param       e the action event
   * @see         java.awt.event.ActionListener
   * @see         java.awt.Component#enableEvents
   */
  protected void processActionEvent ( ActionEvent e )
  {
    if ( actionListener != null )
      actionListener.actionPerformed( e );
  }

}
