package cz.cuni.jagrlib.gui;

import java.awt.*;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Improved class that care about visual representation of channels.
 * It has four orientation of arrow - North, South, West, East.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/ChannelGUIImproved.java">ChannelGUIImproved.java</a>
 */
public class ChannelGUIImproved extends ChannelGUI
{
  //==========================================================================
  //  Data:

  /** Start position of a channel. */
  int x1;

  /** Start position of a channel. */
  int y1;

  /** End position of a channel. */
  int x2;

  /** End position of a channel. */
  int y2;

  /** Orientation of "from-plugs". */
  int orF;

  /** Orientation of "to-plugs". */
  int orT;

  //==========================================================================
  //  Methods ChannelGUI:

  /**
   * Tests, if point lies on channel.
   *
   * @param  px x-axis.
   * @param  py y-axis.
   * @return {@code true} if point lies on a channel.
   */
  public boolean contains ( int px, int py )
  {
    if ( x2 > x1 && (x2 < px || x1 > px) ||
         x2 < x1 && (x2 > px || x1 < px) ||
         y2 > y1 && (y2 < py || y1 > py) ||
         y2 < y1 && (y2 > py || y1 < py) ) return false;

    int xx1 = x1;
    int yy1 = y1;
    int xx2;
    int yy2;

    switch ( orT )
    {
      case PlugGUIImproved.PGI_ORIENTATION_EAST:
        xx2 = x2 + 7;
        yy2 = y2;
        break;

      case PlugGUIImproved.PGI_ORIENTATION_NORTH:
        xx2 = x2;
        yy2 = y2 - 7;
        break;

      case PlugGUIImproved.PGI_ORIENTATION_WEST:
        xx2 = x2 - 7;
        yy2 = y2;
        break;

      case PlugGUIImproved.PGI_ORIENTATION_SOUTH:
      default:
        xx2 = x2;
        yy2 = y2 + 7;
    }

    if ( Geometry.pointSegment2D( px, py, xx1, yy1, xx2, yy2 ) < 2.0 )
      return true;

      // arrow
    switch ( orT )
    {
      case PlugGUIImproved.PGI_ORIENTATION_EAST:
        if ( (xx1 = px - x2) > 6 ||
              xx1 < 0 ) return false;
        return( py >= y2 - xx1 &&
                py <= y2 + xx1 );

      case PlugGUIImproved.PGI_ORIENTATION_NORTH:
        if ( (yy1 = y2 - py) > 6 ||
              yy1 < 0 ) return false;
        return( px >= x2 - yy1 &&
                px <= x2 + yy1 );

      case PlugGUIImproved.PGI_ORIENTATION_WEST:
        if ( (yy1 = x2 - px) > 6 ||
              yy1 < 0 ) return false;
        return( py >= y2 - yy1 &&
                py <= y2 + yy1 );

      case PlugGUIImproved.PGI_ORIENTATION_SOUTH:
      default:
        if ( (yy1 = py - y2) > 6 ||
              yy1 < 0 ) return false;
        return( px >= x2 - yy1 &&
                px <= x2 + yy1 );
    }
  }

  /** Extends the given rectangle to hold the channel image. */
  public void extend ( Rectangle r )
  {
    r.add( x1, y1 );
    r.add( x2, y2 );
  }

  /** Registration of channel in plugs. */
  public void registryChannel ()
  {
    if ( info.plugFrom != null )
      info.plugFrom.registryChannel( info );

    if ( info.plugTo != null )
      info.plugTo.registryChannel( info );
  }

  /**
   * Remove channel.
   * Un-registers channel from all plugs.
   */
  public void removeChannel ()
  {
    if ( info.plugFrom != null )
      info.plugFrom.unregistryChannel( info );

    if ( info.plugTo != null )
      info.plugTo.unregistryChannel( info );
  }

  //==========================================================================
  //  Methods:

  /**
   * Creates new ChannelGUIImproved.
   *
   * @param  _info Information about channel.
   */
  public ChannelGUIImproved ( InfoChannel _info )
  {
    try
    {
      info = _info;
      if ( info.infoGUI == null )
        info.infoGUI = new InfoChannelGUI();

      info.infoGUI.gui = this;
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Component initialization.
   */
  private void jbInit ()
  throws Exception
  {
    registryChannel();
  }

  /**
   * Paints extra graphics on composition panel:
   * channels with arrows..
   */
  public void paintItem ( Graphics g )
  {
      // color of channel
    g.setColor( InfoChannelGUI.colorNormal );
    if ( info.plugFrom != null && info.plugFrom.owner.infoGUI.selected )
      g.setColor( InfoChannelGUI.colorActiveModule );

    if ( info.plugTo != null && info.plugTo.owner.infoGUI.selected )
      g.setColor( InfoChannelGUI.colorActiveModule );

      // Plug position
    InfoModule im;
    if ( info.plugFrom != null )
    {
      orF = info.plugFrom.infoGUI.orientation;
      x1  = info.plugFrom.infoGUI.gui.getX();
      y1  = info.plugFrom.infoGUI.gui.getY();
      im  = info.plugFrom.owner;
      x1 += im.infoGUI.gui.getX();
      y1 += im.infoGUI.gui.getY();
      if ( im.nextInfo != null )
      {
        im = (InfoModule)im.nextInfo.get( "OWNER" );
        if ( im != null && info.plugFrom.infoGUI.visible )
        {
          x1 += im.infoGUI.gui.getX();
          y1 += im.infoGUI.gui.getY();
        }
      }
    }
    else // temporary channel
    {
      g.setColor( InfoChannelGUI.colorTemp );
      String xx = (String)info.infoGUI.nextInfo.get( "X" );
      if ( xx != null )
        x1 = Integer.parseInt( xx );

      String yy = (String)info.infoGUI.nextInfo.get( "Y" );
      if ( yy != null )
        y1 = Integer.parseInt( yy );

      orF = PlugGUI.PGI_ORIENTATION_SOUTH;
    }

    if ( info.plugTo != null )
    {
      orT = info.plugTo.infoGUI.orientation;
      x2  = info.plugTo.infoGUI.gui.getX();
      y2  = info.plugTo.infoGUI.gui.getY();
      im  = info.plugTo.owner;
      x2 += im.infoGUI.gui.getX();
      y2 += im.infoGUI.gui.getY();
      if ( im.nextInfo != null )
      {
        im = (InfoModule)im.nextInfo.get( "OWNER" );
        if ( im != null && info.plugTo.infoGUI.visible )
        {
          x2 += im.infoGUI.gui.getX();
          y2 += im.infoGUI.gui.getY();
        }
      }
    }
    else // temporary channel
    {
      g.setColor( InfoChannelGUI.colorTemp );
      String xx = (String)info.infoGUI.nextInfo.get( "X" );
      if ( xx != null )
        x2 = Integer.parseInt( xx );

      String yy = (String)info.infoGUI.nextInfo.get( "Y" );
      if ( yy != null )
        y2 = Integer.parseInt( yy );

      orT = PlugGUI.PGI_ORIENTATION_SOUTH;
    }

      // paint channel
    switch ( orT )
    {
      case PlugGUIImproved.PGI_ORIENTATION_EAST:
        g.drawLine( x1, y1, x2 + 7, y2 );
        break;

      case PlugGUIImproved.PGI_ORIENTATION_NORTH:
        g.drawLine( x1, y1, x2, y2 - 7 );
        break;

      case PlugGUIImproved.PGI_ORIENTATION_WEST:
        g.drawLine( x1, y1, x2 - 7, y2 );
        break;

      case PlugGUI.PGI_ORIENTATION_SOUTH:
        g.drawLine( x1, y1, x2, y2 + 7 );
        break;
    }

      // draws an arrow
    Polygon pol = new Polygon();
    switch ( orT )
    {
      case PlugGUIImproved.PGI_ORIENTATION_EAST:
        pol.addPoint( x2,     y2 );
        pol.addPoint( x2 + 7, y2 - 5 );
        pol.addPoint( x2 + 7, y2 + 5 );
        break;

      case PlugGUIImproved.PGI_ORIENTATION_NORTH:
        pol.addPoint( x2,     y2 );
        pol.addPoint( x2 - 5, y2 - 7 );
        pol.addPoint( x2 + 5, y2 - 7 );
        break;

      case PlugGUIImproved.PGI_ORIENTATION_WEST:
        pol.addPoint( x2,     y2 );
        pol.addPoint( x2 - 7, y2 - 5 );
        pol.addPoint( x2 - 7, y2 + 5 );
        break;

      case PlugGUI.PGI_ORIENTATION_SOUTH:
        pol.addPoint( x2,     y2 );
        pol.addPoint( x2 - 5, y2 + 7 );
        pol.addPoint( x2 + 5, y2 + 7 );
        break;
    }

    g.fillPolygon( pol );
  }

}
