package cz.cuni.jagrlib.gui;

import java.util.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Basic class that cares about visual representation of a composition.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/CompositionGUIBasic.java">CompositionGUIBasic.java</a>
 */
public class CompositionGUIBasic extends CompositionGUI
{
  private static final long serialVersionUID = 1L;

  /** Key of actual channel. */
  private Integer channelKey;

  /** Undo/Redo constants. */
  final static public int ACTION_MODULE_ADD  = 3;
  final static public int ACTION_CHANNEL_ADD = 4;

  // GUI components:
  private JPopupMenu jPopupMenu1            = new JPopupMenu();
  private JMenuItem  jMenuItemDeleteChannel = new JMenuItem();

  /**
   * Connects the given module with others..
   */
  @Override
  public void connectWithOther ( InfoModule infoM )
  {
    for ( InfoModule mod : info.modules.values() )
      for ( InfoPlug myPlug : infoM.plugs.values() )
      {
        InfoPlug opposite  = findOpposite( myPlug, mod );
        if ( opposite != null &&
             findChannel( myPlug, opposite ) == null )
        {
          InfoChannel ic   = new InfoChannel();
          ic.infoGUI       = new InfoChannelGUI();
          ic.key           = idChannel.getNextId();
          if ( opposite.input )
          {
            ic.plugFrom    = myPlug;
            ic.plugTo      = opposite;
          }
          else
          {
            ic.plugFrom    = opposite;
            ic.plugTo      = myPlug;
          }
          ic.nameInterface = opposite.name;
          ic.owner         = info;

          if ( undoReg != null )
            undoReg.registry( new ActionsUndoReg( this, ACTION_CHANNEL_ADD, null, ic ) );

          newChannel( ic );
          info.channels.put( ic.key, ic );
        }
      }
  }

  /**
   * Finds module with field Name equals _name.
   *
   * @param  _name Module name to find.
   * @return Module named {@code _name} or {@code null}.
   */
  public InfoModule findModule ( String _name )
  {
    for ( InfoModule im : info.modules.values() )
      if ( im.reg.name.equals( _name ) )
        return im;

    return null;
  }

  /**
   * If the new module has the same name as any other in composition,
   * rename it! (use number extensions 2, 3, ..).
   *
   * @param  _newModule New module to add.
   */
  public void renameNewModule ( InfoModule _newModule )
  {
    if ( findModule( _newModule.reg.name ) == null )
      return;

    int count = 2;
    String newName;
    while ( findModule( newName = (_newModule.reg.name + String.valueOf( count )) ) != null )
      count++;

    _newModule.reg.name = newName;
  }

  /** Delete all selected modules. */
  public void delete ()
  {
    Set< Integer > keys = new HashSet< Integer >( info.modules.keySet() );
    for ( Integer key : keys )
      if ( info.modules.get( key ).infoGUI.selected )
        removeModule( key );
  }

  /**
   * Replace module with new one.
   *
   * @param  infoOld Information about old module.
   */
  public void replaceModule ( InfoModule infoOld )
  {
    InfoModule infoNew = RegDatabaseBasic.viewModules( infoOld );
    if ( infoNew == null ) return;

      // change of module
    if ( infoNew.infoGUI == null )
      infoNew.infoGUI = new InfoModuleGUI();

    infoNew.key              = infoOld.key;
    infoNew.infoGUI.selected = infoOld.infoGUI.selected;
    infoNew.infoGUI.modeShow = infoOld.infoGUI.modeShow;
    infoNew.infoGUI.x        = infoOld.infoGUI.x;
    infoNew.infoGUI.y        = infoOld.infoGUI.y;
    infoNew.infoGUI.height   = infoOld.infoGUI.height;
    infoNew.infoGUI.width    = infoOld.infoGUI.width;
    infoNew.owner            = infoOld.owner;

      // new module: key set. Contains only available plugs.
    Set< String > newNames = new HashSet< String >( infoNew.plugs.keySet() );

      // keys which must be removed from newNames after the iteration (due to the ConcurrentModificationException)
    Set< String > toRemove = new HashSet< String >();

      // plug mapping (old plug id -> new plug id):
    Map< String, String > plugMap  = new HashMap< String, String >();

      // highest priority: plug names are equal (compatible plugs)
    for ( String key : infoOld.plugs.keySet() )
    {
      if ( newNames.contains( key ) )
      {
        InfoPlug ipOld = infoOld.plugs.get( key );
        InfoPlug ipNew = infoNew.plugs.get( key );
        if ( ipNew.name.equals( ipOld.name ) &&
             ipNew.input == ipOld.input )
        {
          plugMap.put( key, key );
          newNames.remove( key );
        }
      }
    }
      // lowest priority: matching only plug types (interfaces)
    for ( String oldKey : infoOld.plugs.keySet() )
      if ( !plugMap.containsKey( oldKey ) )
      {                                   // unmapped key
        InfoPlug ipOld = infoOld.plugs.get( oldKey );
        String oldType = ipOld.name;
        toRemove.clear();
        for ( String newKey : newNames )
        {
          InfoPlug ipNew = infoNew.plugs.get( newKey );
          if ( ipNew.name.equals( oldType ) &&
               ipNew.input == ipOld.input )
          {
            plugMap.put( oldKey, newKey );
            toRemove.add( newKey );
          }
        }
        newNames.removeAll( toRemove );
      }

        // unmatched plugs:
    if ( newNames.size() > 0 )
    {
      StringBuffer sb = new StringBuffer( "Plugs" );
      for ( String n : newNames )
      {
        sb.append( " '" );
        sb.append( n );
        sb.append( "'" );
      }
      sb.append( " will not be connected!" );
      JOptionPane.showMessageDialog( this, sb.toString(), "Warning", JOptionPane.WARNING_MESSAGE );

        // place the unmatched plug:
      int x = 5;
      int y = infoNew.infoGUI.height - 2;
      for ( String n : newNames )
      {
        InfoPlug ipNew = infoNew.plugs.get( n );
        if ( ipNew.infoGUI == null )
          ipNew.infoGUI = new InfoPlugGUI();
        else
          ipNew.infoGUI.orientation = PlugGUI.PGI_ORIENTATION_SOUTH;
        ipNew.infoGUI.x = x;
        ipNew.infoGUI.y = y;
        x = Formula.clamp( (x += 15), 5, infoNew.infoGUI.width - 15 );
      }
    }

      // transfer plug data:
    for ( String oldKey : plugMap.keySet() )
    {
      String newKey  = plugMap.get( oldKey );
      InfoPlug ipOld = infoOld.plugs.get( oldKey );
      InfoPlug ipNew = infoNew.plugs.get( newKey );
      if ( ipNew.infoGUI == null )
        ipNew.infoGUI = new InfoPlugGUI();
      ipNew.infoGUI.orientation = ipOld.infoGUI.orientation;
      ipNew.infoGUI.x = ipOld.infoGUI.x;
      ipNew.infoGUI.y = ipOld.infoGUI.y;
    }

      // transfer values of compatible parameters..
    for ( String name : infoNew.params.keySet() )
      if ( infoOld.params.containsKey( name ) )
      {
        InfoParam ipNew = infoNew.params.get( name );
        InfoParam ipOld = infoOld.params.get( name );
        if ( ipNew.type.equals( ipOld.type ) )
          ipNew.value = ipOld.value;
      }

    if ( undoReg != null ) undoReg.dont = true;

      // transform incident channels:
    Set< Integer > chKeys = new HashSet< Integer >( info.channels.keySet() );
    for ( Integer k : chKeys )
    {
      InfoChannel ic = info.channels.get( k );

        // from the old (replaced) module..
      if ( ic.plugFrom.owner.equals( infoOld ) )
      {
        removeChannel( k );

        String nameFrom = plugMap.get( ic.plugFrom.type );
        if ( nameFrom != null )           // there is matching plug in the new module
        {
          InfoPlug    ipNew   = infoNew.plugs.get( nameFrom );
          InfoChannel icNew   = new InfoChannel();
          icNew.key           = k;
          icNew.plugFrom      = ipNew;
          icNew.plugTo        = ic.plugTo;
          icNew.nameInterface = ipNew.name;
          icNew.owner         = info;
          newChannel( icNew );
          info.channels.put( k, icNew );
        }
      }

        // to the old (replaced) module..
      if ( ic.plugTo.owner.equals( infoOld ) )
      {
        removeChannel( k );

        String nameTo = plugMap.get( ic.plugTo.type );
        if ( nameTo != null )             // there is matching plug in the new module
        {
          InfoPlug    ipNew   = infoNew.plugs.get( nameTo );
          InfoChannel icNew   = new InfoChannel();
          icNew.key           = k;
          icNew.plugFrom      = ic.plugFrom;
          icNew.plugTo        = ipNew;
          icNew.nameInterface = ipNew.name;
          icNew.owner         = info;
          newChannel( icNew );
          info.channels.put( k, icNew );
        }
      }
    }

    if ( undoReg != null ) undoReg.dont = false;

    remove( infoOld.infoGUI.gui );
    info.modules.remove( infoOld.key );
    info.modules.put( infoNew.key, infoNew );
    ModuleGUI nm = InstanceGUI.newModuleInstance( infoNew );
    nm.setUndoObj( undoReg );
    add( nm );
  }

  /**
   * Adds a new module at the given position.
   * Module type will be specified by the user (registry browser).
   *
   * @param  x X-coordinate of the insertion point.
   * @param  y Y-coordinate of the insertion point.
   */
  public void newModule ( int x, int y )
  {
    InfoModule[] infoP = RegDatabaseBasic.viewModules();
    if ( infoP == null ) return;

    selectAll( false );
    int len = infoP.length;
    for ( int i = 0; i < len; i++ )
    {
      if ( undoReg != null )
        undoReg.registry( new ActionsUndoReg( this, ACTION_MODULE_ADD, null, infoP[i] ) );

      renameNewModule( infoP[i] );
      if ( infoP[i] instanceof InfoGroup )
        newGroup(  x + i * 11, y + i * 28, (InfoGroup)infoP[i] );
      else
        newModule( x + i * 11, y + i * 28, infoP[i] );

      moveToFront( infoP[i].infoGUI.gui );
      infoP[i].infoGUI.gui.validate();
    }

    repaintParent();
  }

  /**
   * Adds a new module.
   *
   * @param  _info Information about module.
   */
  public void newModule ( InfoModule _info )
  {
    if ( _info == null )
    {
      newModule( 0, 0 );
      return;
    }

    _info.owner = info;
    ModuleGUI nm = InstanceGUI.newModuleInstance( _info );
    nm.setUndoObj( undoReg );

    add( nm );
  }

  /**
   * Adds a new channel.
   *
   * @param  _info Information about channel.
   */
  public void newChannel ( InfoChannel _info )
  {
    if ( _info == null )
    {
      newChannel();
      return;
    }

    InstanceGUI.newChannelInstance( _info );
  }

  /**
   * Adds a new group.
   *
   * @param  _info Information about group.
   */
  public void newGroup ( InfoGroup _info )
  {
    _info.owner = info;
    ModuleGUI ng = InstanceGUI.newGroupInstance( _info );
    ng.setUndoObj( undoReg );

    add( ng );
  }

  /** Creates a new group from all selected modules. */
  public void setGroup ()
  {
    InfoGroup infoG;
    if ( (infoG = InfoGroup.createNewGroup( info )) != null )
    {
      Integer ig = idModules.getNextId();
      infoG.key = ig;
      newGroup( infoG );
      info.modules.put( infoG.key, infoG );
    }
  }

  /**
   * Dismisses the given group
   */
  public void unsetGroup ( InfoGroup ig )
  {
    for ( InfoModule im : ig.modules.values() )
    {
      im.infoGUI.selected = true;
      newModule( im.infoGUI.x, im.infoGUI.y, im );
    }

    for ( InfoChannel ic : ig.channels.values() )
    {
      ic.key = idChannel.getNextId();
      info.channels.put( ic.key, ic );
    }

    for ( InfoChannel ic : info.channels.values() )
    {
      if ( ig.plugs.containsValue( ic.plugFrom ) )
        ic.plugFrom = ic.plugFrom.linkToOrig;

      if ( ig.plugs.containsValue( ic.plugTo ) )
        ic.plugTo   = ic.plugTo.linkToOrig;
    }

    info.modules.remove( ig.key );
    this.remove( ig.infoGUI.gui );
    repaintParent();
  }

  /** Creates new channel connecting idModuleFrom and idModuleTo. */
  public void newChannel ()
  {
    if ( !plugFrom.isFree() )
    {
      JOptionPane.showMessageDialog( this, "Plug " + plugFrom.owner.reg.className + '.' + plugFrom.name +
                                     " is not multi.", "Error", JOptionPane.ERROR_MESSAGE );
      plugFrom = null;
      return;
    }

    if ( !plugTo.isFree() )
    {
      JOptionPane.showMessageDialog( this, "Plug " + plugTo.owner.reg.className + '.' + plugTo.name +
                                     " is not multi.", "Error", JOptionPane.ERROR_MESSAGE );
      plugTo = null;
      return;
    }

    if ( InfoPlug.isOpposite( plugFrom,  plugTo ) )
    {
      InfoChannel ic   = new InfoChannel();
      ic.infoGUI       = new InfoChannelGUI();
      ic.key           = idChannel.getNextId();
      ic.plugFrom      = plugFrom;
      ic.plugTo        = plugTo;
      ic.nameInterface = plugFrom.name;
      ic.owner         = info;

      if ( undoReg != null )
        undoReg.registry( new ActionsUndoReg( this, ACTION_CHANNEL_ADD, null, ic ) );

      newChannel( ic );
      info.channels.put( ic.key, ic );
    }
    else
      JOptionPane.showMessageDialog( this, "Incompatible plug types.",
                                     "Error", JOptionPane.ERROR_MESSAGE );
    plugFrom = null;
    plugTo   = null;
  }

  /**
   * Creates new temporary channel.
   *
   * @return new temporary channel.
   */
  public InfoChannel newChannelTemp ()
  {
    InfoChannel ic = new InfoChannel();
    ic.infoGUI     = new InfoChannelGUI();
    ic.key         = idChannel.getNextId();
    ic.plugFrom    = plugFrom;
    ic.plugTo      = plugTo;
    ic.nameInterface = (plugFrom != null) ? plugFrom.name :
                                            plugTo.name;
    ic.owner       = info;

    newChannel( ic );
    info.channels.put( ic.key, ic );
    return ic;
  }

  /**
   * Looking for opposite plug in the given module.
   *
   * @param  _find Plug to look for.
   * @param  _module Module to be searched.
   * @return Opposite plug or {@code null}.
   */
  public static InfoPlug findOpposite ( InfoPlug _find, InfoModule _module )
  {
    for ( InfoPlug ip : _module.plugs.values() )
      if ( InfoPlug.isOpposite( _find, ip ) )
        return ip;

    return null;
  }

  /**
   * Looking for channel connecting two given plugs.
   *
   * @param  _plug1 Plug #1.
   * @param  _plug2 Plug #2.
   * @return Channel connecting the two plugs or {@code null}.
   */
  public InfoChannel findChannel ( InfoPlug _plug1, InfoPlug _plug2 )
  {
    for ( InfoChannel ic : info.channels.values() )
      if ( ic.hasPlugs( _plug1, _plug2 ) )
        return ic;

    return null;
  }

  /**
   * Adds a new module at position [ x, y ].
   *
   * @param  x X-coordinate.
   * @param  y Y-coordinate.
   * @param  _info Module.
   */
  public void newModule ( int x, int y, InfoModule _info )
  {
    if ( _info == null )
      return;

    if ( _info.infoGUI == null )
      _info.infoGUI = new InfoModuleGUI();
    _info.infoGUI.x      = x;
    _info.infoGUI.y      = y;
    _info.infoGUI.height = ModuleGUI.getModuleHeight( _info.getVisibleParamLines() );
    _info.infoGUI.width  = ModuleGUI.getModuleWidth();
    Integer ig =idModules.getNextId();
    _info.key = ig;

    newModule( _info );
    info.modules.put( _info.key, _info );

    if ( InfoGroup.autoConnect )
      connectWithOther( _info );
  }

  /**
   * Adds a new group at position [ x, y ].
   *
   * @param  x X-axis.
   * @param  y Y-axis.
   * @param  _info Group.
   */
  public void newGroup ( int x, int y, InfoGroup _info )
  {
    if ( _info == null )
      return;

    if ( _info.infoGUI == null )
      _info.infoGUI = new InfoGroupGUI();
    _info.infoGUI.x      = x;
    _info.infoGUI.y      = y;
    _info.infoGUI.height = ModuleGUI.getModuleHeight( _info.getVisibleParamLines() );
    _info.infoGUI.width  = ModuleGUI.getModuleWidth();
    Integer ig           = idModules.getNextId();
    _info.key            = ig;

    if ( _info.nextInfo == null )
      _info.nextInfo = new HashMap< String, Object >();
    _info.nextInfo.put( "NEW", "TRUE" );

    newGroup(_info);
    info.modules.put( _info.key, _info );

    if ( InfoGroup.autoConnect )
      connectWithOther( _info );
  }

  /**
   * Component initialization.
   */
  private void jbInit () throws Exception
  {
    jMenuItemDeleteChannel.setText( "Delete Channel" );
    jMenuItemDeleteChannel.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        jMenuItemDeleteChannel_actionPerformed( e );
      }
    });
    jPopupMenu1.add( jMenuItemDeleteChannel );

    addMouseListener( new MouseAdapter ()
    {
      public void mouseClicked ( MouseEvent e )
      {
        ws_mouseClicked( e );
      }
    });
  }

  /**
   * Moves all selected items.
   *
   * @param  id Key of item.
   * @param  nx Relative x coordinate.
   * @param  ny Relative y coordinate.
   */
  public void moveSelected ( Integer id, int nx, int ny )
  {
    for ( InfoModule im : info.modules.values() )
      if ( im.infoGUI.selected ||
           im.key.equals( id ) )
      {
        int px = im.infoGUI.gui.getX() + nx;
        int py = im.infoGUI.gui.getY() + ny;
        if ( px < 0 )
          nx = -im.infoGUI.gui.getX();
        if ( py < 0 )
          ny = -im.infoGUI.gui.getY();
      }

    for ( InfoModule im : info.modules.values() )
      if ( im.infoGUI.selected ||
           im.key.equals( id ) )
        im.infoGUI.gui.moveModule( nx, ny );
  }

  /**
   * Paint bonus items of Channels.
   *
   * @param  g Graphics to paint to.
   */
  public void paintChannels ( Graphics g )
  {
    for ( InfoChannel ic : info.channels.values() )
      ic.infoGUI.gui.paintItem( g );
  }

  /**
   * Paints links between modules-plugs composition-plugs.
   *
   * @param  g Graphics to paint to.
   */
  @Override
  public void paintLinks ( Graphics g )
  {
    if ( info.plugs == null ) return;

      // channel color
    g.setColor( Color.blue );
    int x1, y1, x2, y2;
    for ( InfoPlug ip : info.plugs.values() )
    {
      if ( ip.infoGUI == null ) continue;

      x1 = ip.infoGUI.gui.getX() + getX();
      y1 = ip.infoGUI.gui.getY() + getY();

      switch ( ip.infoGUI.orientation )
      {
        case PlugGUIImproved.PGI_ORIENTATION_EAST:
          y1 = (int)((JViewport)getParent()).getViewPosition().getY() +
               ip.infoGUI.gui.getY() - 28;
          x1 = (int)((JViewport)getParent()).getViewRect().getWidth() +
               (int)((JViewport)getParent()).getViewRect().getX();
          break;

        case PlugGUIImproved.PGI_ORIENTATION_NORTH:
          x1 = (int)((JViewport)getParent()).getViewPosition().getX() +
               ip.infoGUI.gui.getX() - 12;
          y1 = (int)((JViewport)getParent()).getViewRect().getY();
          break;

        case PlugGUIImproved.PGI_ORIENTATION_WEST:
          y1 = (int)((JViewport)getParent()).getViewPosition().getY() +
               ip.infoGUI.gui.getY() - 28;
          x1 = (int)((JViewport)getParent()).getViewRect().getX();
          break;

        case PlugGUI.PGI_ORIENTATION_SOUTH:
          x1 = (int)((JViewport)getParent()).getViewPosition().getX() +
               ip.infoGUI.gui.getX() - 12;
          y1 = (int)((JViewport)getParent()).getViewRect().getHeight() +
               (int)((JViewport)getParent()).getViewRect().getY();
          break;
      }

      if ( y1 < 0 ) y1 = 0;
      if ( x1 < 0 ) x1 = 0;

      x2 = ip.linkToOrig.owner.infoGUI.gui.getX() +
           ip.linkToOrig.infoGUI.gui.getX();
      y2 = ip.linkToOrig.owner.infoGUI.gui.getY() +
           ip.linkToOrig.infoGUI.gui.getY();

      g.drawLine( x1, y1, x2, y2 );
    }
  }

  /**
   * Paints bonus graphics on panel - Modules, Channels.
   */
  public void paintItem ( Graphics g )
  {
    paintChannels( g );
    paintLinks( g );
    paintChildren( g );
    if ( zoom != null )
      zoom.repaintZoom();
  }

  /**
   * Default constructor.
   */
  public CompositionGUIBasic ()
  {
    this( null );
  }

  /**
   * Creates new CompositionGUIBasic.
   */
  public CompositionGUIBasic ( Integer _key )
  {
    try
    {
      if ( info != null )
      {
        if ( info.infoGUI == null )
          info.infoCompositionGUI = new InfoCompositionGUI();
        info.infoCompositionGUI.gui = this;
        info.key = _key;
      }
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Undo last action.
   *
   * @param  action Action to be done.
   */
  public void undo ( ActionsUndoReg action )
  {
    super.undo( action );
    if ( undoReg == null ) return;

    undoReg.dont = true;                  // avoids double-registration of this action

    switch ( action.what )
    {
      case ACTION_MODULE_ADD:
        InfoModule im = (InfoModule)action.newValue;
        removeModule( im.key );
        break;

      case ACTION_CHANNEL_ADD:
        InfoChannel ic = (InfoChannel)action.lastValue;
        removeChannel( ic.key );
        break;
    }

    repaintParent();
    undoReg.dont = false;
  }

  /**
   * Redo last undoed action.
   *
   * @param  action Action to be re-done.
   */
  public void redo ( ActionsUndoReg action )
  {
    super.redo(action);
    if ( undoReg == null ) return;

    undoReg.dont = true;                  // avoids double-registration of this action

    switch ( action.what )
    {
      case ACTION_MODULE_ADD:
        InfoModule im = (InfoModule)action.newValue;
        newModule( im );
        info.modules.put( im.key, im );
        break;

      case ACTION_CHANNEL_ADD:
        InfoChannel ic = (InfoChannel)action.lastValue;
        newChannel( ic );
        info.channels.put( ic.key, ic );
        break;
    }

    repaintParent();
    undoReg.dont = false;
  }

  //==========================================================================
  //  Events:

  /**
   * Deletes the channel.
   */
  void jMenuItemDeleteChannel_actionPerformed ( ActionEvent e )
  {
    removeChannel( channelKey );
    repaintParent();
  }

  /**
   * Mouse click.
   * right button - if mouse is on top of a channel, show popup menu.
   * SHIFT + left button or doubleclick left button -
   * adds new module on actual position.
   */
  void ws_mouseClicked ( MouseEvent e )
  {
    int m = e.getModifiers();

    if ( m == MouseEvent.BUTTON3_MASK )
    {
      channelKey = getChannelAtPoint( e.getX(), e.getY() );
      if ( channelKey != null )
        jPopupMenu1.show( this, e.getX(), e.getY() );
    }

    if ( m == MouseEvent.BUTTON1_MASK + MouseEvent.SHIFT_MASK && e.getClickCount() == 1 ||
         m == MouseEvent.BUTTON1_MASK                         && e.getClickCount() == 2 )
      newModule( e.getX(), e.getY() );

    if ( m == MouseEvent.BUTTON1_MASK &&
         e.getClickCount() == 1 )
    {
      selectAll( false );
      repaintParent();
    }
  }

}
