package cz.cuni.jagrlib.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Basic class that cares about visual representation of a group
 * (obsolete code, use {@link GroupGUIImproved} instead).
 *
 * @author  Jan Kostlivy, PE
 * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/GroupGUIBasic.java">GroupGUIBasic.java</a>
 */
public class GroupGUIBasic extends GroupGUI
{
  private static final long serialVersionUID = 1L;

  /** Window for editing parameters.*/
  protected ParamsEdit windowParam;

  // GUI components:
  private JLabel      jLabelName        = new JLabel();
  private JScrollPane jScrollPaneParams = new JScrollPane();
  private JPanel      jPanelPlugs       = new JPanel();
  private JPanel      jPanelParams      = new JPanel();

  /** Deleting of module with window for editing parameters. */
  @Override
  protected void removeModule ()
  {
    if ( windowParam != null )
    {
      try
      {
        windowParam.setIcon( false );
      }
      catch ( java.beans.PropertyVetoException ee )
      {
        LogFile.exception( ee );
      }
      ((MainWindow)getTopLevelAncestor()).removeFrame( windowParam );
    }
  }

  /**
   * Gets actual mouse mode.
   *
   * @param  mx X-coordinate of mouse.
   * @param  my Y-coordinate of mouse.
   * @return Mode values: 1 - move; 2 - mouse is above plug; 3 - resize E; 4 - resize S; 5 - resize SE; 0 - otherwise
   */
  @Override
  protected int getMouseMode ( int mx, int my )
  {
    if ( jLabelName.getX() < mx &&
         jLabelName.getX() + jLabelName.getWidth() > mx &&
         jLabelName.getY() < my &&
         jLabelName.getY() + jLabelName.getHeight() > my ||
         modeMove == MM_MOVE )
      return MM_MOVE;

    if ( mx > getWidth()  - 5 &&
         my > getHeight() - 5 &&
         info.infoGUI.modeShow.compareTo( InfoModuleGUI.MS_NORMAL ) == 0 )
      return MM_RESIZESE;

    if ( mx > getWidth()  - 5 &&
         info.infoGUI.modeShow.compareTo( InfoModuleGUI.MS_NORMAL ) == 0 )
      return MM_RESIZEE;

    if ( my > getHeight() - 5 &&
         info.infoGUI.modeShow.compareTo( InfoModuleGUI.MS_NORMAL ) == 0 )
      return MM_RESIZES;

    actualPlug = getPlugAtPoint( mx, my );
    if ( actualPlug != null )
      return MM_PLUG;

    return MM_DEFAULT;                    // otherwise
  }

  /** Sets parameters of the module. */
  @Override
  protected void setParams ()
  {
    ParamGUI par;
    if ( info.params != null )
    {
      InfoParam ip;
      int j = 0;
      for ( String name : info.params.keySet() )
      {
        ip = info.params.get( name );
        if ( ip.visible )
        {
          par = InstanceGUI.newParam( ip );
          par.setPreferredSize(  new Dimension( getWidth() - 26, par.paramLines() * ParamGUI.paramLineHeight ) );
          par.setMaximumSize(    new Dimension( Short.MAX_VALUE, par.paramLines() * ParamGUI.paramLineHeight ) );
          jPanelParams.add( par, new GridBagConstraints( 0, j, 1, 1, 1.0, 0.0,
                                                         GridBagConstraints.NORTHWEST,
                                                         GridBagConstraints.HORIZONTAL,
                                                         new Insets( 2, 2, 0, 2 ), 0, 0 ) );
          j++;
        }
      }
      jPanelParams.add( new JPanel(), new GridBagConstraints( 0, -1, 1, 1, 1.0, 1.0,
                                                              GridBagConstraints.NORTHWEST,
                                                              GridBagConstraints.HORIZONTAL,
                                                              GuiConstants.INSETS_0, 0, 0 ) );
    }
  }

  /** Sets plugs and parameters of the module. */
  @Override
  protected void setModuleType ()
  {
    super.setModuleType();
    setParams();
  }

  /**
   * Creates new GroupGUIBasic.
   */
  public GroupGUIBasic ( InfoGroup _info )
  {
    try
    {
      info = _info;
      infoGroup = (InfoGroup)info;
      if ( info.infoGUI == null )
        info.infoGUI = new InfoGroupGUI();
      info.infoGUI.gui = this;
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Component initialization.
   */
  private void jbInit ()
  throws Exception
  {
    setLayout( new BorderLayout() );
    setName( InfoGroup.TI_GROUP );
    jLabelName.setBackground( SystemColor.textHighlight );
    jLabelName.setFont( new Font( "Dialog", 1, 12 ) );
    jLabelName.setForeground( Color.white );
    jLabelName.setOpaque( true );
    if ( info.reg.name == null ||
         info.reg.name == "" )
      info.reg.name = info.reg.className;

    jLabelName.setText( info.reg.name );
    jPanelPlugs.setBorder(  BorderFactory.createEmptyBorder( 10, 10, 10, 10 ) );
    jPanelPlugs.setLayout(  new BorderLayout() );
    jPanelParams.setLayout( new GridBagLayout() );
    jPanelPlugs.add( jLabelName,        BorderLayout.NORTH );
    jPanelPlugs.add( jScrollPaneParams, BorderLayout.CENTER );
    jScrollPaneParams.getViewport().add( jPanelParams, null );
    add( jPanelPlugs, BorderLayout.CENTER );

    for ( InfoModule im : infoGroup.modules.values() )
      if ( im instanceof InfoGroup )      // group
      {
        InfoGroup ig = (InfoGroup)im;
        if ( ig.infoGUI.gui == null )
          ig.infoGUI.gui = InstanceGUI.newGroupInstance( ig );

        ig.owner = infoGroup;
      }
      else                                // ordinary module
      {
        if ( im.infoGUI.gui == null )
        {
          if ( im.infoGUI.height == 0 )
            im.infoGUI.height = ModuleGUI.getModuleHeight( im.getVisibleParamLines() );
          if ( im.infoGUI.width == 0 )
            im.infoGUI.width = ModuleGUI.getModuleWidth();
          im.infoGUI.gui = InstanceGUI.newModuleInstance( im );
        }

        for ( String s2 : im.plugs.keySet() )
          if ( !findPlugInChannels( im.plugs.get( s2 ) ) )
            info.plugs.put( im.reg.className + s2, im.plugs.get( s2 ) );

        im.owner = infoGroup;
      }

    if ( info.infoGUI.modeShow.compareTo( InfoModuleGUI.MS_MINI ) == 0 )
    {
      setBounds( info.infoGUI.x, info.infoGUI.y, minWidth, minHeight );
      jPanelPlugs.remove( jScrollPaneParams );
    }
    else
      setBounds( info.infoGUI.x, info.infoGUI.y, info.infoGUI.width, info.infoGUI.height );

    setModuleType();
  }

  /**
   * Finds the given plug in actual channel set.
   */
  public boolean findPlugInChannels ( InfoPlug ip )
  {
    for ( Integer s : infoGroup.channels.keySet() )
    {
      InfoChannel ic = infoGroup.channels.get( s );
      if ( ic.plugFrom.equals( ip ) )
        return true;
      if ( ic.plugTo.equals( ip ) )
        return true;
    }

    return false;
  }

  //==========================================================================
  //  Events:

  /**
   * Mouse drag:
   * <br />Mode {@link #MM_PLUG} - plug move.
   */
  @Override
  protected void this_mouseDragged ( MouseEvent e )
  {
    super.this_mouseDragged( e );
    int px = e.getX() - oldMouseX;
    int py = e.getY() - oldMouseY;

    switch ( modeMove )
    {
      case MM_PLUG:
        if ( actualPlug != null )
        {
          actualPlug.infoGUI.gui.movePlug( px, py );
          oldMouseX = e.getX();
          oldMouseY = e.getY();
          info.owner.infoCompositionGUI.gui.repaint();
          // !!! TODO: repaint only the affected rectangle.. !!!
        }
        break;
    }
  }

}
