package cz.cuni.jagrlib.gui;

import java.util.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Improved class that cares about visual representation of a group.
 * A group looks like any common module.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/GroupGUIImproved.java">GroupGUIImproved.java</a>
 */
public class GroupGUIImproved extends ModuleGUIImproved
{
  private static final long serialVersionUID = 1L;

  /** Information about Group. */
  public InfoGroup infoGroup;

  /** Undo/Redo constants. */
  final static public int ACTION_GROUP_MODE = 201;
  final static public int ACTION_GROUP_UNDO = 202;

  /** Undo/Redo object for group. */
  public ActionsUndo undoGroup;

  protected JMenuItem miComposition = new JMenuItem();
  protected JMenuItem miUngroup     = new JMenuItem();

  /**
   * Initialization of info-object.
   * Creating modules and channels from group.
   *
   * @param  _info Group-info module.
   */
  public void setInfo ( InfoModule _info )
  {
    info = _info;
    infoGroup = (InfoGroup)info;
    if ( info.infoGUI == null )
      info.infoGUI = new InfoGroupGUI();
    info.infoGUI.gui = this;

    if ( infoGroup.infoCompositionGUI == null )
      infoGroup.infoCompositionGUI = new InfoCompositionGUI();

    CompositionGUI cg = InstanceGUI.newCompositionInstance();
    infoGroup.infoCompositionGUI.gui = cg;
    undoGroup = new ActionsUndo();
    cg.undoReg = undoGroup;
    cg.info = infoGroup;
    cg.readInfo();
  }

  /**
   * Creates new GroupGUIImproved.
   *
   * @param  _info Information about group.
   */
  public GroupGUIImproved ( InfoGroup _info )
  {
    super( _info );
    try
    {
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Component initialization.
   */
  private void jbInit () throws Exception
  {
    this.setName( InfoGroup.TI_GROUP );
    lbName.setBackground( InfoGroupGUI.colorName );
    miSelect.setVisible( false );
    miCode.setVisible( false );
    miDelete.setText( "Delete Group" );
    miRename.setText( "Rename Group" );

    miUngroup.setText( "UnGroup" );
    miUngroup.addActionListener( new java.awt.event.ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miUngroup_actionPerformed( e );
      }
    });
    miSize.setFont( miComposition.getFont() );
    miComposition.setText( "Show Modules" );
    miComposition.setFont( new Font( miComposition.getFont().getFontName(),
                                     Font.BOLD, miComposition.getFont().getSize() ) );
    miComposition.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miComposition_actionPerformed( e );
      }
    });
    jPopupMenuActions.add( miComposition );
    jPopupMenuActions.add( miUngroup );

    if ( infoGroup.infoCompositionGUI.modulesShow )
    {
      jScrollPaneParams.getViewport().add( infoGroup.infoCompositionGUI.gui, null );
      setBounds( getX(), getY(),
                 infoGroup.infoCompositionGUI.width,
                 infoGroup.infoCompositionGUI.height );
    }
    else
      jScrollPaneParams.getViewport().add( panelParams, null );
    undoGroup.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        undoGroup_actionPerformed( e );
      }
    });
    infoGroup.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        change_actionPerformed( e );
      }
    });
  }

  /** Default action on doubleclick of mouse. */
  public void runDefaultAction ()
  {
    miComposition_actionPerformed( null );
  }

  //==========================================================================
  //  Events:

  /**
   * Dissolve the Group. Not implemented yet.
   */
  void miUngroup_actionPerformed ( ActionEvent e )
  {
    info.owner.infoCompositionGUI.gui.unsetGroup( infoGroup );
  }

  /**
   * Show modules as composition.
   */
  void miComposition_actionPerformed ( ActionEvent e )
  {
    if ( infoGroup.infoCompositionGUI.modulesShow )
    {
      jScrollPaneParams.getViewport().add( panelParams, null );
      infoGroup.infoCompositionGUI.modulesShow = false;
      if ( info.infoGUI.isNormal() )
        setBounds( getX(), getY(),
                   info.infoGUI.width,
                   info.infoGUI.height );
    }
    else
    {
      jScrollPaneParams.getViewport().add( infoGroup.infoCompositionGUI.gui, null );
      infoGroup.infoCompositionGUI.modulesShow = true;
      if ( info.infoGUI.isNormal() )
      {
        if ( infoGroup.infoCompositionGUI.width == 0 )
          infoGroup.infoCompositionGUI.width = info.infoGUI.width;
        if ( infoGroup.infoCompositionGUI.height == 0 )
          infoGroup.infoCompositionGUI.height = info.infoGUI.height;
        setBounds( getX(), getY(),
                   infoGroup.infoCompositionGUI.width,
                   infoGroup.infoCompositionGUI.height );
      }
      infoGroup.infoCompositionGUI.gui.setCompositionSize();
    }

    if ( undoReg != null )
      undoReg.registry( new ActionsUndoReg( this, ACTION_GROUP_MODE, null, null ) );
  }

  /**
   * Mouse click.
   * right button shows pop-up menu.
   */
  @Override
  protected void this_mouseClicked ( MouseEvent e )
  {
    int m = e.getModifiers();
    if ( m == MouseEvent.BUTTON3_MASK )
    {
      if ( infoGroup.infoCompositionGUI.modulesShow )
        miComposition.setText( "Hide Modules" );
      else
        miComposition.setText( "Show Modules" );
    }
    super.this_mouseClicked( e );
  }

  /**
   * Module was resized:
   * Plugs' positions need to be recomputed.
   * Changes bound of work space.
   */
  @Override
  protected void this_componentResized ( ComponentEvent e )
  {
    for ( InfoPlug ip : info.plugs.values() )
      resizePlug( ip.infoGUI.gui );

    if ( info.infoGUI.isNormal() )
    {
      if ( infoGroup.infoCompositionGUI.modulesShow )
      {
        infoGroup.infoCompositionGUI.width  = getWidth();
        infoGroup.infoCompositionGUI.height = getHeight();
      }
      else
      {
        info.infoGUI.width  = getWidth();
        info.infoGUI.height = getHeight();
      }
    }

    if ( info.owner != null )
    {
      info.owner.infoCompositionGUI.gui.setCompositionSize();
      info.owner.infoCompositionGUI.gui.repaint();
    }
  }

  /**
   * Minimization or maximization of the module.
   */
  protected void miSize_actionPerformed ( ActionEvent e )
  {
    super.miSize_actionPerformed( e );
    if ( info.infoGUI.isNormal() &&
         infoGroup.infoCompositionGUI.modulesShow )
    {
      setBounds( getX(), getY(),
                 infoGroup.infoCompositionGUI.width,
                 infoGroup.infoCompositionGUI.height );
    }
  }

  /**
   * Undoes last action.
   *
   * @param  action do this action.
   */
  public void undo ( ActionsUndoReg action )
  {
    super.undo( action );
    if ( undoReg == null ) return;

    undoReg.dont = true;                  // avoids double-registration of this action

    switch ( action.what )
    {
      case ACTION_GROUP_MODE:
        miComposition_actionPerformed( null );
        break;

      case ACTION_GROUP_UNDO:
        undoGroup.undo();
        break;
    }

    undoReg.dont = false;
  }

  /**
   * Redoes last un-done action.
   *
   * @param  action Re-do this action.
   */
  public void redo ( ActionsUndoReg action )
  {
    super.redo( action );
    if ( undoReg == null ) return;

    undoReg.dont = true;                  // avoids double-registration of this action

    switch ( action.what )
    {
      case ACTION_GROUP_MODE:
        miComposition_actionPerformed( null );
        break;

      case ACTION_GROUP_UNDO:
        undoGroup.redo();
        break;
    }

    undoReg.dont = false;
  }

  void undoGroup_actionPerformed ( ActionEvent e )
  {
    if ( undoReg != null )
      undoReg.registry( new ActionsUndoReg( this, ACTION_GROUP_UNDO, e.getSource(), null ) );

    if ( infoGroup.registry &&
         !infoGroup.editRegisty )
    {
      if ( JOptionPane.showConfirmDialog( this, "Do you want to edit group in registry data?",
                                          "Confirm", JOptionPane.YES_NO_OPTION ) == JOptionPane.YES_OPTION )
        infoGroup.editRegisty = true;
      else
        infoGroup.registry = false;
    }
  }

  /**
   * Change of group.
   * Delete/add module.
   */
  public void change_actionPerformed ( ActionEvent e )
  {
    switch ( e.getID() )
    {
      case HashMapModules.ACTION_ADD_MODULE:
      {
        InfoModule im = (InfoModule)e.getSource();
        for ( InfoPlug ip : im.plugs.values() )
          ip.infoGUI.visible = false;
        for ( String name : im.params.keySet() )
          im.params.get( name ).infoGUI.visible = false;
        break;
      }

      case HashMapModules.ACTION_DELETE_MODULE:
      {
        InfoModule im = (InfoModule)e.getSource();
        for ( InfoPlug ip : im.plugs.values() )
        {
          Iterator< InfoPlug > it = infoGroup.plugs.values().iterator();
          while ( it.hasNext() )
          {
            InfoPlug ipg = it.next();
            if ( ip.equals( ipg.linkToOrig ) )
              it.remove();
          }
        }
        break;
      }
    }
  }

}
