package cz.cuni.jagrlib.gui;

import java.util.*;
import java.io.IOException;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import java.beans.PropertyVetoException;

import cz.cuni.jagrlib.reg.*;
import cz.cuni.jagrlib.*;

/**
 * Main window of the SKEL application.
 *
 * @author  PE, Jan Kostlivy
 * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/MainWindow.java">MainWindow.java</a>
 */
public class MainWindow extends JFrame
{
  private static final long serialVersionUID = 1L;

  //==========================================================================
  //  Data:

  /**
   * MainWindow singleton.
   * Constructed automatically after MainWindow class loading.
   */
  public static MainWindow mainWindow = new MainWindow();

  /** Actual status-bar (docked or floating). */
  public static StatusBar statusBar;

  private StatusBar panelStatus = new StatusBar();

  /** Size of toolbar-buttons. */
  protected Dimension buttonDimension  = new Dimension( 30, 30 );
  protected Dimension runningDimension = new Dimension( 80, 30 );

  // GUI components
  private JMenuBar     mainMenu           = new JMenuBar();
  private JMenu        menuWindow         = new JMenu();
  private JMenuItem    miOutline          = new JMenuItem();
  private JMenu        menuHelp           = new JMenu();
  private JMenuItem    miAbout            = new JMenuItem();
  private JMenu        menuFile           = new JMenu();
  private JMenuItem    miLoad             = new JMenuItem();
  private JMenuItem    miSave             = new JMenuItem();
  private JMenuItem    miSaveAs           = new JMenuItem();
  private JMenuItem    miExit             = new JMenuItem();
  private JMenuItem    miNew              = new JMenuItem();
  private JMenuItem    miClose            = new JMenuItem();
  private JMenu        menuComposition    = new JMenu();
  private JMenuItem    miAddModule        = new JMenuItem();
  private JMenuItem    miDeleteModule     = new JMenuItem();
  private JMenuItem    miGroup            = new JMenuItem();
  private JMenuItem    miUngroup          = new JMenuItem();
  private JMenu        menuTools          = new JMenu();
  private JMenuItem    miRegistry         = new JMenuItem();
  private JMenuItem    miViewRegistry     = new JMenuItem();
  private JMenuItem    miOptions          = new JMenuItem();
  private JMenuItem    miRun              = new JMenuItem();
  private JMenu        menuEdit           = new JMenu();
  private JMenuItem    miUndo             = new JMenuItem();
  private JMenuItem    miRedo             = new JMenuItem();
  private JMenuItem    miSelectAll        = new JMenuItem();
  private JPanel       panelMain          = new JPanel();
  private JDesktopPane desktop;
  private JPanel       contentPane;
  private ZoomWindow   outlineWindow      = InstanceGUI.newZoomInstance();
  private JToolBar     jToolBarMain       = new JToolBar();
  private JButton      btAdd              = new JButton( Options.getIcon( "Add24.gif" ) );
  private JButton      btNew              = new JButton( Options.getIcon( "New24.gif" ) );
  public  JButton      btLoad             = new JButton( Options.getIcon( "Open24.gif" ) );
  private JButton      btSave             = new JButton( Options.getIcon( "Save24.gif" ) );
  private JButton      btDelete           = new JButton( Options.getIcon( "Delete24.gif" ) );
  private JButton      btGroup            = new JButton( Options.getIcon( "Group24.gif" ) );
  private JButton      btUngroup          = new JButton( Options.getIcon( "UnGroup24.gif" ) );
  private JButton      btRun              = new JButton( Options.getIcon( "Run24.gif" ) );
  private JButton      btRunning          = new JButton( "Running: 0" );
  private JScrollPane  jScrollPaneDesctop = new JScrollPane();

  public class JMenuItemFrame extends JMenuItem
  {
    private static final long serialVersionUID = 1L;

    public JInternalFrame frame;

    public JMenuItemFrame( JInternalFrame _frame )
    {
      super();
      frame = _frame;
      String pomname = frame.getTitle();
      setText( pomname );
      if ( pomname.lastIndexOf('\\') >= 0 )
        setText( pomname.substring( pomname.lastIndexOf('\\') + 1 ) );

      addActionListener( new ActionListener ()
      {
        public void actionPerformed ( ActionEvent e )
        {
          if ( frame == null )
            return;

          if ( frame.isIcon() )
          {
            try
            {
              frame.setIcon( false );
            }
            catch ( PropertyVetoException ee )
            {
              LogFile.exception( ee );
            }
          }
          try
          {
            frame.setSelected( true );
          }
          catch ( PropertyVetoException ee )
          {
            LogFile.exception( ee );
          }
        }
      });
    }
  }

  //==========================================================================
  //  Support:

  /** Adjust origin of the new window according to the actual screen size. */
  public static void adjustScreenPosition ( int[] pos )
  {
    Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
    pos[0] = Formula.clamp( pos[0], 0, screenSize.width  - 50 );
    pos[1] = Formula.clamp( pos[1], 0, screenSize.height - 50 );
  }

  /**
   * Changes text of the "Running:" button.
   * Should be called in {@code synchronized} section only.
   */
  protected void setRunningText ()
  {
    btRunning.setText( "Running: " + running.size() );
  }

  //==========================================================================
  //  Running worker threads:

  /**
   * Number of mild tries (to stop {@link RunningWorker}) before a hard one
   * will be performed.
   */
  protected static final int COUNTER_KILL = 2;

  /** Actual running worker threads. */
  protected Map< Thread, RunningWorker > running = new HashMap< Thread, RunningWorker >();

  /**
   * Class holding information about one running worker thread.
   * Will be inserted into a {@code Thread -> RunningWorker} map.
   */
  protected static class RunningWorker
  {
    /** Associated breakable object (usually a {@link Worker} module). */
    public Breakable br;

    /** Composition in which this {@link Worker} runs.. */
    public InfoGroup composition;

    /** Number of mild-tries so far. */
    public int counter;

    public RunningWorker ( Breakable b, InfoGroup comp )
    {
      br          = b;
      composition = comp;
      counter     = 0;
    }
  }

  /**
   * Adds new running composition thread.
   */
  public synchronized void runningInc ( Thread t, Breakable br, InfoGroup comp )
  {
    if ( br == null ) return;

    running.put( t, new RunningWorker( br, comp ) );
    setRunningText();
  }

  /** Must be called in {@code synchronized} section. */
  protected void removeRunning ( RunningWorker w )
  {
    if ( w == null ) return;

    final InfoGroup comp = w.composition;
    boolean last = true;
      // Was I the last running worker in the composition?
    for ( RunningWorker rw : running.values() )
      if ( rw.composition == comp )
      {
        last = false;
        break;
      }

    if ( last )
    {
      Composition.disposePieces( comp.modules );
      LogFile.close();
    }
  }

  /**
   * Removes one running composition thread.
   */
  public synchronized void runningDec ( Thread t )
  {
    final RunningWorker w = running.get( t );
    running.remove( t );
    removeRunning( w );
    setRunningText();
  }

  /**
   * Stops any running composition thread.
   */
  @SuppressWarnings("deprecation")
  public synchronized void stopRunningWorkers ()
  {
    final int size = running.size();
    if ( size == 0 ) return;

    Iterator< Map.Entry< Thread, RunningWorker > > it = running.entrySet().iterator();
    do
    {
      final Map.Entry< Thread, RunningWorker > entry = it.next();
      final Thread        th = entry.getKey();
      final RunningWorker w  = entry.getValue();

      if ( w.counter++ < COUNTER_KILL )
      {                                   // trying to stop the Breakable object..
        w.br.stop();
        th.interrupt();                   // give its thread a chance to respond
      }
      else
      {                                   // final instance => use brute force to stop not responding thread
        th.stop();
        it.remove();
        LogFile.log( "Brute-force break: " + w.br.getClass().getName() );
        removeRunning( w );
      }
    }
    while ( it.hasNext() );

    if ( size != running.size() )
      setRunningText();
  }

  //==========================================================================
  //  Construction:

  /**
   * Default constructor - creates MainWindow.
   */
  public MainWindow ()
  {
    enableEvents( AWTEvent.WINDOW_EVENT_MASK );
    try
    {
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Component initialization.
   */
  private void jbInit () throws Exception
  {
      // Create the main window.
    Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
    setBounds( 0, 0,
               screenSize.width,
               screenSize.height - 30 );

    this.setTitle( "Skel" );
    this.setIconImage( Options.getIcon( "logo32.gif" ).getImage() );

    contentPane = (JPanel)this.getContentPane();
    desktop     = new JDesktopPane();
    panelStatus.setBorder( BorderFactory.createBevelBorder( BevelBorder.LOWERED,
                                                            Color.white, Color.white,
                                                            new Color( 103, 101, 98 ),
                                                            new Color( 148, 145, 140 ) ) );
    panelStatus.setPreferredSize( new Dimension( 14, 20 ) );
    btAdd.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btAdd_actionPerformed( e );
      }
    });

    btNew.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miNew_actionPerformed( e );
      }
    });

    btLoad.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miLoad_actionPerformed( e );
      }
    });

    btSave.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miSave_actionPerformed( e );
      }
    });

    btDelete.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btDelete_actionPerformed( e );
      }
    });

    btGroup.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btGroup_actionPerformed( e );
      }
    });

    miOutline.setText( "Outline" );
    miOutline.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miOutline_actionPerformed( e );
      }
    });

    btUngroup.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btUngroup_actionPerformed( e );
      }
    });

    btRun.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btRun_actionPerformed( e );
      }
    });

    btRunning.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        stopRunningWorkers();
      }
    });

    menuTools.setText( "Tools" );

    btNew.setMaximumSize( buttonDimension );
    btNew.setToolTipText( "New Composition" );

    btLoad.setMaximumSize( buttonDimension );
    btLoad.setToolTipText( "Load Composition" );

    btSave.setMaximumSize( buttonDimension );
    btSave.setToolTipText( "Save Composition" );

    btAdd.setMaximumSize( buttonDimension );
    btAdd.setToolTipText( "Add Modules" );

    btDelete.setMaximumSize( buttonDimension );
    btDelete.setToolTipText( "Delete Module/Group" );

    btGroup.setMaximumSize( buttonDimension );
    btGroup.setToolTipText( "Group" );

    btUngroup.setMaximumSize( buttonDimension );
    btUngroup.setToolTipText( "Ungroup" );

    btRun.setMaximumSize( buttonDimension );
    btRun.setToolTipText( "Run Composition" );

    btRunning.setMaximumSize( runningDimension );
    btRunning.setToolTipText( "Stop Running Threads" );

    menuEdit.setText( "Edit" );

    miUndo.setText( "Undo" );
    miUndo.setAccelerator( KeyStroke.getKeyStroke( KeyEvent.VK_Z, ActionEvent.CTRL_MASK ) );
    miUndo.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miUndo_actionPerformed( e );
      }
    });

    miRedo.setText( "Redo" );
    miRedo.setAccelerator( KeyStroke.getKeyStroke( KeyEvent.VK_Y, ActionEvent.CTRL_MASK ) );
    miRedo.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miRedo_actionPerformed( e );
      }
    });

    miSelectAll.setText( "Select All" );
    miSelectAll.setAccelerator( KeyStroke.getKeyStroke( KeyEvent.VK_A, ActionEvent.CTRL_MASK ) );
    miSelectAll.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miSelectAll_actionPerformed( e );
      }
    });

    miOptions.setText( "Options" );
    miOptions.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miOptions_actionPerformed( e );
      }
    });

    menuWindow.addMenuListener( new MenuListener ()
    {
      public void menuCanceled ( MenuEvent e )
      {}
      public void menuDeselected ( MenuEvent e )
      {}
      public void menuSelected ( MenuEvent e )
      {
        menuWindow_menuSelected( e );
      }
    });

    miViewRegistry.setText( "View Registry" );
    miViewRegistry.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miViewRegistry_actionPerformed( e );
      }
    });

    panelMain.setLayout( new BorderLayout() );
    panelMain.add( panelStatus, BorderLayout.SOUTH );
    panelMain.add( jScrollPaneDesctop, BorderLayout.CENTER );

    contentPane.add( panelMain, BorderLayout.CENTER );

    jScrollPaneDesctop.getViewport().add( desktop, null );

    contentPane.add( jToolBarMain, BorderLayout.NORTH );
    jToolBarMain.add( btNew,     null );
    jToolBarMain.add( btLoad,    null );
    jToolBarMain.add( btSave,    null );
    jToolBarMain.addSeparator();
    jToolBarMain.add( btAdd,     null );
    jToolBarMain.add( btDelete,  null );
    jToolBarMain.add( btGroup,   null );
    jToolBarMain.add( btUngroup, null );
    jToolBarMain.addSeparator();
    jToolBarMain.add( btRun,     null );
    jToolBarMain.add( btRunning, null );

      // Make dragging a little faster but perhaps uglier.
    desktop.setDragMode( JDesktopPane.OUTLINE_DRAG_MODE );

      // Outline window
    outlineWindow.setLocation( getWidth() - 192, 10 );
    outlineWindow.setVisible( true );
    outlineWindow.setName( "Outline" );
    desktop.add( outlineWindow, JDesktopPane.DRAG_LAYER );

    menuFile.setText( "File" );

    miClose.setText( "Close" );
    miClose.setAccelerator( KeyStroke.getKeyStroke( KeyEvent.VK_W, ActionEvent.CTRL_MASK ) );
    miClose.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miClose_actionPerformed( e );
      }
    });

    miLoad.setText( "Load" );
    miLoad.setAccelerator( KeyStroke.getKeyStroke( KeyEvent.VK_O, ActionEvent.CTRL_MASK ) );
    miLoad.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miLoad_actionPerformed( e );
      }
    });

    miSave.setText( "Save" );
    miSave.setAccelerator( KeyStroke.getKeyStroke( KeyEvent.VK_S, ActionEvent.CTRL_MASK ) );
    miSave.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miSave_actionPerformed( e );
      }
    });

    miSaveAs.setText( "Save As..." );
    miSaveAs.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miSave_actionPerformed( e );
      }
    });

    menuComposition.setText( "Composition" );

    miAddModule.setText( "Add Modules" );
    miAddModule.setAccelerator( KeyStroke.getKeyStroke( KeyEvent.VK_I, ActionEvent.CTRL_MASK ) );
    miAddModule.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btAdd_actionPerformed( e );
      }
    });

    miDeleteModule.setText( "Delete Module" );
    miDeleteModule.setAccelerator( KeyStroke.getKeyStroke( KeyEvent.VK_DELETE, 0 ) );
    miDeleteModule.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btDelete_actionPerformed( e );
      }
    });

    miGroup.setText( "Group" );
    miGroup.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btGroup_actionPerformed( e );
      }
    });

    miUngroup.setText( "Ungroup" );
    miUngroup.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btUngroup_actionPerformed( e );
      }
    });

    miRun.setText( "Run" );
    miRun.setAccelerator( KeyStroke.getKeyStroke( KeyEvent.VK_R, ActionEvent.CTRL_MASK ) );
    miRun.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btRun_actionPerformed( e );
      }
    });

    menuWindow.setText( "Window" );
    menuHelp.setText( "Help" );

    miAbout.setText( "About" );
    miAbout.setAccelerator( KeyStroke.getKeyStroke( KeyEvent.VK_F1, 0 ) );
    miAbout.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miAbout_actionPerformed( e );
      }
    });

    this.setJMenuBar( mainMenu );

    miExit.setText( "Exit" );
    miExit.setAccelerator( KeyStroke.getKeyStroke( KeyEvent.VK_Q, ActionEvent.CTRL_MASK ) );
    miExit.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miExit_actionPerformed();
      }
    });

    miRegistry.setText( "Module Registration" );
    miRegistry.setAccelerator( KeyStroke.getKeyStroke( KeyEvent.VK_G, ActionEvent.CTRL_MASK ) );
    miRegistry.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miRegistry_actionPerformed( e );
      }
    });

    miNew.setText( "New" );
    miNew.setAccelerator( KeyStroke.getKeyStroke( KeyEvent.VK_N, ActionEvent.CTRL_MASK ) );
    miNew.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miNew_actionPerformed( e );
      }
    });

    setDefaultCloseOperation( WindowConstants.DO_NOTHING_ON_CLOSE );
    addWindowListener( new WindowAdapter ()
    {
      @Override
      public void windowClosing ( WindowEvent e )
      {
        miExit_actionPerformed();
      }
    });

    mainMenu.add( menuFile );
    mainMenu.add( menuEdit );
    mainMenu.add( menuComposition );
    mainMenu.add( menuTools );
    mainMenu.add( menuWindow );
    mainMenu.add( menuHelp );

    menuFile.add( miNew );
    menuFile.add( miClose );
    menuFile.addSeparator();
    menuFile.add( miLoad );
    menuFile.add( miSave );
    menuFile.add( miSaveAs );
    menuFile.addSeparator();
    menuFile.add( miExit );

    menuComposition.add( miAddModule );
    menuComposition.add( miDeleteModule );
    menuComposition.add( miGroup );
    menuComposition.add( miUngroup );
    menuComposition.addSeparator();
    menuComposition.add( miRun );

    menuTools.add( miRegistry );
    menuTools.add( miViewRegistry );
    menuTools.addSeparator();
    menuTools.add( miOptions );

    menuEdit.add( miUndo );
    menuEdit.add( miRedo );
    menuEdit.addSeparator();
    menuEdit.add( miSelectAll );
    menuHelp.add( miAbout );
    statusBar = panelStatus;
  }

  /**
   * Adds new frame with composition.
   *
   * @param _f Frame with composition.
   */
  public void addFrame ( JInternalFrame _f )
  {
    Component[] pc = desktop.getComponentsInLayer( JDesktopPane.POPUP_LAYER.intValue() );
    for ( int i = 0; i < pc.length; i++ )
    {
      if ( pc[i].equals( _f ) )
      {
        pc[i].setVisible( true );
        try
        {
          ((JInternalFrame)pc[i]).setSelected( true );
        }
        catch ( PropertyVetoException ee )
        {
          LogFile.exception( ee );
        }
        return;
      }
    }
    desktop.add( _f, JDesktopPane.POPUP_LAYER );
  }

  /**
   * Remove frame with composition.
   *
   * @param _f Frame with composition.
   */
  public void removeFrame ( JInternalFrame _f )
  {
    Component[] pc = desktop.getComponents();
    for ( int i = 0; i < pc.length; i++ )
    {
      if ( pc[i].equals( _f ) )
      {
        desktop.remove( _f );
        desktop.repaint();
      }
    }
  }

  //==========================================================================
  //  Events:

  /**
   * Loads composition to actual frame.
   * If no frame is actual, then cretes new one.
   */
  public void miLoad_actionPerformed ( ActionEvent e )
  {
    miNew_actionPerformed( null );
    JInternalFrame pf = desktop.getSelectedFrame();

    if ( pf != null && (pf instanceof WorkSpaceGUI) )
      ((WorkSpaceGUI)pf).pipeToComposition( WorkSpaceGUI.CMD_LOAD, null );
  }

  /**
   * Saves composition in actual frame.
   */
  void miSave_actionPerformed ( ActionEvent e )
  {
    String save = InputOutput.SAVE;
    if ( e.getSource().equals( miSaveAs ) )
      save = InputOutput.SAVEAS;

    JInternalFrame pf = desktop.getSelectedFrame();
    if ( pf != null && (pf instanceof WorkSpaceGUI) )
      ((WorkSpaceGUI)pf).pipeToComposition( WorkSpaceGUI.CMD_SAVE, save );
  }

  /**
   * Closing main application frame..
   */
  void miExit_actionPerformed ()
  {
    JInternalFrame[] com = desktop.getAllFrames();
    for ( int i = 0; i < com.length; i++ )
    {
      if ( com[i] instanceof WorkSpaceGUI )
      {
        com[i].doDefaultCloseAction();
        if ( !com[i].isClosed() )
          return;
      }
    }

    try
    {
      Options.save();
    }
    catch ( IOException ex )
    {
      LogFile.exception( ex );
    }

    System.exit( 0 );
  }

  /**
   * Close actual frame.
   */
  void miClose_actionPerformed ( ActionEvent e )
  {
    JInternalFrame pf = desktop.getSelectedFrame();
    if ( pf != null && (pf instanceof WorkSpaceGUI) )
      pf.doDefaultCloseAction();
  }

  /**
   * Opens About dialog.
   */
  void miAbout_actionPerformed ( ActionEvent e )
  {
    AboutDialog aboutWindow = new AboutDialog( this );
    aboutWindow.setVisible( true );
  }

  /**
   * Registration dialog.
   */
  void miRegistry_actionPerformed ( ActionEvent e )
  {
    RegDatabaseBasic.registryModule( null, null, null );
  }

  /**
   * Create new frame for new composition.
   */
  void miNew_actionPerformed ( ActionEvent e )
  {
    WorkSpaceGUI workSpace = InstanceGUI.newWorkSpaceInstance();
    workSpace.setSize( desktop.getWidth() - 193, desktop.getHeight() - 20 );
    workSpace.setVisible( true );
    workSpace.setName( "WORKSPACE" );
    workSpace.pipeToComposition( WorkSpaceGUI.CMD_ZOOMWINDOW, outlineWindow );
    desktop.add( workSpace );

    try
    {
      workSpace.setSelected( true );
    }
    catch ( PropertyVetoException ee )
    {
      LogFile.exception( ee );
    }
  }

  /**
   * Show Outline window.
   */
  void miOutline_actionPerformed ( ActionEvent e )
  {
    if ( outlineWindow.isIcon() )
    {
      try
      {
        outlineWindow.setIcon( false );
        return;
      }
      catch ( PropertyVetoException ee )
      {
        LogFile.exception( ee );
      }
    }

    if ( outlineWindow.isMaximum() )
      return;

    if ( outlineWindow.isClosed() )
    {
      outlineWindow.setVisible( true );
      outlineWindow.setLocation( 0, 0 );
      desktop.add( outlineWindow, JDesktopPane.DRAG_LAYER );
      try
      {
        outlineWindow.setSelected( true );
      }
      catch ( PropertyVetoException ee )
      {
        LogFile.exception( ee );
      }
    }
  }

  /**
   * Add new modules or groups into actual composition.
   */
  void btAdd_actionPerformed ( ActionEvent e )
  {
    JInternalFrame pf = desktop.getSelectedFrame();
    if ( pf != null && (pf instanceof WorkSpaceGUI) )
      ((WorkSpaceGUI)pf).pipeToComposition( WorkSpaceGUI.CMD_ADDMODULE, null );
  }

  /**
   * Delete selected modules in actual composition.
   */
  void btDelete_actionPerformed ( ActionEvent e )
  {
    JInternalFrame pf = desktop.getSelectedFrame();
    if ( pf != null && (pf instanceof WorkSpaceGUI) )
      ((WorkSpaceGUI)pf).pipeToComposition( WorkSpaceGUI.CMD_DELETEMODULE, null );
  }

  /**
   * Create new group.
   */
  void btGroup_actionPerformed ( ActionEvent e )
  {
    JInternalFrame pf = desktop.getSelectedFrame();
    if ( pf != null && (pf instanceof WorkSpaceGUI) )
      ((WorkSpaceGUI)pf).pipeToComposition( WorkSpaceGUI.CMD_GROUP, null );
  }

  /**
   * Dissmiss group.
   */
  void btUngroup_actionPerformed ( ActionEvent e )
  {
    JInternalFrame pf = desktop.getSelectedFrame();
    if ( pf != null && (pf instanceof WorkSpaceGUI) )
      ((WorkSpaceGUI)pf).pipeToComposition( WorkSpaceGUI.CMD_UNGROUP, null );
  }

  /**
   * Run composition.
   */
  void btRun_actionPerformed ( ActionEvent e )
  {
    JInternalFrame pf = desktop.getSelectedFrame();
    if ( pf != null && (pf instanceof WorkSpaceGUI) )
      ((WorkSpaceGUI)pf).pipeToComposition( WorkSpaceGUI.CMD_RUN, null );
  }

  /**
   * Undo.
   */
  void miUndo_actionPerformed ( ActionEvent e )
  {
    JInternalFrame pf = desktop.getSelectedFrame();
    if ( pf != null && (pf instanceof WorkSpaceGUI) )
      ((WorkSpaceGUI)pf).pipeToComposition( WorkSpaceGUI.CMD_UNDO, null );
  }

  /**
   * Redo.
   */
  void miRedo_actionPerformed ( ActionEvent e )
  {
    JInternalFrame pf = desktop.getSelectedFrame();
    if ( pf != null && (pf instanceof WorkSpaceGUI) )
      ((WorkSpaceGUI)pf).pipeToComposition( WorkSpaceGUI.CMD_REDO, null );
  }

  /**
   * Select all modules.
   */
  void miSelectAll_actionPerformed ( ActionEvent e )
  {
    JInternalFrame pf = desktop.getSelectedFrame();
    if ( pf != null && (pf instanceof WorkSpaceGUI) )
      ((WorkSpaceGUI)pf).pipeToComposition( WorkSpaceGUI.CMD_SELECTALL, null );
  }

  /**
   * Invokes Options dialog.
   */
  void miOptions_actionPerformed ( ActionEvent e )
  {
    OptionsDialog optionsWindow = new OptionsDialog( this, "Options", true );
    optionsWindow.initValues();
    optionsWindow.setVisible( true );
  }

  /**
   * Registering all workspaces in menu.
   */
  void menuWindow_menuSelected ( MenuEvent e )
  {
    menuWindow.removeAll();
    menuWindow.add( miOutline );
    menuWindow.addSeparator();
    WorkSpaceGUI workSpace;

    JInternalFrame[] com = desktop.getAllFrames();
    for ( int i = 0; i < com.length; i++ )
    {
      if ( com[i] instanceof WorkSpaceGUI )
      {
        workSpace = (WorkSpaceGUI)com[i];
        JMenuItemFrame menuItem = new JMenuItemFrame( workSpace );
        menuWindow.add( menuItem );
      }
    }
  }

  /**
   * View registry data.
   */
  void miViewRegistry_actionPerformed ( ActionEvent e )
  {
    RegDatabaseBasic.previewModules();
  }

  {
    Options.init();
  }

}
