package cz.cuni.jagrlib.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Abstract class that cares about visual representation of a module.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @since   0.25
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/ModuleGUI.java">ModuleGUI.java</a>
 */
abstract public class ModuleGUI extends JPanel implements Undo
{
  /** Information about module. */
  public InfoModule info;

  /** Actual plug. */
  protected InfoPlug actualPlug;

  /** Old mouse position (X-coordinate). */
  protected int oldMouseX = 0;

  /** Old mouse position (Y-coordinate). */
  protected int oldMouseY = 0;

  protected Point     oldPosition;

  protected Dimension oldSize;

  protected Rectangle drawRegion      = new Rectangle();

  /** No special mouse action. */
  public final static int MM_DEFAULT  = 0;

  /** Module move. */
  public final static int MM_MOVE     = 1;

  /** Plug move. */
  public final static int MM_PLUG     = 2;

  /** Module resize - direction E (horizontal). */
  public final static int MM_RESIZEE  = 3;

  /** Module resize - direction S (vertical). */
  public final static int MM_RESIZES  = 4;

  /** Module resize - direction SE (upper right corner). */
  public final static int MM_RESIZESE = 5;

  /** Mode of mouse move or mouse procedure in action. */
  protected int      modeMove         = MM_DEFAULT;

  /** Initial module width. */
  protected static int moduleWidth    = 300;

  /** Initial module height. */
  protected static int moduleHeight   = 38;

  /** Module width in minimization mode. */
  public static int minWidth          = 120;

  /** Module height in minimization mode. */
  public static int minHeight         = 38;   // alt: moduleHeight

  /** Undo/Redo object. */
  public ActionsUndo undoReg          = null;

  public final static int ACTION_MODULE_MOVE   = 101;
  public final static int ACTION_MODULE_RESIZE = 102;

  // GUI components:
  protected JPopupMenu jPopupMenuActions = new JPopupMenu();

  public MouseAdapter mouseClick = new MouseAdapter ()
  {
    public void mousePressed ( MouseEvent e )
    {
      this_mousePressed( e );
    }

    public void mouseReleased ( MouseEvent e )
    {
      this_mouseReleased( e );
    }

    public void mouseClicked ( MouseEvent e )
    {
      this_mouseClicked( e );
    }
  };

  public MouseMotionAdapter mouseMove = new MouseMotionAdapter ()
  {
    public void mouseDragged ( MouseEvent e )
    {
      this_mouseDragged( e );
    }

    public void mouseMoved ( MouseEvent e )
    {
      this_mouseMoved( e );
    }
  };

  /** Sets plugs for the module. */
  protected void setModuleType ()
  {
    boolean isNew = false;
    if ( info.nextInfo != null &&
         info.nextInfo.containsKey( "NEW" ) )
    {
      isNew = true;
      info.nextInfo.remove( "NEW" );
    }

    int x     = 5;
    int maxX  = getWidth() - 15;
    int initY = getHeight() - 2;

    for ( InfoPlug ip : info.plugs.values() )
    {
      if ( ip.infoGUI == null )
        ip.infoGUI = new InfoPlugGUI();

      int px = x;
      x     += 20;

      if ( px > maxX ) px = maxX;

      if ( ip.infoGUI.x == 0 ||
           isNew )
        ip.infoGUI.x = px;

      if ( ip.infoGUI.y == 0 )
        ip.infoGUI.y = initY;

      newPlug( ip );
      resizePlug( ip.infoGUI.gui );
    }
  }

  /**
   * Finds a plug at the given screen position [x,y].
   *
   * @param  x X-coordinate.
   * @param  y Y-coordinate.
   * @return Plug's key or {@code null}.
   */
  protected InfoPlug getPlugAtPoint ( int x, int y )
  {
    for ( InfoPlug ip : info.plugs.values() )
    {
      PlugGUI pg = ip.infoGUI.gui;
      if ( pg.contains( x, y ) )
        return pg.info;
    }

    return null;
  }

  /** Component initialization. */
  private void jbInit ()
  throws Exception
  {
    setBorder( BorderFactory.createLineBorder( Color.black ) );

    addAncestorListener( new AncestorListener ()
    {
      public void ancestorAdded ( AncestorEvent e )
      {}

      public void ancestorRemoved ( AncestorEvent e )
      {
        this_ancestorRemoved( e );
      }

      public void ancestorMoved ( AncestorEvent e )
      {}
    });

    addComponentListener ( new ComponentAdapter ()
    {
      public void componentResized ( ComponentEvent e )
      {
        this_componentResized( e );
      }

      public void componentMoved ( ComponentEvent e )
      {
        this_componentMoved( e );
      }
    });

    addMouseListener( mouseClick );
    addMouseMotionListener( mouseMove );
    jPopupMenuActions.setInvoker( this );
  }

  /** Sets parameters of the module. */
  abstract protected void setParams ();

  /**
   * Adds new plug (initial orientation: South).
   *
   * @param  _infoP Information about plug.
   */
  public void newPlug ( InfoPlug _infoP )
  {
    InstanceGUI.newPlugInstance( _infoP );
  }

  /**
   * Returns mouse's mode.
   *
   * @param  mx X-coordinate of mouse.
   * @param  my Y-coordinate of mouse.
   * @return Mouse mode.
   */
  abstract protected int getMouseMode ( int mx, int my );

  /**
   * Deletes module.
   */
  abstract protected void removeModule ();

  /**
   * Resizes the window (Plug has to adapt).
   */
  protected void resizePlug ( PlugGUI p )
  {
    p.resize( getWidth() - 2, getHeight() - 2 );
  }

  //==========================================================================
  //  Events:

  /**
   * Mouse drag:
   * <br />mode {@code MM_MOVE} - move module.
   * <br />mode {@code MM_RESIZEE} - resize East.
   * <br />mode {@code MM_RESIZES} - resize South.
   * <br />mode {@code MM_RESIZESE} - resize SouthEast.
   */
  protected void this_mouseDragged ( MouseEvent e )
  {
    int ex = e.getX();
    int ey = e.getY();
    int px = ex - oldMouseX;
    int py = ey - oldMouseY;
    int ppx;
    int ppy;

    switch ( modeMove )
    {
      case MM_MOVE:
        if ( e.getModifiers() == MouseEvent.BUTTON1_MASK )
          info.owner.infoCompositionGUI.gui.moveSelected( info.key, px, py );
        break;

      case MM_RESIZEE:
        if ( ex < minWidth )
          ppx = minWidth;
        else
          ppx = ex;

        setBounds( getX(), getY(), ppx, getHeight() );
        break;

      case MM_RESIZES:
        if ( ey < minHeight )
          ppy = minHeight;
        else
          ppy = ey;

        setBounds( getX(), getY(), getWidth(), ppy );
        break;

      case MM_RESIZESE:
        if ( ex < minWidth )
          ppx = minWidth;
        else
          ppx = ex;
        if ( ey < minHeight )
          ppy = minHeight;
        else
          ppy = ey;

        setBounds( getX(), getY(), ppx, ppy );
        break;
    }
  }

  /**
   * Mouse pressed.
   * <br /><b>left button</b> - select/unselect module.
   * <br /><b>SHIFT + left button</b> - select/unselect module.
   * <br />it doesn't change selecting of others modules.
   */
  protected void this_mousePressed ( MouseEvent e )
  {
    int m       = e.getModifiers();
    modeMove    = getMouseMode( e.getX(), e.getY() );
    oldMouseX   = e.getX();
    oldMouseY   = e.getY();
    oldPosition = getLocation();
    oldSize     = getSize();

    if ( m == MouseEvent.BUTTON1_MASK + MouseEvent.SHIFT_MASK )
    {
      info.owner.infoCompositionGUI.gui.setSelectModule( info.key, !info.infoGUI.selected );
    }

    if ( m == MouseEvent.BUTTON1_MASK )
    {
      if ( !info.infoGUI.selected )
      {
        info.owner.infoCompositionGUI.gui.selectAll( false );
        info.owner.infoCompositionGUI.gui.setSelectModule( info.key, true );
      }
    }
  }

  /**
   * Mouse released.
   */
  protected void this_mouseReleased ( MouseEvent e )
  {
    if ( modeMove == MM_MOVE  &&
         e.getModifiers() == MouseEvent.BUTTON1_MASK )
    {
      Point newPosition = this.getLocation();
      if ( undoReg != null )
        undoReg.registry( new ActionsUndoReg( this, ACTION_MODULE_MOVE, oldPosition, newPosition ) );
    }

    if ( modeMove == MM_RESIZEE ||
         modeMove == MM_RESIZES ||
         modeMove == MM_RESIZESE )
    {
      Dimension newSize = getSize();
      if ( undoReg != null )
        undoReg.registry( new ActionsUndoReg( this, ACTION_MODULE_RESIZE, oldSize, newSize ) );
    }

    modeMove = MM_DEFAULT;
    setCursor( Cursor.getPredefinedCursor( Cursor.DEFAULT_CURSOR ) );
  }

  /**
   * Mouse click.
   */
  protected void this_mouseClicked ( MouseEvent e )
  {
  }

  /**
   * Mouse move:
   * <br />mode {@code MM_DEFAULT} - sets cursor on normal cursor.
   * <br />mode {@code MM_MOVE} - sets cursor on move cursor.
   * <br />mode {@code MM_PLUG} - sets cursor on hand cursor and sets ToolTip of Plug.
   * <br />mode {@code MM_RESIZEE} - sets cursor on resizeE cursor.
   * <br />mode {@code MM_RESIZES} - sets cursor on resizeS cursor.
   * <br />mode {@code MM_RESIZESE} - sets cursor on resizeSE cursor.
   */
  protected void this_mouseMoved ( MouseEvent e )
  {
    if ( e.getSource().equals( this ) )
    {
      setToolTipText( info.reg.className + " (" + info.reg.template + ")\n" +
                      info.reg.description );

      switch ( getMouseMode( e.getX(), e.getY() ) )
      {
        case MM_DEFAULT:
          setCursor( Cursor.getPredefinedCursor( Cursor.DEFAULT_CURSOR ) );
          break;

        case MM_MOVE:
          setCursor( Cursor.getPredefinedCursor( Cursor.MOVE_CURSOR ) );
          break;

        case MM_PLUG:
          setCursor( Cursor.getPredefinedCursor( Cursor.HAND_CURSOR ) );
          setToolTipText( actualPlug.infoGUI.gui.getToolTipText() );
          break;

        case MM_RESIZEE:
          setCursor( Cursor.getPredefinedCursor( Cursor.E_RESIZE_CURSOR ) );
          break;

        case MM_RESIZES:
          setCursor( Cursor.getPredefinedCursor( Cursor.S_RESIZE_CURSOR ) );
          break;

        case MM_RESIZESE:
          setCursor( Cursor.getPredefinedCursor( Cursor.SE_RESIZE_CURSOR ) );
          break;
      }
    }
    else
      setCursor( Cursor.getPredefinedCursor( Cursor.DEFAULT_CURSOR ) );
  }

  /**
   * Reflect changes depending on module's geometry..
   *
   * @param  resize Module was resized? (resize its interior)
   */
  protected void newModuleGeometry ( boolean resize )
  {
    if ( resize )
      info.infoGUI.gui.validate();

    if ( info.owner != null )
    {
      info.owner.infoCompositionGUI.gui.setCompositionSize();
        // changed region:
      drawRegion.x      = info.infoGUI.x;
      drawRegion.y      = info.infoGUI.y;
      drawRegion.width  = info.infoGUI.width;
      drawRegion.height = info.infoGUI.height;
      for ( InfoPlug ip : info.plugs.values() )
        if ( ip.channels != null )
          for ( InfoChannel ch : ip.channels.values() )
            ch.infoGUI.gui.extend( drawRegion );
      drawRegion.grow( 8, 8 );
      info.owner.infoCompositionGUI.gui.repaint( drawRegion );
    }
  }

  /**
   * Module was resized:
   * Plugs' positions need to be recomputed.
   * Changes bound of work space.
   */
  protected void this_componentResized ( ComponentEvent e )
  {
    for ( InfoPlug ip : info.plugs.values() )
      resizePlug( ip.infoGUI.gui );

    if ( info.infoGUI.isNormal() )
    {
      info.infoGUI.width  = getWidth();
      info.infoGUI.height = getHeight();
    }

    newModuleGeometry( true );
  }

  /**
   * Module moved.
   * Changes bound of work space.
   */
  protected void this_componentMoved ( ComponentEvent e )
  {
    info.infoGUI.x = getX();
    info.infoGUI.y = getY();

    newModuleGeometry( false );
  }

  /**
   * Deleting of composition.
   */
  protected void this_ancestorRemoved ( AncestorEvent e )
  {
    removeModule();
  }

  /** Default constructor. */
  public ModuleGUI ()
  {
    enableEvents( AWTEvent.WINDOW_EVENT_MASK );
    try
    {
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Moves the module.
   *
   * @param  nx Relative x coordinate.
   * @param  ny Relative y coordainte.
   */
  public void moveModule ( int nx, int ny )
  {
    int px = getX() + nx;
    int py = getY() + ny;
    if ( px < 0 ) px = 0;
    if ( py < 0 ) py = 0;

    setLocation( px, py );
  }

  /**
   * Gets max axis of module.
   *
   * @return (xmax, ymax).
   */
  public Dimension getMaxBounds ()
  {
    return new Dimension( (int)getBounds().getMaxX(),
                          (int)getBounds().getMaxY() );
  }

  /**
   * Undo last action.
   *
   * @param  action do this action.
   */
  public void undo ( ActionsUndoReg action )
  {
    if ( undoReg == null ) return;

    undoReg.dont = true;                  // prevents re-registration

    switch ( action.what )
    {
      case ACTION_MODULE_MOVE:
      {
        Point newPosition = (Point)action.lastValue;
        setLocation( newPosition );
        break;
      }

      case ACTION_MODULE_RESIZE:
      {
        Dimension newSize = (Dimension)action.lastValue;
        setSize( newSize );
        break;
      }
    }

    undoReg.dont = false;
  }

  /**
   * Redo last on-done action.
   */
  public void redo ( ActionsUndoReg action )
  {
    if ( undoReg == null ) return;

    undoReg.dont = true;                  // prevents re-registration

    switch ( action.what )
    {
      case ACTION_MODULE_MOVE:
      {
        Point newPosition = (Point)action.newValue;
        setLocation( newPosition );
        break;
      }

      case ACTION_MODULE_RESIZE:
      {
        Dimension newSize = (Dimension)action.newValue;
        setSize( newSize );
        break;
      }
    }

    undoReg.dont = false;
  }

  /**
   * Sets undo object for module and plugs.
   *
   * @param  _undo new ActionsUndo object.
   */
  public void setUndoObj ( ActionsUndo _undo )
  {
    undoReg = _undo;
  }

  /**
   * Initial width of module.
   */
  public static int getModuleWidth ()
  {
    return moduleWidth;
  }

  /**
   * Initial height of module.
   */
  public static int getModuleHeight ()
  {
    return moduleHeight;
  }

  /**
   * Get initial height of module with parametrs.
   *
   * @param  _paramCount Number of parameters.
   * @return Module height in pixels.
   */
  public static int getModuleHeight ( int _paramCount )
  {
    if ( _paramCount == 0 )
      return moduleHeight;
    else
      return( 5 + moduleHeight + _paramCount * (ParamGUI.paramLineHeight + 2) );
  }

  /**
   * Set initial width of a module.
   *
   * @param  _width new value for moduleWidth.
   */
  public static void setModuleWidth ( int _width )
  {
    moduleWidth = Formula.clamp( _width, minWidth, Integer.MAX_VALUE );
  }

  /**
   * Set initial height of a module.
   *
   * @param  _height new value for moduleHeight.
   */
  public static void setModuleHeight ( int _height )
  {
    moduleHeight = Formula.clamp( _height, minHeight, Integer.MAX_VALUE );
  }

}
