package cz.cuni.jagrlib.gui;

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.io.*;
import javax.swing.*;
import javax.swing.border.*;
import java.beans.PropertyVetoException;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Improved class that care about visual representation of module.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/ModuleGUIImproved.java">ModuleGUIImproved.java</a>
 */
public class ModuleGUIImproved extends ModuleGUI
{
  private static final long serialVersionUID = 1L;

  //==========================================================================
  //  Data:

  /** Window for editing parameters. */
  protected ParamsEdit windowParam;

  /** Temporary channel. */
  protected InfoChannel tempChannel;

  /** Undo/Redo constants. */
  final static public int ACTION_MODULE_MODE = 103;

  final static public int ACTION_PLUG_MOVE   = 104;

  protected class PlugPosition
  {
    InfoPlugGUI plug;

    Point position;

    int orientation;

    PlugPosition ( InfoPlugGUI _plug, Point _position, int _orientation )
    {
      plug        = _plug;
      orientation = _orientation;
      position    = _position;
    }
  }

  protected PlugPosition oldPositionPlug;

    // components
  protected JLabel      lbName            = new JLabel();
  protected JTextField  tfName            = new JTextField();
  protected JScrollPane jScrollPaneParams = new JScrollPane();
  protected JPanel      panelPlugs        = new JPanel();
  protected JPanel      panelParams       = new JPanel();

    // menu actions
  protected JMenuItem   miSelect          = new JMenuItem();
  protected JMenuItem   miChannel         = new JMenuItem();
  protected JMenuItem   miConnect         = new JMenuItem();
  protected JMenuItem   miDelete          = new JMenuItem();
  protected JMenuItem   miGroup           = new JMenuItem();
  protected JMenuItem   miParams          = new JMenuItem();
  protected JMenuItem   miSize            = new JMenuItem();
  protected JMenuItem   miCode            = new JMenuItem();
  protected JMenuItem   miRename          = new JMenuItem();

  //==========================================================================
  //  Support classes:

  /**
   * Border with plug-drawing capability.
   */
  protected class PlugBorder extends EmptyBorder
  {
    private static final long serialVersionUID = 1L;

    public PlugBorder ( int arg0, int arg1, int arg2, int arg3 )
    {
      super( arg0, arg1, arg2, arg3 );
    }

    /**
     * Border drawing.
     */
    @Override
    public void paintBorder ( Component c, Graphics g, int x, int y, int width, int height )
    {
        // draw plugs on top of the border:
      for ( InfoPlug ip : info.plugs.values() )
        ip.infoGUI.gui.paintItem( g );
    }

  }

  //==========================================================================
  //  Methods ModuleGUI:

  /** Sets Module's parameters. */
  protected void setParams ()
  {
    ParamGUI par;
    if ( info.params != null )
    {
      double yweight = 0.0;
      InfoParam ip;
      int j = 0;
      int size = info.getVisibleParamLines();

      for ( String name : info.params.keySet() )
      {
        ip = info.params.get( name );
        if ( ip.visible )
        {
          par = InstanceGUI.newParam( ip );

          par.setListeners( mouseClick, mouseMove );

          if ( j + 1 == size )
            yweight = 1.0;

          panelParams.add( par,
                           new GridBagConstraints( 0, j, 1, 1, 1.0, yweight,
                                                   GridBagConstraints.NORTHWEST,
                                                   GridBagConstraints.HORIZONTAL,
                                                   new Insets( 2, 2, 0, 2 ), 0, 0 ) );
          j++;
        }
      }
    }
  }

  /**
   * Returns mouse's mode:
   * <br />{@link #MM_MOVE} - move.
   * <br />{@link #MM_PLUG} - mouse is above plug.
   * <br />{@link #MM_RESIZEE} - resize E.
   * <br />{@link #MM_RESIZES} - resize S.
   * <br />{@link #MM_RESIZESE} - resize SE.
   * <br />{@link #MM_DEFAULT} - otherwise.
   *
   * @param  mx X-coordinate of mouse.
   * @param  my Y-coordinate of mouse.
   * @return Mouse mode.
   */
  @Override
  protected int getMouseMode ( int mx, int my )
  {
    if ( ( (lbName.getX() < mx) &&
           (lbName.getX() + lbName.getWidth() > mx) &&
           (lbName.getY() < my) &&
           (lbName.getY() + lbName.getHeight() > my) )
           || (modeMove == MM_MOVE) )
      return MM_MOVE;                     // move

    int borderR = 5;
    if ( (mx > getWidth()  - borderR) &&
         (my > getHeight() - borderR) &&
         (!info.infoGUI.isMini()) )
      return MM_RESIZESE;                 // resizeSE

    if ( (mx > getWidth() - borderR) &&
         (!info.infoGUI.isMini()) )
      return MM_RESIZEE;                  // resizeE

    if ( (my > getHeight() - borderR) &&
         (!info.infoGUI.isMini()) )
      return MM_RESIZES;                  // resizeS

    actualPlug = getPlugAtPoint( mx, my );
    if ( actualPlug != null )
      return MM_PLUG;                     // plug

    return MM_DEFAULT;                    // general
  }

  /** Sets plugs and parameters of the module. */
  protected void setModuleType ()
  {
    super.setModuleType();
    setParams();
  }

  /** Deleting of module with window for editing parameters. */
  protected void removeModule ()
  {
    if ( windowParam != null )
    {
      try
      {
        windowParam.setIcon( false );
      }
      catch ( PropertyVetoException ee )
      {
        LogFile.exception( ee );
      }
      ((MainWindow)getTopLevelAncestor()).removeFrame( windowParam );
    }
  }

  //==========================================================================
  //  Methods:

  /**
   * Component initialization.
   */
  private void jbInit () throws Exception
  {
    setLayout( new BorderLayout() );
    setName( InfoModule.TI_MODULE );

    lbName.setBackground( InfoModuleGUI.colorName );
    lbName.setFont( new java.awt.Font( "Dialog", 1, 12 ) );
    lbName.setForeground( Color.white );
    lbName.setOpaque( true );

    if ( info.infoGUI.nextInfo != null )
    {
      ImageIcon ic = (ImageIcon)info.infoGUI.nextInfo.get( InfoModuleGUI.MS_ICON );
      lbName.setIcon( ic );
    }
    lbName.setText( info.reg.name );

    tfName.addFocusListener( new FocusAdapter ()
    {
      public void focusLost ( FocusEvent e )
      {
        tfName_focusLost( e );
      }
    });
    tfName.addKeyListener( new KeyAdapter ()
    {
      public void keyTyped ( KeyEvent e )
      {
        tfName_keyTyped( e );
      }
    });

    panelPlugs.setBorder( new PlugBorder( 10, 10, 10, 10 ) );
    panelPlugs.setLayout(  new BorderLayout() );

    panelParams.setLayout( new GridBagLayout() );
    jScrollPaneParams.setBorder( BorderFactory.createEtchedBorder( EtchedBorder.LOWERED ) );
    panelParams.setBorder( BorderFactory.createEmptyBorder() );
    panelPlugs.add( lbName, BorderLayout.NORTH );
    panelPlugs.add( jScrollPaneParams, BorderLayout.CENTER );
    jScrollPaneParams.getViewport().add( panelParams, null );
    add( panelPlugs, BorderLayout.CENTER );

    panelParams.addMouseListener( mouseClick );
    panelParams.addMouseMotionListener( mouseMove );
    panelParams.setToolTipText( info.reg.className + " (" + info.reg.template + ')' );

    miSelect.setText( "Replace Piece" );
    miSelect.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miSelect_actionPerformed( e );
      }
    });

    miRename.setText( "Rename Module" );
    miRename.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miRename_actionPerformed( e );
      }
    });

    miChannel.setText( "New Channel" );
    miChannel.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miChannel_actionPerformed( e );
      }
    });

    miConnect.setText( "Connect with Others" );
    miConnect.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miConnect_actionPerformed( e );
      }
    });

    miDelete.setText( "Delete Module" );
    miDelete.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miDelete_actionPerformed( e );
      }
    });

    miGroup.setText( "Group" );
    miGroup.addActionListener( new ActionListener()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miGroup_actionPerformed( e );
      }
    });

    miParams.setText( "Edit Params" );
    miParams.addActionListener( new ActionListener()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miParams_actionPerformed( e );
      }
    });

    miSize.setText( "Mini/Maxi" );
    miSize.setFont( new Font( miSize.getFont().getFontName(),
                              Font.BOLD, miSize.getFont().getSize() ) );
    miSize.addActionListener( new ActionListener()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miSize_actionPerformed( e );
      }
    });

    miCode.setText( "View Source Code" );
    miCode.addActionListener( new ActionListener()
    {
      public void actionPerformed ( ActionEvent e )
      {
        miCode_actionPerformed( e );
      }
    });

    jPopupMenuActions.add( miChannel );
    jPopupMenuActions.add( miConnect );
    jPopupMenuActions.add( miSize );
    jPopupMenuActions.add( miSelect );
    jPopupMenuActions.add( miRename );
    jPopupMenuActions.add( miDelete );
    jPopupMenuActions.add( miGroup );
    jPopupMenuActions.add( miParams );
    jPopupMenuActions.add( miCode );

    if ( !info.infoGUI.isNormal() )
    {
      setBounds( info.infoGUI.x, info.infoGUI.y, minWidth, minHeight );
      panelPlugs.remove( jScrollPaneParams );
    }
    else
      setBounds( info.infoGUI.x, info.infoGUI.y,
                 info.infoGUI.width, info.infoGUI.height );

    setModuleType();
  }

  /**
   * Initialization of info.
   *
   * @param  _info info o Piece.
   */
  public void setInfo ( InfoModule _info )
  {
    info = _info;
    if ( info.infoGUI == null )
      info.infoGUI = new InfoModuleGUI();

    info.infoGUI.gui = this;
  }

  /**
   * Creates new ModuleGUIImproved.
   *
   * @param  _info Information about module.
   */
  public ModuleGUIImproved ( InfoModule _info )
  {
    try
    {
      setInfo( _info );
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /** Default action on mouse double-click. */
  public void runDefaultAction ()
  {
    miSize_actionPerformed( null );
  }

  //==========================================================================
  //  Events:

  /**
   * Mouse click:
   * <b>right button</b> - show popup menu.
   *
   * @param e MouseEvent
   */
  @Override
  protected void this_mouseClicked ( MouseEvent e )
  {
    super.this_mouseClicked( e );
    int m = e.getModifiers();
    if ( m == MouseEvent.BUTTON1_MASK &&
         e.getClickCount() == 2 )
      runDefaultAction();

    if ( m == MouseEvent.BUTTON3_MASK )
    {
      actualPlug = getPlugAtPoint( e.getX(), e.getY() );
      if ( actualPlug != null )
      {
        miChannel.setVisible( true );
        miChannel.setText( actualPlug.input ? "New Channel - Input Plug" :
                                              "New Channel - Output Plug" );
      }
      else
        miChannel.setVisible( false );

      miSize.setText( info.infoGUI.isMini() ? "Maximization" : "Minimization" );

      jPopupMenuActions.show( e.getComponent(), e.getX(), e.getY() );
    }
  }

  /**
   * Mouse drag.
   * In {@link #MM_PLUG} mode - moves the plug.
   */
  @Override
  protected void this_mouseDragged ( MouseEvent e )
  {
    super.this_mouseDragged( e );
    int ex = e.getX();
    int ey = e.getY();
    int px = ex - oldMouseX;
    int py = ey - oldMouseY;

    switch ( modeMove )
    {
      case MM_PLUG:
        if ( tempChannel != null )
        {
          tempChannel.infoGUI.nextInfo.put( "X", String.valueOf( getX() + ex ) );
          tempChannel.infoGUI.nextInfo.put( "Y", String.valueOf( getY() + ey ) );
            // changed region:
          drawRegion.width = -1;
          tempChannel.infoGUI.gui.extend( drawRegion );
          drawRegion.grow( 8, 8 );
          info.owner.infoCompositionGUI.gui.repaint( drawRegion );
        }
        else
          if ( actualPlug != null )
          {
            actualPlug.infoGUI.gui.movePlug( px, py );
            oldMouseX = ex;
            oldMouseY = ey;
              // changed region:
            drawRegion.width = -1;
            if ( actualPlug.channels != null )
              for ( InfoChannel ch : actualPlug.channels.values() )
                ch.infoGUI.gui.extend( drawRegion );
            else
            {
              drawRegion.add( getX() + actualPlug.infoGUI.x + 9,
                              getY() + actualPlug.infoGUI.y - 5 );
              drawRegion.add( getX() + actualPlug.infoGUI.x + 9 - px,
                              getY() + actualPlug.infoGUI.y - 5 - py );
            }
            drawRegion.grow( 10, 10 );
            info.owner.infoCompositionGUI.gui.repaint( drawRegion );
          }
        break;
    }
  }

  /**
   * Mouse was pressed.
   * <b>Left button</b> - sets plug for new channel.
   */
  @Override
  protected void this_mousePressed ( MouseEvent e )
  {
    super.this_mousePressed( e );
    if ( modeMove == MM_PLUG )
    {
      actualPlug = getPlugAtPoint( e.getX(), e.getY() );
      if ( e.getModifiers() == MouseEvent.BUTTON1_MASK )
      {
        if ( actualPlug != null )
        {
          info.owner.infoCompositionGUI.gui.setIDModule( actualPlug );
          info.owner.infoCompositionGUI.gui.undoReg.dont = true;
          tempChannel = info.owner.infoCompositionGUI.gui.newChannelTemp();
          info.owner.infoCompositionGUI.gui.undoReg.dont = false;
          tempChannel.infoGUI.nextInfo = new HashMap< String, Object >();
          tempChannel.infoGUI.nextInfo.put( "X", String.valueOf( getX() + e.getX() ) );
          tempChannel.infoGUI.nextInfo.put( "Y", String.valueOf( getY() + e.getY() ) );
        }
      }
      if ( e.getModifiers() == MouseEvent.BUTTON3_MASK )
      {
        if ( actualPlug != null )
        {
          oldPositionPlug = new PlugPosition( actualPlug.infoGUI,
                                              new Point( actualPlug.infoGUI.x, actualPlug.infoGUI.y ),
                                              actualPlug.infoGUI.orientation );
        }
      }
    }
  }

  /**
   * Mouse was released.
   * Creates a new channel if necessary.
   */
  @Override
  protected void this_mouseReleased ( MouseEvent e )
  {
    switch ( modeMove )
    {
      case MM_PLUG:
      {
        if ( tempChannel == null && actualPlug != null )
        {
          PlugPosition newPositionPlug = new PlugPosition( actualPlug.infoGUI,
                                                           new Point( actualPlug.infoGUI.x, actualPlug.infoGUI.y ),
                                                           actualPlug.infoGUI.orientation );
          if ( undoReg != null )
            undoReg.registry( new ActionsUndoReg( this, ACTION_PLUG_MOVE, oldPositionPlug, newPositionPlug ) );
        }
        break;
      }
    }

    super.this_mouseReleased( e );
    modeMove = MM_DEFAULT;
    setCursor( Cursor.getPredefinedCursor( Cursor.DEFAULT_CURSOR ) );
    if ( tempChannel != null )
    {
      String xx = (String)tempChannel.infoGUI.nextInfo.get( "X" );
      int x1 = 0;
      int y1 = 0;
      if ( xx != null )
        x1 = Integer.parseInt( xx );
      String yy = (String)tempChannel.infoGUI.nextInfo.get( "Y" );
      if ( yy != null )
        y1 = Integer.parseInt( yy );
      info.owner.infoCompositionGUI.gui.undoReg.dont = true;
      info.owner.infoCompositionGUI.gui.removeChannel( tempChannel.key );
      info.owner.infoCompositionGUI.gui.undoReg.dont = false;
      Component cc = info.owner.infoCompositionGUI.gui.getComponentAt( x1, y1 );
      if ( cc != null && cc instanceof ModuleGUI )
      {
        ModuleGUI mg = (ModuleGUI)cc;
        InfoPlug op = mg.getPlugAtPoint( x1 - mg.getX(), y1 - mg.getY() );
        if ( op != null )
          info.owner.infoCompositionGUI.gui.setIDModule( op );
      }

      info.owner.infoCompositionGUI.gui.plugFrom = null;
      info.owner.infoCompositionGUI.gui.plugTo   = null;
      info.owner.infoCompositionGUI.gui.repaint();
    }
    tempChannel = null;
  }

  /**
   * Changing of modules.
   * Opens dialog for selecting similar modules.
   */
  protected void miSelect_actionPerformed ( ActionEvent e )
  {
    info.owner.infoCompositionGUI.gui.replaceModule( info );
  }

  /**
   * Setting active plug for new channel.
   */
  protected void miChannel_actionPerformed ( ActionEvent e )
  {
    if ( actualPlug != null )
      info.owner.infoCompositionGUI.gui.setIDModule( actualPlug );
  }

  /**
   * Connecting module to neighbours.
   */
  protected void miConnect_actionPerformed ( ActionEvent e )
  {
    info.owner.infoCompositionGUI.gui.connectWithOther( info );
    info.owner.infoCompositionGUI.gui.repaint();
  }

  /**
   * Renaming module - start.
   */
  protected void miRename_actionPerformed ( ActionEvent e )
  {
    tfName.setText( info.reg.name );
    panelPlugs.remove( lbName );
    panelPlugs.add( tfName, BorderLayout.NORTH );
    panelPlugs.repaint();
    tfName.grabFocus();
  }

  /**
   * Renaming module - finish.
   */
  protected void tfName_focusLost ( FocusEvent e )
  {
    panelPlugs.remove( tfName );
    panelPlugs.add( lbName, BorderLayout.NORTH );
    panelPlugs.repaint();
  }

  /**
   * Renaming module - keyboard event.
   */
  protected void tfName_keyTyped ( KeyEvent e )
  {
    if ( e.getKeyChar() == '\u001B' )
    {
      tfName.setText( lbName.getText() );
      tfName_focusLost( null );
    }
    if ( e.getKeyChar() == '\n' )
    {
      if ( tfName.getText().compareTo( "" ) != 0 )
      {
        lbName.setText( tfName.getText() );
        info.reg.name = tfName.getText();
      }
      tfName_focusLost( null );
    }
  }

  /**
   * Deleting module.
   */
  protected void miDelete_actionPerformed ( ActionEvent e )
  {
    info.owner.infoCompositionGUI.gui.removeModule( info.key );
  }

  /**
   * Creating a new group.
   */
  protected void miGroup_actionPerformed ( ActionEvent e )
  {
    info.owner.infoCompositionGUI.gui.setGroup();
  }

  /**
   * Open window for editing parameters.
   * Works only in <b>Minimization mode</b>.
   */
  protected void miParams_actionPerformed ( ActionEvent e )
  {
    if ( windowParam == null )
      windowParam = new ParamsEdit( info.reg.name );
    if ( info.infoGUI.isNormal() )
      miSize_actionPerformed( null );

    if ( !info.infoGUI.isNormal() )
    {
      windowParam.setPanelParams( panelParams, new Dimension( info.infoGUI.width, info.infoGUI.height ) );
      repaint();
      windowParam.show();
      try
      {
        windowParam.setIcon( false );
        windowParam.setSelected( true );
      }
      catch ( PropertyVetoException ee )
      {
        LogFile.exception( ee );
      }
      ((MainWindow)getTopLevelAncestor()).addFrame( windowParam );
    }
  }

  /**
   * Minimization or maximization of the module.
   */
  protected void miSize_actionPerformed ( ActionEvent e )
  {
    if ( !info.infoGUI.isNormal() )
    {
      if ( windowParam != null )
      {
        ((MainWindow)getTopLevelAncestor()).removeFrame( windowParam );
        jScrollPaneParams.getViewport().add( panelParams, null );
      }
      setBounds( getX(),getY(), info.infoGUI.width, info.infoGUI.height );
      panelPlugs.add( jScrollPaneParams, BorderLayout.CENTER );
      info.infoGUI.modeShow = InfoModuleGUI.MS_NORMAL;
      if ( undoReg != null )
        undoReg.registry( new ActionsUndoReg( this, ACTION_MODULE_MODE, InfoModuleGUI.MS_MINI, InfoModuleGUI.MS_NORMAL ) );
    }
    else
    {
      info.infoGUI.modeShow = InfoModuleGUI.MS_MINI;
      setBounds( getX(),getY(), minWidth, minHeight );
      panelPlugs.remove( jScrollPaneParams );
      if ( undoReg != null )
        undoReg.registry( new ActionsUndoReg( this, ACTION_MODULE_MODE, InfoModuleGUI.MS_NORMAL, InfoModuleGUI.MS_MINI ) );
    }

    info.infoGUI.gui.validate();
  }

  /**
   * Open editor showing module's source code.
   */
  protected void miCode_actionPerformed ( ActionEvent e )
  {
    try
    {
      String sourceName = Options.pathSource +
                          info.reg.packageName.replace( '.', '/' ) +
                          '/' + info.reg.className + ".java";
      File sourceFile = new File( sourceName );
      if ( !sourceFile.exists() )
      {
        JOptionPane.showMessageDialog( this, "Source file '" + sourceName + "' was not found.",
                                       "Information", JOptionPane.INFORMATION_MESSAGE );
        return;
      }

      Runtime.getRuntime().exec( new String[] { Options.pathEditor, sourceName } );
    }
    catch ( Exception ex )
    {
      LogFile.exception( ex );
    }
  }

  /**
   * Override the {@link JComponent#paintComponent(Graphics)}..
   */
  @Override
  public void paintComponent ( Graphics g )
  {
    panelPlugs.setBackground( info.infoGUI.selected ? InfoModuleGUI.colorSelect : getBackground() );
    super.paintComponent( g );
  }

  /**
   * Undo last action.
   */
  public void undo ( ActionsUndoReg action )
  {
    super.undo( action );
    if ( undoReg == null ) return;

    undoReg.dont = true;                  // avoids double-registration of this action

    switch ( action.what )
    {
      case ACTION_MODULE_MODE:
      {
        miSize_actionPerformed( null );
        break;
      }

      case ACTION_PLUG_MOVE:
      {
        PlugPosition newPositionPlug     = (PlugPosition)action.lastValue;
        newPositionPlug.plug.x           = (int)newPositionPlug.position.getX();
        newPositionPlug.plug.y           = (int)newPositionPlug.position.getY();
        newPositionPlug.plug.orientation = newPositionPlug.orientation;
        break;
      }
    }
    undoReg.dont = false;
  }

  /**
   * Redo last undoed action.
   */
  public void redo ( ActionsUndoReg action )
  {
    super.redo( action );
    if ( undoReg == null ) return;

    undoReg.dont = true;                  // avoids double-registration of this action

    switch ( action.what )
    {
      case ACTION_MODULE_MODE:
      {
        miSize_actionPerformed( null );
        break;
      }

      case ACTION_PLUG_MOVE:
      {
        PlugPosition newPositionPlug     = (PlugPosition)action.newValue;
        newPositionPlug.plug.x           = (int)newPositionPlug.position.getX();
        newPositionPlug.plug.y           = (int)newPositionPlug.position.getY();
        newPositionPlug.plug.orientation = newPositionPlug.orientation;
        break;
      }
    }

    undoReg.dont = false;
  }

}
