package cz.cuni.jagrlib.gui;

import java.io.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.border.*;

import cz.cuni.jagrlib.gui.comp.*;
import cz.cuni.jagrlib.reg.*;
import cz.cuni.jagrlib.LogFile;

/**
 * GUI class for editing of SKEL preferences.
 *
 * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @version 0.24
 * @see     Options
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/OptionsDialog.java">OptionsDialog.java</a>
 */
public class OptionsDialog extends JDialog
{
  private static final long serialVersionUID = 1L;

  /** File chooser. */
  JFileChooser chooser;

  /** File filter for file chooser. */
  CommonFileFilter filter;

  /** Minimum height of dialog. */
  static final int MIN_HEIGHT = 400;

  /** Minimum width of dialog. */
  static final int MIN_WIDTH  = 400;

    // GUI Components:
  private JPanel            panelButton         = new JPanel();
  private JButton           btnStorno           = new JButton();
  private JButton           btnOK               = new JButton();
  private JTabbedPane       tabPaneOptions      = new JTabbedPane();
  private JPanel            panelColor          = new JPanel();
  private PanelColorChooser jColors             = new PanelColorChooser();
  private JPanel            panelLabels         = new JPanel();

  private ColorLabel        lbPlugsConnect      = new ColorLabel( "Plugs Connect",         jColors );
  private ColorLabel        lbPlugsMandatory    = new ColorLabel( "Plugs Mandatory",       jColors );
  private ColorLabel        lbPlugsNonMandatory = new ColorLabel( "Plugs Non-Mandatory",   jColors );
  private ColorLabel        lbPlugsActive       = new ColorLabel( "Plugs Active",          jColors );
  private ColorLabel        lbPlugsOpposite     = new ColorLabel( "Plugs Opposite",        jColors );
  private ColorLabel        lbChannelsNormal    = new ColorLabel( "Channels Normal",       jColors );
  private ColorLabel        lbChannelsActive    = new ColorLabel( "Channels Active",       jColors );
  private ColorLabel        lbChannelsTemp      = new ColorLabel( "Channels Temp",         jColors );
  private ColorLabel        lbModuleSelect      = new ColorLabel( "Module Selected",       jColors );
  private ColorLabel        lbModuleName        = new ColorLabel( "Module Name",           jColors );
  private ColorLabel        lbGroupName         = new ColorLabel( "Group Name",            jColors );
  private ColorLabel        lbZoomModule        = new ColorLabel( "Outline Module",        jColors );
  private ColorLabel        lbZoomModuleMand    = new ColorLabel( "Outline Mandatory",     jColors );
  private ColorLabel        lbZoomModuleNonM    = new ColorLabel( "Outline Non-Mandatory", jColors );

  private JPanel            panelMisc           = new JPanel();
  private JCheckBox         cbConnect           = new JCheckBox();
  private JLabel            lbModuleHeight      = new JLabel();
  private IntNumberField    edModuleHeight      = new IntNumberField( 1000, 1 );
  private JLabel            lbModuleWidth       = new JLabel();
  private IntNumberField    edModuleWidth       = new IntNumberField( 1000, 1 );
  private JLabel            lbParamHeight       = new JLabel();
  private IntNumberField    edParamHeight       = new IntNumberField( 1000, 1 );

  private JPanel            panelPaths          = new JPanel();
  private JLabel            lbPathEditor        = new JLabel();
  private JLabel            lbPathRes           = new JLabel();
  private JLabel            lbPathData          = new JLabel();
  private JLabel            lbPathReg           = new JLabel();
  private JTextField        tfPathRes           = new JTextField();
  private JTextField        tfPathReg           = new JTextField();
  private JTextField        tfPathData          = new JTextField();
  private JTextField        tfPathEditor        = new JTextField();
  private JButton           btPathRes           = new JButton();
  private JButton           btPathReg           = new JButton();
  private JButton           btPathData          = new JButton();
  private JButton           btPathEditor        = new JButton();

  /** Labels for OptionsDialog colors. */
  public class ColorLabel extends JLabel implements MouseListener
  {
    private static final long serialVersionUID = 1L;

    /** Color chooser panel. */
    public PanelColorChooser colorChooser;

    /**
     * Creates new ColorLabel.
     *
     * @param _text Label's text.
     * @param _jCC Color chooser panel.
     */
    public ColorLabel( String _text, PanelColorChooser _jCC )
    {
      super( _text );
      colorChooser = _jCC;
      setOpaque( true );
      addMouseListener( this );
    }

    /**
     * Sets foreground color.
     *
     * @param c Color of foreground.
     */
    public void setColor ( Color c )
    {
      setForeground( c );
    }

    /**
     * Not implemented.
     */
    public void mousePressed ( MouseEvent e )
    {
    }

    /**
     * Not implemented.
     */
    public void mouseReleased ( MouseEvent e )
    {
    }

    /**
     * Mouse click.
     * Sets color chooser on color of foreground.
     */
    public void mouseClicked ( MouseEvent e )
    {
      if ( colorChooser.activeLabel != null )
        colorChooser.activeLabel.setBorder( null );
      setBorder( BorderFactory.createEtchedBorder( EtchedBorder.RAISED ) );
      colorChooser.activeLabel = this;
      colorChooser.jCC.setColor( getForeground() );
    }

    /**
     * Not implemented.
     */
    public void mouseExited ( MouseEvent e )
    {
    }

    /**
     * Not implemented.
     */
    public void mouseEntered ( MouseEvent e )
    {
    }
  }

  /** Panel with Color chooser. */
  public class PanelColorChooser extends JPanel implements ChangeListener
  {
    private static final long serialVersionUID = 1L;

    /** Active label for seting. */
    public ColorLabel activeLabel;

    /** Color chooser object. */
    public JColorChooser jCC;
    {
      jCC = new JColorChooser();
      jCC.getSelectionModel().addChangeListener( this );
      jCC.setBorder( BorderFactory.createTitledBorder( "Choose Text Color" ) );
      add( jCC, BorderLayout.CENTER );
    }

    /**
     * Change of color.
     */
    public void stateChanged ( ChangeEvent e )
    {
      Color newColor = jCC.getColor();
      if ( activeLabel != null )
        activeLabel.setColor( newColor );
    }
  }

  /**
   * Creates new OptionsDialog.
   *
   * @param frame Owner frame.
   * @param title Title of dialog.
   * @param modal Modality.
   */
  public OptionsDialog ( Frame frame, String title, boolean modal )
  {
    super( frame, title, modal );
    try
    {
      jbInit();
      pack();
    }
    catch ( Exception ex )
    {
      LogFile.exception( ex );
    }
  }

  /** Initialization. */
  public void initValues ()
  {
    lbPlugsConnect.setColor(      InfoPlugGUI.colorConnect );
    lbPlugsMandatory.setColor(    InfoPlugGUI.colorMandatory );
    lbPlugsNonMandatory.setColor( InfoPlugGUI.colorNonMandatory );
    lbPlugsActive.setColor(       InfoPlugGUI.colorActive );
    lbPlugsOpposite.setColor(     InfoPlugGUI.colorOpposite );
    lbChannelsNormal.setColor(    InfoChannelGUI.colorNormal );
    lbChannelsActive.setColor(    InfoChannelGUI.colorActiveModule );
    lbChannelsTemp.setColor(      InfoChannelGUI.colorTemp );
    lbModuleSelect.setColor(      InfoModuleGUI.colorSelect );
    lbModuleName.setColor(        InfoModuleGUI.colorName );
    lbGroupName.setColor(         InfoGroupGUI.colorName );
    lbZoomModule.setColor(        ZoomBasic.colorModule );
    lbZoomModuleMand.setColor(    ZoomBasic.colorMandatory );
    lbZoomModuleNonM.setColor(    ZoomBasic.colorNonMandatory );

    cbConnect.setSelected(        InfoGroup.autoConnect );
    edModuleHeight.setValue(      ModuleGUI.getModuleHeight() );
    edModuleWidth.setValue(       ModuleGUI.getModuleWidth() );
    edParamHeight.setValue(       ParamGUI.paramLineHeight );

    tfPathRes.setText(            Options.pathResources );
    tfPathReg.setText(            Options.pathReg );
    tfPathData.setText(           Options.pathData );
    tfPathEditor.setText(         Options.pathEditor );
  }

  /**
   * Component initialization.
   */
  private void jbInit () throws Exception
  {
    addComponentListener( new ComponentAdapter ()
    {
      public void componentResized ( ComponentEvent e )
      {
        this_componentResized( e );
      }
    } );

    chooser = new JFileChooser( "." );
    filter  = new CommonFileFilter();

    btnStorno.setText( "Storno" );
    btnStorno.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btnStorno_actionPerformed( e );
      }
    } );

    btnOK.setMaximumSize(   new Dimension( 71, 27 ) );
    btnOK.setMinimumSize(   new Dimension( 71, 27 ) );
    btnOK.setPreferredSize( new Dimension( 71, 27 ) );
    btnOK.setText( "OK" );
    btnOK.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btnOK_actionPerformed( e );
      }
    } );

    btPathRes.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btPathRes_actionPerformed( e );
      }
    } );

    btPathReg.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btPathReg_actionPerformed( e );
      }
    } );

    btPathData.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btPathData_actionPerformed( e );
      }
    } );

    btPathEditor.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btPathEditor_actionPerformed( e );
      }
    } );

    panelButton.add( btnOK, null );
    panelButton.add( btnStorno, null );
    getContentPane().add( panelButton, BorderLayout.SOUTH );

    panelColor.setLayout( new BorderLayout() );
    panelColor.add( panelLabels, BorderLayout.WEST );
    panelColor.add( jColors, BorderLayout.EAST );

    panelLabels.setLayout( new GridBagLayout() );
    panelLabels.add( lbPlugsConnect,
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                             GuiConstants.INSETS_0, 0, 0 ) );
    panelLabels.add( lbPlugsMandatory,
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                             GuiConstants.INSETS_0, 0, 0 ) );
    panelLabels.add( lbPlugsNonMandatory,
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                             GuiConstants.INSETS_0, 0, 0 ) );
    panelLabels.add( lbPlugsActive,
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                             GuiConstants.INSETS_0, 0, 0 ) );
    panelLabels.add( lbPlugsOpposite,
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                             GuiConstants.INSETS_0, 0, 0 ) );
    panelLabels.add( lbChannelsNormal,
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                             GuiConstants.INSETS_0, 0, 0 ) );
    panelLabels.add( lbChannelsActive,
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                             GuiConstants.INSETS_0, 0, 0 ) );
    panelLabels.add( lbChannelsTemp,
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                             GuiConstants.INSETS_0, 0, 0 ) );
    panelLabels.add( lbModuleSelect,
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                             GuiConstants.INSETS_0, 0, 0 ) );
    panelLabels.add( lbModuleName,
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                             GuiConstants.INSETS_0, 0, 0 ) );
    panelLabels.add( lbGroupName,
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                             GuiConstants.INSETS_0, 0, 0 ) );
    panelLabels.add( lbZoomModule,
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                             GuiConstants.INSETS_0, 0, 0 ) );
    panelLabels.add( lbZoomModuleMand,
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                             GuiConstants.INSETS_0, 0, 0 ) );
    panelLabels.add( lbZoomModuleNonM,
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                             GuiConstants.INSETS_0, 0, 0 ) );
    tabPaneOptions.addTab( "Color", panelColor );

    cbConnect.setText( "Automatic connecting of new module" );
    lbModuleHeight.setText( "Module height" );
    edModuleHeight.setMinimumSize(   new Dimension( 110, 21 ) );
    edModuleHeight.setPreferredSize( new Dimension( 110, 21 ) );
    lbModuleWidth.setText( "Module width" );
    edModuleWidth.setMinimumSize(    new Dimension( 110, 21) );
    edModuleWidth.setPreferredSize(  new Dimension( 110, 21) );
    lbParamHeight.setText( "Parameter height" );
    edParamHeight.setMinimumSize(    new Dimension( 110, 21 ) );
    edParamHeight.setPreferredSize(  new Dimension( 110, 21 ) );

    panelMisc.setLayout( new GridBagLayout() );
    panelMisc.add( cbConnect,
                   new GridBagConstraints( 0, 0, 3, 1, 1.0, 0.0,
                                           GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                           GuiConstants.INSETS_5555, 0, 0 ) );
    panelMisc.add( lbModuleHeight,
                   new GridBagConstraints( 0, 1, 1, 1, 0.0, 0.0,
                                           GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                           GuiConstants.INSETS_5555, 0, 0 ) );
    panelMisc.add( edModuleHeight,
                   new GridBagConstraints( 1, 1, 1, 1, 0.2, 0.0,
                                           GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                           GuiConstants.INSETS_5555, 0, 0 ) );
    panelMisc.add( lbModuleWidth,
                   new GridBagConstraints( 0, 2, 1, 1, 0.0, 0.0,
                                           GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                           GuiConstants.INSETS_5555, 0, 0 ) );
    panelMisc.add( edModuleWidth,
                   new GridBagConstraints( 1, 2, 1, 1, 0.0, 0.0,
                                           GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                           GuiConstants.INSETS_5555, 0, 0 ) );
    panelMisc.add( lbParamHeight,
                   new GridBagConstraints( 0, 3, 1, 1, 0.0, 1.0,
                                           GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                           GuiConstants.INSETS_5555, 0, 0 ) );
    panelMisc.add( edParamHeight,
                   new GridBagConstraints( 1, 3, 1, 1, 0.0, 1.0,
                                           GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                           GuiConstants.INSETS_5555, 0, 0 ) );
    tabPaneOptions.addTab( "Misc", panelMisc );

    lbPathRes.setText(    "Path to resources" );
    lbPathReg.setText(    "Registry file-name" );
    lbPathData.setText(   "Path to compositions" );
    lbPathEditor.setText( "External editor" );

    btPathRes.setText(    "Browse" );
    btPathReg.setText(    "Browse" );
    btPathData.setText(   "Browse" );
    btPathEditor.setText( "Browse" );

    final Insets first = new Insets( 15, 5, 5, 5 );
    panelPaths.setLayout( new GridBagLayout() );
    panelPaths.add( lbPathRes,
                    new GridBagConstraints( 0, 0, 1, 1, 0.0, 0.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                            first, 0, 0 ) );
    panelPaths.add( tfPathRes,
                    new GridBagConstraints( 1, 0, 1, 1, 1.0, 0.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                            first, 0, 0 ) );
    panelPaths.add( btPathRes,
                    new GridBagConstraints( 2, 0, 1, 1, 0.0, 0.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                            first, 0, 0 ) );
    panelPaths.add( lbPathReg,
                    new GridBagConstraints( 0, 1, 1, 1, 0.0, 0.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                            GuiConstants.INSETS_5555, 0, 0 ) );
    panelPaths.add( tfPathReg,
                    new GridBagConstraints( 1, 1, 1, 1, 1.0, 0.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                            GuiConstants.INSETS_5555, 0, 0 ) );
    panelPaths.add( btPathReg,
                    new GridBagConstraints( 2, 1, 1, 1, 0.0, 0.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                            GuiConstants.INSETS_5555, 0, 0 ) );
    panelPaths.add( lbPathData,
                    new GridBagConstraints( 0, 2, 1, 1, 0.0, 0.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                            GuiConstants.INSETS_5555, 0, 0 ) );
    panelPaths.add( tfPathData,
                    new GridBagConstraints( 1, 2, 1, 1, 1.0, 0.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                            GuiConstants.INSETS_5555, 0, 0 ) );
    panelPaths.add( btPathData,
                    new GridBagConstraints( 2, 2, 1, 1, 0.0, 0.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                            GuiConstants.INSETS_5555, 0, 0 ) );
    panelPaths.add( lbPathEditor,
                    new GridBagConstraints( 0, 3, 1, 1, 0.0, 1.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                            GuiConstants.INSETS_5555, 0, 0 ) );
    panelPaths.add( tfPathEditor,
                    new GridBagConstraints( 1, 3, 1, 1, 1.0, 1.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                            GuiConstants.INSETS_5555, 0, 0 ) );
    panelPaths.add( btPathEditor,
                    new GridBagConstraints( 2, 3, 1, 1, 0.0, 1.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                            GuiConstants.INSETS_5555, 0, 0 ) );
    tabPaneOptions.addTab( "Paths", panelPaths );

    getContentPane().add( tabPaneOptions, BorderLayout.CENTER );
  }

  /**
   * Confirmation of OptionsDialog.
   * Updates both 'data', 'sysData' maps and target (working) values.
   */
  void btnOK_actionPerformed ( ActionEvent e )
  {
    InfoPlugGUI.colorConnect          = lbPlugsConnect.getForeground();
    InfoPlugGUI.colorMandatory        = lbPlugsMandatory.getForeground();
    InfoPlugGUI.colorNonMandatory     = lbPlugsNonMandatory.getForeground();
    InfoPlugGUI.colorActive           = lbPlugsActive.getForeground();
    InfoPlugGUI.colorOpposite         = lbPlugsOpposite.getForeground();
    InfoChannelGUI.colorNormal        = lbChannelsNormal.getForeground();
    InfoChannelGUI.colorActiveModule  = lbChannelsActive.getForeground();
    InfoChannelGUI.colorTemp          = lbChannelsTemp.getForeground();
    InfoModuleGUI.colorSelect         = lbModuleSelect.getForeground();
    InfoModuleGUI.colorName           = lbModuleName.getForeground();
    InfoGroupGUI.colorName            = lbGroupName.getForeground();
    ZoomBasic.colorModule             = lbZoomModule.getForeground();
    ZoomBasic.colorMandatory          = lbZoomModuleMand.getForeground();
    ZoomBasic.colorNonMandatory       = lbZoomModuleNonM.getForeground();
    InfoGroup.autoConnect             = cbConnect.isSelected();
    ModuleGUI.setModuleHeight(          (int)edModuleHeight.getValue() );
    ModuleGUI.setModuleWidth(           (int)edModuleWidth.getValue() );
    ParamGUI.paramLineHeight          = (int)edParamHeight.getValue();
    Options.pathResources             = tfPathRes.getText();
    Options.pathData                  = tfPathData.getText();
    Options.pathReg                   = tfPathReg.getText();
    Options.pathEditor                = tfPathEditor.getText();

    Options.reflect();
    try
    {
      Options.save();
    }
    catch ( IOException ex )
    {
      LogFile.exception( ex );
    }
    setVisible( false );
  }

  /**
   * Cancel the OptionsDialog.
   */
  void btnStorno_actionPerformed ( ActionEvent e )
  {
    setVisible( false );
  }

  /**
   * Set path to resources.
   */
  void btPathRes_actionPerformed ( ActionEvent e )
  {
    chooser.setDialogType( JFileChooser.DIRECTORIES_ONLY );
    if ( chooser.showDialog( this, "" ) == JFileChooser.APPROVE_OPTION )
    {
      Options.pathResources = chooser.getSelectedFile().getPath();
      tfPathRes.setText( Options.pathResources );
    }
  }

  /**
   * Set registry file.
   */
  void btPathReg_actionPerformed ( ActionEvent e )
  {
    chooser.setDialogType( JFileChooser.FILES_ONLY );
    if ( chooser.showDialog( this, "" ) == JFileChooser.APPROVE_OPTION )
    {
      Options.pathReg = chooser.getSelectedFile().getPath();
      tfPathReg.setText( Options.pathReg );
    }
  }

  /**
   * Set path to compositions.
   */
  void btPathData_actionPerformed ( ActionEvent e )
  {
    chooser.setDialogType( JFileChooser.DIRECTORIES_ONLY );
    if ( chooser.showDialog( this, "" ) == JFileChooser.APPROVE_OPTION )
    {
      Options.pathData = chooser.getSelectedFile().getPath();
      tfPathData.setText( Options.pathData );
    }
  }

  /**
   * Set external editor.
   */
  void btPathEditor_actionPerformed ( ActionEvent e )
  {
    chooser.setDialogType( JFileChooser.FILES_ONLY );
    if ( chooser.showDialog( this, "" ) == JFileChooser.APPROVE_OPTION )
    {
      Options.pathEditor = chooser.getSelectedFile().getPath();
      tfPathEditor.setText( Options.pathEditor );
    }
  }

  /**
   * Resized the dialog.
   */
  void this_componentResized ( ComponentEvent e )
  {
    int height = Math.max( getHeight(), MIN_HEIGHT );
    int width  = Math.max( getWidth(),  MIN_WIDTH );
    this.setSize( width, height );
  }

}
