package cz.cuni.jagrlib.gui;

import java.util.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import cz.cuni.jagrlib.reg.*;
import cz.cuni.jagrlib.LogFile;

/**
 * Class that cares about visual representation of Combobox parameters.
 * It returns value different from displayed one.
 *
 * @author  PE, Jan Kostlivy
 * @version 0.26 $Rev: 469 $ $Date: 2007-05-26 21:24:07 +0200 (so, 26 V 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/ParamCombo.java">ParamCombo.java</a>
 */
public class ParamCombo extends ParamGUI
{
  private static final long serialVersionUID = 1L;

  //==========================================================================
  //  Data:

    // components
  private JComboBox jComboBox1 = new JComboBox();

  //==========================================================================
  //  Methods:

  /** Default constructor. */
  public ParamCombo()
  {
    try
    {
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Components initialization.
   */
  private void jbInit() throws Exception
  {
    getPanelValue().add( jComboBox1, BorderLayout.CENTER );
  }

  /**
   * Gets true value of parameter, not the displayed.
   *
   * @param _type Real type of parameter.
   * @param _value Real value of parameter in String.
   * @return true value of parameter in right type.
   */
  public Object getTrueValue ( String _type, Object _value )
  {
    if ( _type.compareTo( "Integer" ) == 0 )
      return new Integer( _value.toString() );
    return _value.toString();
  }

  //==========================================================================
  //  Methods ParamGUI:

  /**
   * Initialization of parameter. It fill combobox with items.
   */
  public void initParam ()
  {
    DefaultComboBoxModel m = new DefaultComboBoxModel();

    for ( int i = 0; i < info.values.size(); i++ )
    {
      Map< String, Object > h = (HashMap< String, Object >)info.values.get( i );
      m.addElement( h.get( InfoParam.IP_STRING ) );
      if ( h.get( InfoParam.IP_TYPE ) == "" )
        h.put( InfoParam.IP_TYPE, "String" );

      if ( h.get( InfoParam.IP_VALUE ) == "" )
        h.put( InfoParam.IP_VALUE, h.get( InfoParam.IP_STRING ) );
    }

    jComboBox1.setModel( m );
    jComboBox1.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        jComboBox1_actionPerformed( e );
      }
    });

    setValue( (info.value != null) ? info.value : info.defaultValue );
  }

  /**
   * Sets parameter value.
   *
   * @param _newValue New value.
   * @return Old value.
   */
  public Object setValue ( Object _newValue )
  {
    if ( info == null ) return null;

    Object old = info.value;
    Object val = _newValue;
    for ( int i = 0; i < info.values.size(); i++ )
    {
      Map< String, Object > h = (HashMap< String, Object >)info.values.get( i );
      if ( h.get( InfoParam.IP_VALUE ).toString().compareTo( val.toString() ) == 0 )
        jComboBox1.getModel().setSelectedItem( h.get( InfoParam.IP_STRING ) );
    }

    return old;
  }

  /**
   * Gets parameter value.
   *
   * @see #getTrueValue(String _type, Object _value).
   */
  public Object getValue ()
  {
    String val = (String)jComboBox1.getModel().getSelectedItem();
    for ( int i = 0; i < info.values.size(); i++ )
    {
      Map< String, Object > h = (HashMap< String, Object >)info.values.get( i );
      if ( h.get( InfoParam.IP_STRING ).toString().compareTo( val.toString() ) == 0 )
        return getTrueValue( (String)h.get( InfoParam.IP_TYPE ),
                             h.get( InfoParam.IP_VALUE ) );
    }
    return val;
  }

  //==========================================================================
  //  Events:

  /**
   * Event for change selection of combobox.
   */
  void jComboBox1_actionPerformed ( ActionEvent e )
  {
    String val = (String)jComboBox1.getModel().getSelectedItem();
    for ( int i = 0; i < info.values.size(); i++ )
    {
      Map< String, Object > h = (HashMap< String, Object >)info.values.get( i );
      if ( h.get(InfoParam.IP_STRING).toString().compareTo( val.toString() ) == 0 )
        info.value = getTrueValue( (String)h.get( InfoParam.IP_TYPE ),
                                   h.get( InfoParam.IP_VALUE ) );
    }
  }

}
