package cz.cuni.jagrlib.gui;

import java.awt.*;
import java.awt.event.*;

import cz.cuni.jagrlib.gui.comp.*;
import cz.cuni.jagrlib.LogFile;

/**
 * Class that cares about visual representation of Double parameters.
 *
 * @version 0.26 $Rev: 430 $ $Date: 2007-04-29 04:27:07 +0200 (ne, 29 IV 2007) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/ParamDouble.java">ParamDouble.java</a>
 */
public class ParamDouble extends ParamGUI
{
  private static final long serialVersionUID = 1L;

  //==========================================================================
  //  Data:

  private DoubleNumberField jTextFieldValue = new DoubleNumberField( 0.0, 1 );

  private Volume jPanelVolume = new Volume();

  //==========================================================================
  //  Methods:

  /** Default constructor. */
  public ParamDouble ()
  {
    try
    {
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Components initialization.
   */
  private void jbInit () throws Exception
  {
    jTextFieldValue.setText( "0.0" );
    jTextFieldValue.addFocusListener( new FocusAdapter ()
    {
      public void focusLost ( FocusEvent e )
      {
        jTextFieldValue_focusLost( e );
      }
    } );
    jPanelVolume.setMinimumSize(   new Dimension( 20, 10 ) );
    jPanelVolume.setPreferredSize( new Dimension( 20, 10 ) );
    jPanelVolume.param     = this;
    jPanelVolume.type      = "Double";
    jPanelVolume.increment = 0.1;
    setValue( 0.0 );
    getPanelValue().add( jTextFieldValue, BorderLayout.CENTER );
    getPanelValue().add( jPanelVolume,    BorderLayout.EAST );
  }

  //==========================================================================
  //  Methods ParamGUI:

  /**
   * Sets parameter value.
   *
   * @param  _newValue New numeric or String value.
   * @return Old value.
   */
  public Object setValue ( Object _newValue )
  {
    if ( info == null )
      return null;

    Object old = info.value;
    double val;

    if ( _newValue instanceof Double )
      val = ((Double)_newValue).doubleValue();
    else
    if ( _newValue instanceof Float )
      val = ((Float)_newValue).doubleValue();
    else
    if ( _newValue instanceof Integer )
      val = ((Integer)_newValue).doubleValue();
    else
    if ( _newValue instanceof Long )
      val = ((Long)_newValue).doubleValue();
    else
      val = Double.parseDouble( _newValue.toString() );

    jTextFieldValue.setValue( val );
    jPanelVolume.number = val;
    return old;
  }

  /**
   * Gets parameter value.
   */
  public Object getValue ()
  {
    info.value = jTextFieldValue.getValue();
    return info.value;
  }

  //==========================================================================
  //  Events:

  /**
   * Event handling for lost focus.
   */
  void jTextFieldValue_focusLost ( FocusEvent e )
  {
    info.value = jTextFieldValue.getValue();
  }

}
