package cz.cuni.jagrlib.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import cz.cuni.jagrlib.reg.*;
import cz.cuni.jagrlib.*;

/**
 * Abstract class that cares about visual representation of parameter.
 *
 * @author  PE, Jan Kostlivy
 * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @since   0.25
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/ParamGUI.java">ParamGUI.java</a>
 */
public abstract class ParamGUI extends JPanel
{
  //==========================================================================
  //  Data:

  /** Standard value for parameter height in pixels (one line). */
  public final static int PARAM_LINE_HEIGHT = 20;

  /** Default parameter height in pixels (one line). */
  public static int paramLineHeight = PARAM_LINE_HEIGHT;

  /** Information about parameter. */
  public InfoParam info;

  /** Manipulator for special parameters. */
  public interface ParamEdit
  {
    /**
     * Sets value of the parameter.
     *
     * @param val New value (internal representation).
     * @return Old value (internal representation).
     */
    public Object setValue ( Object val );

    /**
     * Returns internal value of the parameter.
     */
    public Object getValue ();

    /**
     * Returns String representation of parameter value.
     */
    public String getText ();

    /**
     * Invokes edit dialog for special parameter.
     *
     * @return String representation of the new parameter value.
     */
    public String edit ();
  }

  /** The actual manipulator. */
  protected ParamEdit manipulator = null;

    // GUI components:
  private JLabel jLabelName  = new JLabel();
  private JPanel jPanelValue = new JPanel();
  private JPanel jPanelParam = new JPanel();

  //==========================================================================
  //  Methods:

  /**
   * Sets parameter value.
   *
   * @param _newValue New value.
   * @return Old value.
   */
  public abstract Object setValue ( Object _newValue );

  /**
   * Gets parameter value.
   */
  public abstract Object getValue ();

  /**
   * Sets info parameter.
   *
   * @param ip Information about parameter.
   */
  public void setInfo ( InfoParam ip )
  {
    info = ip;
    if ( info.infoGUI == null )
      info.infoGUI = new InfoParamGUI();
    info.infoGUI.gui = this;
    jLabelName.setText( info.name );
    jLabelName.setToolTipText( info.owner.reg.className + ": " + info.name + " (" + info.description + ')' );
    setManipulator();
    initParam();
    if ( info.value != null )
      setValue( info.value );
    info.value = getValue();
  }

  /** Parameter initialization. */
  public void initParam ()
  {
    setValue( info.defaultValue );
  }

  /**
   * Gets panel for descendant.
   */
  protected JPanel getPanelValue ()
  {
    return jPanelValue;
  }

  /** Sets manipulator of special parameter. */
  public void setManipulator ()
  {
    if ( info.propManipClass == null ||
         info.propManipClass.length() == 0 )
      return;

    final String className = info.propManipClass.indexOf( '.' ) > 0 ?
                               info.propManipClass :
                               Template.JAGRLIB2 + "gui." + info.propManipClass;
    try
    {
      manipulator = (ParamEdit)Class.forName( className ).newInstance();
    }
    catch ( Exception e )
    {
      LogFile.exception( "Unknown manipulator class '" + className + "'!", e );
      manipulator = null;
    }
  }

  /** Default constructor. */
  public ParamGUI ()
  {
    try
    {
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Component initialization.
   */
  private void jbInit ()
  throws Exception
  {
    jLabelName.setBorder( BorderFactory.createEmptyBorder( 0, 0, 0, 3 ) );
    jLabelName.setText( "Unknown" );

    this.setLayout( new BorderLayout() );
    jPanelParam.setLayout( new BorderLayout() );
    jPanelValue.setLayout( new BorderLayout() );
    this.add( jPanelParam, BorderLayout.CENTER );

    jPanelParam.add( jLabelName,  BorderLayout.WEST );
    jPanelParam.add( jPanelValue, BorderLayout.CENTER );

    this.setMinimumSize(   new Dimension( 20, paramLines() * paramLineHeight ) );
    this.setPreferredSize( new Dimension( 20, paramLines() * paramLineHeight ) );
  }

  /**
   * Set Listeners for mouse click and move.
   *
   * @param mouseClick listeners for mouse click.
   * @param mouseMove listeners for mose move.
   */
  public void setListeners ( MouseAdapter mouseClick, MouseMotionAdapter mouseMove )
  {
    this.addMouseListener( mouseClick );
    this.addMouseMotionListener( mouseMove );

    jLabelName.addMouseListener( mouseClick );
    jLabelName.addMouseMotionListener( mouseMove );

    jPanelValue.addMouseListener( mouseClick );
    jPanelValue.addMouseMotionListener( mouseMove );
  }

  /**
   * Returns visual parameter height in lines.
   */
  public int paramLines ()
  {
    return 1;
  }

}
