package cz.cuni.jagrlib.gui;

import java.awt.*;

import cz.cuni.jagrlib.reg.*;

/**
 * Abstract class for visual representation of a plug.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.25 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/PlugGUI.java">PlugGUI.java</a>
 */
abstract public class PlugGUI
{
  //==========================================================================
  //  Data:

  /** Information about Plug. */
  public InfoPlug info;

  /** Maximal plug position (X-coordinate). */
  protected int maxX;

  /** Maximal plug position (Y-coordinate). */
  protected int maxY;

  /** Initial plug orientation. */
  public final static int PGI_ORIENTATION_SOUTH = 1;

  //==========================================================================
  //  Methods:

  /**
   * Returns plug orientation.
   */
  public int getOrientaion ()
  {
    return info.infoGUI.orientation;
  }

  /**
   * Tests, if point lies on the plug.
   *
   * @param  px x-coordinate.
   * @param  py y-coordinate.
   * @return Positive if the given point lies on the plug.
   */
  abstract public boolean contains ( int px, int py );

  /**
   * Tooltip text for the plug.
   */
  abstract public String getToolTipText ();

  /**
   * Gets relative x-coordinate of the plug.
   */
  abstract public int getX ();

  /**
   * Gets relative y-coordinate of the plug.
   */
  abstract public int getY ();

  /**
   * Moves the Plug.
   *
   * @param  nx X-coordinate offset (relative coordinate).
   * @param  ny Y-coordinate offset (relative coordinate).
   */
  abstract public void movePlug ( int nx, int ny );

  /**
   * The Plug's module was resized.
   *
   * @param  nx New module width.
   * @param  ny New module height.
   */
  abstract public void resize ( int nx, int ny );

  /**
   * Paint bonus graphics on module panel.
   */
  abstract public void paintItem ( Graphics g );

}
