package cz.cuni.jagrlib.gui;

import java.awt.*;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Concrete class for visual representation of a plug.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.25 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/PlugGUIImproved.java">PlugGUIImproved.java</a>
 */
public class PlugGUIImproved extends PlugGUI
{
  //==========================================================================
  //  Data:

  /** Other orientation of plug - west. */
  public final static int PGI_ORIENTATION_WEST  = 2;

  /** Other orientation of plug - north. */
  public final static int PGI_ORIENTATION_NORTH = 3;

  /** Other orientation of plug - east. */
  public final static int PGI_ORIENTATION_EAST  = 4;

  //==========================================================================
  //  Methods PlugGUI:

  /**
   * Tests whether the given point lies on the plug.
   *
   * @param  px x-coordinate.
   * @param  py y-coordinate.
   * @return {@code true} if point lies on the plug.
   */
  @Override
  public boolean contains ( int px, int py )
  {
    final int x = info.infoGUI.x;
    final int y = info.infoGUI.y;

    switch ( info.infoGUI.orientation )
    {
      case PGI_ORIENTATION_EAST:
        return( px >= x +  7 &&
                px <= x + 14 &&
                py >= y - 15 &&
                py <= y );

      case PGI_ORIENTATION_NORTH:
        return( px >= x      &&
                px <= x + 15 &&
                py >= y - 15 &&
                py <= y -  8 );

      case PGI_ORIENTATION_WEST:
        return( px >= x      &&
                px <= x +  8 &&
                py >= y - 15 &&
                py <= y );

      default:
      case PGI_ORIENTATION_SOUTH:
        return( px >= x      &&
                px <= x + 15 &&
                py >= y -  8 &&
                py <= y );
    }
  }

  /**
   * Tooltip text for the plug.
   */
  @Override
  public String getToolTipText ()
  {
    return( info.getModuleOwner().reg.className + " - " + info.name +" (" + info.type + ")" + "\n" + info.inputOutput() );
  }

  /**
   * Gets relative x-coordinate of the plug.
   */
  @Override
  public int getX ()
  {
    switch ( info.infoGUI.orientation )
    {
      case PGI_ORIENTATION_EAST:
        return info.infoGUI.x + 17;

      case PGI_ORIENTATION_NORTH:
        return info.infoGUI.x +  7;

      case PGI_ORIENTATION_WEST:
        return info.infoGUI.x -  2;

      case PGI_ORIENTATION_SOUTH:
      default:
        return info.infoGUI.x +  8;
    }
  }

  /**
   * Gets relative y-coordinate of the plug.
   */
  @Override
  public int getY ()
  {
    switch ( info.infoGUI.orientation )
    {
      case PGI_ORIENTATION_EAST:
        return info.infoGUI.y -  7;

      case PGI_ORIENTATION_NORTH:
        return info.infoGUI.y - 16;

      case PGI_ORIENTATION_WEST:
        return info.infoGUI.y -  7;

      case PGI_ORIENTATION_SOUTH:
      default:
        return info.infoGUI.y +  2;
    }
  }

  //==========================================================================
  //  Methods:

  /**
   * Sets orientation of the plug.
   *
   * @param  _o New orientation.
   */
  public void setOrientation ( int _o )
  {
    info.infoGUI.orientation = _o;
  }

  /**
   * Creates new PlugGUIImproved.
   *
   * @param  _infoP Information about plug.
   */
  public PlugGUIImproved ( InfoPlug _infoP )
  {
    info = _infoP;
    if ( info.infoGUI == null )
      info.infoGUI = new InfoPlugGUI();

    info.infoGUI.gui = this;
  }

  /**
   * Moves the Plug.
   *
   * @param  nx X-coordinate offset (relative coordinate).
   * @param  ny Y-coordinate offset (relative coordinate).
   */
  @Override
  public void movePlug ( int nx, int ny )
  {
    switch ( info.infoGUI.orientation )
    {
      case PGI_ORIENTATION_EAST:
        info.infoGUI.y += ny;
        if ( info.infoGUI.y <= 15 &&
             info.infoGUI.x + nx < maxX )
        {
          info.infoGUI.orientation = PGI_ORIENTATION_NORTH;
          info.infoGUI.x += nx;
          info.infoGUI.y  = 15;
          break;
        }
        if ( info.infoGUI.y >= maxY &&
             info.infoGUI.x + nx < maxX )
        {
          info.infoGUI.orientation = PGI_ORIENTATION_SOUTH;
          info.infoGUI.x += nx;
          info.infoGUI.y  = maxY;
          break;
        }
        info.infoGUI.y = Formula.clamp( info.infoGUI.y, 15, maxY );
        break;

      case PGI_ORIENTATION_NORTH:
        info.infoGUI.x += nx;
        if ( info.infoGUI.x <= 2 &&
             info.infoGUI.y + ny > 15 )
        {
          info.infoGUI.orientation = PGI_ORIENTATION_WEST;
          info.infoGUI.x  = 2;
          info.infoGUI.y += ny;
          break;
        }
        if ( info.infoGUI.x >= maxX &&
             info.infoGUI.y + ny > 15 )
        {
          info.infoGUI.orientation = PGI_ORIENTATION_EAST;
          info.infoGUI.x  = maxX;
          info.infoGUI.y += ny;
          break;
        }
        info.infoGUI.x = Formula.clamp( info.infoGUI.x, 2, maxX );
        break;

      case PGI_ORIENTATION_WEST:
        info.infoGUI.y += ny;
        if ( info.infoGUI.y >= maxY &&
             info.infoGUI.x + nx > 2 )
        {
          info.infoGUI.orientation = PGI_ORIENTATION_SOUTH;
          info.infoGUI.x += nx;
          info.infoGUI.y  = maxY;
          break;
        }
        if ( info.infoGUI.y <= 15 &&
             info.infoGUI.x + nx > 2 )
        {
          info.infoGUI.orientation = PGI_ORIENTATION_NORTH;
          info.infoGUI.x += nx;
          info.infoGUI.y  = 15;
          break;
        }
        info.infoGUI.y = Formula.clamp( info.infoGUI.y, 15, maxY );
        break;

      case PGI_ORIENTATION_SOUTH:
        info.infoGUI.x += nx;
        if ( info.infoGUI.x >= maxX &&
             info.infoGUI.y + ny < maxY )
        {
          info.infoGUI.orientation = PGI_ORIENTATION_EAST;
          info.infoGUI.x  = maxX;
          info.infoGUI.y += ny;
          break;
        }
        if ( info.infoGUI.x <= 2 &&
             info.infoGUI.y + ny < maxY )
        {
          info.infoGUI.orientation = PGI_ORIENTATION_WEST;
          info.infoGUI.x  = 2;
          info.infoGUI.y += ny;
          break;
        }
        info.infoGUI.x = Formula.clamp( info.infoGUI.x, 2, maxX );
        break;
    }
  }

  /**
   * The Plug's module was resized.
   *
   * @param  nx New module width.
   * @param  ny New module height.
   */
  public void resize ( int nx, int ny )
  {
    maxX = nx - 15;
    maxY = ny;
    switch ( info.infoGUI.orientation )
    {
      case PGI_ORIENTATION_EAST:
        if ( info.infoGUI.y >= maxY )
          info.infoGUI.y = maxY;
        info.infoGUI.x = maxX;
        break;

      case PGI_ORIENTATION_NORTH:
        if ( info.infoGUI.x >= maxX )
          info.infoGUI.x = maxX;
        break;

      case PGI_ORIENTATION_WEST:
        if ( info.infoGUI.y >= maxY )
          info.infoGUI.y = maxY;
        break;

      case PGI_ORIENTATION_SOUTH:
        if ( info.infoGUI.x >= maxX )
          info.infoGUI.x = maxX;
        info.infoGUI.y = maxY;
        break;
    }
  }

  /**
   * Paint bonus graphics on module panel.
   */
  public void paintItem ( Graphics g )
  {
    if ( info.isAssigned() )
      g.setColor( InfoPlugGUI.colorConnect );
    else
      if ( info.mandatory )
        g.setColor( InfoPlugGUI.colorMandatory );
      else
        g.setColor( InfoPlugGUI.colorNonMandatory );

    InfoPlug opos = null;
    if ( info.owner != null )
      opos = info.owner.owner.infoCompositionGUI.gui.plugFrom;

    if ( opos != null && InfoPlug.isOpposite( info, opos ) )
      g.setColor( InfoPlugGUI.colorOpposite );

    if ( info.equals( opos ) )
      g.setColor( InfoPlugGUI.colorActive );

    if ( info.owner != null )
      opos = info.owner.owner.infoCompositionGUI.gui.plugTo;

    if ( opos != null && InfoPlug.isOpposite( info, opos ) )
      g.setColor( InfoPlugGUI.colorOpposite );

    if ( info.equals( opos ) )
      g.setColor( InfoPlugGUI.colorActive );

    int x = info.infoGUI.x;
    int y = info.infoGUI.y;

    switch ( info.infoGUI.orientation )
    {
      case PGI_ORIENTATION_EAST:
        if ( info.input )
        {
            // paint input Plug
          g.drawArc(  x +  7, y - 14,     15,     15, 90, 180 );
          g.drawArc(  x + 12, y -  9,      5,      5, 90, 180 );
          g.drawLine( x + 15, y - 14, x + 15, y - 10 );
          g.drawLine( x + 15, y -  3, x + 15, y +  1 );
        }
        else
            // paint output Plug
          g.fillArc( x, y - 14, 15, 15, 270, 180 );
        break;

      case PGI_ORIENTATION_NORTH:
        if ( info.input )
        {
            // paint input Plug
          g.drawArc(  x,      y - 21,     15,     15, 180, 180 );
          g.drawArc(  x +  5, y - 16,      5,      5, 180, 180 );
          g.drawLine( x,      y - 14, x +  4, y - 14 );
          g.drawLine( x + 11, y - 14, x + 15, y - 14 );
        }
        else
            // paint output Plug
          g.fillArc( x, y - 14, 15, 15, 0, 180 );
        break;

      case PGI_ORIENTATION_WEST:
        if ( info.input )
        {
            // paint input Plug
          g.drawArc(  x - 7, y - 14,    15,     15, 270, 180 );
          g.drawArc(  x - 2, y -  9,     5,      5, 270, 180 );
          g.drawLine( x - 1, y - 14, x - 1, y - 10 );
          g.drawLine( x - 1, y -  3, x - 1, y +  1 );
        }
        else
            // paint output Plug
          g.fillArc( x, y - 14, 15, 15, 90, 180 );
        break;

      case PGI_ORIENTATION_SOUTH:
      default:
        if ( info.input )
        {
            // paint input Plug
          g.drawArc(  x,      y - 8,     15, 15, 0, 180 );
          g.drawArc(  x +  5, y - 3,      5,  5, 0, 180 );
          g.drawLine( x,      y,     x +  4,  y );
          g.drawLine( x + 11, y,     x + 15,  y );
        }
        else
            // paint output Plug
          g.fillArc( x, y - 14, 15, 15, 180, 180 );
    }
  }

}
