package cz.cuni.jagrlib.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.JPanel;

import cz.cuni.jagrlib.*;

/**
 * Button for incrementing and decrementing value of params.
 *
 * @author  Jan Kostlivy
 * @version 0.25 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/Volume.java">Volume.java</a>
 */
public class Volume extends JPanel
{
  private static final long serialVersionUID = 1L;

  //==========================================================================
  //  Data:

  /** Position of mouse cursor. */
  private int lastMouseX;

  /** Position of mouse cursor. */
  private int lastMouseY;

  /** Actual value. */
  public double number;

  /** Panel with parameter. */
  public ParamGUI param;

  /**
   * Type of value.
   * Integer, Long, Float or Double
   */
  public String type = "Integer";

  /** Step of inceremnting/decrementing. */
  public double increment = 1.0;

  //==========================================================================
  //  Methods:

  /**
   * Override the {@link JPanel#paintComponent}.
   */
  @Override
  public void paintComponent ( Graphics g )
  {
    super.paintComponent( g );
    int pol = getHeight() / 2;
    g.drawOval( 2, 2, 2*pol-4, 2*pol-4 );
    g.drawLine( pol, pol, 2*pol-4, pol );
  }

  /** Default constructor. */
  public Volume ()
  {
    try
    {
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Components initialization.
   *
   * @throws Exception
   */
  private void jbInit () throws Exception
  {
    addMouseMotionListener( new MouseMotionAdapter ()
    {
      public void mouseDragged ( MouseEvent e )
      {
        this_mouseDragged( e );
      }
    });
    addMouseListener ( new MouseAdapter ()
    {
      public void mousePressed ( MouseEvent e )
      {
        this_mousePressed( e );
      }
      public void mouseReleased ( MouseEvent e )
      {
        this_mouseReleased( e );
      }
    });
  }

  /**
   * Test, if move of mouse was clockwise or anticlockwise.
   *
   * @param newX New position of x.
   * @param newY New position of y.
   * @return +/- increment.
   */
  private double getInc ( int newX, int newY )
  {
    int pol = getHeight() / 2;
    if ( lastMouseY < newY && pol < newX ||
         lastMouseY > newY && pol > newX ||
         lastMouseX > newX && pol < newY ||
         lastMouseX < newX && pol > newY )
      return increment;
    else
      return -increment;
  }

  //==========================================================================
  //  Events:

  /**
   * Mouse pressed.
   *
   * @param e MouseEvent
   */
  void this_mousePressed ( MouseEvent e )
  {
    setCursor( Cursor.getPredefinedCursor( Cursor.HAND_CURSOR ) );
    lastMouseX = e.getX();
    lastMouseY = e.getY();
  }

  /**
   * Mouse released.
   *
   * @param e MouseEvent
   */
  void this_mouseReleased ( MouseEvent e )
  {
    setCursor( Cursor.getPredefinedCursor( Cursor.DEFAULT_CURSOR ) );
  }

  /**
   * Mouse drag.
   * clockwise - incrementing of value.
   * anticlockwise - decrementing of value.
   * And seting value of parameter.
   *
   * @param e MouseEvent
   */
  void this_mouseDragged ( MouseEvent e )
  {
    number = number + getInc( e.getX(), e.getY() );
    if ( type.compareTo( "Integer" ) == 0 )
      param.setValue( Formula.round( number ) );
    else
    if ( type.compareTo( "Long" ) == 0 )
      param.setValue( Math.round( number ) );
    else
    if ( type.compareTo( "Float" ) == 0 )
      param.setValue( (float)number );
    else
    if ( type.compareTo( "Double" ) == 0 )
      param.setValue( (double)number );
    else
      param.setValue( String.valueOf( number ) );

    lastMouseX = e.getX();
    lastMouseY = e.getY();
  }

}
