package cz.cuni.jagrlib.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import cz.cuni.jagrlib.LogFile;

/**
 * Internal frame for composition.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.25 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/WorkSpaceGUI.java">WorkSpaceGUI.java</a>
 */
public abstract class WorkSpaceGUI extends JInternalFrame
{
  private static final long serialVersionUID = 1L;

  //==========================================================================
  //  Data:

  public final static int CMD_LOAD         =  1;
  public final static int CMD_SAVE         =  2;
  public final static int CMD_ADDMODULE    =  3;
  public final static int CMD_DELETEMODULE =  4;
  public final static int CMD_GROUP        =  5;
  public final static int CMD_UNGROUP      =  6;
  public final static int CMD_RUN          =  7;
  public final static int CMD_UNDO         =  8;
  public final static int CMD_REDO         =  9;
  public final static int CMD_ZOOMWINDOW   = 10;
  public final static int CMD_SELECTALL    = 11;

  //==========================================================================
  //  Methods:

  /**
   * Tunnel for commands from Main Window to the Composition.
   *
   * @param command command from main window.
   * @param params params for that command.
   * @return Result codes:
   *   {@code 0} - OK or no returning value
   */
  public abstract int pipeToComposition ( int command, Object params );

  /** Loading composition. */
  public abstract void load ();

  /**
   * Saving the composition.
   *
   * @param type Type of saving (SAVE or SAVEAS).
   */
  public abstract void save ( String type );

  /** Running the composition. */
  public abstract void run ();

  /**
   * Creates new WorkSpaceGUI.
   * Sets position and size of the frame.
   */
  public WorkSpaceGUI ()
  {
    super( "New Composition", true, true, true, true );
    setLocation( 10, 10 );
    setSize( 750, 600 );
    try
    {
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Component initialization.
   */
  private void jbInit ()
  throws Exception
  {
    this.addComponentListener( new ComponentAdapter ()
    {
      public void componentMoved ( ComponentEvent e )
      {
        this_componentMoved( e );
      }

      public void componentResized ( ComponentEvent e )
      {
        this_componentResized( e );
      }
    });
  }

  //==========================================================================
  //  Events:

  /**
   * Resizing the DesktopPane.
   */
  void this_componentMoved ( ComponentEvent e )
  {
    if ( getDesktopPane() != null )
    {
      int maxx = 0;
      int maxy = 0;
      Component c;
      for ( int i = 0; i < getDesktopPane().getComponentCount(); i++ )
      {
        c = getDesktopPane().getComponent( i );
        if ( maxx < c.getX() + c.getWidth() )
          maxx = c.getX() + c.getWidth();

        if ( maxy < c.getY() + c.getHeight() )
          maxy = c.getY() + c.getHeight();
      }
      getDesktopPane().setPreferredSize( new Dimension( maxx, maxy ) );
      getDesktopPane().repaint();
    }
  }

  /**
   * Resizing the composition.
   */
  protected void this_componentResized ( ComponentEvent e )
  {
  }

}
