package cz.cuni.jagrlib.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import cz.cuni.jagrlib.reg.*;
import cz.cuni.jagrlib.LogFile;

/**
 * Improved class for outline window (composition outline).
 *
 * @author  Jan Kostlivy, PE
 * @version 0.25 $Rev: 381 $ $Date: 2007-01-02 15:51:44 +0100 (út, 02 I 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/ZoomImproved.java">ZoomImproved.java</a>
 */
public class ZoomImproved extends ZoomBasic
{
  private static final long serialVersionUID = 1L;

  /** Flag for painting channles. */
  protected boolean paintChannels = false;

  /** Flag for painting modules in real ratio. */
  protected boolean paintModules = false;

  // GUI components
  private JPopupMenu        jPopupMenuZoom           = new JPopupMenu();
  private JCheckBoxMenuItem jCheckBoxMenuItemChannel = new JCheckBoxMenuItem();
  private JCheckBoxMenuItem jCheckBoxMenuItemModule  = new JCheckBoxMenuItem();

  /** Composition outline painting. */
  public void paintItems ( Graphics g )
  {
    if ( composition == null ) return;

    Point p = ((JViewport)composition.getParent()).getViewPosition();
    g.drawRect( p.x / pomer,
                p.y / pomer,
                composition.getParent().getWidth()  / pomer,
                composition.getParent().getHeight() / pomer );

    for ( Component com : composition.getComponents() )
      if ( com instanceof ModuleGUI )
      {
        int _state = ((ModuleGUI)com).info.getState();
        if ( (_state & InfoState.NOTCONNECTED_HARD) > 0 )
          g.setColor( colorMandatory );
        else
        if ( _state != InfoState.OK )
          g.setColor( colorNonMandatory );
        else
          g.setColor( colorModule );

        if ( paintModules )
          g.fillRect( com.getX()     / pomer, com.getY()      / pomer,
                      com.getWidth() / pomer, com.getHeight() / pomer );
        else
          g.fillRect( com.getX()     / pomer, com.getY()      / pomer,
                      5,                      5 );
      }

    if ( paintChannels )
    {
      g.setColor( Color.black );
      int x1, y1, x2, y2;
      for ( InfoChannel ic : composition.info.channels.values() )
      {
        x1 = ic.plugFrom.owner.infoGUI.gui.getX();
        y1 = ic.plugFrom.owner.infoGUI.gui.getY();
        x2 = ic.plugTo.owner.infoGUI.gui.getX();
        y2 = ic.plugTo.owner.infoGUI.gui.getY();

        if ( paintModules )
        {
          x1 += ic.plugFrom.infoGUI.gui.getX();
          y1 += ic.plugFrom.infoGUI.gui.getY();
          x2 += ic.plugTo.infoGUI.gui.getX();
          y2 += ic.plugTo.infoGUI.gui.getY();
        }

        g.drawLine( x1 / pomer, y1 / pomer, x2 / pomer, y2 / pomer );
      }
    }
  }

  /**
   * Component initialization.
   */
  private void jbInit ()
  throws Exception
  {
    jCheckBoxMenuItemChannel.setText( "Channels" );
    jCheckBoxMenuItemChannel.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        jCheckBoxMenuItemChannel_actionPerformed( e );
      }
    });

    jCheckBoxMenuItemModule.setText( "Modules" );
    jCheckBoxMenuItemModule.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        jCheckBoxMenuItemModule_actionPerformed( e );
      }
    });

    jPopupMenuZoom.add( jCheckBoxMenuItemChannel );
    jPopupMenuZoom.add( jCheckBoxMenuItemModule );
  }

  /** Default constructor. */
  public ZoomImproved ()
  {
    super();
    try
    {
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  //==========================================================================
  //  Events:

  /**
   * Set flag for painting channels.
   */
  void jCheckBoxMenuItemChannel_actionPerformed ( ActionEvent e )
  {
    paintChannels = jCheckBoxMenuItemChannel.isSelected();
    repaintZoom();
  }

  /**
   * Mouse click.
   * <br><b>right button</b> - show popup menu.
   */
  void jPanelZoom_mouseClicked ( MouseEvent e )
  {
    super.jPanelZoom_mouseClicked( e );

    if ( e.getModifiers() == MouseEvent.BUTTON3_MASK )
      jPopupMenuZoom.show( e.getComponent(), e.getX(), e.getY() );
  }

  /**
   * Set flag for painting modules in real ratio.
   */
  void jCheckBoxMenuItemModule_actionPerformed ( ActionEvent e )
  {
    paintModules = jCheckBoxMenuItemModule.isSelected();
    repaintZoom();
  }

}
