package cz.cuni.jagrlib.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import cz.cuni.jagrlib.LogFile;

/**
 * Abstract class for zoom window (composition Zoom).
 *
 * @author  Jan Kostlivy
 * @version 0.24 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/ZoomWindow.java">ZoomWindow.java</a>
 */
abstract public class ZoomWindow extends JInternalFrame
{
  //==========================================================================
  //  Data:

  /** Active composition. */
  protected CompositionGUI composition;

  /** Ratio of zoom. */
  public int pomer = 10;

    // components
  protected JPanel      contentPane;
  private   JScrollPane jScrollPaneZoom = new JScrollPane();

  /** Panel for painting composition. */
  private   JPanel      jPanelZoom = new JPanel ()
  {
    private static final long serialVersionUID = 1L;

    @Override
    public void paintComponent ( Graphics g )
    {
      super.paintComponent( g );
      paintItems( g );
    }
  };

  //==========================================================================
  //  Methods:

  /**
   * Sets actual composition.
   * Sets actual size painting panel.
   * @param _composition Composition gui.
   */
  public void setComposition ( CompositionGUI _composition )
  {
    composition = _composition;
    if ( composition != null )
      jPanelZoom.setPreferredSize( new Dimension( composition.getWidth() / pomer, composition.getHeight() / pomer ) );
  }

  /** Repainting of zoom window.*/
  public void repaintZoom ()
  {
    jPanelZoom.repaint();
  }

  /**
   * Painting of composition.
   * @param  g Graphics.
   */
  abstract public void paintItems ( Graphics g );

  /**
   * Component initialization.
   */
  private void jbInit ()
  throws Exception
  {
    this.setSize( new Dimension( 180, 180 ) );

    this.addComponentListener( new ComponentAdapter ()
    {
      public void componentMoved ( ComponentEvent e )
      {
        this_componentMoved( e );
      }
    });

    jPanelZoom.setBackground( Color.white );
    jPanelZoom.setCursor( Cursor.getPredefinedCursor( Cursor.HAND_CURSOR ) );
    jPanelZoom.addMouseListener( new MouseAdapter ()
    {
      public void mouseClicked ( MouseEvent e )
      {
        jPanelZoom_mouseClicked( e );
      }
    });
    contentPane = (JPanel)this.getContentPane();
    contentPane.setLayout( new BorderLayout() );
    contentPane.add( jScrollPaneZoom, BorderLayout.CENTER );
    jScrollPaneZoom.getViewport().add( jPanelZoom, null );
  }

  /**
   * Creates new ZoomWindow.
   *
   * @param  title Title of frame.
   * @param  resizable Resizable frame.
   * @param  closable Closable frame.
   * @param  maximizable Maximizable frame.
   * @param  iconifiable Iconifiable frame.
   */
  public ZoomWindow ( String title,
                      boolean resizable,
                      boolean closable,
                      boolean maximizable,
                      boolean iconifiable )
  {
    super( title, resizable, closable, maximizable, iconifiable );

    try
    {
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  //==========================================================================
  //  Events:

  /**
   * Mouse click.
   * <br><b>left button</b> - sets position of viewing of actual composition.
   * Cursor defines centre of viewing.
   */
  void jPanelZoom_mouseClicked ( MouseEvent e )
  {
    if ( composition == null )
      return;

    if ( e.getModifiers() == MouseEvent.BUTTON1_MASK )
    {
      Rectangle d = ((JViewport)composition.getParent()).getBounds();
      Point p = new Point();
      p.x = e.getX() * pomer - ((int)d.width / 2);
      p.y = e.getY() * pomer - ((int)d.height / 2);

      if ( p.x < 0 ) p.x = 0;
      if ( p.y < 0 ) p.y = 0;
      if ( p.x > composition.getWidth() - ((JViewport)composition.getParent()).getWidth() )
        p.x = composition.getWidth() - ((JViewport)composition.getParent()).getWidth();
      if ( p.y > composition.getHeight() - ((JViewport)composition.getParent()).getHeight() )
        p.y = composition.getHeight() - ((JViewport)composition.getParent()).getHeight();

      ((JViewport)composition.getParent()).setViewPosition( p );
    }
  }

  /**
   * Resizing of DesktopPane.
   */
  void this_componentMoved ( ComponentEvent e )
  {
    if ( getDesktopPane() != null )
    {
      int maxx = 0;
      int maxy = 0;
      Component c;
      for ( int i = 0; i < getDesktopPane().getComponentCount(); i++ )
      {
        c = getDesktopPane().getComponent( i );
        if ( maxx < c.getX() + c.getWidth() )
          maxx = c.getX() + c.getWidth();
        if ( maxy < c.getY() + c.getHeight() )
          maxy = c.getY() + c.getHeight();
      }
      getDesktopPane().setPreferredSize( new Dimension( maxx, maxy ) );
      getDesktopPane().repaint();
    }
  }

}
