package cz.cuni.jagrlib.gui.comp;

import java.awt.Toolkit;
import javax.swing.*;
import javax.swing.text.*;

import cz.cuni.jagrlib.LogFile;

/**
 * Text field for double numbers.
 *
 * @version 0.25 $Rev: 329 $ $Date: 2006-10-25 23:05:47 +0200 (st, 25 X 2006) $ $Author: pepca $
 * @see     <a href="../../../../../../cz/cuni/jagrlib/gui/comp/DoubleNumberField.java">DoubleNumberField.java</a>
 */
public class DoubleNumberField extends JTextField
{
  private static final long serialVersionUID = 1L;

  private static Toolkit toolkit = Toolkit.getDefaultToolkit();

  /**
   * Creates the field.
   *
   * @param  value Initial value.
   * @param  columns Number of columns.
   */
  public DoubleNumberField ( double value, int columns )
  {
    super( columns );
    setValue( value );
  }

  /**
   * Returns actual value of the field.
   *
   * @return Actual value or <tt>0.0</tt>.
   */
  public double getValue ()
  {
    double retVal = 0.0;

    try
    {
      retVal = Double.parseDouble( getText() );
    }
    catch ( NumberFormatException e )
    {
        // This should never happen because insertString allows
        // only properly formatted data in the field.
      toolkit.beep();
      LogFile.error( "DoubleNumberField.getValue(): cannot parse '" + getText() + "'" );
    }
    return retVal;
  }

  /**
   * Sets new actual value.
   */
  public void setValue ( double value )
  {
    setText( Double.toString( value ) );
  }

  /**
   * Override for on-line content checking.
   */
  protected Document createDefaultModel ()
  {
    return new DoubleNumberDocument();
  }

  /**
   * Document class for on-line checking of double numbers.
   */
  protected static class DoubleNumberDocument extends PlainDocument
  {
    private static final long serialVersionUID = 1L;

    public void insertString( int offs,
                                String str,
                                AttributeSet a )
    throws BadLocationException
    {
      char[] source = str.toCharArray();
      char[] result = new char[ source.length ];
      int i, j;

      for ( i = j = 0; i < result.length; i++ )
      {
        if ( Character.isDigit( source[i] ) ||
             source[i] == '+' ||
             source[i] == '-' ||
             source[i] == '.' ||
             Character.toLowerCase( source[i] ) == 'e' )
          result[j++] = source[i];
        else
        {
          toolkit.beep();
          LogFile.error( "Error in DoubleNumberDocument.insertString(" + source[i] + ")" );
        }
      }
      super.insertString( offs, new String( result, 0, j ), a );
    }
  }
}
