package cz.cuni.jagrlib.gui.comp;

import java.awt.Toolkit;
import javax.swing.*;
import javax.swing.text.*;

import cz.cuni.jagrlib.LogFile;

/**
 * Text field for integer numbers.
 * Internal representation: long.
 *
 * @version 0.25 $Rev: 330 $ $Date: 2006-10-26 01:35:47 +0200 (čt, 26 X 2006) $ $Author: pepca $
 * @see      <a href="../../../../../../cz/cuni/jagrlib/gui/comp/IntNumberField.java">IntNumberField.java</a>
 */
public class IntNumberField extends JTextField
{
  private static final long serialVersionUID = 1L;

  private static Toolkit toolkit = Toolkit.getDefaultToolkit();

  /**
   * Creates the field.
   *
   * @param  value Initial value.
   * @param  columns Number of columns.
   */
  public IntNumberField ( long value, int columns )
  {
    super( columns );
    setValue( value );
  }

  /**
   * Returns actual value of the field.
   *
   * @return Actual value or <tt>0</tt>.
   */
  public long getValue ()
  {
    long retVal = 0;
    try
    {
      retVal = Long.parseLong( getText() );
    }
    catch ( NumberFormatException e )
    {
        // This should never happen because insertString allows
        // only properly formatted data in the field.
      toolkit.beep();
      LogFile.error( "IntNumberField.getValue(): cannot parse '" + getText() + "'" );
    }
    return retVal;
  }

  /**
   * Sets new actual value.
   */
  public void setValue ( long value )
  {
    setText( Long.toString( value ) );
  }

  /**
   * Override for on-line content checking.
   */
  protected Document createDefaultModel ()
  {
    return new IntNumberDocument();
  }

  /**
   * Document class for on-line checking of integer numbers.
   */
  protected static class IntNumberDocument extends PlainDocument
  {
    private static final long serialVersionUID = 1L;

    public void insertString( int offs,
                              String str,
                              AttributeSet a )
    throws BadLocationException
    {
      char[] source = str.toCharArray();
      char[] result = new char[ source.length ];
      int i, j;

      for ( i = j = 0; i < result.length; i++ )
      {
        if ( Character.isDigit( source[i] ) ||
             source[i] == '-' )
          result[j++] = source[i];
        else
        {
          toolkit.beep();
          LogFile.error( "Error in IntNumberDocument.insertString(" + source[i] + ")" );
        }
      }
      super.insertString( offs, new String( result, 0, j ), a );
    }
  }
}
