package cz.cuni.jagrlib.gui.comp;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.plaf.ToolTipUI;
import javax.swing.plaf.ComponentUI;

/**
 * Multi-line tooltips.
 *
 * @author JALT, PE
 * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 */
public class MultiLineToolTipUI extends ToolTipUI
{
  /** Indicates whether we should display the accelerator key, if any, for a tooltip. */
  static boolean displayAccelerator;

  static MultiLineToolTipUI SINGLETON = new MultiLineToolTipUI();
  static boolean DISPLAY_ACCELERATOR  = true;
  int accelerator_offset              = 15;
  int inset                           = 3;

  private MultiLineToolTipUI ()
  {
  }

  public static void initialize ()
  {
      // don't hardcode class name, this way we can obfuscate.
    String key   = "ToolTipUI";
    Class<?> cls = SINGLETON.getClass();
    String name  = cls.getName();
    UIManager.put( key, name );
    UIManager.put( name, cls );
  }

  public static ComponentUI createUI ( JComponent c )
  {
    return SINGLETON;
  }

  public void installUI ( JComponent c )
  {
    LookAndFeel.installColorsAndFont ( c, "ToolTip.background",
                                       "ToolTip.foreground", "ToolTip.font" );
    LookAndFeel.installBorder ( c, "ToolTip.border" );
  }

  public void uninstallUI ( JComponent c )
  {
    LookAndFeel.uninstallBorder( c );
  }

  public static void setDisplayAcceleratorKey ( boolean val )
  {
    displayAccelerator = val;
  }

  public Dimension getPreferredSize ( JComponent c )
  {
    Font font = c.getFont();
    FontMetrics fontMetrics = c.getFontMetrics( font );
    int fontHeight = fontMetrics.getHeight();
    String tipText = ((JToolTip)c).getTipText();
    if ( tipText == null )
      tipText = "";

    String lines[] = tipText.split( "\n" );
    int num_lines  = lines.length;

    int width, height, onewidth;
    height = num_lines * fontHeight;
    width  = 0;
    for ( int i = 0; i < num_lines; i++ )
    {
      onewidth = fontMetrics.stringWidth( lines[i] );
      if ( displayAccelerator && i == num_lines - 1 )
      {
        String keyText = getAcceleratorString( (JToolTip)c );
        if ( !keyText.equals( "" ) )
           onewidth += fontMetrics.stringWidth( keyText ) +
                       accelerator_offset;
      }
      width = Math.max( width, onewidth );
    }

    return new Dimension( width + inset * 2, height + inset * 2 );
  }

  public Dimension getMinimumSize ( JComponent c )
  {
    return getPreferredSize( c );
  }

  public Dimension getMaximumSize ( JComponent c )
  {
    return getPreferredSize( c );
  }

  public void paint ( Graphics g, JComponent c )
  {
    Font        font        = c.getFont();
    FontMetrics fontMetrics = c.getFontMetrics( font );
    Dimension   dimension   = c.getSize();
    int         fontHeight  = fontMetrics.getHeight();
    int         fontAscent  = fontMetrics.getAscent();
    String      tipText     = ((JToolTip)c).getTipText();
    String      lines[]     = tipText.split( "\n" );
    int         num_lines   = lines.length;
    int height;
    int i;

    g.setColor( c.getBackground() );
    g.fillRect( 0, 0, dimension.width, dimension.height );
    g.setColor( c.getForeground() );
    for ( i = 0, height = 2 + fontAscent;
          i < num_lines; i++, height += fontHeight )
    {
      g.drawString( lines[i], inset, height );
      if ( displayAccelerator && i == num_lines - 1 )
      {
        String keyText = getAcceleratorString( (JToolTip)c );
        if ( !keyText.equals( "" ) )
        {
          Font smallFont = new Font( font.getName(), font.getStyle(), font.getSize() - 2 );
          g.setFont( smallFont );
          g.drawString( keyText, fontMetrics.stringWidth( lines[i] ) + accelerator_offset, height );
        }
      }
    }
  }

  public String getAcceleratorString ( JToolTip tip )
  {
    JComponent comp = tip.getComponent();
    if ( comp == null ) return "";

    KeyStroke[] keys          = comp.getRegisteredKeyStrokes();
    String      controlKeyStr = "";
    KeyStroke   postTip       = KeyStroke.getKeyStroke( KeyEvent.VK_F1, Event.CTRL_MASK );

    for ( KeyStroke key : keys )
    {
        // Ignore ToolTipManager postTip action,
        // in swing1.1beta3 and onward
      if ( postTip.equals( key ) ) continue;

      int mod = key.getModifiers();
      if ( mod == InputEvent.CTRL_MASK )
      {
        controlKeyStr = "Ctrl+" + (char)key.getKeyCode();
        break;
      }

      if ( mod == InputEvent.ALT_MASK )
      {
        controlKeyStr = "Alt+" + (char)key.getKeyCode();
        break;
      }
    }

    return controlKeyStr;
  }
}
