package cz.cuni.jagrlib.gui.comp;

import javax.swing.table.*;

/**
 * Model for viewing registry tables.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.25 $Rev: 381 $ $Date: 2007-01-02 15:51:44 +0100 (út, 02 I 2007) $ $Author: pepca $
 * @see     <a href="../../../../../../cz/cuni/jagrlib/gui/comp/MyTableModel.java">MyTableModel.java</a>
 */
public class MyTableModel extends AbstractTableModel
{
  private static final long serialVersionUID = 1L;

  /** Column names. */
  final String[] columnNames;

  /** Data itself. */
  Object[][] data;

  /**
   * Table width.
   *
   * @return  Number of table columns.
   */
  public int getColumnCount ()
  {
    return columnNames.length;
  }

  /**
   * Table height.
   *
   * @return  Number of table rows.
   */
  public int getRowCount ()
  {
    return data.length;
  }

  /**
   * Returns name of the given column.
   *
   * @param  col Column index.
   */
  public String getColumnName ( int col )
  {
    return columnNames[ col ];
  }

  /**
   * Retrieves object at the given position [ row, col ].
   *
   * @param row Row index.
   * @param col Column index.
   */
  public Object getValueAt ( int row, int col )
  {
    return data[ row ][ col ];
  }

  /**
   * Returns column type.
   *
   * @param c Column index.
   */
  public Class< ? > getColumnClass ( int c )
  {
    return getValueAt( 0, c ).getClass();
  }

  /**
   * Is the given cell editable?
   *
   * @param row Row index.
   * @param col Column index.
   */
  public boolean isCellEditable ( int row, int col )
  {
    return false;
  }

  /**
   * Adds new row to the table.
   *
   * @param _row The new row.
   */
  public void addRow ( Object[] _row )
  {
    int _rowCount    = getRowCount();
    int _columnCount = getColumnCount();
    Object[][] _newData = new Object[ _rowCount + 1 ][ _columnCount ];

      // copy of the old rows
    System.arraycopy( data, 0, _newData, 0, _rowCount );

      // new row
    System.arraycopy( _row, 0, _newData[ _rowCount ], 0, _row.length );

    data = _newData;
  }

  /**
   * Creates a new table from the given data.
   *
   * @param _data Table interior (data).
   * @param _col Column titles.
   */
  public MyTableModel ( Object[][] _data, String[] _col )
  {
    data        = _data;
    columnNames = _col;
  }

}
