package cz.cuni.jagrlib.iface;

/**
 * Rendering interface for stroked circular arcs.
 * @author  PE
 * @version 0.24 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
 * @since   0.01
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/ArcRender.java">ArcRender.java</a>
 */
public interface ArcRender extends Render
{
  /**
   * Draws a circular arc with center [x,y], radius r and between angles alpha
   * and beta (anticlockwise).
   * @param  x X coordinate of circle center.
   * @param  y X coordinate of circle center.
   * @param  r Circle radius.
   * @param  alpha Starting angle.
   * @param  beta Ending angle.
   */
  void drawArc ( int x, int y, int r, double alpha, double beta );

  /**
   * Draws a circular arc with center [x,y], radius r and between angles alpha
   * and beta (clockwise).
   * @param  x X coordinate of circle center.
   * @param  y X coordinate of circle center.
   * @param  r Circle radius.
   * @param  alpha Starting angle.
   * @param  beta Ending angle.
   */
  void drawRArc ( int x, int y, int r, double alpha, double beta );

  /**
   * Draws a circular arc with center [x,y], radius r and between angles alpha
   * and beta (anticlockwise).
   * @param  x X coordinate of circle center.
   * @param  y X coordinate of circle center.
   * @param  r Circle radius.
   * @param  alpha Starting angle.
   * @param  beta Ending angle.
   */
  void drawArc ( double x, double y, double r, double alpha, double beta );

  /**
   * Draws a circular arc with center [x,y], radius r and between angles alpha
   * and beta (clockwise).
   * @param  x X coordinate of circle center.
   * @param  y X coordinate of circle center.
   * @param  r Circle radius.
   * @param  alpha Starting angle.
   * @param  beta Ending angle.
   */
  void drawRArc ( double x, double y, double r, double alpha, double beta );

}
