package cz.cuni.jagrlib.iface;

/**
 * Bit-mask interface (representation of pixel set in 2D plane).
 *
 * @version 0.25 $Rev: 381 $ $Date: 2007-01-02 15:51:44 +0100 (út, 02 I 2007) $ $Author: pepca $
 * @since   0.01
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/BitMask.java">BitMask.java</a>
 */
public interface BitMask extends BitMaskCore, Property
{
  String WIDTH  = "Width";

  String HEIGHT = "Height";

  /**
   * Sets the binary set operation (used in all {@code set*()} methods).
   *
   * @param  _op Binary set operation ({@code BinaryOperation.BIN_OP_*} constant).
   * @return The old binary set operation.
   * @see    cz.cuni.jagrlib.BinaryOperation Binary operations
   */
  int setOperation ( int _op );

  /**
   * Sets the given pixel's value (ignores current <b>binary set operation</b>).
   *
   * @param  x X coordinate of a pixel.
   * @param  y Y coordinate of a pixel.
   * @param  value New pixel's value.
   */
  void putPixel ( int x, int y, boolean value );

  /**
   * Sets the horizontal line's values (ignores current <b>binary set operation</b>).
   *
   * @param  x1 X coordinate of the starting pixel.
   * @param  x2 X coordinate of the first pixel after the line.
   * @param  y Common Y coordinate of the line.
   * @param  values New pixels' values.
   */
  void putHLine ( int x1, int x2, int y, boolean[] values );

  /**
   * Returns the pixels' values for the given horizontal line.
   *
   * @param  x1 X coordinate of the starting pixel.
   * @param  x2 X coordinate of the first pixel after the line.
   * @param  y Common Y coordinate of the line.
   * @param  values Returned values in {@code boolean[]} array ({@code false} for
   *                off-canvas access).
   */
  void getHLine ( int x1, int x2, int y, boolean[] values );

  /**
   * Sets the rectangle from [min(x1,x2),min(y1,y2)] to [max(x1,x2)-1,max(y1,y2)-1].
   * Accepts current <b>binary set operation</b>.
   *
   * @param  x1 X coordinate of the upper left corner.
   * @param  y1 Y coordinate of the upper left corner.
   * @param  x2 X coordinate of the lower right corner (outside pixel).
   * @param  y2 Y coordinate of the upper left corner (outside pixel).
   */
  void setRectangle ( int x1, int y1, int x2, int y2 );

  /**
   * Sets the rectangle's values (ignores current <b>binary set operation</b>).
   *
   * @param  x1 X coordinate of the upper left corner.
   * @param  y1 Y coordinate of the upper left corner.
   * @param  x2 X coordinate of the lower right corner (outside pixel).
   * @param  y2 Y coordinate of the upper left corner (outside pixel).
   * @param  values New pixels' values.
   */
  void putRectangle ( int x1, int y1, int x2, int y2, boolean[][] values );

  /**
   * Returns the pixels' values for the given rectangle.
   *
   * @param  x1 X coordinate of the upper left corner.
   * @param  y1 Y coordinate of the upper left corner.
   * @param  x2 X coordinate of the lower right corner (outside pixel).
   * @param  y2 Y coordinate of the upper left corner (outside pixel).
   * @param  values Returned values in {@code boolean[][]} array ({@code false} for
   *                off-canvas access).
   */
  void getRectangle ( int x1, int y1, int x2, int y2, boolean[][] values );

  /**
   * Bit-block-transfer routine: copies the source rectangle [sx,sy,width,height] to
   * the new location [dx,dy]. Binary set operation is ignored.
   *
   * @param  dx X coordinate of the upper left destination corner.
   * @param  dy Y coordinate of the upper left destination corner.
   * @param  sx X coordinate of the upper left source corner.
   * @param  sy Y coordinate of the upper left source corner.
   * @param  width Rectangle width.
   * @param  height Rectangle height.
   */
  void bitBlt ( int dx, int dy, int sx, int sy, int width, int height );

}
