package cz.cuni.jagrlib.iface;

import cz.cuni.jagrlib.*;

/**
 * Core of bit-mask interface (representation of pixel set in 2D plane).
 *
 * @version 0.25 $Rev: 381 $ $Date: 2007-01-02 15:51:44 +0100 (út, 02 I 2007) $ $Author: pepca $
 * @since   0.25
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/BitMaskCore.java">BitMaskCore.java</a>
 */
public interface BitMaskCore
{
  /**
   * Bit-mask (re-)initialization.
   *
   * @param  x Width of a new bitmask.
   * @param  y Height of a new bitmask.
   */
  void init ( int x, int y );

  /**
   * Bit-mask re-initialization (keeps current bitmask size - if the size
   * is relevant).
   */
  void init ();

  /**
   * Sets the given pixel's value to {@code true} = "painted".
   * Accepts current <b>binary set operation</b>.
   *
   * @param  x X coordinate of a pixel.
   * @param  y Y coordinate of a pixel.
   */
  void setPixel ( int x, int y );

  /**
   * Returns the pixel's value.
   *
   * @param  x X coordinate of a pixel.
   * @param  y Y coordinate of a pixel.
   * @return Pixel value ({@code false} for off-canvas access).
   */
  boolean getPixel ( int x, int y );

  /**
   * Sets the horizontal line from [min(x1,x2),y] to [max(x1,x2)-1,y].
   * Accepts current <b>binary set operation</b>.
   *
   * @param  x1 X coordinate of the starting pixel.
   * @param  x2 X coordinate of the first pixel after the line.
   * @param  y Common Y coordinate of the line.
   */
  void setHLine ( int x1, int x2, int y );

  /**
   * Bit-mask enumeration.
   *
   * @return The {@link BitMaskEnumerator} object instance.
   */
  BitMaskEnumerator enumerator ();

}
