package cz.cuni.jagrlib.iface;

/**
 * Bounding-volume interface for 3D scenes.
 *
 * @version 0.25 $Rev: 294 $ $Date: 2006-07-06 00:50:34 +0200 (čt, 06 VII 2006) $ $Author: pepca $
 * @since   0.11
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/BoundingVolume.java">BoundingVolume.java</a>
 * @see     Solid
 */
public interface BoundingVolume
{
  /**
   * Ray vs. bounding-volume intersection test.
   *
   * @param  P0 Ray origin (<tt>double[3]</tt> or <tt>double[4]</tt>).
   * @param  P1 Direction vector of the ray (<tt>double[3]</tt> or <tt>double[4]</tt>).
   * @return <tt>true</tt> if the ray intersects the bounding-volume.
   * @see    #intersection
   */
  boolean intersectsRay ( double[] P0, double[] P1 );

  /**
   * Ray vs. bounding-volume intersection test with quantitative result.
   *
   * @param  P0 Ray origin (<tt>double[3]</tt> or <tt>double[4]</tt>).
   * @param  P1 Direction vector of the ray (<tt>double[3]</tt> or <tt>double[4]</tt>).
   * @return <tt>t</tt>-parameter {@code >= 0.0} if the ray intersects the bounding-volume,
   *         number {@code < 0.0} if no intersection exists.
   * @see    #intersectsRay
   */
  double intersection ( double[] P0, double[] P1 );

  /**
   * Rectangular box (AABB) vs. bounding-volume intersection test.
   *
   * @param  o Coordinate of minimal cell-vertex (<tt>double[3]</tt>).
   * @param  size Box size (<tt>double[3]</tt>).
   * @return <tt>true</tt> if intersection of the cell and the bounding-volume is non-empty.
   * @see    #isInside
   */
  boolean intersectsCell ( double[] o, double[] size );

  /**
   * Point vs. bounding-volume test ("inside-test").
   *
   * @param  point Coordinates of the 3D point (<tt>double[3]</tt> or
   *               <tt>double[4]</tt>).
   * @return <tt>true</tt> if the given point lies inside the bounding-volume.
   * @see    #intersectsCell
   */
  boolean isInside ( double[] point );

}
