package cz.cuni.jagrlib.iface;

/**
 * Abstract brush interface (filling of a 2D area).
 *
 * @version 0.25 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
 * @since   0.03
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/Brush.java">Brush.java</a>
 */
public interface Brush extends Property
{
  /**
   * Area (re-)initialization.
   */
  void init ();

  /**
   * Sets the binary set operation (used in {@link #fill} method).
   *
   * @param  _op Binary set operation (<tt>BinaryOperation.BIN_OP_*</tt> constant).
   * @return The old binary set operation.
   * @see    RasterGraphics
   * @see    cz.cuni.jagrlib.BinaryOperation Binary operations
   */
  int setOperation ( int _op );

  /**
   * Sets the alpha-channel operation (used in {@link #fill} method).
   *
   * @param  _op Alpha-channel operation (<tt>AlphaOperation.ALPHA_*</tt> constant).
   * @return The old alpha-channel operation.
   * @see    cz.cuni.jagrlib.AlphaOperation Alpha-channel operations
   */
  int setAlphaOperation ( int _op );

  /**
   * Sets the value-transfer function (used in {@link #fill} method).
   *
   * @param  _transfer New value-transfer function or <tt>null</tt>.
   * @return The old Value-transfer function or <tt>null</tt>.
   * @see    RasterGraphics
   * @see    cz.cuni.jagrlib.iface.ValueTransferFunction Value-transfor function prototype
   */
  ValueTransferFunction setTransferFunction ( ValueTransferFunction _transfer );

  /**
   * Fills the defined area.
   * Destroys the current area.
   */
  void fill ();

}
