package cz.cuni.jagrlib.iface;

/**
 * Abstract colormap storage. Colormap is "&lt;0,size()-1&gt; -&gt; { Gr[A] | RGB[A] }"
 * mapping. Store can hold a sequence of M colormaps at time.
 *
 * @version 0.25 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
 * @since   0.04
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/ColormapStore.java">ColormapStore.java</a>
 */
public interface ColormapStore extends Property
{
  /**
   * Store (re-)initialization.
   *
   * @param  _mode Colormap item value type (<tt>RasterGraphics.MODE_*</tt> constant).
   * @param  _bands Number of bands (for {@link RasterGraphics#MODE_BAND}).
   * @see    RasterGraphics
   * @see    #init()
   */
  void init ( int _mode, int _bands );

  /**
   * Store re-initialization (keeps current colormap mode).
   *
   * @see    #init(int,int)
   */
  void init ();

  /**
   * Returns the store size (colormaps are indexed from <tt>0</tt> to
   * {@link #size}<tt>-1</tt>).
   *
   * @return Store size.
   * @see    #setSize
   */
  int size ();

  /**
   * Assigns the new store size (potentially discards some colormaps).
   *
   * @param  newSize The new store size.
   * @return The old store size.
   * @see    #size
   */
  int setSize ( int newSize );

  /**
   * Retrieves the i-th colormap.
   *
   * @param  i Colormap index (from <tt>0</tt> to {@link #size}<tt>-1</tt>).
   * @return Array holding the colormap data.
   * @see    #getColormap
   */
  double[][] getColormapDouble ( int i );

  /**
   * Retrieves the i-th colormap.
   *
   * @param  i Colormap index (from <tt>0</tt> to {@link #size}<tt>-1</tt>).
   * @return Array holding the colormap data.
   * @see    #getColormapDouble
   */
  int[][] getColormap ( int i );

  /**
   * Assigns the i-th colormap.
   *
   * @param  i Colormap index.
   * @param  cmap The new colormap data (or <tt>null</tt>).
   * @return Array holding the old colormap data (or <tt>null</tt>).
   * @see    #setColormap(int,double[][])
   */
  int[][] setColormap ( int i, int[][] cmap );

  /**
   * Assigns the i-th colormap.
   *
   * @param  i Colormap index.
   * @param  cmap The new colormap data (or <tt>null</tt>).
   * @return Array holding the old colormap data (or <tt>null</tt>).
   * @see    #setColormap(int,int[][])
   */
  double[][] setColormap ( int i, double[][] cmap );

}
