package cz.cuni.jagrlib.iface;

/**
 * Rendering interface for stroked ellipses.
 *
 * @version 0.25 $Rev: 314 $ $Date: 2006-10-16 02:15:59 +0200 (po, 16 X 2006) $ $Author: pepca $
 * @since   0.01
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/EllipseRender.java">EllipseRender.java</a>
 */
public interface EllipseRender extends Render
{
  /**
   * Draws an axis-aligned ellipse with center [x,y] and radii a, b.
   *
   * @param  x X coordinate of ellipse center.
   * @param  y X coordinate of ellipse center.
   * @param  a Horizontal radius of the ellipse.
   * @param  b Vertical radius of the ellipse.
   */
  void drawEllipse ( int x, int y, int a, int b );

  /**
   * Draws an axis-aligned ellipse with center [x,y] and radii a, b.
   *
   * @param  x X coordinate of ellipse center.
   * @param  y X coordinate of ellipse center.
   * @param  a Horizontal radius of the ellipse.
   * @param  b Vertical radius of the ellipse.
   */
  void drawEllipse ( double x, double y, double a, double b );

  /**
   * Draws a tilted ellipse with center [x,y] and radii a, b.
   *
   * @param  x X coordinate of ellipse center.
   * @param  y X coordinate of ellipse center.
   * @param  a Primary radius of the ellipse.
   * @param  b Secondary radius of the ellipse.
   * @param  tilt Tilt angle in radians. <code>0.0</code> for axis-aligned ellipse.
   *              Positive orientation means counterclockwise.
   */
  void drawEllipse ( double x, double y, double a, double b, double tilt );

}
