package cz.cuni.jagrlib.iface;

/**
 * Rendering interface for stroked elliptic arcs.
 * @author  PE
 * @version 0.24 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
 * @since   0.01
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/EllipticArcRender.java">EllipticArcRender.java</a>
 */
public interface EllipticArcRender extends Render
{
  /**
   * Draws an elliptic arc with center [x,y], radii a, b and between angles alpha
   * and beta (anticlockwise).
   * @param  x X coordinate of ellipse center.
   * @param  y X coordinate of ellipse center.
   * @param  a Horizontal radius of the ellipse.
   * @param  b Vertical radius of the ellipse.
   * @param  alpha Starting angle of the arc.
   * @param  beta Ending angle of the arc.
   */
  void drawEllipticArc ( int x, int y, int a, int b, double alpha, double beta );

  /**
   * Draws an elliptic arc with center [x,y], radii a, b and between angles alpha
   * and beta (clockwise).
   * @param  x X coordinate of ellipse center.
   * @param  y X coordinate of ellipse center.
   * @param  a Horizontal radius of the ellipse.
   * @param  b Vertical radius of the ellipse.
   * @param  alpha Starting angle of the arc.
   * @param  beta Ending angle of the arc.
   */
  void drawREllipticArc ( int x, int y, int a, int b, double alpha, double beta );

  /**
   * Draws an elliptic arc with center [x,y], radii a, b and between angles alpha
   * and beta (anticlockwise).
   * @param  x X coordinate of ellipse center.
   * @param  y X coordinate of ellipse center.
   * @param  a Horizontal radius of the ellipse.
   * @param  b Vertical radius of the ellipse.
   * @param  alpha Starting angle of the arc.
   * @param  beta Ending angle of the arc.
   */
  void drawEllipticArc ( double x, double y, double a, double b, double alpha, double beta );

  /**
   * Draws an elliptic arc with center [x,y], radii a, b and between angles alpha
   * and beta (clockwise).
   * @param  x X coordinate of ellipse center.
   * @param  y X coordinate of ellipse center.
   * @param  a Horizontal radius of the ellipse.
   * @param  b Vertical radius of the ellipse.
   * @param  alpha Starting angle of the arc.
   * @param  beta Ending angle of the arc.
   */
  void drawREllipticArc ( double x, double y, double a, double b, double alpha, double beta );

}
