package cz.cuni.jagrlib.iface;

/**
 * Interface for 3D scene face rendering (texture-mapped, Gouraud-shaded, Phong-shaded, ..).
 *
 * @version 0.26 $Rev: 460 $ $Date: 2007-05-21 17:21:31 +0200 (po, 21 V 2007) $ $Author: pepca $
 * @since   0.09
 * @see     BitMaskCore
 * @see     Brep
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/FaceRender.java">FaceRender.java</a>
 */
public interface FaceRender extends Property
{
  /** Property: name of projected-coordinates attribute. Needs not be changed - default value is {@link Brep#COORD_PROJ}. */
  String PROJECTED_COORDS = "ProjCoords";

  /** Property: name of face-color attribute. Needs not be changed - default value is {@link Brep#COLOR}. */
  String FACE_COLOR = "FaceColor";

  /** Property: name of vertex-color attribute. Needs not be changed - default value is {@link Brep#COLOR}. */
  String VERTEX_COLOR = "VertexColor";

  /** Property: name of face-normal attribute. Needs not be changed - default value is {@link Brep#NORMAL}. */
  String FACE_NORMAL = "FaceNormal";

  /** Property: name of vertex-normal attribute. Needs not be changed - default value is {@link Brep#NORMAL}. */
  String VERTEX_NORMAL = "VertexNormal";

  /** Property: name of face-texture attribute. Identifies texture object for each face. */
  String FACE_TEXTURE = "FaceTexture";

  /** Property: name of vertex-texture attribute (texture-coordinates). Needs not be changed - default value is {@link Brep#TEXTURE_0}. */
  String VERTEX_TEXTURE = "VertexTexture";

  /** Property: name of face-solid attribute. Identifies solid handle for each face. */
  String FACE_SOLID = "FaceSolid";

  /**
   * Fills the given polygonal face. Uses only pixels which are set in the associated
   * {@link BitMaskCore} (fills the whole face if no {@link BitMaskCore} is used).
   *
   * @param  ctx Handle to a context to draw from.
   * @param  face Handle of the face (in the associated {@link Brep} scene).
   * @see    BitMaskCore
   * @see    Brep
   */
  void fillInside ( int ctx, int face );

  /**
   * Fills the horizontal line from the given polygonal face.
   *
   * @param  ctx Handle to a context to draw from.
   * @param  face Handle of the face (in the associated {@link Brep} scene).
   * @param  x1 X coordinate of the starting pixel.
   * @param  x2 X coordinate of the first pixel after the line.
   * @param  y Common Y coordinate of the line.
   * @see    Brep
   */
  void fillHLine ( int ctx, int face, int x1, int x2, int y );

  /**
   * Fills the given polygonal face. Uses only pixels which are not set in the associated
   * {@link BitMaskCore}. Sets the drawn pixels afterwards.
   *
   * @param  ctx Handle to a context to draw from.
   * @param  face Handle of the face (in the associated {@link Brep} scene).
   * @return Number of pixels filled.
   * @see    BitMaskCore
   * @see    Brep
   */
  int fillOutside ( int ctx, int face );

}
