package cz.cuni.jagrlib.iface;

import java.io.*;

/**
 * Interface for fill call-back routines.
 *
 * @version 0.25 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
 * @since   0.02
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/FillCallback.java">FillCallback.java</a>
 */
public interface FillCallback extends Serializable
{
  /** Use bit-mask modulation. */
  int MASK_BIT        = 0x01;

  /** Use alpha-channel modulation. */
  int MASK_ALPHA      = 0x02;

  /** Use color modulation. */
  int MASK_COLOR      = 0x04;

  /** Use parametric (relative) coordinates. */
  int MASK_PARAMETRIC = 0x08;

  /**
   * Tells which features are used by this fill-modulation function.
   *
   * @return Flags using <a href="#MASK_BIT">MASK_*</a> constants.
   */
  int getFeatures ();

  /**
   * Returns boolean information about the given point.
   *
   * @param  i Point's horizontal index (from <tt>0</tt> to <tt>width-1</tt>).
   * @param  j Point's vertical index (from <tt>0</tt> to <tt>height-1</tt>).
   * @param  width Total pattern width.
   * @param  height Total pattern height.
   * @param  cyclic Is that pattern cyclic?.
   * @return <tt>true</tt> for the point that has to be drawn.
   */
  boolean getBit ( int i, int j, int width, int height, boolean cyclic );

  /**
   * Returns boolean information about the given point.
   *
   * @param  t Point's relative horizontal coordinate (from <tt>0.0</tt> to <tt>1.0</tt>).
   * @param  u Point's relative vertical coordinate (from <tt>0.0</tt> to <tt>1.0</tt>).
   * @param  cyclic Is that pattern cyclic?.
   * @return <tt>true</tt> for the point that has to be drawn.
   */
  boolean getBit ( double t, double u, boolean cyclic );

  /**
   * Returns alpha-channel information about the given point.
   *
   * @param  i Point's horizontal index (from <tt>0</tt> to <tt>width-1</tt>).
   * @param  j Point's vertical index (from <tt>0</tt> to <tt>height-1</tt>).
   * @param  width Total pattern width.
   * @param  height Total pattern height.
   * @param  cyclic Is that pattern cyclic?.
   * @return Alpha (opacity) to draw the point with (from 0.0 to 1.0).
   */
  double getAlpha ( int i, int j, int width, int height, boolean cyclic );

  /**
   * Returns alpha-channel information about the given point.
   *
   * @param  t Point's relative horizontal coordinate (from <tt>0.0</tt> to <tt>1.0</tt>).
   * @param  u Point's relative vertical coordinate (from <tt>0.0</tt> to <tt>1.0</tt>).
   * @param  cyclic Is that pattern cyclic?.
   * @return Alpha (opacity) to draw the point with (from 0.0 to 1.0).
   */
  double getAlpha ( double t, double u, boolean cyclic );

  /**
   * Returns color information (RGB) about the given point.
   *
   * @param  color RGB color of the point.
   * @param  i Point's horizontal index (from <tt>0</tt> to <tt>width-1</tt>).
   * @param  j Point's vertical index (from <tt>0</tt> to <tt>height-1</tt>).
   * @param  width Total pattern width.
   * @param  height Total pattern height.
   * @param  cyclic Is that pattern cyclic?.
   */
  void getColor ( double[] color, int i, int j, int width, int height, boolean cyclic );

  /**
   * Returns color information (RGB) about the given point.
   *
   * @param  color RGB color of the point.
   * @param  t Point's relative horizontal coordinate (from <tt>0.0</tt> to <tt>1.0</tt>).
   * @param  u Point's relative vertical coordinate (from <tt>0.0</tt> to <tt>1.0</tt>).
   * @param  cyclic Is that pattern cyclic?.
   */
  void getColor ( double[] color, double t, double u, boolean cyclic );

}
