package cz.cuni.jagrlib.iface;

/**
 * Serial 1D data filter.
 * Used mostly in filtering of audio data (low-pass, high-pass, band, notch filters).
 *
 * @version 0.25 $Rev: 300 $ $Date: 2006-07-20 01:03:44 +0200 (čt, 20 VII 2006) $ $Author: pepca $
 * @since   0.25
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/Filter1D.java">Filter1D.java</a>
 */
public interface Filter1D extends Property
{
  /** Format-array index: number of audio channels. */
  int IND_CHANNELS         = 0;

  /** Format-array index: sample size in bytes. */
  int IND_BYTES_PER_SAMPLE = 1;

  /** Format-array index: number of samples (time-slots). */
  int IND_SAMPLES          = 2;

  /** Format-array index: sampling frequency in Hz. */
  int IND_FREQUENCY        = 3;

  /**
   * Defines format modifications.
   * Sets input sample format for subsequent {@link #batch} calls.
   *
   * @param  source Source audio format (channels, bytes-per-sample, samples, frequency).
   * @param  target Target audio format (channels, bytes-per-sample, samples, frequency).
   * @return <tt>true</tt> if any format changes will be made ({@code false => format identity}).
   * @see    #batch(double[],int,double[])
   * @see    #batch(int[],int,int[])
   */
  boolean format ( int[] source, int[] target );

  /**
   * Starts a new data pass.
   *
   * @see    #batch(double[],int,double[])
   * @see    #batch(int[],int,int[])
   */
  void reset ();

  /**
   * Processes one sample batch in <tt>double</tt> format.
   * Sample ordering in case of multi-channel data: {@code channel0[0], channel1[0], ..
   * channelN[0], channel0[1], ..}.
   *
   * @param  source Source data array.
   * @param  sourceSamples Number of source time-slots.
   * @param  target Target data array.
   * @return Number of target time-slots.
   * @see    #format
   * @see    #batch(int[],int,int[])
   */
  int batch ( double[] source, int sourceSamples, double[] target );

  /**
   * Processes one sample batch in <tt>integer</tt> format.
   * Sample ordering in case of multi-channel data: {@code channel0[0], channel1[0], ..
   * channelN[0], channel0[1], ..}.
   *
   * @param  source Source data array.
   * @param  sourceSamples Number of source time-slots.
   * @param  target Target data array.
   * @return Number of target time-slots.
   * @see    #format
   * @see    #batch(double[],int,double[])
   */
  int batch ( int[] source, int sourceSamples, int[] target );

}
