package cz.cuni.jagrlib.iface;

/**
 * General mapping from R<sup>2</sup> to R<sup>2</sup>.
 *
 * @version 0.24 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
 * @since   0.10
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/FunctionR2ToR2.java">FunctionR2ToR2.java</a>
 */
public interface FunctionR2ToR2 extends Property
{
  /**
   * Compute the mapping: <b>f(x,y)</b>.
   *
   * @param  x X coordinate (1st argument).
   * @param  y Y coordinate (2nd argument).
   * @param  res Result array (<tt>res[0]</tt> = U coordinate,
   *             <tt>res[1]</tt> = V coordinate).
   */
  void f ( double x, double y, double[] res );

  /**
   * Compute partial derivatives: <b>du(x,y)/dx</b>, <b>du(x,y)/dy</b>, <b>dv(x,y)/dx</b> and
   * <b>dv(x,y)/dy</b>.
   *
   * @param  x X coordinate (1st argument).
   * @param  y Y coordinate (2nd argument).
   * @param  d Array to hold results (<tt>d[0]</tt> = du(x,y)/dx,
   *           <tt>d[1]</tt> = du(x,y)/dy, <tt>d[2]</tt> = dv(x,y)/dx,
   *           <tt>d[3]</tt> = dv(x,y)/dy).
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean df ( double x, double y, double d[] );

  /**
   * Compute the inverse mapping: <b>f<sup>-1</sup>(u,v)</b>.
   *
   * @param  u U coordinate (1st argument).
   * @param  v V coordinate (2nd argument).
   * @param  res Result array (<tt>res[0]</tt> = X coordinate,
   *             <tt>res[1]</tt> = Y coordinate).
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean fInv ( double u, double v, double[] res );

  /**
   * Compute partial derivatives of inverse mapping: <b>dx(u,v)/du</b>, <b>dx(u,v)/dv</b>,
   * <b>dy(u,v)/du</b> and <b>dy(u,v)/dv</b>.
   *
   * @param  u U coordinate (1st argument).
   * @param  v V coordinate (2nd argument).
   * @param  d Array to hold results (<tt>d[0]</tt> = dx(u,v)/du,
   *           <tt>d[1]</tt> = dx(u,v)/dv, <tt>d[2]</tt> = dy(u,v)/du,
   *           <tt>d[3]</tt> = dy(u,v)/dv).
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean dfInv ( double u, double v, double d[] );

  /**
   * Returns domain of the mapping.
   *
   * @param  dom Domain array (<tt>dom[0]</tt> = Xmin, <tt>dom[1]</tt> = Xmax,
   *             <tt>dom[2]</tt> = Ymin, <tt>dom[3]</tt> = Ymax).
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean getDomain ( double[] dom );

  /**
   * Returns range of the mapping.
   *
   * @param  rng Range array (<tt>rng[0]</tt> = Umin, <tt>rng[1]</tt> = Umax,
   *             <tt>rng[2]</tt> = Vmin, <tt>rng[3]</tt> = Vmax).
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean getRange ( double[] rng );

}
