package cz.cuni.jagrlib.iface;

import javax.media.opengl.*;
import javax.media.opengl.glu.*;

/**
 * GL graphics producer. Repaints the canvas using OpenGL (JOGL library).
 * Can be used with GL graphics viewer or PBuffer if available.
 *
 * @author  Stuchl
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @since   0.24
 */
public interface GLGraphics
{
  /**
   * Initialization of GL context.
   * It's called in init-time of every GL context.
   *
   * @param  gl GL commands access object.
   * @param  glu GLU commands access object.
   */
  public void initRoutine ( GL gl, GLU glu );

  /**
   * Routine responsible for GL context repainting.
   *
   * @param gl GL commands access object.
   * @param glu GLU commands access object.
   */
  public void paintRoutine ( GL gl, GLU glu );

  /**
   * Reshape routine is called every time the dimensions of GL context are changed.
   * It usually contains projection setup.
   *
   * @param  gl GL commands access object.
   * @param  glu GLU commands access object.
   * @param  x X position of reshaped canvas.
   * @param  y Y position of reshaped canvas.
   * @param  width Width of reshaped canvas.
   * @param  height Height of reshaped canvas.
   */
  public void reshapeRoutine ( GL gl, GLU glu, int x, int y, int width, int height );

}
