package cz.cuni.jagrlib.iface;

import cz.cuni.jagrlib.Breakable;

/**
 * General global-illumination method.
 * Modules implementing this interface should compute light distribution in the whole scene
 * (optionally the computing will be dependent on the given camera position).
 *
 * @author  Tomas "Source" Svab, PE
 * @version 0.26 $Rev: 753 $ $Date: 2008-05-18 17:25:57 +0200 (ne, 18 V 2008) $ $Author: pepca $
 * @since   0.26
 */
public interface GlobalIllumination extends Property, Breakable
{
  /**
   * Sets camera position ({@code null} for no camera = pure global lighting).
   *
   * @param  camera World-space coordinates of the camera.
   * @todo   Importance of the camera (instead of its position).
   */
  void setCamera ( double[] camera );

  /**
   * Computes scene illumination from the scratch.
   * If time/iteration limits are nonzero, tries to fulfill them..
   * This method can be called repeatedly - or in combination with {@link #updateIllumination}.
   *
   * @param  maxIterations If nonzero, defines maximum number of iterations (if applicable).
   * @param  maxTime If nonzero, defines maximum time in milliseconds (if applicable).
   * @return {@code true} if finished.
   */
  boolean illuminate ( int maxIterations, long maxTime );

  /**
   * Recomputes illumination according to scene & light-source changes.
   * Scene & light-source changes are expressed in the {@link SLEData} interface.
   * Camera position/importance changes should be considered too.
   *
   * If time/iteration limits are nonzero, tries to fulfill them..
   *
   * @param  maxIterations If nonzero, defines maximum number of iterations (if applicable).
   * @param  maxTime If nonzero, defines maximum time in milliseconds (if applicable).
   * @return {@code true} if finished.
   */
  boolean updateIllumination ( int maxIterations, long maxTime );
}
