package cz.cuni.jagrlib.iface;

import cz.cuni.jagrlib.Breakable;

/**
 * Abstract interface for image-synthesizing algorithms.
 *
 * @version 0.26 $Rev: 453 $ $Date: 2007-05-14 21:50:00 +0200 (po, 14 V 2007) $ $Author: pepca $
 * @since   0.11
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/ImageSynthesizer.java">ImageSynthesizer.java</a>
 */
public interface ImageSynthesizer extends TimeDependent, Breakable
{
  /** Property name: image width in pixels. */
  String WIDTH         = "Width";

  /** Property name: image height in pixels. */
  String HEIGHT        = "Height";

  /** Property name: number of samples (rays) for supersampling. */
  String SUPERSAMPLING = "Supersampling";

  /** Property name: gamma-correction (or {@code 0.0} for no correction and no clamping - for HDRI). */
  String GAMMA         = "Gamma";

  /**
   * Sets resolution of an output raster image.
   *
   * @param  width Horizontal image size in pixels.
   * @param  height Vertical image size in pixels.
   */
  void setBounds ( int width, int height );

  /**
   * Render the given pixel of the image.
   *
   * @param  x X coordinate of the pixel.
   * @param  y Y coordinate of the pixel.
   * @param  pre Pre-allocated {@code double[3]} array to hold results (can be
   *             {@code null}).
   * @return Color of the pixel (in <b>RGB</b> color space).
   * @see    #renderRectangle
   * @see    #renderAll
   */
  double[] renderPixel ( int x, int y, double[] pre );

  /**
   * Render the given rectangle.
   * Output is written to some connected raster device (not defined in this interface).
   *
   * @param  x1 X coordinate of the upper left corner.
   * @param  y1 Y coordinate of the upper left corner.
   * @param  x2 X coordinate of the lower right corner (outside pixel).
   * @param  y2 Y coordinate of the upper left corner (outside pixel).
   * @see    #renderPixel
   * @see    #renderAll
   */
  void renderRectangle ( int x1, int y1, int x2, int y2 );

  /**
   * Render the whole image.
   * Output is written to some connected raster device (not defined in this interface).
   *
   * @see    #renderPixel
   * @see    #renderRectangle
   */
  void renderAll ();

}
