package cz.cuni.jagrlib.iface;

import java.awt.event.MouseEvent;

/**
 * Listener for input events. Usage: mouse listener for GraphicsViewer window, etc.
 *
 * @version 0.25 $Rev: 406 $ $Date: 2007-03-25 00:06:58 +0100 (ne, 25 III 2007) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/InputListener.java">InputListener.java</a>
 * @see     GraphicsViewer
 */
public interface InputListener
{
  /** Mouse button #1 - left button. */
  int BUTTON1 = MouseEvent.BUTTON1;

  /** Mouse button #2 - middle button. */
  int BUTTON2 = MouseEvent.BUTTON2;

  /** Mouse button #3 - right button. */
  int BUTTON3 = MouseEvent.BUTTON3;

  /**
   * Change the window shape.
   *
   * @param sender Originator of the event
   * @param width Horizontal window size in pixels.
   * @param height Vertical window size in pixels.
   */
  void setWindowSize ( Object sender, int width, int height );

  /**
   * Window was closed (user interaction..).
   *
   * @param sender Originator of the event
   */
  void windowClose ( Object sender );

  /**
   * Mouse button was pressed/released.
   *
   * @param sender Originator of the event
   * @param when System time in milliseconds.
   * @param x Horizontal screen position in pixels.
   * @param y Vertical screen position in pixels.
   * @param button Button number ({@link #BUTTON1}, etc.).
   * @param press Was it press or release?
   * @param flags Input system status (key shifts/alts, ..).
   */
  void mouseButton ( Object sender, long when, int x, int y, int button, boolean press, int flags );

  /**
   * Mouse wheel was rotated.
   *
   * @param sender Originator of the event
   * @param when System time in milliseconds.
   * @param x Horizontal screen position in pixels.
   * @param y Vertical screen position in pixels.
   * @param wheel Wheel number ({@link #BUTTON1}, etc.).
   * @param amount Rotation angle (positive number means down - or towards the user).
   * @param flags Input system status (key shifts/alts, ..).
   */
  void mouseWheel ( Object sender, long when, int x, int y, int wheel, int amount, int flags );

  /**
   * Mouse pointer was moved.
   *
   * @param sender Originator of the event
   * @param when System time in milliseconds.
   * @param x Horizontal screen position in pixels.
   * @param y Vertical screen position in pixels.
   * @param flags Input system status (key shifts/alts, ..).
   */
  void mouseMove ( Object sender, long when, int x, int y, int flags );

  /**
   * Mouse pointer was not moved for the specific time period.
   *
   * @param sender Originator of the event
   * @param when System time in milliseconds.
   * @param x Horizontal screen position in pixels.
   * @param y Vertical screen position in pixels.
   * @param flags Input system status (key shifts/alts, ..).
   */
  void mouseHover ( Object sender, long when, int x, int y, int flags );

  /**
   * Keyboard key was pressed/released.
   *
   * @param sender Originator of the event
   * @param when System time in milliseconds.
   * @param press Was it press or release?
   * @param ch Character represented by the key.
   * @param keyCode Key code.
   * @param flags Input system status (key shifts/alts, ..).
   */
  void keyboard ( Object sender, long when, boolean press, char ch, int keyCode, int flags );

}
