package cz.cuni.jagrlib.iface;

/**
 * General mappings to scalar integer range.
 *
 * @author  PE
 * @version 0.24 $Rev: 227 $ $Date: 2006-05-03 00:58:17 +0200 (st, 03 V 2006) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/IntFunction.java">IntFunction.java</a>
 */
public interface IntFunction extends Property
{
  /**
   * Compute the mapping: <b>double -&gt; int</b>.
   */
  int g ( double x );

  /**
   * Compute the mapping: <b>int -&gt; double</b>.
   */
  int g ( int x );

  /**
   * Compute the mapping: <b>double[2] -&gt; int</b>.
   */
  int g ( double x, double y );

  /**
   * Compute the mapping: <b>int[2] -&gt; int</b>.
   */
  int g ( int x, int y );

  /**
   * Compute the mapping: <b>double[3] -&gt; int</b>.
   */
  int g ( double x, double y, double z );

  /**
   * Compute the mapping: <b>int[3] -&gt; int</b>.
   */
  int g ( int x, int y, int z );

  /**
   * Compute the mapping: <b>double[] -&gt; int</b>.
   */
  int g ( double[] arg );

  /**
   * Compute the mapping: <b>int[] -&gt; int</b>.
   */
  int g ( int[] arg );

  /**
   * Returns domain of the mapping.
   *
   * @param  dom Domain array (<tt>dom[0]</tt> = Xmin, <tt>dom[1]</tt> = Xmax, etc.).
   * @return <tt>null</tt> if this service is not implemented.
   */
  double[] getDomain ( double[] dom );

  /**
   * Returns domain of the mapping.
   *
   * @param  dom Domain array (<tt>dom[0]</tt> = Xmin, <tt>dom[1]</tt> = Xmax, etc.).
   * @return <tt>null</tt> if this service is not implemented.
   */
  int[] getDomain ( int[] dom );

}
