package cz.cuni.jagrlib.iface;

/**
 * General interpolation / approximation interface (mapping from &lt;A,B&gt; to R<sup>N</sup>).
 *
 * @version 0.25 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
 * @since   0.10
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/Interpolation1D.java">Interpolation1D.java</a>
 */
public interface Interpolation1D extends Property
{
  /**
   * Compute the interpolation / approximation (front-end only).
   *
   * @param  t T parameter.
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean compute ( double t );

  /**
   * Compute scalar interpolation / approximation.
   *
   * @param  t T parameter.
   * @return Interpolated value.
   */
  double interpolate ( double t );

  /**
   * Compute vector interpolation / approximation.
   *
   * @param  t T parameter.
   * @param  res Pre-allocated result array.
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean interpolate ( double t, double[] res );

  /**
   * Returns domain of the T parameter.
   *
   * @param  dom Domain array (<tt>dom[0]</tt> = Tmin, <tt>dom[1]</tt> = Tmax).
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean getDomain ( double[] dom );

  /**
   * Sets domain of the T parameter.
   *
   * @param  dom Domain array (<tt>dom[0]</tt> = Tmin, <tt>dom[1]</tt> = Tmax).
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean setDomain ( double[] dom );

  /**
   * Sets a knot attribute (whatever it is) for value of T.
   *
   * @param  t T parameter.
   * @param  attr Attribute array (semanthics is not defined).
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean setAttribute ( double t, double[] attr );

}
