package cz.cuni.jagrlib.iface;

/**
 * General 2D interpolation / approximation interface (mapping from &lt;A,B&gt; x &lt;C,D&gt; to
 * R<sup>N</sup>).
 *
 * @version 0.25 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
 * @since   0.10
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/Interpolation2D.java">Interpolation2D.java</a>
 */
public interface Interpolation2D extends Property
{
  /**
   * Compute the interpolation / approximation (front-end only).
   *
   * @param  u U parameter.
   * @param  v V parameter.
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean compute ( double u, double v );

  /**
   * Compute scalar interpolation / approximation.
   *
   * @param  u U parameter.
   * @param  v V parameter.
   * @return Interpolated value.
   */
  double interpolate ( double u, double v );

  /**
   * Compute vector interpolation / approximation.
   *
   * @param  u U parameter.
   * @param  v V parameter.
   * @param  res Pre-allocated result array.
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean interpolate ( double u, double v, double[] res );

  /**
   * Returns domain of the [U,V] parameters.
   *
   * @param  dom Domain array (<tt>dom[0]</tt> = Umin, <tt>dom[1]</tt> = Umax,
   *             <tt>dom[2]</tt> = Vmin, <tt>dom[3]</tt> = Vmax).
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean getDomain ( double[] dom );

  /**
   * Sets domain of the [U,V] parameters.
   *
   * @param  dom Domain array (<tt>dom[0]</tt> = Umin, <tt>dom[1]</tt> = Umax,
   *             <tt>dom[2]</tt> = Vmin, <tt>dom[3]</tt> = Vmax).
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean setDomain ( double[] dom );

  /**
   * Sets a knot attribute (whatever it is) for value of [U,V].
   *
   * @param  u U parameter.
   * @param  v V parameter.
   * @param  attr Attribute array (semanthics is not defined).
   * @return <tt>true</tt> if this service is implemented.
   */
  boolean setAttribute ( double u, double v, double[] attr );

}
