package cz.cuni.jagrlib.iface;

/**
 * Interface for <b>K-D-tree</b> data structures.
 *
 * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/KDTree.java">KDTree.java</a>
 */
public interface KDTree extends Property
{
  /**
   * K-D-tree node for discrete data (Z<sup>K</sup> space).
   *
   * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
   * @see     <a href="../../../../../cz/cuni/jagrlib/iface/KDTree.java">KDTree.java</a>
   */
  class IntNode
  {
    /** Subtree cardinality (number of stored samples), if applicable. */
    public int cardinality;

    /** Lower bounds [x,y,z..]. Optional in non-root nodes. */
    public int[] lower;

    /** Upper bounds [x,y,z..]. Optional in non-root nodes. */
    public int[] upper;

    /** Splitting dimension. */
    public int dim;

    /** Splitting position = lowest coordinate of the right (upper) cell. */
    public int split;

    /** Node data: samples in leaf node or average value (color) in inner node.. */
    public int[] data;

    /** Left subtree (lower coordinates). */
    public IntNode left;

    /** Dividing - median - hyperplane (dim-1). */
    public IntNode median;

    /** Right subtree (greater coordinates). */
    public IntNode right;
  }

  /** Property name: construction mode (int). */
  String CONSTRUCTION_MODE  = "Construction mode";

  /** Construction mode: both splitted cells have equal size. */
  int MODE_SPACE_BALANCED   = 0;

  /** Construction mode: both splitted cells contain approx. equal number of samples. */
  int MODE_BREADTH_BALANCED = 1;

  /** Property name: use median plane? (boolean) */
  String USE_MEDIAN         = "Use median";

  /**
   * Builds the K-D-tree using actual settings.
   *
   * @see   #CONSTRUCTION_MODE
   * @see   #USE_MEDIAN
   */
  void buildTree ();

  /**
   * Returns actual root node.
   */
  IntNode getIntRoot ();

  /**
   * Tree is assigned from externally prepared data.
   *
   * @param  r The new root node.
   */
  void setRoot ( IntNode r );

  /**
   * Utilize (use) the given tree. There is possibility to enter the tree externally..
   *
   * @param  r The root node or {@code null} if internal tree should be used.
   */
  void utilizeTree ( IntNode r );

}
