package cz.cuni.jagrlib.iface;

/**
 * General interface for light storing. It can recieve light
 * as a photon, ray, pencils or radiosity. Also it can compute illumination
 * at some point (in some direction or all-directional) or at some element.
 *
 * @author Tomas Svab
 * @version 0.26 $Rev: 858 $ $Date: 2009-02-17 23:48:39 +0100 (út, 17 II 2009) $ $Author: Tomas $
 * @since   0.26
 */
public interface LightMap
{
  //==========================================================================
  //  Input methods:

  /** Add single photon. */
  void addPhoton ( double[] origin, double[] dir, float[] power );

  /** Add single ray. */
  void addRays ( double[] origin, double[] dir );

  /** Add single pencil. */
  void addPencil ( double[] center, double[][] dir, float[] radiance,
                   double distance );

  /** Add single contribution of energy to the some element. */
  void addRadiosity ( int handle, float[] amount );

  /**
   * Scales the power of all photons in the once they have been
   * emitted from the light source.
   */
  void scalePhotonPower ( float scale );

  //==========================================================================
  //  Illumination methods:

  /**
   * Computes irradiance at some point.
   *
   * @param position  Position of point in which is irradiance computing.
   * @param direction
   * @param rad       Pre-allocated array to hold resulting irradiance.
   * @return Resulting irradiance.
   */
  double[] radiance ( double[] position, double[] dir, double[] rad );

  /**
   * Computes irradiance at some point.
   *
   * @param position Position of point in which is irradiance computing.
   * @param irrad    Pre-allocated array to hold resulting irradiance.
   * @return Resulting irradiance.
   */
  double[] irradiance ( double[] position, double[] normal, double[] irrad );

  /** Computes the radiosity of the single element. */
  float[] radiosity ( int handle );

  //==========================================================================
  //  Getting method:

  /** Returns number of saved photons. */
  int getNumberPhotons ();

  /** Returns number of saved rays. */
  int getNumberRays ();

  /** Returns number of saved pencils. */
  int getNumberPencils ();

  /** Returns number of saved elements. */
  int getNumberElements ();

  /** Is light map full? */
  boolean isFull ();

}