package cz.cuni.jagrlib.iface;

import cz.cuni.jagrlib.*;

/**
 * Abstract interface represents microfacet distribution.
 *
 * Microfacets help to model rough surfaces as a heightfield with statistically
 * generated faces.
 *
 * @author  Tomas Svab
 * @version 0.26 $Rev: 819 $ $Date: 2008-11-09 11:39:57 +0100 (ne, 09 XI 2008) $ $Author: Tomas $
 * @since   0.26
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/MicrofacetDistribution.java">MicrofacetDistribution.java</a>
 */
public interface MicrofacetDistribution
{
  /**
   * Sample the given microfacet distribution.
   *
   * @param  mf   The {@link MicroFacet} (point on surface of some solid).
   * @param  in   Input direction (should look from the hit point).
   * @param  u    Random uniform number.
   * @param  v    Random uniform numbers.
   * @param  out  Output direction in world coordinates.
   * @param  brdf Color definition - {@code double[C]} array
   *              ({@code C} can be either 1 /for monochrome computing/, 3 /for RGB
   *              color system/ or greater /for more complex spectral color sampling/).
   * @return Probability density function.
   */
  double sample ( MicroFacet mf,
                  double[] in,
                  double u,
                  double v,
                  double[] out,
                  double[] brdf );

  /**
   * Return the probability density function.
   *
   * @param in  Input direction in local coordinates.
   * @param out Output direction in local coordinates.
   */
  double pdf ( double[] in, double[] out );

  /**
   * Return a microfacet distribution term.
   *
   * @param half Half-vector in local coordinates.
   */
  double D ( double[] half );
}