package cz.cuni.jagrlib.iface;

/**
 * Abstract 2D rectangle passing algorithm. From mathematical point of view it is a mapping
 * "&lt;0,M*N-1&gt; -&gt; &lt;0,M-1&gt; x &lt;0,N-1&gt;".
 *
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @since   0.04
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/Order2D.java">Order2D.java</a>
 */
public interface Order2D extends Property
{
  /** Order type property (int). */
  String ORDER_TYPE = "OrderType";

  /**
   * Sets the source rectangle size.
   * Initializes the pass algorithm. For both <b>Active</b> and
   * <b>Passive</b> modes.
   *
   * @param  _m Horizontal rectangle size (width).
   * @param  _n Vertical rectangle size (height).
   * @see    #init
   */
  void setSize ( int _m, int _n );

  /**
   * Re-initializes the pass algorithm.
   * For <b>Passive</b> pass mode.
   *
   * @see    #setSize
   */
  void init ();

  /**
   * Returns the next 2D point.
   * For <b>Passive</b> pass mode.
   *
   * @param  coords Pre-allocated array of size 2 (for [X,Y] coordinates).
   *                Can be {@code null}.
   * @return The next point's coordinates ([X,Y]).
   * @see    #init
   */
  int[] next ( int[] coords );

  /**
   * Anything to pass?
   * For <b>Passive</b> pass mode.
   *
   * @return {@code true} if there is at least one pixel to pass.
   * @see    #init
   * @see    #next
   */
  boolean isNext ();

  /**
   * Executes the whole rectangle pass.
   * For <b>Active</b> (="modal") pass mode.
   *
   * @see    #setSize
   */
  void pass ();

}
