package cz.cuni.jagrlib.iface;

import java.awt.Point;
import java.awt.geom.Point2D;

/**
 * Rendering interface for stroked 2D polygons (poly-lines).
 *
 * @version 0.25 $Rev: 243 $ $Date: 2006-05-08 01:22:21 +0200 (po, 08 V 2006) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/PolygonStrokeRender.java">PolygonStrokeRender.java</a>
 */
public interface PolygonStrokeRender extends PolygonRender
{
  /** Miter-limit property (double). */
  String LINE_MITER_LIMIT = "LineMiterLimit";

  /**
   * Sets default line width in pixels.
   *
   * @param  width New line width in pixels.
   * @return The old line width in pixels.
   */
  double setWidth ( double width );

  /**
   * Sets default miter limit in pixels.
   *
   * @param  miterLimit New miter limit in pixels.
   * @return The old miter limit in pixels.
   */
  double setMiterLimit ( double miterLimit );

  /**
   * Sets default join style.
   *
   * @param  joinStyle New join style.
   * @return The old join style.
   * @see    Render#LINE_JOIN_MITER
   * @see    Render#LINE_JOIN_ROUND
   * @see    Render#LINE_JOIN_BEVEL
   */
  int setJoinStyle ( int joinStyle );

  /**
   * Strokes the given polyline.
   *
   * @param  v Array of polygon vertices (can be closed, <tt>null</tt> can interrupt the sequence).
   */
  void strokePolyline ( Point[] v );

  /**
   * Strokes the given polyline.
   *
   * @param  v Array of polygon vertices (can be closed, <tt>null</tt> can interrupt the sequence).
   */
  void strokePolyline ( Point2D.Double[] v );

}
