package cz.cuni.jagrlib.iface;

/**
 * Simple interface for general property set/get.
 * General interface predecessor.
 *
 * @version 0.25 $Rev: 297 $ $Date: 2006-07-16 01:32:35 +0200 (ne, 16 VII 2006) $ $Author: pepca $
 * @since   0.05
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/Property.java">Property.java</a>
 */
public interface Property
{
  /**
   * Universal property (used mostly only with {@link #set} method) -
   * returns/prints object statistics.
   */
  String STATISTICS = "Statistics";

  /**
   * Universal property for text description of the object.
   * Used only with {@link #get} method.
   */
  String TEXT_DESCRIPTION = "Description";

  /**
   * Universal property for text logging.
   * {@link #get} method returns log string,
   * {@link #set} switches on/off logging mode.
   */
  String LOGGING = "Logging";

  /**
   * Sets the given property.
   * Some objects don't allow partial/sequential state changes - call {@link #commit}
   * at the and of each change-batch.
   *
   * @param  key Key string.
   * @param  value The new value.
   * @see    #commit()
   */
  void set ( String key, Object value );

  /**
   * Gets the given property.
   *
   * @param  key Key string.
   * @return The actual value or <tt>null</tt>.
   */
  Object get ( String key );

  /**
   * Commits all previous changes ({@link #set}) to the internal object state.
   * Non-mandatory.
   */
  void commit ();

}
