package cz.cuni.jagrlib.iface;

import cz.cuni.jagrlib.*;

/**
 * 3D scene representation for Ray-tracing.
 *
 * @version 0.26 $Rev: 841 $ $Date: 2009-01-10 14:02:22 +0100 (so, 10 I 2009) $ $Author: Tomas $
 * @since   0.11
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/RTScene.java">RTScene.java</a>
 * @see     MicroFacet
 * @see     LightSource
 * @see     BSSRDF
 * @see     RayGenerator
 */
public interface RTScene extends Intersectable, TimeDependent
{
  /**
   * Sets root node (assumes hierarchical scene representation based on {@link SceneNode}).
   */
  void setRoot ( SceneNode root );

  /**
   * Sets the camera object (ray-generator) for the scene.
   */
  void setCamera ( RayGenerator camera );

  /**
   * Retrieves the actual camera (ray-generator).
   *
   * @return Actual {@link RayGenerator} object (camera).
   */
  RayGenerator getCamera ();

  /**
   * Sets all the light sources from the given array.
   */
  void setLights ( LightSource[] l );

  /**
   * Retrieves all light sources from the scene.
   *
   * @return Array of light sources.
   * @see    #getLightsToMicroFacet
   */
  LightSource[] getLights ();

  /**
   * Retrieves light sources which light up the given micro-facet.
   *
   * @param  mf Micro-facet which is to be lighted.
   * @param  order Order of this sample inside the actual pixel.
   * @param  total Total number of samples in the actual pixel.
   * @return Array of light sources ({@code null} marks end of data).
   * @see    #getLights
   */
  LightSource[] getLightsToMicroFacet ( MicroFacet mf, int order, int total );

  /** Retrieves background color (used when a ray doesn't hit anything). */
  double[] getBackground ();

}