package cz.cuni.jagrlib.iface;

/**
 * Generator of 3D rays (projection transformation, camera).
 *
 * @version 0.26 $Rev: 443 $ $Date: 2007-05-05 22:43:59 +0200 (so, 05 V 2007) $ $Author: pepca $
 * @since   0.11
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/RayGenerator.java">RayGenerator.java</a>
 * @see     RTScene
 */
public interface RayGenerator extends Property
{
  /**
   * Sets aspect ratio of the target image.
   * Default aspect ratio (if not set) should be <b>4/3</b>.
   *
   * @param  aspect Aspect ratio = width / height. Uses real coordinates.
   */
  void setAspectRatio ( double aspect );

  /**
   * Returns boundary values for projection-plane coordinates (ray-coordinates).
   *
   * @param  pre Pre-allocated array to hold results ({@code double[4]} array). Can be
   *             {@code null}.
   * @return X and Y coordinate bounds: {@code result[0]} .. X<sub>min</sub>,
   *         {@code result[1]} .. X<sub>max</sub>,
   *         {@code result[2]} .. Y<sub>min</sub>,
   *         {@code result[3]} .. Y<sub>max</sub>.
   * @see    #getRay
   */
  double[] getViewport ( double[] pre );

  /**
   * Ray-generator method.
   *
   * @param  x X coordinate in the projection plane.
   * @param  y Y coordinate in the projection plane.
   * @param  P0 Pre-allocated {@code double[3]} (or {@code double[4]}) array to hold
   *            coordinates of the <b>ray origin</b>.
   * @param  P1 Pre-allocated {@code double[3]} (or {@code double[4]}) array to hold
   *            <b>direction vector</b> of the ray.
   * @return {@code true} if the ray was successfully generated.
   */
  boolean getRay ( double x, double y, double[] P0, double[] P1 );

  /**
   * Ray-generator method. Passes parameters for hidden sampling.
   *
   * @param  x X coordinate in the projection plane.
   * @param  y Y coordinate in the projection plane.
   * @param  order Order of this sample inside the actual pixel.
   * @param  total Total number of samples in the actual pixel.
   * @param  P0 Pre-allocated {@code double[3]} (or {@code double[4]}) array to hold
   *            coordinates of the <b>ray origin</b>.
   * @param  P1 Pre-allocated {@code double[3]} (or {@code double[4]}) array to hold
   *            <b>direction vector</b> of the ray.
   * @return {@code true} if the ray was successfully generated.
   */
  boolean getRay ( double x, double y, int order, int total, double[] P0, double[] P1 );

}
