package cz.cuni.jagrlib.iface;

/**
 * Abstract rendering interface (for 1D, 2D and 3D objects).
 *
 * @version 0.25 $Rev: 396 $ $Date: 2007-01-27 03:39:06 +0100 (so, 27 I 2007) $ $Author: pepca $
 * @since   0.01
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/Render.java">Render.java</a>
 */
public interface Render extends Property
{
  /** Line join property (int). */
  String LINE_JOIN = "LineJoin";

  /** Line join with no overlap (BitMask output only). */
  int LINE_JOIN_DISJOINT = 0;

  /** Line join with one-pixel overlap (BitMask output only). */
  int LINE_JOIN_OVERLAP = 1;

  /** Triangle join style. */
  int LINE_JOIN_MITER = 2;

  /** Round join style. */
  int LINE_JOIN_ROUND = 3;

  /** Bevel (cap) join style. */
  int LINE_JOIN_BEVEL = 4;

  /** Line cap property (int): for thick and anti-aliased rendering only. */
  String LINE_CAP = "LineCap";

  /** Line cap w/o any projection beyond the end of the path. */
  int LINE_CAP_BUTT = 0;

  /** Semicircular line cap. */
  int LINE_CAP_ROUND = 1;

  /** Projecting square cap .. projection distance is half the line width */
  int LINE_CAP_SQUARE = 2;

  /** Line width property (double): for thick and anti-aliased rendering only. */
  String LINE_WIDTH = "LineWidth";

  /** Projection matrix (TrMatrix): for 3D rendering. */
  String PROJECTION = "Projection";

  /** 3D rendering style (int): for 3D rendering. */
  String RENDER_STYLE = "RenderStyle";

  /** Rendering style: wire-frame / line (w/o face filling). */
  int RENDER_STYLE_LINE    = 0;

  /** Rendering style: flat shading (faces are filled using constant color). */
  int RENDER_STYLE_FLAT    = 1;

  /** Rendering style: Gouraud shading (color is interpolated from vertices). */
  int RENDER_STYLE_GOURAUD = 2;

  /** Rendering style: Phong shading (normal vectors are interpolated from vertices). */
  int RENDER_STYLE_PHONG   = 3;

  /** Rendergin style: texture mapping (can be used together with previous styles). */
  int RENDER_STYLE_TEXTURE = 4;
}
