package cz.cuni.jagrlib.iface;

import cz.cuni.jagrlib.*;

/**
 * Rendering interface for 3D scenes.
 *
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/Render3D.java">Render3D.java</a>
 */
public interface Render3D extends Render, Breakable
{
  /** Depth-test comparison: less values are accepted. */
  int DEPTH_LESS    = 0;

  /** Depth-test comparison: less or equal values are accepted. */
  int DEPTH_LEQUAL  = 1;

  /** Depth-test comparison: greater or equal values are accepted. */
  int DEPTH_GEQUAL  = 2;

  /** Depth-test comparison: greater values are accepted. */
  int DEPTH_GREATER = 3;

  /** Sets type of depth-test comparison ({@code DEPTH_*} constants). */
  void setDepthComparison ( int comp );

  /**
   * 3D rendering using actual parameters.
   *
   * @see #setViewport
   * @see #setModelView
   * @see #setProjection(TrMatrix)
   * @see #setRenderStyle(int)
   * @see #render(TrMatrix,TrMatrix,int)
   */
  void render ();

  /**
   * 3D rendering using the given projection matrix.
   *
   * @param mv Local model-view matrix.
   * @param proj Local projection matrix.
   * @param style Local rendering style.
   * @see #render()
   */
  void render ( TrMatrix mv, TrMatrix proj, int style );

  /**
   * Sets actual rendering style.
   *
   * @param style New rendering style.
   * @return Old rendering style.
   * @see #RENDER_STYLE_LINE
   * @see #RENDER_STYLE_FLAT
   */
  int setRenderStyle ( int style );

  /**
   * Sets actual viewport size.
   * The same semantics as {@code glSetViewport()}.
   *
   * @param  x0 Viewport origin (x-coord).
   * @param  y0 Viewport origin (y-coord).
   * @param  width Viewport width in pixels.
   * @param  height Viewport height in pixels.
   * @see    #setProjection
   */
  void setViewport ( int x0, int y0, int width, int height );

  /**
   * Sets actual model-view matrix.
   *
   * @param mv New model-view matrix.
   */
  void setModelView ( TrMatrix mv );

  /**
   * Sets actual projection matrix.
   *
   * @param  proj New projection matrix.
   * @see    #setViewport
   */
  void setProjection ( TrMatrix proj );

  /**
   * Sets actual projection parameters (non-mandatory).
   *
   * @param view Viewing vector (from camera to the scene).
   * @param up Up vector (should always point up on the screen).
   * @param lookAt Point in the middle of the view.
   * @param zoom Zoom factor (camera - lookAt distance, element size on the screen, etc.).
   * @return {@code true} if the method is implemented.
   */
  boolean setProjection ( double[] view, double[] up, double[] lookAt, double zoom );

}
