package cz.cuni.jagrlib.iface;

/**
 * Data object holding system of linear equations (SLE) data - writtable variant.
 *
 * Both input (matrix of coefficients and right-hand-side vector) and
 * output (solution vector) data are stored here.
 *
 * For actual data storage (full or sparse SLE matrix).
 *
 * @author  PE
 * @version 0.26 $Rev: 757 $ $Date: 2008-05-19 01:09:45 +0200 (po, 19 V 2008) $ $Author: pepca $
 * @since   0.26
 */
public interface SLEDataStore extends SLEData
{
  /**
   * Initializes the SLE.
   * All values will be set to {@code 0.0}.
   */
  void init ( int rows, int columns );

  /**
   * Sets a single matrix coefficient.
   * Preferred metod in sparse-matrix implementations..
   */
  void setCoeff ( int row, int col, double value );

  /** Sets the whole matrix row. */
  void setRow ( int row, double[] values );

  /** Sets the whole matrix column. */
  void setColumn ( int col, double[] values );

  /** Sets a single element of the right-side vector. */
  void setRight ( int row, double value );

  /** Sets the whole right-side vector. */
  void setRight ( double[] values );

  //==========================================================================
  //  Additional information:

  /** Sets a single element weight (radiosity: element area). */
  void setWeight ( int i, double value );

  /** Sets the whole weight vector. */
  void setWeight ( double[] values );

  /** Sets a single reflectance (radiosity: element albedo). */
  void setReflectance ( int i, double value );

  /** Sets the whole reflectance vector. */
  void setReflectance ( double[] reflectance );
}
