package cz.cuni.jagrlib.iface;

/**
 * Solver API for system of linear equations (SLE).
 * Solver usually reads data using the {@link SLEData} interface from another module..
 *
 * @author  PE, Tomas "Source" Svab
 * @version 0.26 $Rev: 747 $ $Date: 2008-05-17 15:21:58 +0200 (so, 17 V 2008) $ $Author: pepca $
 * @since   0.26
 * @see     SLEData
 * @see     SLEDataStore
 */
public interface SLESolver extends Property
{
  /** Property identifier: over-relaxation factor (non-mandatory). */
  String OMEGA = "Omega";

  /** Property identifier: number of performed iteration steps (if applicable). */
  String STEPS = "Steps";

  /** Property identifier: sum of all residual entries - accuracy of solution (non-mandatory). */
  String TOTAL_RESIDUAL = "Residual";

  /** Sets solver accuracy (whatever it means). Returns the old value.. */
  double setEpsilon ( double epsilon );

  /**
   * Solve the whole system en bloc.
   *
   * @param  save Solution will be saved into the associated {@link SLEDataStore}.
   */
  void solve ( boolean save );

  /** Reset iterative solution algorithm (if applicable). */
  void reset ();

  /**
   * Refine the solution performing several iterations.
   *
   * @param  maxIterations Number of iterations requested.
   * @param  save Solution will be saved into the associated {@link SLEDataStore}.
   * @return Achieved precision (if less than epsilon, the system has converged).
   */
  double refine ( int maxIterations, boolean save );

  /**
   * Input data was changed, solver should adapt to it.
   * Usually {@link #solve} or {@link #refine} will be called afterwards..
   */
  void update ();

  /** Reads a single unknown (element of solution vector). Non-mandatory. */
  double getSolution ( int col );

  /** Reads the whole solution vector. Non-mandatory. */
  double[] getSolution ( double[] result );

  //==========================================================================
  //  Multi-component systems:

  /** Get actual component number. */
  int actualComponent ();

  /** Set actual component (non-mandatory). */
  void setComponent ( int c );
}
