package cz.cuni.jagrlib.iface;

/**
 * Scalar quantizer.
 *
 * @version 0.26 $Rev: 456 $ $Date: 2007-05-19 01:03:36 +0200 (so, 19 V 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/ScalarQuantizer.java">ScalarQuantizer.java</a>
 */
public interface ScalarQuantizer extends Property, PersistentParamsBinary
{
  /**
   * Set actual quantizer variant (context).
   *
   * @param  variant Variant number (from {@code 0}).
   * @return Old variant number.
   * @see    #setBounds
   */
  int setVariant ( int variant );

  /**
   * Sets input and output bounds.
   *
   * @param  inMin Input value minimum.
   * @param  inMax Input value maximum.
   * @param  outLevels Number of output levels.
   * @see    #setVariant
   */
  void setBounds ( double inMin, double inMax, int outLevels );

  /**
   * Quantization (floating-point form).
   *
   * @param  in Input floating-point value.
   * @return Quantized value (or {@code -1} if failed).
   * @see    #quantize(int)
   */
  int quantize ( double in );

  /**
   * Quantization (integer form).
   *
   * @param  in Input integer value.
   * @return Quantized value (or {@code -1} if failed).
   * @see    #quantize(double)
   */
  int quantize ( int in );

  /**
   * Dequantization = reconstruction (floating-point form).
   *
   * @param  quant Quantized value.
   * @return Source (reconstructed) value.
   * @see    #dequantizeInt(int)
   * @see    #quantize(double)
   */
  double dequantizeDouble ( int quant );

  /**
   * Dequantization = reconstruction (integer form).
   *
   * @param  quant Quantized value.
   * @return Source (reconstructed) value.
   * @see    #dequantizeDouble(int)
   * @see    #quantize(int)
   */
  int dequantizeInt ( int quant );

}
