package cz.cuni.jagrlib.iface;

/**
 * Abstract interface for the "Wheel of Fortune" - an ordered array of
 * frequencies used for entropy encoding.
 *
 * @author  PE
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/iface/WheelOfFortune.java">WheelOfFortune.java</a>
 */
public interface WheelOfFortune extends Property
{
  /**
   * Changes total number of symbols (intervals).
   * Keeps previous frequencies (truncated or padded with the default value).
   *
   * @param  _symbols New number of symbols.
   * @see    #getSymbols
   */
  void setSymbols ( int _symbols );

  /**
   * Returns total number of symbols (intervals).
   *
   * @return Number of symbols.
   */
  int getSymbols ();

  /**
   * Sets frequencies of all symbols at once.
   * Can be used for context re-initialization ({@code null} parameter).
   *
   * @param  _freq Array of new frequencies.
   *               Can be {@code null} for context re-initialization.
   * @see    #set(int,long)
   * @see    EntropyHistogram#decimate
   */
  void set ( long[] _freq );

  /**
   * Sets a single symbol's frequency.
   *
   * @param  _symbol Symbol code.
   * @param  _freq New frequency of the symbol.
   * @see    #set(long[])
   * @see    EntropyHistogram#decimate
   */
  void set ( int _symbol, long _freq );

  /**
   * Returns the frequency sum of all symbols.
   * Same as {@code left( getSymbols() )}, but might be more effective.
   *
   * @return The total frequency sum.
   * @see    #left
   * @see    #get
   * @see    #convert
   */
  long total ();

  /**
   * Returns the start of the symbol's cummulative frequency interval
   * (the frequency sum of all preceding symbols).
   *
   * @param  _symbol Symbol code.
   * @return The sum of all preceding symbol frequencies.
   * @see    #total
   * @see    #get
   * @see    #convert
   */
  long left ( int _symbol );

  /**
   * Returns the frequency of the given symbol.
   * Same as {@code left( _symbol + 1 ) - left( _symbol )}.
   *
   * @param  _symbol Symbol code.
   * @return The frequency of that symbol.
   * @see    #total
   * @see    #left
   * @see    #convert
   */
  long get ( int _symbol );

  /**
   * Converts a frequency sum to the corresponding symbol.
   *
   * @param  _sum Frequency sum of the unknown symbol.
   * @return The symbol which has {@code _sum} in it's cummulative frequency interval.
   * @see    #total
   * @see    #left
   * @see    #get
   */
  int convert ( long _sum );

}
