package cz.cuni.jagrlib.piece;

import java.awt.*;
import javax.swing.*;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Window able to display general AWT graphics.
 *
 * @version 0.26 $Rev: 431 $ $Date: 2007-04-29 22:42:22 +0200 (ne, 29 IV 2007) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/piece/AWTWindow.java">AWTWindow.java</a>
 */
public class AWTWindow extends DefaultGraphicsViewer
{
  /** Custom component which receives all AWT drawing. */
  protected class AWTCanvas extends JComponent
  {
    private static final long serialVersionUID = 1L;

    @Override
    protected void paintComponent ( Graphics g )
    {
      if ( gr != null )
        gr.paint( g );
      else
      {
        g.setColor( getBackground() );
        g.fillRect( 0, 0, getWidth(), getHeight() );
      }

        // draw HUD:
      if ( hudSet != null )
      {
        g.setXORMode( Color.WHITE );
        for ( HudPrimitive pr : hudSet.values() )
          pr.draw( g );
      }
    }

    @Override
    public Dimension getPreferredSize ()
    {
      return new Dimension( width, height );
    }

    @Override
    public Dimension getMinimumSize ()
    {
      return new Dimension ( 32, 32 );
    }

  }

  //==========================================================================
  //  Data:

  /** Width of rendering canvas (in pixels). */
  protected int width = 256;

  /** Height of rendering canvas (in pixels). */
  protected int height = 256;

  /** Actual AWT graphics module (rendering source). */
  AWTGraphics gr;

  //==========================================================================
  //  Support routines:

  /** Returns drawing component or {@code null} if failed. */
  protected JComponent getCanvas ()
  {
    gr = (AWTGraphics)getInterface( PL_OUTPUT, IFACE+"AWTGraphics" );
    if ( gr == null ) return null;

    return new AWTCanvas();
  }

  //==========================================================================
  //  Interface GraphicsViewer:

  //==========================================================================
  //  Interface Property:

  public final static String CANVAS_WIDTH  = "Canvas width";
  public final static String CANVAS_HEIGHT = "Canvas height";

  /**
   * Sets the given property.
   *
   * @param  key Key string.
   * @param  value The new value.
   */
  public void set ( String key, Object value )
  {
    if ( key == null || value == null ) return;
        // WINDOW_TITLE:
    if ( key.compareTo( WINDOW_TITLE ) == 0 )
    {
      frameTitle = value.toString();
      if ( frame != null )
        frame.setTitle( frameTitle );
      return;
    }
      // CANVAS_WIDTH:
    if ( key.compareTo(CANVAS_WIDTH) == 0 )
    {
      width = intProperty( value, width, 32, 4096 );
      return;
    }
      // CANVAS_HEIGHT:
    if ( key.compareTo(CANVAS_HEIGHT) == 0 )
    {
      height = intProperty( value, height, 32, 4096 );
      return;
    }
  }

  /**
   * Gets the given property.
   *
   * @param  key Key string.
   * @return The actual value or {@code null}.
   */
  public Object get ( String key )
  {
    if ( key == null )
      return null;
    if ( key.compareTo(WINDOW_TITLE) == 0 )
    {
      if ( frame == null ) return null;
      return frame.getTitle();
    }
    if ( key.compareTo(CANVAS_WIDTH) == 0 )
      return width;
    if ( key.compareTo(CANVAS_HEIGHT) == 0 )
      return height;
    return null;
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "AWT graphics viewer";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "GraphicsViewerToAWTGraphics";

  /** Object description. */
  private final static String DESCRIPTION = "AWT graphics is rendered in simple Swing window.";

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug(     PL_INPUT,   IFACE+"GraphicsViewer" );
      t.newInputPlug(     PL_TRIGGER, IFACE+"Trigger" );
      t.newOutputPlug(    PL_OUTPUT,  IFACE+"AWTGraphics" );
      t.newOptOutputPlug( PL_DIRECT,  IFACE+"InputListener" );
        // Property:
      t.propBegin( CANVAS_WIDTH, TYPE_INTEGER, "Canvas width in pixels", true );
        t.propDefault( 256 );
        t.propBounds(  32, 4096 );
      t.propEnd();
      t.propBegin( CANVAS_HEIGHT, TYPE_INTEGER, "Canvas height in pixels", true );
        t.propDefault( 256 );
        t.propBounds(  32, 4096 );
      t.propEnd();
      t.propBegin( WINDOW_TITLE, TYPE_STRING, "Window title", true );
        t.propDefault( "AWT Graphics" );
      t.propEnd();
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
