package cz.cuni.jagrlib.piece;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Classificator for overwritting flood-fill.
 *
 * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/piece/OverwriteClassificator.java">OverwriteClassificator.java</a>
 */
public class OverwriteClassificator extends Piece implements BitMask
{
  //==========================================================================
  //  Data:

  /** Overwritten color. */
  protected int[] color;

  /** Working color array. */
  protected int[] aColor;

  /** Accelerator: number of color bands of underlying {@link RasterGraphics}. */
  protected int bands = 1;

  /** Width of the underlying image. */
  protected int width = 512;

  /** Height of the underlying image. */
  protected int height = 512;

  /** Accelerator: underlying raster image. */
  protected RasterGraphics image;

  //==========================================================================
  //  Interface BitMask:

  /**
   * {@link BitMask} (re-)initialization.
   *
   * @param  x Width of a new bitmask.
   * @param  y Height of a new bitmask.
   */
  public void init ( int x, int y )
  {
    init();
    width  = x;
    height = y;
  }

  /**
   * {@link BitMask} re-initialization (keeps current bitmask size - if the size
   * is relevant).
   */
  public void init ()
  {
    image  = (RasterGraphics)getInterface( PL_OUTPUT, IFACE+"RasterGraphics" );
    width  = image.getWidth();
    height = image.getHeight();
    bands  = image.getBands();
    color  = new int[ bands ];
    aColor = new int[ bands ];
  }

  /**
   * Sets the binary set operation (used in all {@code set*()} methods).
   *
   * @param  _op Binary set operation ({@code BinaryOperation.BIN_OP_*} constant).
   * @return The old binary set operation.
   * @see    cz.cuni.jagrlib.BinaryOperation Binary operations
   */
  public int setOperation ( int _op )
  {
    return 0;
  }

  /**
   * Sets the given pixel's value to {@code true} = "painted".
   * Accepts current <b>binary set operation</b>.
   *
   * @param  x X coordinate of a pixel.
   * @param  y Y coordinate of a pixel.
   */
  public void setPixel ( int x, int y )
  {
    image.getPixel( x, y, color );
  }

  /**
   * Sets the given pixel's value (ignores current <b>binary set operation</b>).
   *
   * @param  x X coordinate of a pixel.
   * @param  y Y coordinate of a pixel.
   * @param  value New pixel's value.
   */
  public void putPixel ( int x, int y, boolean value )
  {
  }

  /**
   * Returns the pixel's value.
   *
   * @param  x X coordinate of a pixel.
   * @param  y Y coordinate of a pixel.
   * @return Pixel value ({@code false} for off-canvas access).
   */
  public boolean getPixel ( int x, int y )
  {
    if ( x < 0 || x >= width ||
         y < 0 || y >= height ) return false;

    image.getPixel( x, y, aColor );
    for ( int i = 0; i < bands; i++ )
      if ( aColor[i] != color[i] ) return false;

    return true;
  }

  /**
   * Sets the horizontal line from [min(x1,x2),y] to [max(x1,x2)-1,y].
   * Accepts current <b>binary set operation</b>.
   *
   * @param  x1 X coordinate of the starting pixel.
   * @param  x2 X coordinate of the first pixel after the line.
   * @param  y Common Y coordinate of the line.
   */
  public void setHLine ( int x1, int x2, int y )
  {
  }

  /**
   * Sets the horizontal line's values (ignores current <b>binary set operation</b>).
   *
   * @param  x1 X coordinate of the starting pixel.
   * @param  x2 X coordinate of the first pixel after the line.
   * @param  y Common Y coordinate of the line.
   * @param  values New pixels' values.
   */
  public void putHLine ( int x1, int x2, int y, boolean[] values )
  {
  }

  /**
   * Returns the pixels' values for the given horizontal line.
   *
   * @param  x1 X coordinate of the starting pixel.
   * @param  x2 X coordinate of the first pixel after the line.
   * @param  y Common Y coordinate of the line.
   * @param  values Returned values in {@code boolean[]} array ({@code false} for
   *                off-canvas access).
   */
  public void getHLine ( int x1, int x2, int y, boolean[] values )
  {
  }

  /**
   * Sets the rectangle from [min(x1,x2),min(y1,y2)] to [max(x1,x2)-1,max(y1,y2)-1].
   * Accepts current <b>binary set operation</b>.
   *
   * @param  x1 X coordinate of the upper left corner.
   * @param  y1 Y coordinate of the upper left corner.
   * @param  x2 X coordinate of the lower right corner (outside pixel).
   * @param  y2 Y coordinate of the upper left corner (outside pixel).
   */
  public void setRectangle ( int x1, int y1, int x2, int y2 )
  {
  }

  /**
   * Sets the rectangle's values (ignores current <b>binary set operation</b>).
   *
   * @param  x1 X coordinate of the upper left corner.
   * @param  y1 Y coordinate of the upper left corner.
   * @param  x2 X coordinate of the lower right corner (outside pixel).
   * @param  y2 Y coordinate of the upper left corner (outside pixel).
   * @param  values New pixels' values.
   */
  public void putRectangle ( int x1, int y1, int x2, int y2, boolean[][] values )
  {
  }

  /**
   * Returns the pixels' values for the given rectangle.
   *
   * @param  x1 X coordinate of the upper left corner.
   * @param  y1 Y coordinate of the upper left corner.
   * @param  x2 X coordinate of the lower right corner (outside pixel).
   * @param  y2 Y coordinate of the upper left corner (outside pixel).
   * @param  values Returned values in {@code boolean[][]} array ({@code false} for
   *                off-canvas access).
   */
  public void getRectangle ( int x1, int y1, int x2, int y2, boolean[][] values )
  {
  }

  /**
   * Bit-block-transfer routine: copies the source rectangle [sx,sy,width,height] to
   * the new location [dx,dy]. Binary set operation is ignored.
   *
   * @param  dx X coordinate of the upper left destination corner.
   * @param  dy Y coordinate of the upper left destination corner.
   * @param  sx X coordinate of the upper left source corner.
   * @param  sy Y coordinate of the upper left source corner.
   * @param  width Rectangle width.
   * @param  height Rectangle height.
   */
  public void bitBlt ( int dx, int dy, int sx, int sy, int width, int height )
  {
  }

  /**
   * {@link BitMask} enumeration.
   *
   * @return The {@link BitMaskEnumerator} object instance.
   */
  public BitMaskEnumerator enumerator ()
  {
    return null;
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "OverwriteClassificator";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "BitMaskToRasterGraphics";

  /** Object description. */
  private final static String DESCRIPTION = "Classificator predicate (setPixel() resets the overwritten color).";

  /** Object category. */
  protected final static String CATEGORY = C_2D + '.' + C_DRAW + '.' + C_FILL + '.' + C_INTEGER;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug(  PL_INPUT,  IFACE+"BitMask" );
      t.newOutputPlug( PL_OUTPUT, IFACE+"RasterGraphics" );
        // Property:
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
