package cz.cuni.jagrlib.piece;

import java.util.*;
import java.awt.*;
import java.awt.image.*;
import javax.swing.*;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Raster image preview window.
 *
 * @version 0.26 $Rev: 452 $ $Date: 2007-05-09 12:37:20 +0200 (st, 09 V 2007) $ $Author: pepca $
 * @since   0.13
 * @see     <a href="../../../../../cz/cuni/jagrlib/piece/RasterImagePreview.java">RasterImagePreview.java</a>
 */
public class RasterImagePreview extends DefaultGraphicsViewer
{
  /** Custom component which renders raster image. */
  protected class RasterCanvas extends JComponent
  {
    private static final long serialVersionUID = 1L;

    /** Rendered raster image. */
    protected BufferedImage im;

    public RasterCanvas ( BufferedImage image )
    {
      im = image;
    }

    @Override
    protected void paintComponent ( Graphics g )
    {
      if ( blackBackground )
      {
        g.setColor( Color.BLACK );
        g.fillRect( 0, 0, getWidth(), getHeight() );
      }
      if ( im != null )
        g.drawImage( im, 0, 0, null );

        // draw HUD:
      if ( hudSet != null )
      {
        Iterator< HudPrimitive > prit = hudSet.values().iterator();
        g.setXORMode( Color.WHITE );
        while ( prit.hasNext() )
          prit.next().draw( g );
      }
    }

    @Override
    public Dimension getPreferredSize ()
    {
      int width  = (im != null) ? im.getWidth( null )  : 12;
      int height = (im != null) ? im.getHeight( null ) : 12;
      return new Dimension( width, height );
    }

    @Override
    public Dimension getMinimumSize ()
    {
      return new Dimension( 12, 12 );
    }

  }

  //==========================================================================
  //  Data:

  /** Optional black background for RasterGraphics.MODE_RGBA images */
  protected boolean blackBackground = false;

  //==========================================================================
  //  Support routines:

  /** Returns drawing component or {@code null} if failed. */
  protected JComponent getCanvas ()
  {
    RasterGraphics g = (RasterGraphics)getInterface( PL_OUTPUT, IFACE+"RasterGraphics" );
    if ( g == null ) return null;

    return new RasterCanvas( g.getBufferedImage() );
  }

  //==========================================================================
  //  Interface Property:

  public final static String AUTO_START = "Automatic";

  /**
   * Sets the given property.
   *
   * @param  key Key string.
   * @param  value The new value.
   */
  public void set ( String key, Object value )
  {
    if ( key == null || value == null ) return;

      // WINDOW_TITLE:
    if ( key.compareTo( WINDOW_TITLE ) == 0 )
    {
      frameTitle = value.toString();
      if ( frame != null )
        frame.setTitle( frameTitle );
      return;
    }
      // BLACK_BACKGROUND:
    if ( key.compareTo(BLACK_BACKGROUND) == 0 )
    {
      boolean newValue = booleanProperty( value, blackBackground );
      boolean changed = (newValue != blackBackground);
      blackBackground = newValue;
      if ( changed &&
           canvas != null )
        canvas.repaint();
      return;
    }
      // AUTO_START:
    if ( key.compareTo( AUTO_START ) == 0 )
    {
      autoStart = booleanProperty( value, autoStart );
      return;
    }
  }

  /**
   * Gets the given property.
   *
   * @param  key Key string.
   * @return The actual value or {@code null}.
   */
  public Object get ( String key )
  {
    if ( key == null ) return null;

    if ( key.compareTo(WINDOW_TITLE) == 0 )
      return( frame == null ? null : frame.getTitle() );
    if ( key.compareTo(BLACK_BACKGROUND) == 0 )
      return blackBackground;
    if ( key.compareTo(AUTO_START) == 0 )
      return autoStart;

    return null;
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "JFrame viewer for raster image output";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "GraphicsViewerToRasterGraphics";

  /** Object description. */
  private final static String DESCRIPTION = "Raster image is previewed in simple Swing window.";

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug(     PL_INPUT,   IFACE+"GraphicsViewer" );
      t.newInputPlug(     PL_TRIGGER, IFACE+"Trigger" );
      t.newOutputPlug(    PL_OUTPUT,  IFACE+"RasterGraphics" );
      t.newOptOutputPlug( PL_DIRECT,  IFACE+"InputListener" );
        // Property:
      t.propBegin( WINDOW_TITLE, TYPE_STRING, "Window title", true );
        t.propDefault( "Raster Image" );
      t.propEnd();
      t.propBegin( BLACK_BACKGROUND, TYPE_BOOLEAN, "Force black background?", true );
        t.propDefault( false );
      t.propEnd();
      t.propBegin( AUTO_START, TYPE_BOOLEAN, "Force automatic start of preview window?", true );
        t.propDefault( false );
      t.propEnd();
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
