package cz.cuni.jagrlib.piece;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Simple roulette-wheel: set of intervals with equal size (i.e. equal probability).
 *
 * @author  PE
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/piece/StraightRoulette.java">StraightRoulette.java</a>
 */
public class StraightRoulette extends Piece implements WheelOfFortune
{
  //==========================================================================
  //  Data:

  /** Number of intervals. */
  protected int intervals = 256;

  //==========================================================================
  //  Interface WheelOfFortune:

  /**
   * Changes total number of symbols (intervals).
   *
   * @param  _symbols New number of symbols.
   * @see    #getSymbols
   */
  public void setSymbols ( int _symbols )
  {
    intervals = _symbols;
  }

  /**
   * Returns total number of symbols (intervals).
   *
   * @return Number of symbols.
   */
  public int getSymbols ()
  {
    return intervals;
  }

  /**
   * Sets frequencies of all symbols at once.
   * Can be used for context re-initialization ({@code null} parameter).
   *
   * @param  _freq Array of new frequencies.
   *               Can be {@code null} for context re-initialization.
   * @see    #set(int,long)
   * @see    EntropyHistogram#decimate
   */
  public void set ( long[] _freq )
  {
  }

  /**
   * Sets a single symbol's frequency.
   *
   * @param  _symbol Symbol code.
   * @param  _freq New frequency of the symbol.
   * @see    #set(long[])
   * @see    EntropyHistogram#decimate
   */
  public void set ( int _symbol, long _freq )
  {
  }

  /**
   * Returns the frequency sum of all symbols.
   * Same as {@code left( getSymbols() )}, but might be more effective.
   *
   * @return The total frequency sum.
   * @see    #left
   * @see    #get
   * @see    #convert
   */
  public long total ()
  {
    return intervals;
  }

  /**
   * Returns the start of the symbol's cummulative frequency interval
   * (the frequency sum of all preceding symbols).
   *
   * @param  _symbol Symbol code.
   * @return The sum of all preceding symbol frequencies.
   * @see    #total
   * @see    #get
   * @see    #convert
   */
  public long left ( int _symbol )
  {
    return _symbol;
  }

  /**
   * Returns the frequency of the given symbol.
   * Same as {@code left( _symbol + 1 ) - left( _symbol )}.
   *
   * @param  _symbol Symbol code.
   * @return The frequency of that symbol.
   * @see    #total
   * @see    #left
   * @see    #convert
   */
  public long get ( int _symbol )
  {
    return 1L;
  }

  /**
   * Converts a frequency sum to the corresponding symbol.
   *
   * @param  _sum Frequency sum of the unknown symbol.
   * @return The symbol which has {@code _sum} in it's cummulative frequency interval.
   * @see    #total
   * @see    #left
   * @see    #get
   */
  public int convert ( long _sum )
  {
    return (int)_sum;
  }

  //==========================================================================
  //  Module registration

  /** Object name. */
  private final static String NAME = "StraightRoulette";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "WheelOfFortuneTo";

  /** Object description. */
  private final static String DESCRIPTION = "Static straight roulette wheel (set of equally probable intervals).";

  /** Object category. */
  protected final static String CATEGORY = C_DATA + '.' + C_COMPRESSION + ".arithmetic";

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug( PL_OUTPUT, IFACE+"WheelOfFortune" );
        // Property:
     }
   return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }
}
