package cz.cuni.jagrlib.reg;

import java.awt.*;
import java.awt.event.*;
import java.util.*;

/**
 * HashMap for channels.
 * Into these HashMap it is posible insert only objects of {@link InfoChannel}.
 *
 * @author  Jan Kostlivy
 * @version 0.25 $Rev: 378 $ $Date: 2006-12-25 22:12:29 +0100 (po, 25 XII 2006) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/reg/HashMapChannels.java">HashMapChannels.java</a>
 * @see     HashMap
 */
public class HashMapChannels extends HashMap< Integer, InfoChannel >
{
  private static final long serialVersionUID    = 1L;

  public static final int ACTION_DELETE_CHANNEL = 1001;
  public static final int ACTION_ADD_CHANNEL    = 1002;

  //==========================================================================
  //  Methods:

  /**
   * Find maximum value in set of keys contained in this map.
   *
   * @return Maximum key.
   */
  public int getMaxKey ()
  {
    int max = 0;
    for ( Integer ii : keySet() )
      max = Math.max( max, ii.intValue() );

    return max;
  }

  /**
   * Associates the channel with the specified key in this map.
   * If the map previously contained a mapping for this key, the old value is replaced.
   *
   * @param key Channel's key.
   * @param channel Channel's info.
   * @return previous channel associated with specified key,
   *         or null if there was no mapping for key.
   *         A null return can also indicate that the HashMap previously associated null with the specified key.
   */
  public InfoChannel put ( Integer key, InfoChannel channel )
  {
    InfoChannel channelOld = super.put( key, channel );
    changePerformed( ACTION_ADD_CHANNEL, channel );
    return channelOld;
  }

  /**
   * Removes the mapping for this key from this map if present.
   * If the map previously contained a mapping for this key, the old value is replaced.
   *
   * @param key Channel's key.
   * @return previous channel associated with specified key,
   *         or null if there was no mapping for key.
   *         A null return can also indicate that the HashMap previously associated null with the specified key.
   */
  public InfoChannel remove ( Integer key )
  {
    InfoChannel channel = super.remove( key );
    changePerformed( ACTION_DELETE_CHANNEL, channel );
    return channel;
  }

  //--- Listeners ------------------------------------------

  transient ActionListener actionListener;

  /**
   * Group change - add/remove channel.
   *
   * @param id Identification of action.
   * @param _obj Channel.
   */
  public void changePerformed ( int id, InfoChannel _obj )
  {
    ActionEvent e = new ActionEvent( _obj, id, null );
    processActionEvent( e );
  }

  /**
   * Adds the specified action listener to receive action events from
   * this object. Action events occur when any action is performed.
   * If l is null, no exception is thrown and no action is performed.
   *
   * @param         l the action listener
   * @see           #removeActionListener
   * @see           java.awt.event.ActionListener
   */
  public synchronized void addActionListener ( ActionListener l )
  {
    if ( l != null )
      actionListener = AWTEventMulticaster.add( actionListener, l );
  }

  /**
   * Removes the specified action listener so that it no longer
   * receives action events from this object.
   * If l is null, no exception is thrown and no action is performed.
   *
   * @param         l     the action listener
   * @see           #addActionListener
   * @see           java.awt.event.ActionListener
   */
  public synchronized void removeActionListener ( ActionListener l )
  {
    if ( l != null )
      actionListener = AWTEventMulticaster.remove( actionListener, l );
  }

  /**
   * Processes action events occurring on this object
   * by dispatching them to any registered
   * {@link ActionListener} objects.
   *
   * <p>This method is not called unless action events are
   * enabled for this object. Action events are enabled
   * when one of the following occurs:
   * <ul>
   * <li>An {@link ActionListener} object is registered
   * via {@link #addActionListener}.
   * <li>Action events are enabled via <tt>enableEvents</tt>.
   * </ul>
   * Note that if the event parameter is <tt>null</tt>
   * the behavior is unspecified and may result in an
   * exception.
   *
   * @param       e the action event
   * @see         java.awt.event.ActionListener
   * @see         java.awt.Component#enableEvents
   */
  protected void processActionEvent ( ActionEvent e )
  {
    if ( actionListener != null )
      actionListener.actionPerformed( e );
  }

}
