package cz.cuni.jagrlib.reg;

import java.awt.*;
import java.awt.event.*;
import java.util.*;

/**
 * HashMap for modules and groups.
 * Into these HashMap it is posible insert only objects of {@link InfoModule}.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.25 $Rev: 381 $ $Date: 2007-01-02 15:51:44 +0100 (út, 02 I 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/reg/HashMapModules.java">HashMapModules.java</a>
 * @see     HashMap
 */
public class HashMapModules extends HashMap< Integer, InfoModule >
{
  private static final long serialVersionUID   = 1L;

  public static final int ACTION_DELETE_MODULE = 2001;
  public static final int ACTION_ADD_MODULE    = 2002;

  //==========================================================================
  //  Methods:

  /**
   * Find maximum value in set of keys contained in this map.
   *
   * @return Maximum key.
   */
  public int getMaxKey ()
  {
    int max = 0;
    for ( Integer key : keySet() )
    {
      int p = key.intValue();
      if ( p > max ) max = p;
    }

    return max;
  }

  /**
   * Associates the module (or group) with the specified key in this map.
   * If the map previously contained a mapping for this key, the old value is replaced.
   *
   * @param key Module's key.
   * @param module Module's info.
   * @return previous module associated with specified key,
   *         or null if there was no mapping for key.
   *         A null return can also indicate that the HashMap previously associated null with the specified key.
   */
  public InfoModule put ( Integer key, InfoModule module )
  {
    InfoModule moduleOld = super.put( key, module );
    changePerformed( ACTION_ADD_MODULE, module );
    return moduleOld;
  }

  /**
   * Removes the mapping for this key from this map if present.
   * If the map previously contained a mapping for this key, the old value is replaced.
   *
   * @param key Module's key.
   * @return previous module associated with specified key,
   *         or null if there was no mapping for key.
   *         A null return can also indicate that the HashMap previously associated null with the specified key.
   */
  public InfoModule remove ( Integer key )
  {
    InfoModule module = super.remove( key );
    changePerformed( ACTION_DELETE_MODULE, module );
    return module;
  }

  transient ActionListener actionListener;

  /**
   * Group change - add/delete module.
   *
   * @param id Identification of action.
   * @param _obj Module.
   */
  public void changePerformed ( int id, InfoModule _obj )
  {
    ActionEvent e = new ActionEvent( _obj, id, null );
    processActionEvent( e );
  }

  /**
   * Adds the specified action listener to receive action events from
   * this object. Action events occur when any action is performed.
   * If l is null, no exception is thrown and no action is performed.
   *
   * @param         l the action listener
   * @see           #removeActionListener
   * @see           java.awt.event.ActionListener
   */
  public synchronized void addActionListener ( ActionListener l )
  {
    if ( l != null )
      actionListener = AWTEventMulticaster.add( actionListener, l );
  }

  /**
   * Removes the specified action listener so that it no longer
   * receives action events from this object.
   * If l is null, no exception is thrown and no action is performed.
   *
   * @param         l the action listener
   * @see           #addActionListener
   * @see           java.awt.event.ActionListener
   */
  public synchronized void removeActionListener ( ActionListener l )
  {
    if ( l == null )
      actionListener = AWTEventMulticaster.remove( actionListener, l );
  }

  /**
   * Processes action events occurring on this object
   * by dispatching them to any registered
   * {@link ActionListener} objects.
   *
   * <p>This method is not called unless action events are
   * enabled for this object. Action events are enabled
   * when one of the following occurs:
   * <ul>
   * <li>An {@link ActionListener} object is registered
   * via {@link #addActionListener}.
   * <li>Action events are enabled via <tt>enableEvents</tt>.
   * </ul>
   * Note that if the event parameter is <tt>null</tt>
   * the behavior is unspecified and may result in an
   * exception.
   *
   * @param       e the action event
   * @see         java.awt.event.ActionListener
   * @see         java.awt.Component#enableEvents
   */
  protected void processActionEvent ( ActionEvent e )
  {
    if ( actionListener != null )
      actionListener.actionPerformed( e );
  }

}
