package cz.cuni.jagrlib.reg;

import java.util.*;

import cz.cuni.jagrlib.*;

/**
 * Information about one concrete module instance ({@link Piece}) stored in XML file (composition).
 *
 * @author  Jan Kostlivy, PE
 * @version 0.25 $Rev: 381 $ $Date: 2007-01-02 15:51:44 +0100 (út, 02 I 2007) $ $Author: pepca $
 * @since   0.25
 * @see     <a href="../../../../../cz/cuni/jagrlib/reg/InfoModule.java">InfoModule.java</a>
 */
public class InfoModule
{
  /** Key of the module (within the composition/group). */
  public Integer key;

  /** Shared registration data (one concrete template for multi-template modules). */
  public RegPiece reg;

  /** Owner of the module (composition/group). */
  public InfoGroup owner;

  /** Information about module's GUI. */
  public InfoModuleGUI infoGUI = null;

  /** Set of all information about module plugs. */
  public Map< String, InfoPlug > plugs;

  /** Set of all information about module parameters. */
  public Map< String, InfoParam > params;

  /** Space for extra information. */
  public Map< String, Object > nextInfo;

  /**
   * {@link Piece} instance.
   * <br />Used in run-time of a composition.
   */
  public Piece instancePiece;

  public final static String TI_MODULE = "Module";

  /**
   * Initialize the instance from the given registration data.
   */
  public InfoModule ( RegPiece r )
  {
    reg   = r;
    plugs  = new LinkedHashMap< String, InfoPlug >(  r.plugs );
    params = new LinkedHashMap< String, InfoParam >( r.params );
  }

  /**
   * Looking for top level owner of module.
   * If it is {@code null} then returns self,
   * if it is not {@code null} then it calls recursively for owner.
   *
   * @return Top level owner.
   */
  public InfoModule getTopLevelOwner ()
  {
    if ( owner == null ) return this;

    return owner.getTopLevelOwner();
  }

  /**
   * Determines if this module has the key.
   *
   * @param _key In demand key.
   * @return {@code true} if module has the key.
   */
  public boolean isOwner ( Integer _key )
  {
    return key.equals( _key );
  }

  /**
   * State check - checks connection status..
   *
   * @return One of InfoState.* constants.
   */
  public int getState ()
  {
    int result = 0;

    for ( InfoPlug ip : plugs.values() )
      result |= ip.getState();

    return result;
  }

  /** Computes number of visible parameter lines. */
  public int getVisibleParamLines ()
  {
    int num = 0;

    for ( InfoParam ip : params.values() )
      num += ip.visibleLines();

    return num;
  }

}
