package cz.cuni.jagrlib.reg;

import java.util.*;
import java.awt.*;
import javax.swing.*;

import cz.cuni.jagrlib.gui.*;

/**
 * Information about module's GUI.
 *
 * @author  Jan Kostlivy
 * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/reg/InfoModuleGUI.java">InfoModuleGUI.java</a>
 */

public class InfoModuleGUI
{
  //==========================================================================
  //  Data:

  /** Mode of module. Normal or minimization mode. */
  public String modeShow = MS_NORMAL;

  /** Height of module in normal mode. */
  public int height;

  /** Width of module in normal mode. */
  public int width;

  /** X-axis of module on work space. */
  public int x = 0;

  /** Y-axis of module on work space. */
  public int y = 0;

  /** Flag, if the module is editable. Not used yet. */
  public boolean editable    = true;

  /** Flag, if the module is minimizable. Not used yet. */
  public boolean minimizable = true;

  /** Flag, if the module is maximizable. Not used yet. */
  public boolean maximizable = true;

  /** Flag, if the module is selected. */
  public boolean selected    = false;

  // default values:

  /** Starting height of module. Not used yet. */
  public int defaultHeight;

  /** Starting width of module. Not used yet. */
  public int defaultWidth;

  /** Container for all other information. */
  public Map< String, Object > nextInfo;

  /**
   * Class that care about visual representation of a module.
   *
   * @see ModuleGUI
   * @see ModuleGUIImproved
   */
  public ModuleGUI gui;

  /** Minimization mode. */
  final static public String MS_MINI   = "Mini";

  /** Normal mode. */
  final static public String MS_NORMAL = "Normal";

  /** Icon of runable module. */
  public static ImageIcon iconRunable  = Options.getIcon( "RunSmall.gif" );

  /** Key for icon. For nextInfo map. */
  final static public String MS_ICON   = "Icon";

    /* Options information */
  /** Color of selection of selected module. */
  public static Color colorSelect = Color.darkGray;

  /** Color of background of title. */
  public static Color colorName = SystemColor.textHighlight;

  //==========================================================================
  //  Methods:

  /**
   * Tests, if module is in normal mode.
   *
   * @return {@code true} if module is in normal mode.
   */
  public boolean isNormal ()
  {
    return ( modeShow.compareTo( InfoModuleGUI.MS_NORMAL ) == 0 );
  }

  /**
   * Tests, if module is in minimization mode.
   *
   * @return {@code true} if module is in minimization mode.
   */
  public boolean isMini ()
  {
    return ( modeShow.compareTo( InfoModuleGUI.MS_MINI ) == 0 );
  }

  /**
   * Creates a new object of the same class as this object.
   * Except GUI.
   *
   * @return a clone of this instance.
   */
  @SuppressWarnings("unchecked")
  public Object clone ()
  {
    InfoModuleGUI img = new InfoModuleGUI();
    img.modeShow      = modeShow;
    img.height        = height;
    img.width         = width;
    img.x             = x;
    img.y             = y;

    img.editable      = editable;
    img.minimizable   = minimizable;
    img.maximizable   = maximizable;
    img.selected      = selected;
    img.defaultHeight = defaultHeight;
    img.defaultWidth  = defaultWidth;
    if ( nextInfo != null )
      img.nextInfo = (Map< String, Object >)(((HashMap< String, Object >)nextInfo).clone());

    return img;
  }

}
