package cz.cuni.jagrlib.reg;

import java.util.*;

import cz.cuni.jagrlib.*;

/**
 * Parameter information.
 *
 * @author  PE, Jan Kostlivy
 * @version 0.26 $Rev: 440 $ $Date: 2007-05-05 14:14:56 +0200 (so, 05 V 2007) $ $Author: pepca $
 * @since   0.25
 * @see     <a href="../../../../../cz/cuni/jagrlib/reg/InfoParam.java">InfoParam.java</a>
 */
public class InfoParam
{
  /** Display text of item of combobox. */
  public final static String IP_STRING   = "String";

  /** Real value of item of combobox. */
  public final static String IP_VALUE    = "Value";

  /** Type of real value of item of combobox. */
  public final static String IP_TYPE     = "Type";

  /** Description for combobox. */
  public final static String IP_DESCR    = "Description";

  /** Minimum value of parameter. */
  public final static String IP_MINVALUE = "MinValue";

  /** Maximum value of parameter. */
  public final static String IP_MAXVALUE = "MaxValue";

  //==========================================================================
  //  Parameter types:

  /** Type of parameter - String. */
  public final static String IP_TYPE_STRING     = "String";

  /** Type of parameter - multi-line string. */
  public final static String IP_TYPE_MULTILINE  = "Multiline";

  /** Type of parameter - Integer. */
  public final static String IP_TYPE_INTEGER    = "Integer";

  /** Type of parameter - Long. */
  public final static String IP_TYPE_LONG       = "Long";

  /** Type of parameter - Float. */
  public final static String IP_TYPE_FLOAT      = "Float";

  /** Type of parameter - Double. */
  public final static String IP_TYPE_DOUBLE     = "Double";

  /** Type of parameter - Combo box. */
  public final static String IP_TYPE_COMBO      = "Combo";

  /** Type of parameter - Boolean. */
  public final static String IP_TYPE_BOOLEAN    = "Boolean";

  /** Type of parameter - Special. */
  public final static String IP_TYPE_SPEC       = "Spec";

  public final static String TI_PARAM           = "Param";

  /** Multiline parameter height in lines. */
  public final static int MULTILINE_HEIGHT      = 4;

  //==========================================================================
  //  Data:

  /** Name of parameter. Unique in one module. */
  public String name = "";

  /** Parameter type. */
  public String type = "";

  /** Parameter value. */
  public Object value;

  /** Default value. */
  public Object defaultValue;

  /** Description of parameter. */
  public String description = "";

  /** Visible parameter (GUI editable). */
  public boolean visible = true;

  /**
   * Valid values of the parameter.
   * <br />Map contains {@link HashMap}s with information about combobox items:
   * {@code <String>, <Value>, <Type>}
   * <br />or boundary values (min, max).
   */
  public Vector< Map< String, Object > > values = new Vector< Map< String, Object > >();

  /** Manipulator type. */
  public int propManip = Template.MANIPULATOR_DEFAULT;

  /**
   * Class-name for manipulation with special parameter
   * (either fully-qualified or local in {@code package cz.cuni.jagrlib.gui}).
   */
  public String propManipClass;

  /**  Owner of parameter. It can be {@link InfoModule}. */
  public InfoModule owner;

  /** Information about parameter's GUI. */
  public InfoParamGUI infoGUI = null;

  /** All other information goes here.. */
  public Map< String, Object > nextInfo;

  //==========================================================================
  //  Methods:

  protected String typeConvert ( String newType )
  {
    if ( newType.equals( Template.TYPE_STRING ) )
      return IP_TYPE_STRING;

    if ( newType.equals( Template.TYPE_INTEGER ) )
      return IP_TYPE_INTEGER;

    if ( newType.equals( Template.TYPE_LONG ) )
      return IP_TYPE_LONG;

    if ( newType.equals( Template.TYPE_DOUBLE ) )
      return IP_TYPE_DOUBLE;

    if ( newType.equals( Template.TYPE_FLOAT ) )
      return IP_TYPE_FLOAT;

    if ( newType.equals( Template.TYPE_BOOLEAN ) )
      return IP_TYPE_BOOLEAN;

    if ( newType.equals( Template.TYPE_OBJECT ) )
      return IP_TYPE_SPEC;

    return null;
  }

  /**
   * Create a new InfoParam.
   *
   * @param  _name Name of parameter.
   * @param  _type Type of parameter (IP_TYPE_...).
   * @param  _description Description of parameter.
   * @param  _visible Will be this parameter visible in Skel (GUI)?
   */
  public InfoParam ( String _name,
                     String _type,
                     String _description,
                     boolean _visible )
  {
    name         = _name;
    type         = typeConvert( _type );
    description  = _description;
    visible      = _visible;
  }

  public InfoParam ()
  {}

  /** Set parameter bounds. */
  public void setBounds ( Object min, Object max )
  {
    Map< String, Object > m = new HashMap< String, Object >( 2 );
    m.put( IP_MINVALUE, min );
    m.put( IP_MAXVALUE, max );

    values.add( m );
  }

  public void setEnum ( String label, Object value, String descr )
  {
    Map< String, Object > m = new HashMap< String, Object >( 4 );
    m.put( IP_STRING, label );
    m.put( IP_VALUE,  value );
    m.put( IP_TYPE,   type );
    if ( descr != null &&
         descr.length() > 0 )
      m.put( IP_DESCR, descr );

    values.add( m );
  }

  public void propEnd ()
  {
    if ( propManip == Template.MANIPULATOR_CUSTOM )
      type = IP_TYPE_SPEC;
    else
    if ( propManip == Template.MANIPULATOR_MULTILINE )
      type = IP_TYPE_MULTILINE;
    else
      for ( Map< String, Object > item : values )
        if ( item.get( IP_STRING ) != null ) // list-box manipulator
        {
          type = IP_TYPE_COMBO;
          break;
        }
  }

  /** Returns visible height in lines. */
  public int visibleLines ()
  {
    if ( !visible ) return 0;
    return( IP_TYPE_MULTILINE.equals( type ) ? MULTILINE_HEIGHT : 1 );
  }
}
