package cz.cuni.jagrlib.reg;

/**
 * Interface for saving and loading to/from files.
 *
 * @author  Jan Kostlivy
 * @version 0.25 $Rev: 281 $ $Date: 2006-06-01 20:55:34 +0200 (čt, 01 VI 2006) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/reg/InputOutput.java">InputOutput.java</a>
 */
public interface InputOutput
{
  public final static String SAVE = "save";
  public final static String SAVEAS = "saveas";

  /**
   * Main method for save Composition.
   *
   * @param _composition Composition info.
   * @param type type of save (SAVE or SAVEAS)
   */
  public void save ( String type, InfoGroup _composition ) throws Exception;

  /**
   * Saves composition.
   *
   * @param _composition Composition info.
   */
  public void saveComposition ( InfoGroup _composition );

  /**
   * Saves group.
   *
   * @param _info Group info.
   */
  public void saveGroup ( InfoGroup _info );

  /**
   * Saves channel.
   *
   * @param _info Channel info.
   */
  public void saveChannel ( InfoChannel _info );

  /**
   * Saves parameter.
   *
   * @param _info Parameter info.
   * @param _key Key of parameter for module or group.
   */
  public void saveParam ( InfoParam _info, String _key );

  /**
   * Saves module.
   *
   * @param _info Module info.
   */
  public void saveModule ( InfoModule _info );

  /**
   * Saves plug.
   *
   * @param _info Plug info.
   * @param _key Key of plug for module or group.
   */
  public void savePlug ( InfoPlug _info, String _key );

  /**
   * Loads composition w/o asking for its file-name.
   *
   * @param fileName File-name to load.
   */
  void loadFile ( InfoGroup _composition, String fileName )
  throws Exception;

  /**
   * Main method for load Composition.
   *
   * @param _composition Composition info.
   */
  public void load ( InfoGroup _composition ) throws Exception;

  /**
   * Loads composition.
   *
   * @param _composition Composition info.
   * @return Information about composition.
   */
  public InfoGroup loadComposition ( InfoGroup _composition ) throws Exception;

  /**
   * Loads group.
   *
   * @param _info Group info.
   * @return Information about group.
   */
  public InfoGroup loadGroup ( InfoGroup _info ) throws Exception;

  /**
   * Loads channel.
   *
   * @param _info Channel info.
   * @return Information about channel.
   */
  public InfoChannel loadChannel ( InfoChannel _info ) throws Exception;

  /**
   * Loads parameter.
   *
   * @param _info Parameter info.
   * @param _owner Owner of parameter.
   * @return Information about parameter.
   */
  public InfoParam loadParam ( InfoParam _info, InfoModule _owner ) throws Exception;

  /**
   * Loads module.
   *
   * @param _info Module info.
   * @return Information about module.
   */
  public InfoModule loadModule ( InfoModule _info ) throws Exception;

  /**
   * Loads plug.
   *
   * @param _info Plug info.
   * @param _owner Owner of plug.
   * @return Information about plug.
   */
  public InfoPlug loadPlug ( InfoPlug _info, InfoModule _owner ) throws Exception;

}
