package cz.cuni.jagrlib.reg;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.gui.*;
import cz.cuni.jagrlib.xml.*;

/**
 * Basic class for working with registry data.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.25 $Rev: 381 $ $Date: 2007-01-02 15:51:44 +0100 (út, 02 I 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/reg/RegDatabaseBasic.java">RegDatabaseBasic.java</a>
 */
public class RegDatabaseBasic
{
  //==========================================================================
  //  Data:

  /** Registry data (singleton). */
  public static RegTables tables = getRegTables();

  //==========================================================================
  //  Methods RegDatabase:

  /**
   * Creates registry data singleton.
   */
  static private RegTables getRegTables ()
  {
    return new RegTablesXML();
  }

  /**
   * Retrieves registry file name.
   */
  static public String getRegDataFile ()
  {
    return Options.pathReg;
  }

  /**
   * Opens registration window for modules.
   *
   * @param _package Name of package.
   * @param _class Name of class - descendant of {@link Piece}.
   * @param _template template of module.
   */
  public static void registryModule ( String _package, String _class, String _template )
  {
    RegModulesDialog dial = new RegModulesDialog();
    InfoModule im = getInfo( _package, _class, _template );
    if ( im != null )
      dial.openModule( im );

    dial.setVisible( true );
  }

  /**
   * Opens registration window for group.
   *
   * @param  _group Information about group.
   * @return {@code true} if registration was successful.
   */
  static public boolean registryGroup ( InfoGroup _group )
  {
    RegGroupDialog dial = new RegGroupDialog( _group );
    dial.setVisible( true );
    return dial.retVal;
  }

  /**
   * Unregistry module or group.
   *
   * @param _package Name of package.
   * @param _class Name of class - descendant of Piece.
   * @param _template template of module.
   */
  public static void unregistryModule ( String _package, String _class, String _template )
  {
    tables.unregister( tables.getInfo( _package, _class, _template ) );
  }

  /**
   * Save registry data.
   */
  public static void saveRegistryData ()
  {
    tables.save();
  }

  //==========================================================================
  //  Methods:

  /**
   * Gets information about module or group.
   *
   * @param  _package Name of package.
   * @param  _class Name of class.
   * @param  _template Name of template.
   * @return information about module or group.
   */
  public static InfoModule getInfo ( String _package, String _class, String _template )
  {
    return tables.getInfo( _package, _class, _template );
  }

  /**
   * Opens dialog with selection of modules.
   *
   * @param _info Restriction for selecting similar module.
   * @return Selected module.
   */
  public static InfoModule viewModules ( InfoModule _info )
  {
    RegModulesSelect dial = new RegModulesSelect( _info );
    dial.setPreview( false );
    dial.setVisible( true );
    return dial.infoPiece;
  }

  /**
   * Opens dialog with selection of modules.
   *
   * @return Selected modules and/or groups.
   */
  public static InfoModule[] viewModules ()
  {
    RegModulesSelect dial = new RegModulesSelect();
    dial.setPreview( false );
    dial.setVisible( true );
    return dial.infoPieces;
  }

  /**
   * Opens dialog with modules.
   */
  public static void previewModules ()
  {
    RegModulesSelect dial = new RegModulesSelect( MainWindow.mainWindow, "Preview Modules", true, null );
    dial.setPreview( true );
    dial.setVisible( true );
  }

  /**
   * Creates panel-filter for viewing modules.
   */
  public static SelectFilter newSelectFilter ()
  {
    return new SelectFilterBasic();
  }

  /**
   * Creates instance of {@link Piece} from package name and class.
   *
   * @param  _package Name of package.
   * @param  _class Name of class.
   * @return Instance of Piece.
   */
  public static Piece newPieceInstance ( String _package, String _class )
  throws Exception
  {
    return (Piece)Class.forName( _package + "." + _class ).newInstance();
  }

  /**
   * Creates instance of {@link Piece} from {@link InfoModule} data object.
   *
   * @param  _info Informace about module.
   * @return instance of Piece.
   */
  public static Piece newPieceInstance ( InfoModule _info )
  throws Exception
  {
    return (Piece)Class.forName( _info.reg.fullClassName() ).newInstance();
  }

  /**
   * Creates object for saving and loading compositions.
   */
  static public InputOutput getInputOutput ()
  {
    return new InputOutputXML();
  }

}
