package cz.cuni.jagrlib.reg;

import java.util.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;

import cz.cuni.jagrlib.gui.*;
import cz.cuni.jagrlib.LogFile;

/**
 * Dialog for group registration.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/reg/RegGroupDialog.java">RegGroupDialog.java</a>
 */
public class RegGroupDialog extends JDialog
{
  private static final long serialVersionUID = 1L;

  /** Return value. */
  public boolean retVal = false;

  /** Registry data. */
  public RegTables tables = RegDatabaseBasic.tables;

  /** Information about group. */
  private InfoGroup group;

  /** Minimum height of dialog. */
  static final int MIN_HEIGHT = 300;

  /** Minimum width of dialog. */
  static final int MIN_WIDTH = 300;

  private JPanel      panelMain     = new JPanel();
  private JPanel      panelButton   = new JPanel();
  private JLabel      lbName        = new JLabel();
  private JTextField  tfName        = new JTextField();
  private JLabel      lbTemplate    = new JLabel();
  private JTextField  tfTemplate    = new JTextField();
  private JLabel      lbCategory    = new JLabel();
  private JTextField  tfCategory    = new JTextField();
  private JLabel      lbDescription = new JLabel();
  private JTextField  tfDescription = new JTextField();
  private JButton     btRegistry    = new JButton();
  private JButton     btStorno      = new JButton();

  private JSplitPane  splitGroup    = new JSplitPane();
  private JScrollPane scrollGroup   = new JScrollPane();
  private JScrollPane scrollModules = new JScrollPane();
  private JPanel      jPanelModules = new JPanel();

  /**
   * Create a new RegGroupDialog.
   *
   * @param frame Owner frame.
   * @param title Title of dialog.
   * @param modal Modality.
   * @param _group Information about group.
   */
  public RegGroupDialog ( Frame frame, String title, boolean modal, InfoGroup _group )
  {
    super( frame, title, modal );
    try
    {
      group = _group;
      jbInit();
      pack();
      loadOptionsData();
    }
    catch ( Exception ex )
    {
      LogFile.exception( ex );
    }
  }

  /**
   * Create a new RegGroupDialog.
   *
   * @param _group Information about group.
   */
  public RegGroupDialog ( InfoGroup _group )
  {
    this( MainWindow.mainWindow, "Group Registration", true, _group );
  }

  /**
   * Component initialization.
   */
  private void jbInit ()
  throws Exception
  {
    this.addComponentListener( new ComponentAdapter ()
    {
      public void componentResized ( ComponentEvent e )
      {
        this_componentResized( e );
      }
    });

    group.addActionListener ( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        change_actionPerformed( e );
      }
    });

    panelMain.setLayout( new GridBagLayout() );
    panelMain.setPreferredSize( new Dimension( 365, 400 ) );

    btRegistry.setText( "Registry" );
    btRegistry.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btRegistry_actionPerformed( e );
      }
    });

    btStorno.setText( "Storno" );
    btStorno.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btStorno_actionPerformed( e );
      }
    });

    lbName.setText( "Name: " );
    tfName.setText( group.reg.className );

    lbTemplate.setText( "Template: " );
    tfTemplate.setText( group.reg.template );

    lbCategory.setText( "Category: " );
    lbDescription.setText( "Description: " );

    panelMain.add( lbName,
                   new GridBagConstraints( 0, 0, 1, 1, 0.0, 0.0,
                                           GridBagConstraints.WEST, GridBagConstraints.NONE,
                                           new Insets( 5, 13, 0, 0 ), 0, 0 ) );
    panelMain.add( tfName,
                   new GridBagConstraints( 1, 0, 1, 1, 1.0, 0.0,
                                           GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL,
                                           new Insets( 5, 0, 0, 10 ), 0, 0 ) );
    panelMain.add( lbTemplate,
                   new GridBagConstraints( 0, 1, 1, 1, 0.0, 0.0,
                                           GridBagConstraints.WEST, GridBagConstraints.NONE,
                                           new Insets( 5, 13, 0, 0 ), 0, 0 ) );
    panelMain.add( tfTemplate,
                   new GridBagConstraints( 1, 1, 1, 1, 1.0, 0.0,
                                           GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL,
                                           new Insets( 5, 0, 0, 10 ), 0, 0 ) );
    panelMain.add( lbCategory,
                   new GridBagConstraints( 0, 2, 1, 1, 0.0, 0.0,
                                           GridBagConstraints.WEST, GridBagConstraints.NONE,
                                           new Insets( 9, 13, 0, 0 ), 0, 0 ) );
    panelMain.add( tfCategory,
                   new GridBagConstraints( 1, 2, 1, 1, 1.0, 0.0,
                                           GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL,
                                           new Insets( 7, 0, 0, 10 ), 0, 0 ) );
    panelMain.add( lbDescription,
                   new GridBagConstraints( 0, 3, 1, 1, 0.0, 0.0,
                                           GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                           new Insets( 9, 13, 5, 0 ), 0, 0 ) );
    panelMain.add( tfDescription,
                   new GridBagConstraints( 1, 3, 1, 2, 1.0, 0.0,
                                           GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                           new Insets( 7, 0, 5, 10 ), 0, 0 ) );

    if ( group.infoCompositionGUI.gui == null )
    {
      group.infoCompositionGUI.gui           = InstanceGUI.newCompositionInstance();
      group.infoCompositionGUI.gui.info      = group;
      group.infoCompositionGUI.gui.canDelete = true;
    }

    if ( group.infoCompositionGUI.gui != null )
    {
      scrollGroup.getViewport().add( group.infoCompositionGUI.gui, null );
      group.infoCompositionGUI.gui.readInfo();
      splitGroup.setOrientation( JSplitPane.VERTICAL_SPLIT );
      splitGroup.add( scrollGroup, JSplitPane.TOP );
      splitGroup.add( scrollModules, JSplitPane.BOTTOM );
      splitGroup.setResizeWeight( 0.5 );
      splitGroup.setBorder( BorderFactory.createEmptyBorder() );
      panelMain.add( splitGroup,
                     new GridBagConstraints( 0, -1, 2, 1, 1.0, 1.0,
                                             GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                                             new Insets( 0, 5, 5, 5 ), 0, 0 ) );
    }

    else
    {
      panelMain.add( scrollModules,
                     new GridBagConstraints( 0, -1, 2, 1, 1.0, 1.0,
                                             GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                                             new Insets( 0, 5, 5, 5 ), 0, 0 ) );
    }

    jPanelModules.setLayout( new GridBagLayout() );
    scrollModules.getViewport().add( jPanelModules, null );
    scrollModules.setBorder( new TitledBorder( "Modules" ) );
    initPanels();
    initPanelModules();

    panelButton.add( btRegistry, null );
    panelButton.add( btStorno,   null );

    this.getContentPane().add( panelMain,   BorderLayout.CENTER );
    this.getContentPane().add( panelButton, BorderLayout.SOUTH );
  }

  /**
   * Initialization of panel for modules.
   */
  private void initPanelModules ()
  throws Exception
  {
    jPanelModules.removeAll();
    int count = group.modules.size();

    for ( InfoModule im : group.modules.values() )
    {
      JPanel jPanelModule = (JPanel)im.nextInfo.get( "Panel" );

      jPanelModules.add( jPanelModule,
                         new GridBagConstraints( 0, -1, 1, 1, 1.0, (--count == 0) ? 1.0 : 0.0,
                                                 GridBagConstraints.NORTHWEST,
                                                 GridBagConstraints.HORIZONTAL,
                                                 GuiConstants.INSETS_0, 0, 0 ) );
    }
  }

  /** Initialization of panels for modules.*/
  private void initPanels ()
  {
    for ( InfoModule im : group.modules.values() )
      setPanelModule( im );
  }

  /**
   * Creates a panel for the given module.
   */
  private JPanel setPanelModule ( InfoModule im )
  {
    JPanel panelModule = new JPanel();
    panelModule.setBorder( new TitledBorder( BorderFactory.createEtchedBorder( EtchedBorder.LOWERED ),
                                             im.reg.className ) );
    panelModule.setLayout( new GridBagLayout() );

    panelModule.add( new JLabel( "Plugs:" ),
                     new GridBagConstraints( 0, -1, 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST,
                                             GridBagConstraints.NONE, GuiConstants.INSETS_0, 0, 0 ) );

    for ( InfoPlug ip : im.plugs.values() )
    {
      JCheckBox cb = new JCheckBox();

      cb.setText( ip.name + " (" + ip.type + ")" );

      if ( ip.nextInfo == null )
        ip.nextInfo = new HashMap< String, Object >();

      ip.nextInfo.put( "CHECKBOX", cb );

      setPlugVisibility( ip );

      panelModule.add( cb,
                       new GridBagConstraints( 1, -1, 2, 1, 0.0, 0.0,
                                               GridBagConstraints.NORTHWEST,
                                               GridBagConstraints.NONE, GuiConstants.INSETS_0, 0, 0 ) );
    }

    panelModule.add( new JLabel( "Params: " ),
                     new GridBagConstraints( 0, im.plugs.size(), 1, 1, 0.0, 0.0,
                                             GridBagConstraints.NORTHWEST,
                                             GridBagConstraints.NONE, GuiConstants.INSETS_0, 0, 0 ) );

    for ( InfoParam ip : im.params.values() )
    {
      JCheckBox cb = new JCheckBox();

      if ( ip.nextInfo == null )
        ip.nextInfo = new HashMap< String, Object >();
      ip.nextInfo.put( "CHECKBOX", cb );

      setParamVisibility( ip );

      panelModule.add( cb,
                       new GridBagConstraints( 1, -1, 1, 1, 0.0, 0.0,
                                               GridBagConstraints.NORTHWEST,
                                               GridBagConstraints.NONE, GuiConstants.INSETS_0, 0, 0 ) );

      ip.nextInfo.put( "ODLGUI", ip.infoGUI.gui );
      ParamGUI par = InstanceGUI.newParam( ip );
      ip.nextInfo.put( "GUI", par );
      panelModule.add( par,
                       new GridBagConstraints( 2, -1, 1, 1, 1.0, 0.0,
                                               GridBagConstraints.NORTHWEST,
                                               GridBagConstraints.HORIZONTAL, GuiConstants.INSETS_0, 0, 0 ) );
    }

    if ( im.nextInfo == null )
      im.nextInfo = new HashMap< String, Object >();

    im.nextInfo.put( "Panel", panelModule );

    return panelModule;
  }

  /**
   * Initialization of visibility plug.
   *
   * @param ip information about plug.
   */
  private void setPlugVisibility ( InfoPlug ip )
  {
    JCheckBox cb = (JCheckBox)ip.nextInfo.get( "CHECKBOX" );

    cb.setSelected( ip.infoGUI.visible );
    cb.setEnabled( !ip.mandatory );

    if ( ip.mandatory )
    {
      if ( ip.channels != null )
        for ( Integer key : ip.channels.keySet() )
          if ( group.channels.get( key ) != null )
          {
            cb.setEnabled( true );
            return;
          }

      cb.setEnabled( false );
    }
  }

  /**
   * Initialization of visibility param.
   *
   * @param ip information about param.
   */
  private void setParamVisibility ( InfoParam ip )
  {
    JCheckBox cb = (JCheckBox)ip.nextInfo.get( "CHECKBOX" );
    cb.setSelected( ip.infoGUI.visible );
  }

  /** Read information about modules and set visibility of plugs. */
  private void readPanelModules ()
  {
    for ( InfoModule im : group.modules.values() )
    {
      for ( InfoPlug ip : im.plugs.values() )
      {
        if ( ip.infoGUI == null )
          ip.infoGUI = new InfoPlugGUI();

        if ( ip.nextInfo != null )
        {
          JCheckBox cb = (JCheckBox)ip.nextInfo.remove( "CHECKBOX" );
          if ( cb != null )
            ip.infoGUI.visible = cb.isSelected();
        }
      }

      for ( InfoParam ip : im.params.values() )
      {
        if ( ip.infoGUI == null )
          ip.infoGUI = new InfoParamGUI();

        if ( ip.nextInfo != null )
        {
          JCheckBox cb = (JCheckBox)ip.nextInfo.remove( "CHECKBOX" );
          if ( cb != null )
            ip.infoGUI.visible = cb.isSelected();

          ParamGUI pg = (ParamGUI)ip.nextInfo.remove( "ODLGUI" );
          if ( pg != null )
            ip.infoGUI.gui = pg;
          ip.nextInfo.remove( "GUI" );
        }
      }

      if ( im.nextInfo != null )
        im.nextInfo.remove( "Panel" );
    }
  }

  /**
   * Do registration and save registry data.
   */
  void btRegistry_actionPerformed ( ActionEvent e )
  {
    group.reg.name     = tfName.getText();
    group.reg.template = tfTemplate.getText();

    if ( group != null &&
         group.reg.name.compareToIgnoreCase("") != 0 &&
         group.reg.template.compareToIgnoreCase("") != 0 )
    {
      readPanelModules();
      group.reg.className   = group.reg.name;
      group.reg.packageName = "GROUP";
      group.reg.category    = tfCategory.getText();
      group.reg.description = tfDescription.getText();
      group.init();
      group.registry        = false;
      InstanceGUI.newGroupInstance( group );

      tables.registerGroup( group );
      tables.save();
      group.registry        = true;
      retVal                = true;
      saveOptionsData();
      setVisible( false );
    }
  }

  /**
   * Canceling the current registration procedure..
   */
  void btStorno_actionPerformed ( ActionEvent e )
  {
    retVal = false;
    saveOptionsData();
    setVisible( false );
  }

  /**
   * Change of the actual group.
   * Delete/add module.
   */
  public void change_actionPerformed ( ActionEvent e )
  {
    switch ( e.getID() )
    {
      case HashMapModules.ACTION_ADD_MODULE:
        InfoModule im = (InfoModule)e.getSource();
        setPanelModule( im );
        break;  // was not here ???

      case HashMapModules.ACTION_DELETE_MODULE:
        try
        {
          initPanelModules();
        }
        catch ( Exception ex )
        {
          LogFile.exception( ex );
        }
        this.validate();
        break;
    }
  }

  /**
   * Dialog was resized.
   */
  void this_componentResized ( ComponentEvent e )
  {
    int height = this.getHeight();
    if ( height < MIN_HEIGHT )
      height = MIN_HEIGHT;

    int width = this.getWidth();
    if ( width < MIN_WIDTH )
      width = MIN_WIDTH;

    this.setSize( width, height );
  }

  /** Load options data (window pos, height, ...). */
  protected void loadOptionsData ()
  {
    int i, j;

    i = Options.getInteger( "RegGroupDialog.splitModule", -1, Integer.MAX_VALUE, -1 );
    if ( i >= 0 )
      splitGroup.setDividerLocation( i );

    int[] pos =
    {
      Options.getInteger( "RegGroupDialog.windowPosX",  -1, Integer.MAX_VALUE, -1 ),
      Options.getInteger( "RegGroupDialog.windowPosY",  -1, Integer.MAX_VALUE, -1 )
    };
    MainWindow.adjustScreenPosition( pos );
    setLocation( pos[0], pos[1] );

    i = Options.getInteger( "RegGroupDialog.windowWidth",  0, Integer.MAX_VALUE, 0 );
    j = Options.getInteger( "RegGroupDialog.windowHeight", 0, Integer.MAX_VALUE, 0 );
    if ( i > 0 && j > 0 )
      setSize( i, j );
  }

  /** Save options data (window pos, height, ...). */
  protected void saveOptionsData ()
  {
    Options.set( "RegGroupDialog.splitModule",  splitGroup.getDividerLocation() );
    Options.set( "RegGroupDialog.windowPosX",   getX() );
    Options.set( "RegGroupDialog.windowPosY",   getY() );
    Options.set( "RegGroupDialog.windowWidth",  getWidth() );
    Options.set( "RegGroupDialog.windowHeight", getHeight() );
  }

}
