package cz.cuni.jagrlib.reg;

import java.io.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.gui.*;
import cz.cuni.jagrlib.gui.comp.*;

/**
 * Dialog window for module registration.
 *
 * @author  PE, Jan Kostlivy
 * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/reg/RegModulesDialog.java">RegModulesDialog.java</a>
 */
public class RegModulesDialog extends JDialog
{
  private static final long serialVersionUID = 1L;

  /** Registry data.*/
  public RegTables tables = RegDatabaseBasic.tables;

  /** File chooser. */
  JFileChooser chooser;

  /** File filter for file chooser. */
  CommonFileFilter filter;

  /** Minimum height of dialog. */
  static final int MIN_HEIGHT = 400;

  /** Minimum width of dialog. */
  static final int MIN_WIDTH  = 370;

  // GUI components
  private JPanel      contentPane;

  //private JScrollPane spModule    = new JScrollPane();
  private PanelModule panelMain   = new PanelModule();
  private JPanel      panelButton = new JPanel();
  private JButton     btClose     = new JButton();
  private JButton     btRead      = new JButton();
  private JButton     btRegFiles  = new JButton();
  private JButton     btRegistry  = new JButton();
  private JButton     btSave      = new JButton();
  private JTabbedPane tabModules  = new JTabbedPane();

  /** Panel for module + template. */
  private class PanelModule extends JPanel
  {
    private static final long serialVersionUID = 1L;

    private InfoModule info;

    private JLabel      lbPackage     = new JLabel();
    private JComboBox   cbPackage     = new JComboBox();
    private JLabel      lbClass       = new JLabel();
    private JTextField  tfClass       = new JTextField();
    private JLabel      lbTemplate    = new JLabel();
    private JTextField  tfTemplate    = new JTextField();
    private JLabel      lbName        = new JLabel();
    private JTextField  tfName        = new JTextField();
    private JLabel      lbCategory    = new JLabel();
    private JTextField  tfCategory    = new JTextField();
    private JLabel      lbDescription = new JLabel();
    private JTextField  tfDescription = new JTextField();

    private JScrollPane spPlug        = new JScrollPane();
    private JScrollPane spParam       = new JScrollPane();
    private JPanel      panelPlug     = new JPanel();
    private JPanel      panelParam    = new JPanel();

    public PanelModule ()
    {
      setLayout( new GridBagLayout() );
      setPreferredSize( new Dimension( 365, 400 ) );

      lbPackage.setText( "Package: " );
      cbPackage.addItem( Template.JAGRLIB2 + "piece" );
      cbPackage.addItem( Template.JAGRLIB2 + "worker" );
      cbPackage.addItem( Template.JAGRLIB2 + "testing" );
      cbPackage.addItem( Template.JAGRLIB2 + "obscure" );
      lbClass.setText( "Class: " );
      tfClass.setEditable( false );
      lbTemplate.setText( "Template: " );
      tfTemplate.setEditable( false );
      lbName.setText( "Name: " );
      lbCategory.setText( "Category: " );
      lbDescription.setText( "Description: " );

      Insets insets5_13_0_0 = new Insets( 5, 13, 0,  0 );
      Insets insets5_0_0_13 = new Insets( 5,  0, 0, 13 );
      Insets insets9_13_0_0 = new Insets( 9, 13, 0,  0 );

      add( lbPackage,     new GridBagConstraints( 0, 0, 1, 1, 0.0, 0.0,
                                                  GridBagConstraints.WEST, GridBagConstraints.NONE,
                                                  insets5_13_0_0, 0, 0 ) );
      add( cbPackage,     new GridBagConstraints( 1, 0, 1, 1, 1.0, 0.0,
                                                  GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL,
                                                  insets5_0_0_13, 0, 0 ) );
      add( lbClass,       new GridBagConstraints( 0, 1, 1, 1, 0.0, 0.0,
                                                  GridBagConstraints.WEST, GridBagConstraints.NONE,
                                                  insets5_13_0_0, 0, 0 ) );
      add( tfClass,       new GridBagConstraints( 1, 1, 1, 1, 0.0, 0.0,
                                                  GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL,
                                                  insets5_0_0_13, 0, 0 ) );
      add( lbTemplate,    new GridBagConstraints( 0, 2, 1, 1, 0.0, 0.0,
                                                  GridBagConstraints.WEST, GridBagConstraints.NONE,
                                                  insets9_13_0_0, 0, 0 ) );
      add( tfTemplate,    new GridBagConstraints( 1, 2, 1, 1, 1.0, 0.0,
                                                  GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL,
                                                  insets5_0_0_13, 0, 0 ) );
      add( lbName,        new GridBagConstraints( 0, 3, 1, 1, 0.0, 0.0,
                                                  GridBagConstraints.WEST, GridBagConstraints.NONE,
                                                  insets9_13_0_0, 0, 0 ) );
      add( tfName,        new GridBagConstraints( 1, 3, 1, 1, 1.0, 0.0,
                                                  GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL,
                                                  insets5_0_0_13, 0, 0 ) );
      add( lbCategory,    new GridBagConstraints( 0, 4, 1, 1, 0.0, 0.0,
                                                  GridBagConstraints.WEST, GridBagConstraints.NONE,
                                                  insets9_13_0_0, 0, 0 ) );
      add( tfCategory,    new GridBagConstraints( 1, 4, 1, 1, 1.0, 0.0,
                                                  GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL,
                                                  insets5_0_0_13, 0, 0 ) );
      add( lbDescription, new GridBagConstraints( 0, 5, 1, 1, 0.0, 0.0,
                                                  GridBagConstraints.WEST, GridBagConstraints.NONE,
                                                  new Insets( 9, 13, 5, 0 ), 0, 0 ) );
      add( tfDescription, new GridBagConstraints( 1, 5, 1, 1, 1.0, 0.0,
                                                  GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL,
                                                  insets5_0_0_13, 0, 0 ) );
      add( spPlug,        new GridBagConstraints( 0, 6, 2, 1, 1.0, 0.5,
                                                  GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                                                  GuiConstants.INSETS_0, 0, 0 ) );
      add( spParam,       new GridBagConstraints( 0, 7, 2, 1, 1.0, 0.5,
                                                  GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                                                  GuiConstants.INSETS_0, 0, 0 ) );

      panelPlug.setLayout( new GridBagLayout() );
      spPlug.setBorder( new TitledBorder( " Plugs " ) );
      spPlug.getViewport().add( panelPlug, null );
      panelParam.setLayout( new GridBagLayout() );
      spParam.setBorder( new TitledBorder( " Params " ) );
      spParam.getViewport().add( panelParam, null );
    }

    public void initPanel ( InfoModule im )
    {
      info = im;
      cbPackage.setSelectedItem( info.reg.packageName );
      tfClass.setText( info.reg.className );
      tfTemplate.setText( info.reg.template );

      tfName.setText( info.reg.name );
      tfCategory.setText( info.reg.category );
      tfDescription.setText( info.reg.description );

      double yweight = 0.0;
      int    size    = info.plugs.size();
      int    i       = 0;

      for ( InfoPlug ip : info.plugs.values() )
      {
        PanelPlug p = new PanelPlug();
        p.setBorder( BorderFactory.createTitledBorder( BorderFactory.createEtchedBorder( EtchedBorder.LOWERED ),
                                                       ip.name + " (" + ip.inputOutput() + ") - " + ip.type ) );

        p.jCheckBoxMandatory.setSelected( ip.mandatory );
        p.jCheckBoxMandatory.setEnabled( !ip.input );
        p.jCheckBoxMulti.setSelected( ip.multi );
        p.tfDescription.setText( ip.description );
        p.info = ip;

        if ( i + 1 == size ) yweight = 1.0;

        panelPlug.add( p, new GridBagConstraints( 0, i++, 1, 1, 1.0, yweight,
                                                  GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                                  GuiConstants.INSETS_0, 0, 0 ) );
      }

      yweight = 0.0;
      size    = info.params.size();
      i       = 0;

      for ( InfoParam ipa : info.params.values() )
      {
        PanelParam pa = new PanelParam();
        pa.setBorder( BorderFactory.createTitledBorder(
                        BorderFactory.createEtchedBorder( EtchedBorder.LOWERED ),
                        ipa.name + " (" + ipa.type + ')' ) );
        pa.tfDescription.setText( ipa.description );
        pa.jCheckBoxVisible.setSelected( ipa.visible );
        pa.info = ipa;

        if ( i + 1 == size ) yweight = 1.0;

        panelParam.add( pa, new GridBagConstraints( 0, i++, 1, 1, 1.0, yweight,
                                                    GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                                    GuiConstants.INSETS_0, 0, 0 ) );
      }

      validate();
    }

    /** Saves information about module into registry data. */
    public void registry ()
    {
      if ( info != null )
      {
        String pack = (String)cbPackage.getSelectedItem();
        if ( !info.reg.packageName.equals( pack ) )
        {
          if ( JOptionPane.showConfirmDialog( this,
                                              "Do you want to move this module into new package?",
                                              "Confirm", JOptionPane.YES_NO_OPTION ) == JOptionPane.YES_OPTION )
          {
            JOptionPane.showMessageDialog( this,
                                           "Remember -\nYou have to edit and move the relevant source file !\n('package' clause, 'import' clauses, '@see', etc.)" );
            tables.moveModule( info, pack );
            info.reg.packageName = pack;
          }
          else
            return;
        }
        info.reg.name        = tfName.getText();
        info.reg.category    = tfCategory.getText();
        info.reg.description = tfDescription.getText();
        int i;
        for ( i = 0; i < panelPlug.getComponentCount(); i++ )
          ((PanelPlug)panelPlug.getComponent( i )).readInfo();
        for ( i = 0; i < panelParam.getComponentCount(); i++ )
          ((PanelParam)panelParam.getComponent( i )).readInfo();
        tables.registerModule( info );
      }
    }
  }

  /** Panel for plugs. */
  private class PanelPlug extends JPanel
  {
    private static final long serialVersionUID = 1L;

    private JLabel lbDescription         = new JLabel();

    private JTextField tfDescription     = new JTextField();

    private JCheckBox jCheckBoxMandatory = new JCheckBox();

    private JCheckBox jCheckBoxMulti     = new JCheckBox();

    public InfoPlug info;

    public void readInfo ()
    {
      info.description = tfDescription.getText();
      info.mandatory   = jCheckBoxMandatory.isSelected();
      info.multi       = jCheckBoxMulti.isSelected();
    }

    public PanelPlug ()
    {
      lbDescription.setText( "Description:" );
      jCheckBoxMandatory.setText( "Mandatory" );
      jCheckBoxMulti.setText( "Multi" );
      setLayout( new GridBagLayout() );

      add( jCheckBoxMandatory,
           new GridBagConstraints( 0, 0, 1, 1, 0.0, 0.0,
                                   GridBagConstraints.WEST,
                                   GridBagConstraints.HORIZONTAL,
                                   GuiConstants.INSETS_0, 0, 0 ) );
      add( jCheckBoxMulti,
           new GridBagConstraints( 1, 0, 1, 1, 0.0, 0.0,
                                   GridBagConstraints.WEST,
                                   GridBagConstraints.HORIZONTAL,
                                   GuiConstants.INSETS_0, 0, 0 ) );
      add( lbDescription,
           new GridBagConstraints( 0, 1, 1, 1, 0.0, 0.0,
                                   GridBagConstraints.WEST,
                                   GridBagConstraints.NONE,
                                   new Insets( 0, 10, 0, 5 ), 0, 0 ) );
      add( tfDescription,
           new GridBagConstraints( 1, 1, 1, 1, 1.0, 0.0,
                                   GridBagConstraints.WEST,
                                   GridBagConstraints.HORIZONTAL,
                                   GuiConstants.INSETS_0, 0, 0 ) );
    }
  }

  /** Panel for parameters. */
  private class PanelParam extends JPanel
  {
    private static final long serialVersionUID = 1L;

    private JCheckBox  jCheckBoxVisible = new JCheckBox();

    private JLabel     lbDescription    = new JLabel();

    private JTextField tfDescription    = new JTextField();

    public InfoParam info;

    public void readInfo ()
    {
      info.visible     = jCheckBoxVisible.isSelected();
      info.description = tfDescription.getText();
    }

    public PanelParam ()
    {
      jCheckBoxVisible.setText( "Visible" );
      lbDescription.setText( "Description: " );
      setLayout( new GridBagLayout() );

      add( jCheckBoxVisible,
           new GridBagConstraints( 0, 0, 1, 1, 0.0, 0.0,
                                   GridBagConstraints.WEST,
                                   GridBagConstraints.HORIZONTAL,
                                   GuiConstants.INSETS_0, 0, 0 ) );
      add( lbDescription,
           new GridBagConstraints( 1, 0, 1, 1, 0.0, 0.0,
                                   GridBagConstraints.WEST,
                                   GridBagConstraints.NONE,
                                   new Insets( 0, 5, 0, 5 ), 0, 0 ) );
      add( tfDescription,
           new GridBagConstraints( 2, 0, 1, 1, 1.0, 0.0,
                                   GridBagConstraints.WEST,
                                   GridBagConstraints.HORIZONTAL,
                                   GuiConstants.INSETS_0, 0, 0 ) );
    }
  }

  /**
   * Creates new RegModulesDialog.
   *
   * @param  frame Owner frame.
   * @param  title Title of dialog.
   * @param  modal Modality.
   */
  public RegModulesDialog ( Frame frame, String title, boolean modal )
  {
    super( frame, title, modal );
    try
    {
      jbInit();
      pack();
      loadOptionsData();
    }
    catch ( Exception ex )
    {
      LogFile.exception( ex );
    }
  }

  /** Creates new RegModulesDialog. */
  public RegModulesDialog ()
  {
    this( MainWindow.mainWindow, "Module Registration", true );
  }

  /**
   * Component initialization.
   */
  private void jbInit () throws Exception
  {
    addComponentListener( new ComponentAdapter ()
    {
      public void componentResized ( ComponentEvent e )
      {
        this_componentResized( e );
      }
    });

    btClose.setText( "Close" );
    btClose.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btClose_actionPerformed( e );
      }
    });

    btRead.setText( "Read" );
    btRead.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btRead_actionPerformed( e );
      }
    });

    btRegistry.setText( "Registry" );
    btRegistry.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btRegistry_actionPerformed( e );
      }
    });

    btSave.setText( "Save" );
    btSave.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btSave_actionPerformed( e );
      }
    });

    btRegFiles.setText( "Reg Files" );
    btRegFiles.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btRegFiles_actionPerformed( e );
      }
    });

    panelButton.add( btRead,     null );
    panelButton.add( btRegistry, null );
    panelButton.add( btSave,     null );
    panelButton.add( btClose,    null );
    panelButton.add( btRegFiles, null );

    contentPane = (JPanel)this.getContentPane();
    contentPane.add( tabModules, BorderLayout.CENTER );
    tabModules.add( "First", panelMain );
//    spModule.getViewport().add( panelMain, null );
    contentPane.add( panelButton, BorderLayout.SOUTH );

    chooser = new JFileChooser();
    filter  = new CommonFileFilter();
    filter.addExtension( "java" );
    filter.setDescription( "Java files" );
    chooser.setFileFilter( filter );
  }

  /**
   * Open dialog with module.
   *
   * @param  im module info
   */
  public void openModule ( InfoModule im )
  {
    panelMain.initPanel( im );
  }

  //==========================================================================
  //  Events:

  /**
   * Creates module and reads it's info.
   */
  void btRead_actionPerformed ( ActionEvent e )
  {
    int c = tabModules.getComponentCount();
    for ( int j = 1; j < c; j++ )
      tabModules.remove( 1 );

    chooser.setMultiSelectionEnabled( false );
    String pack = (String)panelMain.cbPackage.getSelectedItem();
    if ( e != null )
    {
      chooser.setCurrentDirectory( new File( Options.pathSource + pack.replace( '.', '/' ) ) );
      int returnVal = chooser.showOpenDialog( this );
      if ( returnVal == JFileChooser.APPROVE_OPTION )
          // file-name without path and extension:
        panelMain.tfClass.setText( chooser.getSelectedFile().getName().substring( 0,
                                   chooser.getSelectedFile().getName().lastIndexOf( '.' ) ) );
      else
        return;
    }

    try
    {
      Object o = Class.forName( pack + '.' +
                                panelMain.tfClass.getText()).newInstance();
      if ( !(o instanceof Piece) )
      {
        JOptionPane.showMessageDialog( this, panelMain.tfClass.getText() + " - not descendant of Piece",
                                       "Error", JOptionPane.ERROR_MESSAGE );
        return;
      }

      Piece p = (Piece)o;
      InfoModule info = p.getInfo();
      if ( info == null )
      {
        JOptionPane.showMessageDialog( this, panelMain.tfClass.getText() + " - missing registry data",
                                       "Error", JOptionPane.ERROR_MESSAGE );
        return;
      }

      int noTempl = p.noTemplates();
      if ( noTempl <= 0 )
      {
        JOptionPane.showMessageDialog( this, panelMain.tfClass.getText() + " - corrupted registry data",
                                       "Error", JOptionPane.ERROR_MESSAGE );
        return;
      }

      if ( noTempl > 1 )                  // Multi-template
      {
        for ( int i = 0; i < noTempl; i++ )
        {
          PanelModule panelTemp = new PanelModule();
          tabModules.add( "Template " + (i + 1), panelTemp );
          RegPiece reg = p.getReg( i );
          InfoModule infoTemp = new InfoModule( reg );

          infoTemp.reg.className   = panelMain.tfClass.getText();
          infoTemp.reg.packageName = (String)panelMain.cbPackage.getSelectedItem();
          infoTemp.reg.template    = reg.template;
          if ( reg.category != "" )
            infoTemp.reg.category = reg.category;
          else
            infoTemp.reg.category = info.reg.category;

          if ( reg.description != "" )
            infoTemp.reg.description = reg.description;
          else
            infoTemp.reg.description = info.reg.description;

          if ( reg.name != "" )
            infoTemp.reg.name = reg.name;
          else
            infoTemp.reg.name = info.reg.name;

          infoTemp.infoGUI  = info.infoGUI;
          infoTemp.nextInfo = info.nextInfo;

          for ( String s : reg.plugs.keySet() )
            infoTemp.plugs.put( s, reg.plugs.get( s ) );

          for ( String s : reg.params.keySet() )
            infoTemp.params.put( s, reg.params.get( s ) );

          panelTemp.initPanel( infoTemp );
          tabModules.setSelectedIndex( 1 );
        }
      }
      else
      {
          // regular single-template Piece
        info.reg.className   = panelMain.tfClass.getText();
        info.reg.packageName = (String)panelMain.cbPackage.getSelectedItem();

        panelMain.initPanel( info );
      }
    }
    catch ( Exception ex )
    {
      LogFile.exception( ex );
      JOptionPane.showMessageDialog( this, ex.getMessage(), "Error", JOptionPane.ERROR_MESSAGE );
    }
  }

  /**
   * Saves registry data.
   */
  void btSave_actionPerformed ( ActionEvent e )
  {
    tables.save();
  }

  /**
   * Saves info into registry data.
   */
  void btRegistry_actionPerformed ( ActionEvent e )
  {
    if ( tabModules.getSelectedIndex() == 0 )
      if ( tabModules.getComponentCount() == 1 )
        panelMain.registry();
      else
        for ( int i = 1; i < tabModules.getComponentCount(); i++ )
          ((PanelModule)tabModules.getComponent( i )).registry();
    else
      ((PanelModule)tabModules.getSelectedComponent()).registry();
  }

  /**
   * Close dialog.
   */
  void btClose_actionPerformed ( ActionEvent e )
  {
    saveOptionsData();
    setVisible( false );
  }

  /**
   * Registration of more modules.
   */
  void btRegFiles_actionPerformed ( ActionEvent e )
  {
    chooser.setMultiSelectionEnabled( true );
    String pack = (String)panelMain.cbPackage.getSelectedItem();
    chooser.setCurrentDirectory( new File( Options.pathSource + pack.replace( '.', '/' ) ) );
    int returnVal = chooser.showOpenDialog( null );
    if ( returnVal == JFileChooser.APPROVE_OPTION )
    {
      File[] fs = chooser.getSelectedFiles();
      for ( File f : fs )
      {
          // file name w/o directory & suffix
        panelMain.tfClass.setText( f.getName().substring( 0,
                                   f.getName().lastIndexOf( '.' ) ) );
        btRead_actionPerformed( null );
        tabModules.setSelectedIndex( 0 );
        btRegistry_actionPerformed( null );
      }
    }
  }

  /**
   * Dialog resized.
   */
  void this_componentResized ( ComponentEvent e )
  {
    int height = getHeight();
    if ( height < MIN_HEIGHT ) height = MIN_HEIGHT;
    int width = getWidth();
    if ( width < MIN_WIDTH )   width = MIN_WIDTH;
    setSize( width, height );
  }

  /** Load options data (window pos, height, ...). */
  protected void loadOptionsData ()
  {
    int[] pos =
    {
      Options.getInteger( "RegModulesDialog.windowPosX",  -1, Integer.MAX_VALUE, -1 ),
      Options.getInteger( "RegModulesDialog.windowPosY",  -1, Integer.MAX_VALUE, -1 )
    };
    MainWindow.adjustScreenPosition( pos );
    setLocation( pos[0], pos[1] );

    int i, j;
    i = Options.getInteger( "RegModulesDialog.windowWidth",  0, Integer.MAX_VALUE, 0 );
    j = Options.getInteger( "RegModulesDialog.windowHeight", 0, Integer.MAX_VALUE, 0 );
    if ( i > 0 && j > 0 )
      setSize( i, j );
  }

  /** Save options data (window pos, height, ...). */
  protected void saveOptionsData ()
  {
    Options.set( "RegModulesDialog.windowPosX",   getX() );
    Options.set( "RegModulesDialog.windowPosY",   getY() );
    Options.set( "RegModulesDialog.windowWidth",  getWidth() );
    Options.set( "RegModulesDialog.windowHeight", getHeight() );
  }

}
