package cz.cuni.jagrlib.reg;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.table.*;

import cz.cuni.jagrlib.gui.*;
import cz.cuni.jagrlib.*;

/**
 * Dialog for selecting modules.
 *
 * @author  PE, Jan Kostlivy
 * @version 0.26 $Rev: 599 $ $Date: 2007-11-06 00:01:11 +0100 (út, 06 XI 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/reg/RegModulesSelect.java">RegModulesSelect.java</a>
 */
public class RegModulesSelect extends JDialog
{
  private static final long serialVersionUID = 1L;

  //==========================================================================
  //  Data:

  /** Selected module. */
  public String retName;

  /** Selected module. */
  public String pieceName = "";

  /** Selected package. */
  public String packageName = Template.JAGRLIB2 + "piece";

  /** Selected template. */
  public String templateName = "";

  /** Selected module. */
  public InfoModule infoPiece;

  /** Selected modules. */
  public InfoModule[] infoPieces;

  /** Minimum height of dialog. */
  static final int MIN_HEIGHT = 300;

  /** Minimum width of dialog. */
  static final int MIN_WIDTH  = 300;

  /** Size of tool-buttons. */
  Dimension buttonDimension = new Dimension( 30, 30 );

  /** Registry data. */
  public RegTables tables = RegDatabaseBasic.tables;

  /** Flag, if registry data was changed. */
  boolean changedReg = false;

  // GUI components:
  private JTable jTablePlug;
  private JTable jTablePiece;
  private JTable jTableParam;

  private JToolBar toolBarReg  = new JToolBar();
  private JButton btRegistry   = new JButton( Options.getIcon( "Registry.gif" ) );
  private JButton btUnregistry = new JButton( Options.getIcon( "UnRegistry.gif" ) );
  private JButton btClose      = new JButton( Options.getIcon( "Close.gif" ) );
  private JButton btSaveReg    = new JButton( Options.getIcon( "Save24.gif" ) );
  private JButton btOpen       = new JButton( Options.getIcon( "Edit.gif" ) );

  private JPanel panelButton   = new JPanel();
  private JButton btOK         = new JButton();
  private JButton btStorno     = new JButton();

  private JPanel panelMain     = new JPanel();
  private SelectFilter panelFilter = RegDatabaseBasic.newSelectFilter();

  private JSplitPane  jSplitPaneTables     = new JSplitPane();
  private JSplitPane  jSplitPanePiece      = new JSplitPane();
  private JScrollPane tableScrollPanePiece = new JScrollPane();
  private JScrollPane tableScrollPanePlug  = new JScrollPane();
  private JScrollPane tableScrollPaneParam = new JScrollPane();

  private ListSelectionListener rowChanged = new ListSelectionListener ()
  {
    public void valueChanged ( ListSelectionEvent e )
    {
      jTablePiece_valueChanged( e );
    }
  };
  private JMenuBar  menuMain     = new JMenuBar();
  private JMenu     menuData     = new JMenu();
  private JMenuItem miRegistry   = new JMenuItem();
  private JMenuItem miUnregistry = new JMenuItem();
  private JMenuItem miSave       = new JMenuItem();
  private JMenuItem miClose      = new JMenuItem();
  private JMenuItem miOpen       = new JMenuItem();

  //==========================================================================
  //  Methods:

  /**
   * Creates new RegModulesSelect.
   *
   * @param frame Owner frame.
   * @param title Title of dialog.
   * @param modal Modality.
   * @param _info Filter for selection.
   */
  public RegModulesSelect ( Frame frame, String title, boolean modal, InfoModule _info )
  {
    super( frame, title, modal );
    try
    {
      infoPiece = _info;
      jbInit();
    }
    catch ( Exception ex )
    {
      LogFile.exception( ex );
    }
  }

  /** Creates new RegModulesSelect.*/
  public RegModulesSelect ()
  {
    this( MainWindow.mainWindow, "Select Module", true, null );
  }

  /**
   * Creates new RegModulesSelect.
   *
   * @param _info Filter for selection.
   */
  public RegModulesSelect ( InfoModule _info )
  {
    this( MainWindow.mainWindow, "Select Compatible Module", true, _info );
  }

  /** Component initialization. */
  private void jbInit ()
  throws Exception
  {
    addComponentListener( new ComponentAdapter ()
    {
      public void componentResized ( ComponentEvent e )
      {
        this_componentResized( e );
      }
    });

    btOK.setPreferredSize( new Dimension( 73, 27 ) );
    btOK.setText( "OK" );
    btOK.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btOK_actionPerformed( e );
      }
    });

    btStorno.setText( "Cancel" );
    btStorno.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btStorno_actionPerformed( e );
      }
    });

    panelMain.setLayout( new BorderLayout() );

    if ( infoPiece != null )
    {
      panelFilter.setParam( infoPiece );
      panelFilter.setShowGroup( false );
    }

    btUnregistry.setToolTipText( "Unregistry" );
    btUnregistry.setMaximumSize( buttonDimension );
    btUnregistry.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btUnregistry_actionPerformed( e );
      }
    });

    btClose.setToolTipText( "Close" );
    btClose.setMaximumSize( buttonDimension );
    btClose.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btClose_actionPerformed( e );
      }
    });

    btRegistry.setToolTipText( "Registry module" );
    btRegistry.setMaximumSize( buttonDimension );
    btRegistry.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btRegistry_actionPerformed( e );
      }
    });

    btOpen.setToolTipText( "Edit module/group" );
    btOpen.setMaximumSize( buttonDimension );
    btOpen.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btOpen_actionPerformed( e );
      }
    });

    btSaveReg.setToolTipText( "Save Registry Date" );
    btSaveReg.setMaximumSize( buttonDimension );
    btSaveReg.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btSaveReg_actionPerformed( e );
      }
    });

    jSplitPaneTables.setBorder( BorderFactory.createEmptyBorder() );
    jSplitPanePiece.setBorder(  BorderFactory.createEmptyBorder() );

    menuData.setText( "Data" );
    miRegistry.setText( "Registry" );
    miRegistry.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btRegistry_actionPerformed( e );
      }
    });

    miUnregistry.setText( "Unregistry" );
    miUnregistry.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btUnregistry_actionPerformed( e );
      }
    });

    miSave.setText( "Save Registry Data" );
    miSave.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btSaveReg_actionPerformed( e );
      }
    });

    miClose.setText( "Close" );
    miClose.addActionListener( new ActionListener ()
    {
      public void actionPerformed( ActionEvent e )
      {
        btClose_actionPerformed( e );
      }
    });

    miOpen.setText( "Edit Data" );
    miOpen.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        btOpen_actionPerformed( e );
      }
    });

    panelFilter.addActionListener( new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        panelFilter_actionPerformed( e );
      }
    });

    tableScrollPanePiece.setBorder( BorderFactory.createTitledBorder( "Modules" ) );
    tableScrollPanePlug.setBorder(  BorderFactory.createTitledBorder( "Plugs" ) );
    tableScrollPaneParam.setBorder( BorderFactory.createTitledBorder( "Parameters" ) );

    panelMain.add( panelFilter,      BorderLayout.NORTH );
    panelMain.add( jSplitPaneTables, BorderLayout.CENTER );

    panelButton.add( btOK,     null );
    panelButton.add( btStorno, null );

    getContentPane().add( panelMain,   BorderLayout.CENTER );
    getContentPane().add( panelButton, BorderLayout.SOUTH );
    getContentPane().add( toolBarReg,  BorderLayout.NORTH );

    toolBarReg.add( btClose,      null );
    toolBarReg.addSeparator();
    toolBarReg.add( btRegistry,   null );
    toolBarReg.add( btUnregistry, null );
    toolBarReg.add( btOpen,       null );
    toolBarReg.add( btSaveReg,    null );

    setJMenuBar( menuMain );
    menuMain.add( menuData );
    menuData.add( miRegistry );
    menuData.add( miUnregistry );
    menuData.add( miOpen );
    menuData.add( miSave );
    menuData.addSeparator();
    menuData.add( miClose );

    tableScrollPanePiece.setSize( new Dimension( 472, 225 ) );
    tableScrollPanePlug.setSize(  new Dimension( 495, 71 ) );
    tableScrollPaneParam.setSize( new Dimension( 495, 71 ) );

    jSplitPaneTables.setOrientation( JSplitPane.VERTICAL_SPLIT );
    jSplitPaneTables.add( tableScrollPanePiece, JSplitPane.TOP );
    jSplitPaneTables.add( jSplitPanePiece,      JSplitPane.BOTTOM );

    jSplitPanePiece.setOrientation( JSplitPane.VERTICAL_SPLIT );
    jSplitPanePiece.add( tableScrollPanePlug,  JSplitPane.TOP );
    jSplitPanePiece.add( tableScrollPaneParam, JSplitPane.BOTTOM );

    loadOptionsData();

    setTableModules( packageName );
  }

  /**
   * Set preview dialog. Hide panelButton, show toolBarReg.
   *
   * @param pr {@code true} - preview; {@code false} - normal select dialog.
   */
  public void setPreview ( boolean pr )
  {
    toolBarReg.setVisible( pr );
    menuMain.setVisible( pr );
    panelButton.setVisible( !pr );
  }

  /**
   * Creates and fill table of modules.
   *
   * @param _package Name of package.
   */
  protected void setTableModules ( String _package )
  {
    if ( jTablePiece != null )
      saveOptionsData();

    jTablePiece = new JTable( tables.getTableModelModule( panelFilter ) );
    jTablePiece.getSelectionModel().addListSelectionListener( rowChanged );
    loadTableModules();

    if ( infoPiece == null )
      jTablePiece.setSelectionMode( ListSelectionModel.MULTIPLE_INTERVAL_SELECTION );
    else
      jTablePiece.setSelectionMode( ListSelectionModel.SINGLE_SELECTION );

    if ( jTablePiece.getRowCount() != 0 )
      jTablePiece.setRowSelectionInterval( 0, 0 );
    else
    {
      pieceName = "no piece";
      setTablePlug(  _package, pieceName, templateName );
      setTableParam( _package, pieceName, templateName );
    }

    tableScrollPanePiece.getViewport().removeAll();
    tableScrollPanePiece.getViewport().add( jTablePiece, null );
  }

  /**
   * Creates and fill table of plugs.
   *
   * @param _package Name of package.
   * @param _class Name of class.
   * @param _template Name of template.
   */
  protected void setTablePlug ( String _package, String _class, String _template )
  {
    jTablePlug = new JTable( tables.getTableModelPlug( _package, _class, _template ) );

    jTablePlug.setSelectionMode( ListSelectionModel.SINGLE_SELECTION );
    loadTablePlug();
    tableScrollPanePlug.getViewport().removeAll();
    tableScrollPanePlug.getViewport().add( jTablePlug, null );
  }

  /**
   * Creates and fill table of parameters.
   *
   * @param _package Name of package.
   * @param _class Name of class.
   * @param _template Name of template.
   */
  protected void setTableParam ( String _package, String _class, String _template )
  {
    jTableParam = new JTable( tables.getTableModelParam( _package, _class, _template ) );
    jTableParam.setSelectionMode( ListSelectionModel.SINGLE_SELECTION );
    loadTableParam();
    tableScrollPaneParam.getViewport().removeAll();
    tableScrollPaneParam.getViewport().add( jTableParam, null );
  }

  /** Load options data (window pos, height, ...). */
  protected void loadOptionsData ()
  {
    int i, j;

    i = Options.getInteger( "RegModulesSelect.splitModule", -1, Integer.MAX_VALUE, -1 );
    if ( i >= 0 )
      jSplitPaneTables.setDividerLocation( i );

    i = Options.getInteger( "RegModulesSelect.splitPlug", -1, Integer.MAX_VALUE, -1 );
    if ( i >= 0 )
      jSplitPanePiece.setDividerLocation( i );

    int[] pos =
    {
      Options.getInteger( "RegModulesSelect.windowPosX",  -1, Integer.MAX_VALUE, -1 ),
      Options.getInteger( "RegModulesSelect.windowPosY",  -1, Integer.MAX_VALUE, -1 )
    };
    MainWindow.adjustScreenPosition( pos );
    setLocation( pos[0], pos[1] );

    i = Options.getInteger( "RegModulesSelect.windowWidth",  0, Integer.MAX_VALUE, 0 );
    j = Options.getInteger( "RegModulesSelect.windowHeight", 0, Integer.MAX_VALUE, 0 );
    if ( i > 0 && j > 0 )
      setSize( i, j );
  }

  /** Load options data (Column Index, Column Width). */
  protected void loadTableX ( JTable jTable, String keyPrefix )
  {
    String s;
    TableColumn column;
    jTable.setAutoResizeMode( JTable.AUTO_RESIZE_OFF );

    for ( int i = 0; i < jTable.getColumnCount(); i++ )
    {
      column = jTable.getColumnModel().getColumn( i );
      String colName = (String)column.getHeaderValue();
      s = Options.getString( keyPrefix+colName );
      int pos;
      if ( s != null && (pos = s.indexOf( ',' )) > 0 )
      {
        try
        {
          int val = Integer.parseInt( s.substring( pos + 1 ) );
          column.setPreferredWidth( val );
          val = Integer.parseInt( s.substring( 0, pos ) );
          jTable.moveColumn( i, val );
        }
        catch ( NumberFormatException e )
        {}
      }
    }
  }

  /** Load options data (Column Index, Column Width). */
  protected void loadTableModules ()
  {
    loadTableX( jTablePiece, "RegModulesSelect.tableModule" );
  }

  /** Load options data (Column Index, Column Width). */
  protected void loadTableParam ()
  {
    loadTableX( jTableParam, "RegModulesSelect.tableParam" );
  }

  /** Load options data (Column Index, Column Width). */
  protected void loadTablePlug ()
  {
    loadTableX( jTablePlug, "RegModulesSelect.tablePlug" );
  }

  /** Save options data (window pos, height, ...). */
  protected void saveOptionsData ()
  {
    Options.set( "RegModulesSelect.splitModule",  jSplitPaneTables.getDividerLocation() );
    Options.set( "RegModulesSelect.splitPlug",    jSplitPanePiece.getDividerLocation() );
    Options.set( "RegModulesSelect.windowPosX",   getX() );
    Options.set( "RegModulesSelect.windowPosY",   getY() );
    Options.set( "RegModulesSelect.windowWidth",  getWidth() );
    Options.set( "RegModulesSelect.windowHeight", getHeight() );

    int i;
    if ( jTablePiece != null )
      for ( i = 0; i < jTablePiece.getColumnCount() ; i++ )
      {
        String colName = jTablePiece.getColumnName( i );
        Options.set( "RegModulesSelect.tableModule" + colName,
                     String.valueOf( i ) + ',' +
                     String.valueOf( jTablePiece.getColumn( colName ).getWidth() ) );
      }

    if ( jTablePlug != null )
      for ( i = 0; i < jTablePlug.getColumnCount() ; i++ )
      {
        String colName = jTablePlug.getColumnName( i );
        Options.set( "RegModulesSelect.tablePlug" + colName,
                     String.valueOf( i ) + ',' +
                     String.valueOf( jTablePlug.getColumn( colName ).getWidth() ) );
      }

    if ( jTableParam != null )
      for ( i = 0; i < jTableParam.getColumnCount(); i++ )
      {
        String colName = jTableParam.getColumnName( i );
        Options.set( "RegModulesSelect.tableParam" + colName,
                     String.valueOf( i ) + ',' +
                     String.valueOf( jTableParam.getColumn( colName ).getWidth() ) );
      }
  }

  //==========================================================================
  //  Events:

  /** Confirm the actual selection. */
  void btOK_actionPerformed ( ActionEvent e )
  {
    retName    = pieceName;
    infoPiece  = RegDatabaseBasic.getInfo( packageName, pieceName, templateName );
    infoPieces = new InfoModule[ jTablePiece.getSelectedRowCount() ];
    int[]   rs = jTablePiece.getSelectedRows();
    for ( int i = 0; i < jTablePiece.getSelectedRowCount(); i++ )
    {
      String ppieceName    = jTablePiece.getModel().getValueAt( rs[i], 1 ).toString();
      String ppackageName  = jTablePiece.getModel().getValueAt( rs[i], 0 ).toString();
      String ptemplateName = jTablePiece.getModel().getValueAt( rs[i], 2 ).toString();
      infoPieces[i]        = RegDatabaseBasic.getInfo( ppackageName, ppieceName, ptemplateName );
    }
    saveOptionsData();
    setVisible( false );
  }

  /** Selection was cancelled. */
  void btStorno_actionPerformed ( ActionEvent e )
  {
    retName    = null;
    infoPieces = null;
    saveOptionsData();
    setVisible( false );
  }

  /** Cursor moved in module table. Changes: plygs pane, parameter pane. */
  void jTablePiece_valueChanged ( ListSelectionEvent e )
  {
    if ( jTablePiece.getSelectedRow() >= 0 )
    {
      String _name = jTablePiece.getModel().getValueAt( jTablePiece.getSelectedRow(), 1 ).toString();
      if ( _name.compareTo(pieceName) != 0 )
      {
        pieceName    = _name;
        packageName  = jTablePiece.getModel().getValueAt( jTablePiece.getSelectedRow(), 0 ).toString();
        templateName = jTablePiece.getModel().getValueAt( jTablePiece.getSelectedRow(), 2 ).toString();
        setTablePlug(  packageName, pieceName, templateName );
        setTableParam( packageName, pieceName, templateName );
      }
    }
  }

  /** Filter change. */
  void panelFilter_actionPerformed ( ActionEvent e )
  {
    setTableModules( packageName );
  }

  /** Unregistry selected module[s]. */
  void btUnregistry_actionPerformed ( ActionEvent e )
  {
    if ( JOptionPane.showConfirmDialog( this, "Do you want to unregistry all selected modules?",
                                        "Confirm", JOptionPane.YES_NO_OPTION, JOptionPane.WARNING_MESSAGE ) == JOptionPane.YES_OPTION )
    {
      int[] rs = jTablePiece.getSelectedRows();
      for ( int i = 0; i < jTablePiece.getSelectedRowCount(); i++ )
      {
        String ppieceName    = jTablePiece.getModel().getValueAt( rs[i], 1 ).toString();
        String ppackageName  = jTablePiece.getModel().getValueAt( rs[i], 0 ).toString();
        String ptemplateName = jTablePiece.getModel().getValueAt( rs[i], 2 ).toString();

        RegDatabaseBasic.unregistryModule( ppackageName, ppieceName, ptemplateName );
      }
      setTableModules( packageName );
      changedReg = true;
    }
  }

  /** Registry the actual filled module. */
  void btRegistry_actionPerformed ( ActionEvent e )
  {
    RegDatabaseBasic.registryModule( null, null, null );
    setTableModules( packageName );
    changedReg = true;
  }

  /** Save registry data. */
  void btSaveReg_actionPerformed ( ActionEvent e )
  {
    RegDatabaseBasic.saveRegistryData();
    changedReg = false;
  }

  void btOpen_actionPerformed ( ActionEvent e )
  {
    if ( packageName.compareTo( "GROUP" ) == 0 )
    {
      InfoGroup ig = (InfoGroup)RegDatabaseBasic.getInfo( packageName, pieceName, templateName );
      RegDatabaseBasic.registryGroup( ig );
    }
    else
      RegDatabaseBasic.registryModule( packageName, pieceName, templateName );
    setTableModules( packageName );
    changedReg = true;
  }

  /** Close dialog window: check if changes were saved.. */
  void btClose_actionPerformed ( ActionEvent e )
  {
    if ( changedReg )
      if ( JOptionPane.showConfirmDialog ( this, "Do you want to save registry data?",
                                           "Confirm", JOptionPane.YES_NO_OPTION ) == JOptionPane.YES_OPTION )
        btSaveReg_actionPerformed( null );

    saveOptionsData();
    setVisible( false );
  }

  /** Dialog was resized. */
  void this_componentResized ( ComponentEvent e )
  {
    setSize( Formula.clamp( getWidth(),  MIN_WIDTH,  Integer.MAX_VALUE ),
             Formula.clamp( getHeight(), MIN_HEIGHT, Integer.MAX_VALUE ) );
  }
}
