package cz.cuni.jagrlib.reg;

import java.util.Set;

import javax.swing.table.AbstractTableModel;

/**
 * Abstract class for registry database.
 *
 * @author  Jan Kostlivy
 * @version 0.25 $Rev: 376 $ $Date: 2006-12-25 04:22:48 +0100 (po, 25 XII 2006) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/reg/RegTables.java">RegTables.java</a>
 */
public interface RegTables
{
  /** Multitemplate class. */
  String MULTI_TEMPLATE = "MULTITEMPLATE";

  //==========================================================================
  //  Methods:

  /**
   * Registration of Piece into registry data.
   *
   * @param _info Information about module.
   */
  void registerModule ( InfoModule _info );

  /**
   * Registration of group into registry data.
   *
   * @param _info Information about group.
   */
  void registerGroup ( InfoGroup _info );

  /**
   * Unregistration of Piece into registry data.
   *
   * @param _info Information about module.
   */
  void unregister ( InfoModule _info );

  /**
   * Move module to diferent package.
   *
   * @param _info Information about module.
   * @param newPackageName new package.
   */
  void moveModule ( InfoModule _info, String newPackageName );

  /**
   * Gets information about module or group.
   *
   * @param _package Name of package.
   * @param _class Name of class.
   * @param _template Name of template.
   * @return information about module or group.
   */
  InfoModule getInfo ( String _package, String _class, String _template );

  /**
   * Gets TableModel for table of modules.
   *
   * @param _filter Filter.
   * @return table.
   */
  AbstractTableModel getTableModelModule ( SelectFilter _filter );

  /**
   * Gets TableModel for table of plugs.
   *
   * @param _package Name of package.
   * @param _class Name of class.
   * @param _template Name of template.
   * @return table.
   */
  AbstractTableModel getTableModelPlug ( String _package, String _class, String _template );

  /**
   * Gets TableModel for table of parameters.
   *
   * @param _package Name of package.
   * @param _class Name of class.
   * @param _template Name of template.
   * @return table.
   */
  AbstractTableModel getTableModelParam ( String _package, String _class, String _template );

  /** Returns set of all used interfaces (Plug types). */
  Set< String > getInterfaces ();

  /** Saves registry data. */
  void save ();

}
