package cz.cuni.jagrlib.reg;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * Filter for viewing modules.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.25 $Rev: 381 $ $Date: 2007-01-02 15:51:44 +0100 (út, 02 I 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/reg/SelectFilter.java">SelectFilter.java</a>
 */
public abstract class SelectFilter extends JPanel
{
  private static final long serialVersionUID = 1L;

  //==========================================================================
  //  Data:

  transient ActionListener actionListener;

  protected boolean showGroup = true;

  //==========================================================================
  //  Methods:

  /**
   * Sets filtering parameters from provided object.
   */
  public void setParam ( Object par )
  {
  }

  /**
   * Able to select groups?
   */
  public boolean getShowGroup ()
  {
    return showGroup;
  }

  /**
   * Sets ability of groups-selecting.
   */
  public void setShowGroup ( boolean b )
  {
    showGroup = b;
  }

  /**
   * Test if module passes the associated filter.
   */
  public abstract boolean filter ( InfoModule im );

  /**
   * Invoked in case of potential filter-change.
   */
  public void doActionPerformed ( ActionEvent e )
  {
    processActionEvent( e );
  }

  /**
   * Adds the specified action listener to receive action events from
   * this filter. Action events occur when a user changes any limit.
   * If l is null, no exception is thrown and no action is performed.
   *
   * @param  l the action listener
   * @see    #removeActionListener
   * @see    #getActionListeners
   * @see    java.awt.event.ActionListener
   */
  public synchronized void addActionListener ( ActionListener l )
  {
    if ( l == null )
      return;

    actionListener = AWTEventMulticaster.add( actionListener, l );
  }

  /**
   * Removes the specified action listener so that it no longer
   * receives action events from this filter.
   * If l is null, no exception is thrown and no action is performed.
   *
   * @param  l the action listener
   * @see    #addActionListener
   * @see    #getActionListeners
   * @see    java.awt.event.ActionListener
   */
  public synchronized void removeActionListener ( ActionListener l )
  {
    if ( l == null )
      return;

    actionListener = AWTEventMulticaster.remove( actionListener, l );
  }

  /**
   * Returns an array of all the action listeners
   * registered on this filter.
   *
   * @return all of this filter's <tt>ActionListener</t>s
   *         or an empty array if no action
   *         listeners are currently registered
   *
   * @see    #addActionListener
   * @see    #removeActionListener
   * @see    java.awt.event.ActionListener
   */
  public synchronized ActionListener[] getActionListeners ()
  {
    return (ActionListener[])getListeners( ActionListener.class );
  }

  /**
   * Processes action events occurring on this filter
   * by dispatching them to any registered
   * <tt>ActionListener</tt> objects.
   * <p>
   * This method is not called unless action events are
   * enabled for this filter. Action events are enabled
   * when one of the following occurs:
   * <p><ul>
   * <li>An <tt>ActionListener</tt> object is registered
   * via <tt>addActionListener</tt>.
   * <li>Action events are enabled via <tt>enableEvents</tt>.
   * </ul>
   * <p>Note that if the event parameter is <tt>null</tt>
   * the behavior is unspecified and may result in an
   * exception.
   *
   * @param  e the action event
   * @see    java.awt.event.ActionListener
   * @see    java.awt.Component#enableEvents
   */
  protected void processActionEvent ( ActionEvent e )
  {
    ActionListener listener = actionListener;
    if ( listener != null )
      listener.actionPerformed( e );
  }

}
