package cz.cuni.jagrlib.reg;

import java.util.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import cz.cuni.jagrlib.LogFile;
import cz.cuni.jagrlib.gui.GuiConstants;

/**
 * Basic filter for viewing modules.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.25 $Rev: 398 $ $Date: 2007-02-04 23:34:56 +0100 (ne, 04 II 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/reg/SelectFilterBasic.java">SelectFilterBasic.java</a>
 */
public class SelectFilterBasic extends SelectFilter
{
  private static final long serialVersionUID = 1L;

  //==========================================================================
  //  Data:

  private InfoModule  infoPiece;

  private JPanel      panelFilter;
  private JLabel      lbFilter;

  private JPanel      panelCategory  = new JPanel();
  private JTextField  tfLimit        = new JTextField();
  private JLabel      lbLimit        = new JLabel();

  private JPanel      panelPlugLimit = new JPanel();
  private JCheckBox   cbPlugLimit    = new JCheckBox();
  private JComboBox   comboIface     = new JComboBox();

  //==========================================================================
  //  Methods:

  /** Creates new SelectFilter. */
  public SelectFilterBasic ()
  {
    try
    {
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Component initialization.
   */
  private void jbInit ()
  throws Exception
  {
    ActionListener listener = new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        doActionPerformed( e );
      }
    };

    FocusAdapter focusAd = new FocusAdapter ()
    {
      public void focusLost ( FocusEvent e )
      {
        doActionPerformed( null );
      }
    };

    lbLimit.setText( " Category: " );

    tfLimit.addActionListener( listener );
    tfLimit.addFocusListener( focusAd );

      // collect all existing interfaces:
    Set< String > ifaces = RegDatabaseBasic.tables.getInterfaces();
    for ( String iface : ifaces )
      comboIface.addItem( iface );
    comboIface.addActionListener( listener );

    cbPlugLimit.addActionListener( listener );
    cbPlugLimit.setText( "Plug" );

    panelPlugLimit.setLayout( new BorderLayout() );
    panelPlugLimit.add( cbPlugLimit, BorderLayout.WEST );
    panelPlugLimit.add( comboIface, BorderLayout.CENTER );

    panelCategory.setLayout( new BorderLayout() );
    panelCategory.add( lbLimit, BorderLayout.WEST );
    panelCategory.add( tfLimit, BorderLayout.CENTER );

    this.setBorder( BorderFactory.createEtchedBorder() );
    this.setLayout( new GridBagLayout() );

    GridBagConstraints cons = new GridBagConstraints( 0, -1, 1, 1, 1.0, 0.0,
                                                      GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                                      new Insets( 2, 2, 0, 2 ), 0, 0 );
    add( panelPlugLimit, cons );
    add( panelCategory,  cons );
  }

  /**
   * Sets filtering parameters according to the given info-module.
   *
   * @param par Either {@link InfoModule} or {@link InfoGroup}.
   */
  @Override
  public void setParam ( Object par )
  {
    infoPiece = null;
    if ( !(par instanceof InfoModule) )
      return;

    infoPiece      = (InfoModule)par;
    panelFilter    = new JPanel();
    lbFilter       = new JLabel();

    add( panelFilter,
         new GridBagConstraints( 0, -1, 1, 1, 1.0, 0.0,
                                 GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                 new Insets( 2, 2, 0, 2 ), 0, 0 ) );

    lbFilter.setText( " Modules with matching plugs (plug-set imported from '" +
                      infoPiece.reg.fullClassName() + "'):" );
    panelFilter.setLayout( new GridBagLayout() );
    panelFilter.add( lbFilter,
                     new GridBagConstraints( 0, 0, 1, 1, 1.0, 1.0,
                                             GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                             GuiConstants.INSETS_0, 0, 0 ) );

    ActionListener chListener = new ActionListener ()
    {
      public void actionPerformed ( ActionEvent e )
      {
        String name = ((JCheckBox)e.getSource()).getToolTipText();
        InfoPlug ip = infoPiece.plugs.get( name );
        ip.infoGUI.selected = ((JCheckBox)e.getSource()).isSelected();
        doActionPerformed( null );
      }
    };

    for ( InfoPlug ip : infoPiece.plugs.values() )
    {
      JCheckBox cb = new JCheckBox();
      cb.setToolTipText( ip.type );
      cb.setText( ip.name );
      cb.setSelected( true );
      cb.addActionListener( chListener );
      ip.infoGUI.selected = true;

      panelFilter.add( cb,
                       new GridBagConstraints( 0, -1, 1, 1, 1.0, 1.0,
                                               GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                                               GuiConstants.INSETS_0, 0, 0 ) );
    }
  }

  /**
   * Test if module passes the associated filter.
   */
  @Override
  public boolean filter ( InfoModule im )
  {
    // Test whether category matches the pattern:
    String[] tokens = tfLimit.getText().split( "[., ]" );
    if ( tokens != null &&
         tokens.length > 0 )
    {
      String cat = im.reg.category;
      for ( String tok : tokens )
        if ( cat.indexOf( tok ) < 0 )
          return false;
    }

    // Matching plug-set test:
    if ( infoPiece != null )
    {
      Set< String > plugs = new HashSet< String >( im.plugs.keySet() );
      for ( InfoPlug ip : infoPiece.plugs.values() )
      {
        if ( !ip.infoGUI.selected ) continue;
        String iface  = ip.name;
        boolean input = ip.input;
        boolean found = false;
        for ( String name : plugs )
        {
          InfoPlug imIp = im.plugs.get( name );
          if ( imIp.name.equals( iface ) &&
               imIp.input == input )
          {
            plugs.remove( name );
            found = true;
            break;
          }
        }
        if ( !found )
          return false;
      }
    }

    // Single plug (interface) presence test:
    String fixedIface = (String)comboIface.getSelectedItem();
    if ( cbPlugLimit.isSelected() &&
         fixedIface.length() > 0 )
    {
      for ( InfoPlug ip : im.plugs.values() )
        if ( fixedIface.equals( ip.name ) )
          return true;

      return false;
    }

    return true;
  }

}
