package cz.cuni.jagrlib.testing;

import java.awt.Color;
import java.util.*;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Renders Ant-city (pilot implementation - not correct).
 *
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/testing/AntCity.java">AntCity.java</a>
 */
public class AntCity extends DefaultRender3D
{
  //==========================================================================
  //  Data:

  /** Actual light source direction. */
  protected double[] light;
  {
    light = new double[] { -0.5, 0.2, 0.3 };
    lightSetup();
  }

  /** One of 4 (8) view directions. */
  protected int viewDirection;

  /** Center of the view frustup ("lookAt" point). */
  protected double[] center;

  /** Projected brick size in pixels.. */
  protected double brickSize;

  /** Distance between two neighbours in vertical direction. */
  protected static final double brickHeight = 0.7;

  /** Shade coefficients (multiplication coefficients for displayed case colors). */
  protected double shadeLeft, shadeRight, shadeUp;

  /** Background color. */
  protected Color background = Color.DARK_GRAY;

  //==========================================================================
  //  Support:

  protected void lightSetup ()
  {
    if ( light == null || light.length < 3 ) return;

    Geometry.normalize3D( light );

      // !!! TODO: compute exact shade coefficients !!!
    shadeLeft  = 0.7;
    shadeRight = 0.3;
    shadeUp    = 1.0;
  }

  //==========================================================================
  //  Interface Render3D:

  /**
   * 3D rendering using actual parameters.
   *
   * @see #setProjection(TrMatrix)
   * @see #setRenderStyle(int)
   * @see #render(TrMatrix,TrMatrix,int)
   * @see #setProjection(double[],double[],double[],double)
   */
  @Override
  public void render ()
  {
    SampleData     data   = (SampleData)    getInterface( PL_DATA,   IFACE+"SampleData" );
    RasterGraphics output = (RasterGraphics)getInterface( PL_OUTPUT, IFACE+"RasterGraphics" );
    if ( data == null || output == null ) return;

    double width  = output.getWidth();    // window width in pixels
    double height = output.getHeight();   // window height in pixels
    double sx0    = 0.5 * width;          // screen coordinates (center)
    double sy0    = 0.5 * height;
    double dx     = brickSize;            // brick size in pixels
    double dy     = brickSize * brickHeight * 0.5;

    int dims      = data.getDataDim( null );
    int[] dim     = new int[ dims ];
    data.getDataDim( dim );               // dimensions of source data array
    int dataXmax  = dim[dims-1];          // I'll be using the last two dimensions
    int dataYmax  = dim[dims-2];          // !!! TODO: this has to be changed in 3D Ant-city rendering !!!
    int[] to      = new int[ dims ];
    to[dims-1]    = dataXmax;
    to[dims-2]    = dataYmax;
    Arrays.fill( to, 0, dims - 2, 1 );

    int[] d = new int[ dataXmax * dataYmax ];
    data.getSamples( null, to, d );
    int xi = Formula.round( center[0] );
    int yi = Formula.round( center[1] );

      // 2D data array is in d[] (each word: 0xAABBGGRR)
      // data size is: dataXmax x dataYmax
      // [xi,yi] will be displayed in the center of the screen [sx0,sy0]
      // brick size is dx x dy (in pixels)
    int x0 = xi;                          // data coordinates for upper left corner
    int y0 = yi;
      // determine coordinates for the upper left corner:
    sy0 -= 0.5 * dy;                      // upper left corner of the brick
    sx0 -= 0.5 * dx;

    while ( sy0 > 0 )
    {
      sy0 -= dy;
      sx0 -= 0.5 * dx;
      x0--;
      if ( sy0 <= 0 ) break;
      sy0 -= dy;
      sx0 += 0.5 * dx;
      y0--;
    }

    while ( sx0 > -0.5 * dx )
    {
      sx0 -= dx;
      x0--; y0++;
    }

      // [x0,y0] is data-pointer to upper-left corner, [xi,yi] will be used in loops
      // [sx0,sy0] are screen-coordinates, sxi will be used in loops
    double sxi;
    int[] color = new int[ 3 ];

      // screen row loop:
    while ( sy0 < height &&
            !userBreak )
    {
        // 1st row:
      sxi = sx0;
      xi = x0; yi = y0;

      while ( sxi < width )               // draw one brick
      {
        if ( yi >= 0 && yi < dataYmax &&
             xi >= 0 && xi < dataXmax )
        {
          int col = d[ yi * dataXmax + xi ];
          color[0] =  col        & 0xff;
          color[1] = (col >>  8) & 0xff;
          color[2] = (col >> 16) & 0xff;
        }
        else
        {
          color[0] = background.getRed();
          color[1] = background.getGreen();
          color[2] = background.getBlue();
        }

        output.setRectangle( Formula.round( sxi ),      Formula.round( sy0 ),
                             Formula.round( sxi + dx ), Formula.round( sy0 + dy ), color );
        sxi += dx;
        xi++;
        yi--;
      }

      sy0 += dy;
      if ( sy0 >= height ) break;

        // 2nd row:
      sx0 -= 0.5 * dx;
      y0++;
      sxi = sx0;
      xi = x0; yi = y0;

      while ( sxi < width )               // draw one brick
      {
        if ( yi >= 0 && yi < dataYmax &&
             xi >= 0 && xi < dataXmax )
        {
          int col = d[ yi * dataXmax + xi ];
          color[0] =  col        & 0xff;
          color[1] = (col >>  8) & 0xff;
          color[2] = (col >> 16) & 0xff;
        }
        else
        {
          color[0] = background.getRed();
          color[1] = background.getGreen();
          color[2] = background.getBlue();
        }

        output.setRectangle( Formula.round( sxi ),      Formula.round( sy0 ),
                             Formula.round( sxi + dx ), Formula.round( sy0 + dy ), color );
        sxi += dx;
        xi++;
        yi--;
      }

      sy0 += dy;
      sx0 += 0.5 * dx;
      x0++;
    }
  }

  /**
   * Sets actual projection parameters (non-mandatory).
   *
   * @param view Viewing vector (from camera to the scene).
   * @param up Up vector (should always point up on the screen).
   * @param lookAt Point in the middle of the view.
   * @param zoom Zoom factor (camera - lookAt distance, element size on the screen, etc.).
   * @return {@code true} if the method is implemented.
   */
  @Override
  public boolean setProjection ( double[] view, double[] up, double[] lookAt, double zoom )
  {
      // !!! TODO: determine correct viewing direction from the 'view' vector !!!
    viewDirection = 0;
    center        = lookAt;
    brickSize     = zoom;

    return true;
  }

  //==========================================================================
  //  Interface Property:

  public final static String LIGHT_SOURCE = "Light source";
  public final static String BACKGROUND   = "Background";

  /**
   * Sets the given property.
   *
   * @param  key Key string.
   * @param  value The new value.
   */
  @Override
  public void set ( String key, Object value )
  {
    if ( key == null || value == null ) return;

      // LIGHT_SOURCE:
    if ( key.compareTo(LIGHT_SOURCE) == 0 )
    {
      if ( value instanceof double[] &&
           ((double[])value).length >= 3 )
      {
        light = (double[])value;
        lightSetup();
      }
      return;
    }
      // BACKGROUND:
    if ( key.compareTo(BACKGROUND) == 0 )
    {
      background = colorProperty( value, background );
      return;
    }
  }

  /**
   * Gets the given property.
   *
   * @param  key Key string.
   * @return The actual value or {@code null}.
   */
  @Override
  public Object get ( String key )
  {
    if ( key == null ) return null;

    if ( key.compareTo(LIGHT_SOURCE) == 0 )
      return light;
    if ( key.compareTo(BACKGROUND) == 0 )
      return background;

    return null;
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "AntCity";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "Render3DToSampleDataAndRasterGraphics";

  /** Object description. */
  private final static String DESCRIPTION = "Renders 'Ant city' into RasterGraphics.";

  /** Object category. */
  protected final static String CATEGORY = C_3D + '.' + C_RENDER;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug(  PL_INPUT,  IFACE+"Render3D" );
      t.newOutputPlug( PL_DATA,   IFACE+"SampleData" );
      t.newOutputPlug( PL_OUTPUT, IFACE+"RasterGraphics" );
        // Property:
      t.propBegin( LIGHT_SOURCE, TYPE_OBJECT, "Light-source direction", false );
      t.propEnd();
      t.propBegin( BACKGROUND, TYPE_OBJECT, "Background color", true );
        t.propDefault( "[64;64;64]" );
        t.propManipulator( "ParamColor" );
      t.propEnd();
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
