package cz.cuni.jagrlib.testing;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/** Support class for storing difference data. */
class DiffRecord
{
  int a, b, c, d;

  /** Makes regular step. */
  void step ()
  {
    d = d + (c >> 12);
    c = c + b;
    b = b + a;
  }

  /** Doubles the step. */
  void up ()
  {
    c = (c << 1) + b;
    b = (b << 2) + (a << 2);
    a =  a << 3;
  }

  /** Divides the step by 2. */
  void down ()
  {
    c = (c >> 1) - (b >> 3) + (a >> 4); // 1/2, -1/8, 1/16
    b = (b >> 2) - (a >> 3);            // 1/4, -1/8
    a = (a >> 3);                       // 1/8
  }
}

/**
 * Algorithm for drawing a Bezier cubic curve
 *
 * @author  Ivo Pavlik, Martin Murin
 * @version 0.25 $Rev: 276 $ $Date: 2006-05-27 18:24:56 +0200 (so, 27 V 2006) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/testing/BezierCurve.java">BezierCurve.java</a>
 */
public class BezierCurve extends Piece implements CurveRender
{
  //==========================================================================
  //  Data:

  //==========================================================================
  //  Interface Property:

  /**
   * Sets the given property.
   *
   * @param  key Key string.
   * @param  value The new value.
   */
  public void set ( String key, Object value )
  {
    if ( key == null || value == null ) return;
    return;
  }

  /**
   * Gets the given property.
   *
   * @param  key Key string.
   * @return The actual value or <tt>null</tt>.
   */
  public Object get ( String key )
  {
    if ( key == null ) return null;
    return null;
  }

  //==========================================================================
  //  Interface CurveRender

  /**
   * Draws curve segment using the given array of control points.
   *
   * @param cp Array of control points.
   * @param orig First array item to be used.
   * @param len Number of control points (can define curve order).
   * @param dim Number of coordinate components (2 for plane, ..).
   */
  public void drawCurve ( double[] cp, int orig, int len, int dim )
  {
    int dataLen = len * dim;
    int[] icp = new int[ dataLen ];

    for ( int i = 0; i < dataLen; i++ )
      icp[i] = Formula.round( cp[orig++] );

    drawCurve( icp, 0, len, dim );
  }

  /**
   * Draws curve segment using the given array of control points.
   *
   * @param cp Array of control points.
   * @param orig First array item to be used.
   * @param len Number of control points (can define curve order).
   * @param dim Number of coordinate components (2 for plane, ..).
   */
  public void drawCurve ( int[] cp, int orig, int len, int dim )
  {
    AlphaMask mask = (AlphaMask)getInterface( PL_OUTPUT, IFACE+"AlphaMask" );

    int Ax, Bx, Cx, Dx, Ay, By, Cy, Dy; // Cubic polynomial quotients
    int B1x, B1y, B2x, B2y, B3x, B3y;   // Points B1, B2, B3
    double t = 0.0;
    double hParameter = 0.001;

    DiffRecord X = new DiffRecord();
    DiffRecord Y = new DiffRecord();

      // Checks reference
    if( mask == null )
    {
      LogFile.error( "BezierCurve: mask == null" );
      return;
    }

      // Computes Bezier parameters
    Ax =  - cp[orig  ] + 3*cp[orig+2] - 3*cp[orig+4] + cp[orig+6];
    Ay =  - cp[orig+1] + 3*cp[orig+3] - 3*cp[orig+5] + cp[orig+7];
    Bx =  3*cp[orig  ] - 6*cp[orig+2] + 3*cp[orig+4];
    By =  3*cp[orig+1] - 6*cp[orig+3] + 3*cp[orig+5];
    Cx = -3*cp[orig  ] + 3*cp[orig+2];
    Cy = -3*cp[orig+1] + 3*cp[orig+3];
    Dx =    cp[orig  ];
    Dy =    cp[orig+1];

      // Initializes parameters of X and Y (a, b, c, d)
      // Computes in double, "shifts" by 16 or 28 and converts into (shifted) int
    double abcShiftingValue = (double)(1 << 28);

    X.d = Dx << 16;
    X.c = (int)(
        ( ( hParameter * Cx ) +
          ( hParameter * hParameter * Bx ) +
          ( hParameter * hParameter * hParameter * Ax ) )
        * abcShiftingValue );
    X.b = (int)(
        ( ( 2 * hParameter * hParameter * Bx ) +
          ( 6 * hParameter * hParameter * hParameter * Ax ) )
        * abcShiftingValue );
    X.a =(int)(
        ( 6 * hParameter * hParameter * hParameter * Ax )
        * abcShiftingValue );

    Y.d = Dy << 16;
    Y.c = (int)(
        ( ( hParameter * Cy ) +
          ( hParameter * hParameter * By ) +
          ( hParameter * hParameter * hParameter * Ay ) )
        * abcShiftingValue );
    Y.b = (int)(
        ( ( 2 * hParameter * hParameter * By ) +
          ( 6 * hParameter * hParameter * hParameter * Ay ) )
        * abcShiftingValue );
    Y.a = (int)(
        ( 6 * hParameter * hParameter * hParameter * Ay )
        * abcShiftingValue );

      // Other initializings
    t   = 0.0;
    B1x = X.d; B1y = Y.d;
    B2x = B1x; B2y = B1y;
    B3x = B1x; B3y = B1y;

    int dShiftedOne    = 1 << 16;
    int abcShiftedOne  = 1 << 28;
    int abcShiftedHalf = 1 << 27;

    // Main cycle
    do
    {
        // If new point is far enough from the one last painted
      if( ( Math.abs( B1x - B3x ) >= dShiftedOne ) ||
          ( Math.abs( B1y - B3y ) >= dShiftedOne ) )
      {
          // Draws a pixel
        mask.putPixel( B1x >> 16, B1y >> 16, 0.8 );

        if ( ( ((B2x >> 16) == (B1x >> 16)) && ((B2y >> 16) == (B3y >> 16)) ) ||
             ( ((B2x >> 16) == (B3x >> 16)) && ((B2y >> 16) == (B1y >> 16)) ) )
        {   // If improper triangle (corner) was created
            // skip B2 point
          B1x = B3x;
          B1y = B3y;
        }
        else
        {   // Otherwise move to next point
          B1x = B2x;
          B1y = B2y;
        }
      }

      B2x = B3x;
      B2y = B3y;

        // Check step size
      while ( Math.abs( X.c ) > abcShiftedOne || Math.abs( Y.c ) > abcShiftedOne )
      {
        X.down();
        Y.down();
        hParameter /= 2;
      }

      while ( Math.abs( X.c ) < abcShiftedHalf && Math.abs( Y.c ) < abcShiftedHalf )
      {
        X.up();
        Y.up();
        hParameter *= 2;
      }

        // Regular step
      X.step();
      Y.step();

      B3x = X.d;
      B3y = Y.d;

      t += hParameter;

    } while ( t <= 1.0 );

      // Last two points
    mask.putPixel( B1x >> 16, B1y >> 16, 0.8 );
    mask.putPixel( B2x >> 16, B2y >> 16, 0.8 );
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "BezierDifferential";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "CurveRenderToAlphaMask";

  /** Object description. */
  private final static String DESCRIPTION = "Draws Bezier curve.";

  /** Object category. */
  protected final static String CATEGORY = C_2D + "." + C_DRAW + "." + C_CURVE + "." + C_INTEGER;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug(  PL_INPUT,  IFACE+"CurveRender" );
      t.newOutputPlug( PL_OUTPUT, IFACE+"AlphaMask" );
        // Property:
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
