package cz.cuni.jagrlib.testing;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Color-reducing example - rounding with 3-3-2 color palette.
 *
 * @version 0.24 $Rev: 235 $ $Date: 2006-05-05 09:39:40 +0200 (pá, 05 V 2006) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/testing/ColorReduce.java">ColorReduce.java</a>
 */
public class ColorReduce extends Piece implements Trigger
{
  //==========================================================================
  //  Data:

  /** Random pseudo-dithering amplitude. */
  protected int randomize = 16;

  //==========================================================================
  //  Interface Trigger:

  /**
   * Starts image remapping.
   *
   * @param  type The action type (whatever it means..).
   * @return <tt>true</tt> if the action was successful.
   */
  public boolean fire ( int type )
  {
    final RasterGraphics input    = (RasterGraphics)getInterface( "image1",   IFACE+"RasterGraphics" );
    final RasterGraphics output   = (RasterGraphics)getInterface( "image2",   IFACE+"RasterGraphics" );
    final ColormapStore  colorMap = (ColormapStore) getInterface( PL_PALETTE, IFACE+"ColormapStore" );
    int i, j;

      // output image:
    int width = input.getWidth();
    int height = input.getHeight();
    output.init( width, height, RasterGraphics.MODE_COLORMAP, 0 );

      // create 3-3-2 palette:
    double R, G, B;
    double dRG = 255.0 / 7;
    double dB = 255.0 / 3;
    int r, g, b;
    int palette[][] = new int[ 256 ][ 3 ];
    for ( r = i = 0, R = 0.0; r < 8; r++, R += dRG )
      for ( g = 0, G = 0.0; g < 8; g++, G += dRG )
        for ( b = 0, B = 0.0; b < 4; b++, B += dB )
        {
          palette[i][0] = (int)( R + 0.5d );
          palette[i][1] = (int)( G + 0.5d );
          palette[i][2] = (int)( B + 0.5d );
          i++;
        }
    colorMap.setSize( 1 );
    colorMap.setColormap( 0, palette );
    output.setColormapType( RasterGraphics.MODE_RGB, 255 );
    output.setColormap( palette );

      // main loop:
    RandomJames rnd = new RandomJames();
    int randomizeHalf = randomize / 2;
    int[] pixel = new int[3];
    for ( j = 0; j < height; j++ )        // one output row
      for ( i = 0; i < width; i++ )       // one output pixel
      {
        input.getRGB( i, j, pixel );
        if ( randomize > 0 )
        {
          pixel[0] += (rnd.uniformNumber() * randomize) - randomizeHalf;
          if ( pixel[0] < 0 ) pixel[0] = 0;
          pixel[1] += (rnd.uniformNumber() * randomize) - randomizeHalf;
          if ( pixel[1] < 0 ) pixel[1] = 0;
          pixel[2] += (rnd.uniformNumber() * randomize) - randomizeHalf;
          if ( pixel[2] < 0 ) pixel[2] = 0;
        }
        r = (pixel[0] + 16) >> 5;
        if ( r > 7 ) r = 7;
        g = (pixel[1] + 16) >> 5;
        if ( g > 7 ) g = 7;
        b = (pixel[2] + 32) >> 6;
        if ( b > 3 ) b = 3;
        output.putPixel( i, j, (r << 5) + (g << 2) + b );
      }
    return true;
  }

  //==========================================================================
  //  Interface Property:

  public final static String RANDOMIZE = "Randomize";

  /**
   * Sets the given property.
   *
   * @param  key Key string.
   * @param  value The new value.
   */
  public void set ( String key, Object value )
  {
    if ( key == null || value == null ) return;
      // RANDOMIZE:
    if ( key.compareTo(RANDOMIZE) == 0 )
    {
      randomize = intProperty( value, randomize, 0, 256 );
      return;
    }
  }

  /**
   * Gets the given property.
   *
   * @param  key Key string.
   * @return The actual value or <tt>null</tt>.
   */
  public Object get ( String key )
  {
    if ( key == null ) return null;
    if ( key.compareTo(RANDOMIZE) == 0 )
      return randomize;
    return null;
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "ColorReduce";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "TriggerToRasterGraphicsAndColormapStoreAndRasterGraphics";

  /** Object description. */
  private final static String DESCRIPTION = "Image remapping, using 3-3-2 palette and simple rounding.";

  /** Object category. */
  protected final static String CATEGORY = C_2D + "." + C_RASTER + "." + C_FILTER;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug(  PL_INPUT,   IFACE+"Trigger" );
      t.newOutputPlug( "image1",   IFACE+"RasterGraphics" );
      t.newOutputPlug( "image2",   IFACE+"RasterGraphics" );
      t.newOutputPlug( PL_PALETTE, IFACE+"ColormapStore" );
        // Property:
      t.propBegin( RANDOMIZE, TYPE_INTEGER, "Randomization aplitude", true );
        t.propDefault( "16" );
        t.propBounds( "0", "256" );
      t.propEnd();
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
