package cz.cuni.jagrlib.testing;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Color-reducing example - rounding with pre-defined color palette.
 *
 * @version 0.25 $Rev: 243 $ $Date: 2006-05-08 01:22:21 +0200 (po, 08 V 2006) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/testing/ColorReduceRound.java">ColorReduceRound.java</a>
 */
public class ColorReduceRound extends Piece implements Trigger
{
  //==========================================================================
  //  Data:

  //==========================================================================
  //  Interface Trigger:

  /**
   * Starts image remapping.
   *
   * @param  type Colormap index.
   * @return <tt>true</tt> if the action was successful.
   */
  public boolean fire ( int type )
  {
    RasterGraphics input   = (RasterGraphics)getInterface( "image1",   IFACE+"RasterGraphics" );
    RasterGraphics output  = (RasterGraphics)getInterface( "image2",   IFACE+"RasterGraphics" );
    ColormapStore colorMap = (ColormapStore) getInterface( PL_PALETTE, IFACE+"ColormapStore" );

      // color palette:
    int palette[][] = colorMap.getColormap( type );
    int size;
    if ( palette == null ||
         (size = palette.length) < 1 )
      return false;

    int bands = palette[0].length;

      // output image:
    int width  = input.getWidth();
    int height = input.getHeight();
    output.init( width, height, RasterGraphics.MODE_COLORMAP, 0 );
    output.setColormapType( (bands == 3) ? RasterGraphics.MODE_RGB :
                                           RasterGraphics.MODE_RGBA , size - 1 );
    output.setColormap( palette );
    int i, j, k, l;
    int diff, err, best, bestErr;

      // main loop:
    int[] pixel = new int[bands];
    for ( j = 0; j < height; j++ )        // one output row
      for ( i = 0; i < width; i++ )       // one output pixel
      {
        input.getRGB( i, j, pixel );
        best    = 0;
        bestErr = Integer.MAX_VALUE;
        for ( k = 0; k < size; k++ )      // try one colormap entry
        {
          err = 0;
          for ( l = 0; l < bands; l++ )
          {
            diff = pixel[l] - palette[k][l];
            err += diff * diff;
          }
          if ( err < bestErr )
          {
            bestErr = err;
            best = k;
          }
        }
        output.putPixel( i, j, best );
      }

    return true;
  }

  //==========================================================================
  //  Interface Property:

  /**
   * Sets the given property.
   *
   * @param  key Key string.
   * @param  value The new value.
   */
  public void set ( String key, Object value )
  {
    if ( key == null || value == null ) return;
  }

  /**
   * Gets the given property.
   *
   * @param  key Key string.
   * @return The actual value or <tt>null</tt>.
   */
  public Object get ( String key )
  {
    if ( key == null ) return null;
    return null;
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "ColorReduceRound";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "TriggerToRasterGraphicsAndColormapStoreAndRasterGraphics";

  /** Object description. */
  private final static String DESCRIPTION = "Image remapping, rounds colors to pre-defined color palette.";

  /** Object category. */
  protected final static String CATEGORY = C_2D + "." + C_RASTER + "." + C_FILTER;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug(  PL_INPUT,   IFACE+"Trigger" );
      t.newOutputPlug( "image1",   IFACE+"RasterGraphics" );
      t.newOutputPlug( "image2",   IFACE+"RasterGraphics" );
      t.newOutputPlug( PL_PALETTE, IFACE+"ColormapStore" );
        // Property:
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
