package cz.cuni.jagrlib.testing;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Color-reducing example - 3-3-2 palette generator.
 *
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/testing/Colormap332.java">Colormap332.java</a>
 */
public class Colormap332 extends Piece implements Trigger
{
  //==========================================================================
  //  Data:

  /** Colormap is used for error distribution? */
  protected boolean errorDistr = false;

  //==========================================================================
  //  Interface Trigger:

  /**
   * Starts colormap generation.
   *
   * @param  type Colormap index.
   * @return {@code true} if the action was successful.
   */
  public boolean fire ( int type )
  {
    //RasterGraphics input   = (RasterGraphics)getInterface( PL_IMAGE,   IFACE+"RasterGraphics" );
    ColormapStore colorMap = (ColormapStore) getInterface( PL_PALETTE, IFACE+"ColormapStore" );

      // output image:
    //int width = input.getWidth();
    //int height = input.getHeight();

      // create the palette:
    double R, G, B;
    double R0, G0, B0;
    double dRG, dB;
    int r, g, b, i;
    int palette[][] = new int[ 256 ][ 3 ];

    if ( errorDistr )                     // convex closure of the colormap should be equal
    {                                     // to the whole RGB space
      R0  =
      G0  =
      B0  = 0.0;
      dRG = 255.0 /  7;
      dB  = 255.0 /  3;
    }
    else
    {                                     // the colormap will be optimal for rounding
      R0  =
      G0  = 255.0 / 16;
      B0  = 255.0 /  8;
      dRG = 255.0 /  8;
      dB  = 255.0 /  4;
    }

    for ( r = i = 0, R = R0; r < 8; r++, R += dRG )
      for ( g = 0, G = G0; g < 8; g++, G += dRG )
        for ( b = 0, B = B0; b < 4; b++, B += dB )
        {
          palette[i][0] = (int)( R + 0.5 );
          palette[i][1] = (int)( G + 0.5 );
          palette[i][2] = (int)( B + 0.5 );
          i++;
        }

    int size = colorMap.size();
    if ( type >= size )
      colorMap.setSize( type + 1 );
    colorMap.setColormap( type, palette );

    return true;
  }

  //==========================================================================
  //  Interface Property:

  public final static String ERROR_DISTRIBUTION = "ErrorDistribution";

  /**
   * Sets the given property.
   *
   * @param  key Key string.
   * @param  value The new value.
   */
  public void set ( String key, Object value )
  {
    if ( key == null || value == null ) return;

      // ERROR_DISTRIBUTION:
    if ( key.compareTo(ERROR_DISTRIBUTION) == 0 )
    {
      errorDistr = booleanProperty( value, errorDistr );
      return;
    }
  }

  /**
   * Gets the given property.
   *
   * @param  key Key string.
   * @return The actual value or {@code null}.
   */
  public Object get ( String key )
  {
    if ( key == null ) return null;

    if ( key.compareTo(ERROR_DISTRIBUTION) == 0 )
      return errorDistr;

    return null;
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "Colormap332";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "TriggerToRasterGraphicsAndColormapStore";

  /** Object description. */
  private final static String DESCRIPTION = "3-3-2 palette generation.";

  /** Object category. */
  protected final static String CATEGORY = C_2D + '.' + C_RASTER + ".colormap";

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug(  PL_INPUT,   IFACE+"Trigger" );
      t.newOutputPlug( PL_IMAGE,   IFACE+"RasterGraphics" );
      t.newOutputPlug( PL_PALETTE, IFACE+"ColormapStore" );
        // Property:
      t.propBegin( ERROR_DISTRIBUTION, TYPE_BOOLEAN, "Is this colormap suitable for error distribution?", true );
        t.propDefault( false );
      t.propEnd();
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
