package cz.cuni.jagrlib.testing;

import java.awt.*;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Draws simple 3D scene to test projection matrices.
 *
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/testing/DrawAxes.java">DrawAxes.java</a>
 */
public class DrawAxes extends DefaultRender3D implements AWTGraphics
{
  //==========================================================================
  //  Data:

  /** Support variable. */
  protected Rectangle clipRect = new Rectangle();

  /** Object vertices (world coordinates). */
  protected static final double[][] vert =
  {
    { 0.0, 0.0, 0.0 },  //  0 .. origin
    { 1.3, 0.0, 0.0 },  //  1 .. X-axis
    { 0.0, 1.3, 0.0 },  //  2 .. Y-axis
    { 0.0, 0.0, 1.3 },  //  3 .. Z-axis
    { 1.0, 0.0, 0.0 },  //  4 .. x
    { 0.0, 1.0, 0.0 },  //  5 ..   y
    { 1.0, 1.0, 0.0 },  //  6 .. x y
    { 0.0, 0.0, 1.0 },  //  7 ..     z
    { 1.0, 0.0, 1.0 },  //  8 .. x   z
    { 0.0, 1.0, 1.0 },  //  9 ..   y z
    { 1.0, 1.0, 1.0 },  // 10 .. x y z
  };

  /** Object vertices (screen coordinates). */
  protected double[][] v = new double[ vert.length ][ 3 ];

  //==========================================================================
  //  Interface Render3D:

  // heritage is OK

  //==========================================================================
  //  Interface AWTGraphics:

  protected final void line ( Graphics g, int i, int j )
  {
    g.drawLine( Formula.round( v[i][0] ), Formula.round( v[i][1] ),
                Formula.round( v[j][0] ), Formula.round( v[j][1] ) );
  }

  /**
   * Repaints the given canvas from scratch.
   *
   * @param g Graphics ready to receive painting. Its clip-region should be set
   *          to reduce painting volume.
   */
  public void paint ( Graphics g )
  {
    g.getClipBounds( clipRect );
    g.setColor( Color.DARK_GRAY );
    g.fillRect( clipRect.x, clipRect.y, clipRect.width, clipRect.height );
    checkMatrix();                        // "compound" matrix needs to be ready..

      // axes:
    for ( int i = 0; i < vert.length; i++ )
      compound.transformPoint3D( vert[i], v[i] );
    g.setColor( Color.WHITE );
    line( g,  0,  1 );
    g.drawString( "X", (int)v[1][0] + 7, (int)v[1][1] + 7 );
    g.setColor( Color.RED );
    line( g,  0,  2 );
    g.drawString( "Y", (int)v[2][0] + 7, (int)v[2][1] + 7 );
    g.setColor( Color.GREEN );
    line( g,  0,  3 );
    g.drawString( "Z", (int)v[3][0] + 7, (int)v[3][1] + 7 );

      // cube:
    g.setColor( Color.YELLOW );
    line( g,  4,  6 );
    line( g,  4,  8 );
    line( g,  5,  6 );
    line( g,  5,  9 );
    line( g,  7,  8 );
    line( g,  7,  9 );
    line( g,  6, 10 );
    line( g,  8, 10 );
    line( g,  9, 10 );
  }

  /**
   * Updates drawing in the given region.
   * Previous drawing in the region can be considered non-damaged.
   *
   * @param g Graphics ready to receive painting. The clip-region should be set
   *          as narrow as possible (area which has to be updated).
   */
  public void update ( Graphics g )
  {
    paint( g );
  }

  //==========================================================================
  //  Interface Property:

  /**
   * Sets the given property.
   *
   * @param  key Key string.
   * @param  value The new value.
   */
  public void set ( String key, Object value )
  {
    if ( key == null || value == null ) return;
  }

  /**
   * Gets the given property.
   *
   * @param  key Key string.
   * @return The actual value or {@code null}.
   */
  public Object get ( String key )
  {
    if ( key == null ) return null;

    return null;
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "DrawAxes";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "Render3DAndAWTGraphics";

  /** Object description. */
  private final static String DESCRIPTION = "Draws simple 3D axes to test projection matrices.";

  /** Object category. */
  protected final static String CATEGORY = C_3D + '.' + C_RENDER;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug( PL_RENDER, IFACE+"Render3D" );
      t.newInputPlug( PL_INPUT,  IFACE+"AWTGraphics" );
        // Property:
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
