package cz.cuni.jagrlib.testing;

import javax.media.opengl.GL;
import javax.media.opengl.glu.GLU;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Draws simple 3D scene to test projection matrices (OpenGL version).
 *
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/testing/DrawAxesGL.java">DrawAxesGL.java</a>
 */
public class DrawAxesGL extends DefaultRender3D implements GLGraphics
{
  //==========================================================================
  //  Data:

  /** Object vertices (world coordinates). */
  protected static final double[][] vert =
  {
    { 0.0, 0.0, 0.0, 1.0 },  //  0 .. origin
    { 1.3, 0.0, 0.0, 1.0 },  //  1 .. X-axis
    { 0.0, 1.3, 0.0, 1.0 },  //  2 .. Y-axis
    { 0.0, 0.0, 1.3, 1.0 },  //  3 .. Z-axis
    { 1.0, 0.0, 0.0, 1.0 },  //  4 .. x
    { 0.0, 1.0, 0.0, 1.0 },  //  5 ..   y
    { 1.0, 1.0, 0.0, 1.0 },  //  6 .. x y
    { 0.0, 0.0, 1.0, 1.0 },  //  7 ..     z
    { 1.0, 0.0, 1.0, 1.0 },  //  8 .. x   z
    { 0.0, 1.0, 1.0, 1.0 },  //  9 ..   y z
    { 1.0, 1.0, 1.0, 1.0 },  // 10 .. x y z
  };

  //==========================================================================
  //  Interface Render3D:

  // heritage is OK

  //==========================================================================
  //  Interface GLGraphics:

  /**
   * Initialization of GL context.
   * It's called in init-time of every GL context.
   *
   * @param  gl GL commands access object.
   * @param  glu GLU commands access object.
   */
  public void initRoutine ( GL gl, GLU glu )
  {
      // Basic GL init:
    gl.glShadeModel( GL.GL_FLAT );

      // Set background color:
    gl.glClearColor( 0.2f, 0.2f, 0.2f, 1.0f );

      // glEnable global constants:
    gl.glEnable( GL.GL_DEPTH_TEST );

      // Depth-buffer setup:
    gl.glClearDepth( 1.0f );
    gl.glDepthFunc(  GL.GL_LEQUAL );

      // GL-hint tuples:
    gl.glHint( GL.GL_PERSPECTIVE_CORRECTION_HINT, GL.GL_NICEST );
  }

  /**
   * Reshape routine is called every time the dimensions of GL context are changed.
   * It usually contains projection setup.
   *
   * @param  gl GL commands access object.
   * @param  glu GLU commands access object.
   * @param  x X position of reshaped canvas.
   * @param  y Y position of reshaped canvas.
   * @param  width Width of reshaped canvas.
   * @param  height Height of reshaped canvas.
   */
  public void reshapeRoutine ( GL gl, GLU glu, int x, int y, int width, int height )
  {
    if ( height <= 0 )  // avoid divide by zero
      height = 1;

    final float aspect = (float)width / (float)height;
    gl.glViewport( x, y, width, height );
    vpChanged = false;

      // Projection matrix setup:
    gl.glMatrixMode( GL.GL_PROJECTION );
    if ( projection == null )             // default projection matrix (perspective)
    {
      gl.glLoadIdentity();
      glu.gluPerspective( 40.0f, aspect, 0.2f, 50.0f );
    }
    else
    {
      gl.glLoadMatrixd( projection.toArray( 4, 4, true, null ), 0 );
    }
    prChanged = false;

    /*
    double[] mat = new double[ 16 ];
    gl.glGetDoublev( GL.GL_PROJECTION_MATRIX, mat, 0 );
    LogFile.log( "Projection: " + Formula.vectorToString( mat ) );
    */

      // Model-view matrix setup:
    gl.glMatrixMode( GL.GL_MODELVIEW );
  }

  /**
   * Routine responsible for GL context repainting.
   *
   * @param  gl GL commands access object.
   * @param  glu GLU commands access object.
   */
  public void paintRoutine ( GL gl, GLU glu )
  {
      // clear the buffers:
    gl.glClear( GL.GL_COLOR_BUFFER_BIT | GL.GL_DEPTH_BUFFER_BIT );

      // I'm using GL_MODELVIEW mode..
    if ( modelView == null )              // default camera position and orientation
    {
      gl.glLoadIdentity();
      glu.gluLookAt( 0.0f, 0.0f, 5.0f,
                     0.0f, 0.0f, 0.0f,
                     0.0f, 1.0f, 0.0f );
    }
    else
    {
      gl.glLoadMatrixd( modelView.toArray( 4, 4, true, null ), 0 );
    }

    /*
    double[] mat = new double[ 16 ];
    gl.glGetDoublev( GL.GL_MODELVIEW_MATRIX, mat, 0 );
    LogFile.log( "ModelView: " + Formula.vectorToString( mat ) );
    */

      // draw the axes:
    gl.glBegin( GL.GL_LINES );

      gl.glColor4f(   1.0f, 1.0f, 1.0f, 1.0f );
      gl.glVertex4dv( vert[ 0], 0 );
      gl.glVertex4dv( vert[ 1], 0 );

      gl.glColor4f(   1.0f, 0.0f, 0.0f, 1.0f );
      gl.glVertex4dv( vert[ 0], 0 );
      gl.glVertex4dv( vert[ 2], 0 );

      gl.glColor4f(   0.0f, 1.0f, 0.0f, 1.0f );
      gl.glVertex4dv( vert[ 0], 0 );
      gl.glVertex4dv( vert[ 3], 0 );

      gl.glColor4f(   1.0f, 1.0f, 0.0f, 1.0f );
      gl.glVertex4dv( vert[ 4], 0 );
      gl.glVertex4dv( vert[ 6], 0 );
      gl.glVertex4dv( vert[ 4], 0 );
      gl.glVertex4dv( vert[ 8], 0 );
      gl.glVertex4dv( vert[ 5], 0 );
      gl.glVertex4dv( vert[ 6], 0 );
      gl.glVertex4dv( vert[ 5], 0 );
      gl.glVertex4dv( vert[ 9], 0 );
      gl.glVertex4dv( vert[ 7], 0 );
      gl.glVertex4dv( vert[ 8], 0 );
      gl.glVertex4dv( vert[ 7], 0 );
      gl.glVertex4dv( vert[ 9], 0 );
      gl.glVertex4dv( vert[ 6], 0 );
      gl.glVertex4dv( vert[10], 0 );
      gl.glVertex4dv( vert[ 8], 0 );
      gl.glVertex4dv( vert[10], 0 );
      gl.glVertex4dv( vert[ 9], 0 );
      gl.glVertex4dv( vert[10], 0 );

    gl.glEnd();
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "DrawAxesGL";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "Render3DAndGLGraphicsTo";

  /** Object description. */
  private final static String DESCRIPTION = "Draws simple 3D axes using OpenGL.";

  /** Object category. */
  protected final static String CATEGORY = C_3D + '.' + C_RENDER;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug( PL_RENDER, IFACE+"Render3D" );
      t.newInputPlug( PL_INPUT,  IFACE+"GLGraphics" );
        // Property:
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
