package cz.cuni.jagrlib.testing;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Line clipping template.
 *
 * @version 0.26 $Rev: 431 $ $Date: 2007-04-29 22:42:22 +0200 (ne, 29 IV 2007) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/testing/LineClipping.java">LineClipping.java</a>
 */
public class LineClipping extends Piece implements LineRenderAnti, RectangleWindow
{
  //==========================================================================
  //  Data:

  /** Minimal X coordinate */
  protected int xMi =   0;

  /** Maximal X coordinate */
  protected int xMa = 128;

  /** Minimal Y coordinate */
  protected int yMi =   0;

  /** Maximal Y coordinate */
  protected int yMa = 128;

  //==========================================================================
  //  Interface LineRender:

  /**
   * Draws a line from [x1,y1] to [x2,y2].
   *
   * @param  x1 X coordinate of the starting pixel.
   * @param  y1 Y coordinate of the starting pixel.
   * @param  x2 X coordinate of the line end.
   * @param  y2 Y coordinate of the line end.
   */
  public void drawLine ( int x1, int y1, int x2, int y2 )
  {
    drawLine( (double)x1, (double)y1, (double)x2, (double)y2 );
  }

  /**
   * Draws a line from [x1,y1] to [x2,y2].
   * Calls {@link #drawLine(int,int,int,int)}
   * directly after rounding the {@code double} arguments.
   *
   * @param  x1 X coordinate of the starting pixel.
   * @param  y1 Y coordinate of the starting pixel.
   * @param  x2 X coordinate of the line end.
   * @param  y2 Y coordinate of the line end.
   */
  public void drawLine ( double x1, double y1, double x2, double y2 )
  {
    LineRender out = (LineRender)getInterface( PL_OUTPUT, IFACE+"LineRender" );
    double xx1 = 0.25 * (3.0 * x1 + x2);
    double yy1 = 0.25 * (3.0 * y1 + y2);
    x2 = 0.25 * (x1 + 3.0 * x2);
    y2 = 0.25 * (y1 + 3.0 * y2);
    out.drawLine( xx1, yy1, x2, y2 );
  }

  //==========================================================================
  //  Interface LineRenderAnti:

  /**
   * Sets default line width in pixels.
   *
   * @param  wid New line width in pixels.
   * @return The old line width in pixels.
   */
  public double setWidth ( double wid )
  {
    LineRenderAnti out = (LineRenderAnti)getInterface( PL_OUTPUT, IFACE+"LineRenderAnti" );
    return out.setWidth( wid );
  }

  /**
   * Draws a line from [x1,y1] to [x2,y2].
   *
   * @param  x1 X coordinate of the starting pixel.
   * @param  y1 Y coordinate of the starting pixel.
   * @param  x2 X coordinate of the line end.
   * @param  y2 Y coordinate of the line end.
   * @param  wid Line width in pixels.
   */
  public void drawLine ( int x1, int y1, int x2, int y2, double wid )
  {
    drawLine( (double)x1, (double)y1, (double)x2, (double)y2, wid );
  }

  /**
   * Draws a line from [x1,y1] to [x2,y2].
   *
   * @param  x1 X coordinate of the starting pixel.
   * @param  y1 Y coordinate of the starting pixel.
   * @param  x2 X coordinate of the line end.
   * @param  y2 Y coordinate of the line end.
   * @param  wid Line width in pixels.
   */
  public void drawLine ( double x1, double y1, double x2, double y2, double wid )
  {
    LineRenderAnti out = (LineRenderAnti)getInterface( PL_OUTPUT, IFACE+"LineRenderAnti" );
    double xx1 = 0.25 * (3.0 * x1 + x2);
    double yy1 = 0.25 * (3.0 * y1 + y2);
    x2 = 0.25 * (x1 + 3.0 * x2);
    y2 = 0.25 * (y1 + 3.0 * y2);
    out.drawLine( xx1, yy1, x2, y2, wid );
  }

  //==========================================================================
  //  Interface RectangleWindow:

  /**
   * Sets the given rectangle as clipping window.
   *
   * @param  xMin Minimal x coordinate.
   * @param  xMax Maximal x coordinate.
   * @param  yMin Minimal y coordinate.
   * @param  yMax Maximal y coordinate.
   */
  public void rectangleWindow ( int xMin, int xMax, int yMin, int yMax )
  {
    xMi = xMin;
    xMa = xMax;
    yMi = yMin;
    yMa = yMax;
  }

  /**
   * Sets the given rectangle as clipping window.
   *
   * @param  xMin Minimal x coordinate.
   * @param  xMax Maximal x coordinate.
   * @param  yMin Minimal y coordinate.
   * @param  yMax Maximal y coordinate.
   */
  public void rectangleWindow ( double xMin, double xMax, double yMin, double yMax )
  {
    xMi = (int)xMin;
    xMa = (int)xMax;
    yMi = (int)yMin;
    yMa = (int)yMax;
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "LineClipping";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "LineRenderAntiAndRectangleWindowToLineRenderAnti";

  /** Object description. */
  private final static String DESCRIPTION = "Clips incoming line segments to the given rectangle.";

  /** Object category. */
  protected final static String CATEGORY = C_2D + "." + C_CLIP + "." + C_LINE + "." + C_INTEGER;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug(  PL_INPUT,  IFACE+"LineRenderAnti" );
      t.newInputPlug(  PL_WINDOW, IFACE+"RectangleWindow" );
      t.newOutputPlug( PL_OUTPUT, IFACE+"LineRender" );
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
