package cz.cuni.jagrlib.testing;

import java.awt.Point;
import java.awt.geom.Point2D;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Polygon clipping - arbitrary polygon vs. sinple polygonal window.
 *
 * @version 0.25 $Rev: 346 $ $Date: 2006-11-06 15:40:23 +0100 (po, 06 XI 2006) $ $Author: pepca $
 * @since   0.25
 * @see     <a href="../../../../../cz/cuni/jagrlib/testing/PolygonFill.java">PolygonFill.java</a>
 */
public class PolygonClip extends Piece implements PolygonFillRender, PolygonWindow
{
  //==========================================================================
  //  Data:

  /** Actual polygonal window. */
  protected Point2D.Double[] win = null;

  //==========================================================================
  //  Interface PolygonWindow:

  /**
   * Sets the given polygon as clipping window.
   *
   * @param  v Array of polygon vertices (needs not to be closed, <tt>null</tt> can interrupt the sequence).
   */
  public void polygonWindow ( Point[] v )
  {
    if ( v        == null ||
         v.length < 3 ) return;

      // copy & convert:
    win = new Point2D.Double[ v.length ];
    int i;
    for ( i = 0; i < v.length && v[i] != null; i++ )
      win[i] = new Point2D.Double( v[i].x, v[i].y );
  }

  /**
   * Sets the given polygon as clipping window.
   *
   * @param  v Array of polygon vertices (needs not to be closed, <tt>null</tt> can interrupt the sequence).
   */
  public void polygonWindow ( Point2D.Double[] v )
  {
    if ( v        == null ||
         v.length < 3 ) return;

      // deep-copy:
    win = new Point2D.Double[ v.length ];
    int i;
    for ( i = 0; i < v.length && v[i] != null; i++ )
      win[i] = new Point2D.Double( v[i].x, v[i].y );
  }

  //==========================================================================
  //  Interface PolygonFillRender:

  /**
   * Fills the given polygon.
   * Uses pre-defined fill style.
   *
   * @param  v Array of polygon vertices (needs not to be closed, <tt>null</tt> can interrupt the sequence).
   */
  public void fillPolygon ( Point[] v )
  {
    if ( win      == null ||
         v        == null ||
         v.length < 3 ) return;

    Point2D.Double[] d = new Point2D.Double[ v.length ];
    int i;
    for ( i = 0; i < v.length && v[i] != null; i++ )
      d[i] = new Point2D.Double( v[i].x, v[i].y );

    fillPolygon( d );
  }

  /**
   * Fills the given polygon.
   * Uses pre-defined fill style.
   *
   * @param  v Array of polygon vertices (needs not to be closed, <tt>null</tt> can interrupt the sequence).
   */
  public void fillPolygon ( Point2D.Double[] v )
  {
    final PolygonFillRender out = (PolygonFillRender)getInterface( PL_OUTPUT, IFACE+"PolygonFillRender" );

    if ( win      == null ||
         out      == null ||
         v        == null ||
         v.length < 3 ) return;

    int vlen = 0;
    for ( vlen = 0; vlen < v.length && v[vlen] != null; vlen++ ) ;
    int nlen = Math.max( 3, vlen / 2 );
    int cut  = vlen - nlen;
    Point2D.Double[] n;

    if ( cut == 0 )
      n = v;
    else
    {
      n = new Point2D.Double[ nlen ];
      int i, j;
      for ( i = j = 0; i < vlen; i++ )
        if ( cut > 0 && (i & 1) > 0 )
          cut--;
        else
          n[j++] = v[i];
    }

    out.fillPolygon( n );
  }

  //==========================================================================
  //  Interface Property:

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "PolygonClip";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "PolygonFillRenderAndPolygonWindowToPolygonFillRender";

  /** Object description. */
  private final static String DESCRIPTION = "Polygon clipping specimen (arbitrary polygon vs. sinple polygonal window).";

  /** Object category. */
  protected final static String CATEGORY = C_2D + "." + C_CLIP + "." + C_POLYGON + "." + C_INTEGER;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug(  PL_INPUT,  IFACE+"PolygonFillRender" );
      t.newInputPlug(  PL_WINDOW, IFACE+"PolygonWindow" );
      t.newOutputPlug( PL_OUTPUT, IFACE+"PolygonFillRender" );
        // Property:
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
