package cz.cuni.jagrlib.testing;

import java.awt.Point;
import java.awt.geom.Point2D;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Polygon fill with antialiasing - pilot implementation.
 *
 * @version 0.25 $Rev: 385 $ $Date: 2007-01-07 01:47:21 +0100 (ne, 07 I 2007) $ $Author: pepca $
 * @since   0.25
 * @see     <a href="../../../../../cz/cuni/jagrlib/testing/PolygonFillAnti.java">PolygonFillAnti.java</a>
 */
public class PolygonFillAnti extends Piece implements PolygonFillRender
{
  //==========================================================================
  //  Data:

  /**
   * Actual inside-test mode.
   *
   * @see    #POLY_INSIDE
   * @see    #POLY_INSIDE_PARITY
   * @see    #POLY_INSIDE_WINDING
   */
  protected int insideRule = POLY_INSIDE_PARITY;

  //==========================================================================
  //  Support:

  /** Draws line segment using DDA. */
  protected void drawLine ( AlphaMask out, Point2D.Double a, Point2D.Double b )
  {
    double minor, dMinor;
    double major, dMajor;
    double len,   aCoef;

    double dx = Math.abs( a.x - b.x );
    double dy = Math.abs( a.y - b.y );
    if ( dx > dy )
    {
      major  = a.x;
      dMajor = (a.x < b.x) ? 1 : -1;
      minor  = a.y;
      dMinor = (b.y - a.y) / dx;
      len    = Math.abs( a.x - b.x );
      aCoef  = 1.0 / len;

      while ( len > 0.0 )
      {
        out.putPixel( Formula.round( major ), Formula.round( minor ), len * aCoef );
        major += dMajor;
        minor += dMinor;
        len   -= 1.0;
      }
    }
    else
    {
      major  = a.y;
      dMajor = (a.y < b.y) ? 1 : -1;
      minor  = a.x;
      dMinor = (b.x - a.x) / dy;
      len    = Math.abs( a.y - b.y );
      aCoef  = 1.0 / len;

      while ( len > 0.0 )
      {
        out.putPixel( Formula.round( minor ), Formula.round( major ), len * aCoef );
        major += dMajor;
        minor += dMinor;
        len   -= 1.0;
      }
    }
  }

  //==========================================================================
  //  Interface PolygonFillRender:

  /**
   * Fills the given polygon.
   * Uses pre-defined fill style.
   *
   * @param  v Array of polygon vertices (needs not to be closed, {@code null} can interrupt the sequence).
   * @see    #POLY_INSIDE
   */
  public void fillPolygon ( Point[] v )
  {
    if ( v        == null ||
         v.length < 3 ) return;

    Point2D.Double[] d = new Point2D.Double[ v.length ];
    int i;
    for ( i = 0; i < v.length && v[i] != null; i++ )
      d[i] = new Point2D.Double( v[i].x, v[i].y );

    fillPolygon( d );
  }

  /**
   * Fills the given polygon.
   * Uses pre-defined fill style.
   *
   * @param  v Array of polygon vertices (needs not to be closed, {@code null} can interrupt the sequence).
   * @see    #POLY_INSIDE
   */
  public void fillPolygon ( Point2D.Double[] v )
  {
    final AlphaMask out = (AlphaMask)getInterface( PL_OUTPUT, IFACE+"AlphaMask" );
    if ( out      == null ||
         v        == null ||
         v.length < 3 ) return;

    int i, i1;
    for ( i = 0; i < v.length && v[i] != null ; i++ ) // draw line from v[i] to v[i+1]
    {
      if ( (i1 = i + 1) >= v.length ||
           v[i1] == null )
        i1 = 0;

      if ( v[i].x == v[i1].x &&
           v[i].y == v[i1].y )
        continue;

      drawLine( out, v[i], v[i1] );
    }
  }

  //==========================================================================
  //  Interface Property:

  /**
   * Sets the given property.
   *
   * @param  key Key string.
   * @param  value The new value.
   */
  public void set ( String key, Object value )
  {
    if ( key == null || value == null ) return;
      // POLY_INSIDE:
    if ( key.compareTo(POLY_INSIDE) == 0 )
    {
      insideRule = intProperty( value, insideRule, POLY_INSIDE_PARITY, POLY_INSIDE_WINDING );
      return;
    }
  }

  /**
   * Gets the given property.
   *
   * @param  key Key string.
   * @return The actual value or {@code null}.
   */
  public Object get ( String key )
  {
    if ( key == null ) return null;
    if ( key.compareTo(POLY_INSIDE) == 0 )
      return insideRule;
    return null;
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "PolygonFillAnti";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "PolygonFillRenderToAlphaMask";

  /** Object description. */
  private final static String DESCRIPTION = "Polygon fill with antialiasing specimen.";

  /** Object category. */
  protected final static String CATEGORY = C_2D + "." + C_DRAW + "." + C_POLYGON + "." + C_FLOAT;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug(  PL_INPUT,  IFACE+"PolygonFillRender" );
      t.newOutputPlug( PL_OUTPUT, IFACE+"AlphaMask" );
        // Property:
      t.propBegin( POLY_INSIDE, TYPE_INTEGER, "Inside-test mode", true );
        t.propDefault( POLY_INSIDE_PARITY );
        t.propBounds(  POLY_INSIDE_PARITY, POLY_INSIDE_WINDING );
        t.propManipulator( MANIPULATOR_COMBO );
        t.propEnum( "Parity",  POLY_INSIDE_PARITY,  "Odd-even rule" );
        t.propEnum( "Winding", POLY_INSIDE_WINDING, "Positive winding rule" );
      t.propEnd();
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
