package cz.cuni.jagrlib.testing;

import java.nio.*;

import javax.media.opengl.GL;
import javax.media.opengl.glu.*;

import com.sun.opengl.util.*;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.RegPiece;

/**
 * Simple GLGraphics using simple GLUT objects.
 * Useful for testing GLGraphics interface.
 *
 * @author  Stuchl, PE
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/testing/SimpleGLGraphics.java">SimpleGLGraphics.java</a>
 */
public class SimpleGLGraphics extends Piece implements GLGraphics
{
  //==========================================================================
  //  Data:

  /** Angular speed in degrees/ms. */
  protected final static float ANGLE_PER_MS = 0.05f;

  /** Origin system time. */
  protected final long time0 = System.currentTimeMillis();

  /** Solid type: box. */
  public static final int SOLID_BOX = 1;

  /** Solid type: sphere. */
  public static final int SOLID_SPHERE = 2;

  /** Solid type: teapot. */
  public static final int SOLID_TEAPOT = 3;

  /** Texture type: 2D - normal. */
  public static final int TEXTURE_TYPE_1 = 1;

  /** Texture type: 1D - contures. */
  public static final int TEXTURE_TYPE_2 = 2;

  /** Texture type: 1D - eye plane. */
  public static final int TEXTURE_TYPE_3 = 3;

  /** Texture type: 2D - environment. */
  public static final int TEXTURE_TYPE_4 = 4;

  /** Texture type: 2D - environment spheric. */
  public static final int TEXTURE_TYPE_5 = 5;

  /** Actual solid type. */
  protected int solidTypeParam;

  /** Actual texture type. */
  protected int textureTypeParam;

  //==========================================================================
  //  Painting:

  /**
   * Painting routine is launched each time when context is repainted.
   *
   * @param  gl GL commands access object
   * @param  glu GLU commands access object
   */
  public void paintRoutine ( GL gl, GLU glu )
  {
    gl.glClear( GL.GL_COLOR_BUFFER_BIT | GL.GL_DEPTH_BUFFER_BIT );

      // I'm in the GL_MODELVIEW mode..
    gl.glLoadIdentity();
    gl.glTranslatef( 0f, 0.0f, -4.5f );
    final long timeDelta = System.currentTimeMillis() - time0;
    gl.glRotatef( timeDelta * ANGLE_PER_MS, 1.0f, 1.0f, 1.0f );

    gl.glColor3f( 0.0f, 1.0f, 0.0f );
    switch ( solidTypeParam )
    {
      case SOLID_BOX:
        box( gl, glu );
        break;
      case SOLID_SPHERE:
        sphere( gl, glu );
        break;
      case SOLID_TEAPOT:
        teapot( gl, glu );
        break;
    }
  }

  //==========================================================================
  //  Textures:

  protected byte[] texture;

  protected byte[] texture2;

  private void makeTexture ()
  {
    int curr = 0;
    int i, j, c;
    texture = new byte[ 64 * 64 * 4 ];

    for ( j = 0; j < 64; j++ )
    {
      for ( i = 0; i < 64; i++ )
      {
        int a = (i & 0x08) == 0 ? 1 : 0;
        int b = (j & 0x08) == 0 ? 1 : 0;
        c = (a ^ b) * 255;
        texture[curr++] = (byte)c;
        texture[curr++] = (byte)c;
        texture[curr++] = (byte)c;
        texture[curr++] = (byte)255;
      }
    }
  }

  private void makeTexture2 ()
  {
    int i, c;
    texture2 = new byte[ 64 * 3 ];
    int curr = 0;

    for ( i = 0; i < 64; i++ )
    {
      int a = (i & 0x10) == 0 ? 1 : 0;
      c = a * 255;
      texture2[curr++] = (byte)c;
      texture2[curr++] = (byte)c;
      texture2[curr++] = (byte)c;
    }
  }

  private void setTexParams ( GL gl, GLU glu )
  {
    ByteBuffer bb = BufferUtil.newByteBuffer( texture.length );
    bb.put( texture );
    bb.rewind();

    gl.glPixelStorei( GL.GL_UNPACK_ALIGNMENT, 1 );
    gl.glTexParameteri( GL.GL_TEXTURE_2D, GL.GL_TEXTURE_WRAP_S, GL.GL_REPEAT );
    gl.glTexParameteri( GL.GL_TEXTURE_2D, GL.GL_TEXTURE_WRAP_T, GL.GL_REPEAT );
    gl.glTexParameteri( GL.GL_TEXTURE_2D, GL.GL_TEXTURE_MAG_FILTER, GL.GL_LINEAR );
    gl.glTexParameteri( GL.GL_TEXTURE_2D, GL.GL_TEXTURE_MIN_FILTER, GL.GL_LINEAR );
    gl.glTexImage2D( GL.GL_TEXTURE_2D, 0, 4, 64, 64, 0, GL.GL_RGBA, GL.GL_UNSIGNED_BYTE, bb );
    gl.glTexEnvi( GL.GL_TEXTURE_ENV, GL.GL_TEXTURE_ENV_MODE, GL.GL_MODULATE );
    gl.glHint( GL.GL_PERSPECTIVE_CORRECTION_HINT, GL.GL_NICEST );
    gl.glEnable( GL.GL_TEXTURE_2D );
  }

  private void setTexParams2 ( GL gl, GLU glu )
  {
    ByteBuffer bb = BufferUtil.newByteBuffer( texture2.length );
    bb.put( texture2 );
    bb.rewind();

    float params[] = { 1.0f, 1.0f, 1.0f, 0.0f };
    gl.glPixelStorei( GL.GL_UNPACK_ALIGNMENT, 1 );
    gl.glTexParameteri( GL.GL_TEXTURE_1D, GL.GL_TEXTURE_WRAP_S, GL.GL_REPEAT );
    gl.glTexParameteri( GL.GL_TEXTURE_1D, GL.GL_TEXTURE_MAG_FILTER, GL.GL_LINEAR );
    gl.glTexParameteri( GL.GL_TEXTURE_1D, GL.GL_TEXTURE_MIN_FILTER, GL.GL_LINEAR );
    gl.glTexImage1D( GL.GL_TEXTURE_1D, 0, 3, 64, 0, GL.GL_RGB, GL.GL_UNSIGNED_BYTE, bb );
    gl.glTexEnvi( GL.GL_TEXTURE_ENV, GL.GL_TEXTURE_ENV_MODE, GL.GL_MODULATE );
    gl.glHint( GL.GL_PERSPECTIVE_CORRECTION_HINT, GL.GL_NICEST );
    gl.glTexGeni( GL.GL_S, GL.GL_TEXTURE_GEN_MODE, GL.GL_OBJECT_LINEAR );
    gl.glTexGenfv( GL.GL_S, GL.GL_OBJECT_PLANE, params, 0 );
    gl.glEnable( GL.GL_TEXTURE_GEN_S );
    gl.glEnable( GL.GL_TEXTURE_1D );
  }

  private void setTexParams3 ( GL gl, GLU glu )
  {
    ByteBuffer bb = BufferUtil.newByteBuffer( texture2.length );
    bb.put( texture2 );
    bb.rewind();

    float params[] = { 1.0f, 1.0f, 1.0f, 0.0f };
    gl.glPixelStorei( GL.GL_UNPACK_ALIGNMENT, 1 );
    gl.glTexParameteri( GL.GL_TEXTURE_1D, GL.GL_TEXTURE_WRAP_S, GL.GL_REPEAT );
    gl.glTexParameteri( GL.GL_TEXTURE_1D, GL.GL_TEXTURE_MAG_FILTER, GL.GL_LINEAR );
    gl.glTexParameteri( GL.GL_TEXTURE_1D, GL.GL_TEXTURE_MIN_FILTER, GL.GL_LINEAR );
    gl.glTexImage1D( GL.GL_TEXTURE_1D, 0, 3, 64, 0, GL.GL_RGB, GL.GL_UNSIGNED_BYTE, bb );
    gl.glTexEnvi( GL.GL_TEXTURE_ENV, GL.GL_TEXTURE_ENV_MODE, GL.GL_MODULATE );
    gl.glHint( GL.GL_PERSPECTIVE_CORRECTION_HINT, GL.GL_NICEST );
    gl.glTexGeni( GL.GL_S, GL.GL_TEXTURE_GEN_MODE, GL.GL_EYE_LINEAR );
    gl.glTexGenfv( GL.GL_S, GL.GL_EYE_PLANE, params, 0 );
    gl.glEnable( GL.GL_TEXTURE_GEN_S );
    gl.glEnable( GL.GL_TEXTURE_1D );
  }

  private void setTexParams4 ( GL gl, GLU glu )
  {
    ByteBuffer bb = BufferUtil.newByteBuffer( texture.length );
    bb.put( texture );
    bb.rewind();

    gl.glPixelStorei( GL.GL_UNPACK_ALIGNMENT, 1 );
    gl.glTexParameteri( GL.GL_TEXTURE_2D, GL.GL_TEXTURE_WRAP_S, GL.GL_REPEAT );
    gl.glTexParameteri( GL.GL_TEXTURE_2D, GL.GL_TEXTURE_WRAP_T, GL.GL_REPEAT );
    gl.glTexParameteri( GL.GL_TEXTURE_2D, GL.GL_TEXTURE_MAG_FILTER, GL.GL_LINEAR );
    gl.glTexParameteri( GL.GL_TEXTURE_2D, GL.GL_TEXTURE_MIN_FILTER, GL.GL_LINEAR );
    gl.glTexImage2D( GL.GL_TEXTURE_2D, 0, 4, 64, 64, 0, GL.GL_RGBA, GL.GL_UNSIGNED_BYTE, bb );
    gl.glTexEnvi( GL.GL_TEXTURE_ENV, GL.GL_TEXTURE_ENV_MODE, GL.GL_MODULATE );
    gl.glHint( GL.GL_PERSPECTIVE_CORRECTION_HINT, GL.GL_NICEST );
    gl.glEnable( GL.GL_TEXTURE_2D );
    gl.glTexGeni( GL.GL_S, GL.GL_SPHERE_MAP, 0 );
    gl.glTexGeni( GL.GL_T, GL.GL_SPHERE_MAP, 0 );
    gl.glEnable( GL.GL_TEXTURE_GEN_S );
    gl.glEnable( GL.GL_TEXTURE_GEN_T );
  }

  private void setTexParams5 ( GL gl, GLU glu )
  {
    ByteBuffer bb = BufferUtil.newByteBuffer( texture.length );
    bb.put( texture );
    bb.rewind();

    float params[] = { 1.0f, 0.0f, 0.0f, 0.0f };
    gl.glPixelStorei( GL.GL_UNPACK_ALIGNMENT, 1 );
    gl.glTexParameteri( GL.GL_TEXTURE_2D, GL.GL_TEXTURE_WRAP_S, GL.GL_REPEAT );
    gl.glTexParameteri( GL.GL_TEXTURE_2D, GL.GL_TEXTURE_WRAP_T, GL.GL_REPEAT );
    gl.glTexParameteri( GL.GL_TEXTURE_2D, GL.GL_TEXTURE_MAG_FILTER, GL.GL_LINEAR );
    gl.glTexParameteri( GL.GL_TEXTURE_2D, GL.GL_TEXTURE_MIN_FILTER, GL.GL_LINEAR );
    gl.glTexImage2D( GL.GL_TEXTURE_2D, 0, 4, 64, 64, 0, GL.GL_RGBA, GL.GL_UNSIGNED_BYTE, bb );
    gl.glTexEnvi( GL.GL_TEXTURE_ENV, GL.GL_TEXTURE_ENV_MODE, GL.GL_MODULATE );
    gl.glHint( GL.GL_PERSPECTIVE_CORRECTION_HINT, GL.GL_NICEST );
    gl.glEnable( GL.GL_TEXTURE_2D );
    gl.glTexGeni( GL.GL_S, GL.GL_SPHERE_MAP, 0 );
    gl.glTexGeni( GL.GL_T, GL.GL_TEXTURE_GEN_MODE, GL.GL_OBJECT_LINEAR );
    gl.glTexGenfv( GL.GL_T, GL.GL_OBJECT_PLANE, params, 0 );
    gl.glEnable( GL.GL_TEXTURE_GEN_S );
    gl.glEnable( GL.GL_TEXTURE_GEN_T );
  }

  private void teapot ( GL gl, GLU glu )
  {
    GLUT glut = new GLUT();
    glut.glutSolidTeapot( 1.0d );
  }

  private void sphere ( GL gl, GLU glu )
  {
    GLUquadric quadr = glu.gluNewQuadric();
    glu.gluQuadricDrawStyle( quadr, GLU.GLU_FILL );
    glu.gluQuadricNormals( quadr, GLU.GLU_SMOOTH );
    glu.gluQuadricOrientation( quadr, GLU.GLU_OUTSIDE );

    glu.gluSphere( quadr, 1f, 30, 30 );
  }

  private void box ( GL gl, GLU glu )
  {
    gl.glBegin( GL.GL_QUADS );

    gl.glColor3f(   0.0f,  1.0f,  0.0f );
    gl.glVertex3f(  1.0f,  1.0f, -1.0f );
    gl.glVertex3f( -1.0f,  1.0f, -1.0f );
    gl.glVertex3f( -1.0f,  1.0f,  1.0f );
    gl.glVertex3f(  1.0f,  1.0f,  1.0f );

    gl.glColor3f(   1.0f,  0.5f,  0.0f );
    gl.glVertex3f(  1.0f, -1.0f,  1.0f );
    gl.glVertex3f( -1.0f, -1.0f,  1.0f );
    gl.glVertex3f( -1.0f, -1.0f, -1.0f );
    gl.glVertex3f(  1.0f, -1.0f, -1.0f );

    gl.glColor3f(   1.0f,  0.0f,  0.0f );
    gl.glVertex3f(  1.0f,  1.0f,  1.0f );
    gl.glVertex3f( -1.0f,  1.0f,  1.0f );
    gl.glVertex3f( -1.0f, -1.0f,  1.0f );
    gl.glVertex3f(  1.0f, -1.0f,  1.0f );

    gl.glColor3f(   1.0f,  1.0f,  0.0f );
    gl.glVertex3f(  1.0f, -1.0f, -1.0f );
    gl.glVertex3f( -1.0f, -1.0f, -1.0f );
    gl.glVertex3f( -1.0f,  1.0f, -1.0f );
    gl.glVertex3f(  1.0f,  1.0f, -1.0f );

    gl.glColor3f(   0.0f,  0.0f,  1.0f );
    gl.glVertex3f( -1.0f,  1.0f,  1.0f );
    gl.glVertex3f( -1.0f,  1.0f, -1.0f );
    gl.glVertex3f( -1.0f, -1.0f, -1.0f );
    gl.glVertex3f( -1.0f, -1.0f,  1.0f );

    gl.glColor3f(   1.0f,  0.0f,  1.0f );
    gl.glVertex3f(  1.0f,  1.0f, -1.0f );
    gl.glVertex3f(  1.0f,  1.0f,  1.0f );
    gl.glVertex3f(  1.0f, -1.0f,  1.0f );
    gl.glVertex3f(  1.0f, -1.0f, -1.0f );

    gl.glEnd();
  }

  /**
   * Initialization of GL context.
   * It's called in init-time of every GL context.
   *
   * @param  gl GL commands access object.
   * @param  glu GLU commands access object.
   */
  public void initRoutine ( GL gl, GLU glu )
  {
    gl.glShadeModel( GL.GL_SMOOTH );
    gl.glClearColor( 0.0f, 0.0f, 0.0f, 1.0f );
    gl.glClearDepth( 1.0f );
    gl.glEnable( GL.GL_DEPTH_TEST );
    gl.glDepthFunc( GL.GL_LEQUAL );
    gl.glHint( GL.GL_PERSPECTIVE_CORRECTION_HINT, GL.GL_NICEST );

    float[] materialAmbient   = { 0.4f, 0.4f, 0.4f, 1.0f };
    float[] materialDiffuse   = { 0.8f, 0.4f, 0.4f, 1.0f };
    float[] materialSpecular  = { 1.0f, 1.0f, 1.0f, 1.0f };
    float[] materialShininess = { 50.0f };
    float[] light_position    = { 0.0f, 100.0f, 0.0f, 1.0f };

    switch ( textureTypeParam )
    {
      case TEXTURE_TYPE_1:
        makeTexture();
        setTexParams( gl, glu );
        break;

      case TEXTURE_TYPE_2:
        makeTexture2();
        setTexParams2( gl, glu );
        break;

      case TEXTURE_TYPE_3:
        makeTexture2();
        setTexParams3( gl, glu );
        break;

      case TEXTURE_TYPE_4:
        makeTexture();
        setTexParams4( gl, glu );
        break;

      case TEXTURE_TYPE_5:
        makeTexture();
        setTexParams5( gl, glu );
        break;
    }

    gl.glMaterialfv( GL.GL_FRONT, GL.GL_AMBIENT, materialAmbient, 0 ); // nastaveni ambientni slozky barvy materialu
    gl.glMaterialfv( GL.GL_FRONT, GL.GL_DIFFUSE, materialDiffuse, 0 );
    gl.glMaterialfv( GL.GL_FRONT, GL.GL_SPECULAR, materialSpecular, 0 );
    gl.glMaterialfv( GL.GL_FRONT, GL.GL_SHININESS, materialShininess, 0 );
    gl.glLightfv( GL.GL_LIGHT0, GL.GL_POSITION, light_position, 0 );
    gl.glEnable( GL.GL_LIGHTING );
    gl.glEnable( GL.GL_LIGHT0 );
  }

  /**
   * Reshape routine is launched when dimensions of GL context is changed.
   * In most cases contains projection changes due to context size.
   *
   * @param  gl GL commands access object
   * @param  glu GLU commands access object
   * @param  x X position of reshaped canvas
   * @param  y Y position of reshaped canvas
   * @param  width Width of reshaped canvas
   * @param  height Height of reshaped canvas
   */
  public void reshapeRoutine ( GL gl, GLU glu, int x, int y, int width, int height )
  {
    if ( height <= 0 )                    // avoid division by zero
      height = 1;
    final float h = (float)width / (float)height;
    gl.glViewport( x, y, width, height );

      // Projection matrix:
    gl.glMatrixMode( GL.GL_PROJECTION );
    gl.glLoadIdentity();
    glu.gluPerspective( 45.0f, h, 1.0, 20.0 );

      // Model-view matrix:
    gl.glMatrixMode( GL.GL_MODELVIEW );
    gl.glLoadIdentity();
  }

  //==========================================================================
  //  Interface Property:

  public static final String SOLID_TYPE   = "Solid";
  public static final String TEXTURE      = "Texture";
  public static final String TEXTURE_TYPE = "Texture type";

  /**
   * Sets the given property.
   *
   * @param  key Key string.
   * @param  value The new value.
   */
  public void set ( String key, Object value )
  {
    if ( key == null || value == null ) return;

      // SAMPLE_TYPE:
    if ( key.compareTo(SOLID_TYPE) == 0 )
    {
      solidTypeParam = intProperty( value, solidTypeParam );
      return;
    }
      // TEXTURE_TYPE:
    if ( key.compareTo(TEXTURE_TYPE) == 0 )
    {
      textureTypeParam = intProperty( value, textureTypeParam );
      return;
    }
  }

  /**
   * Gets the given property.
   *
   * @param  key Key string.
   * @return The actual value or {@code null}.
   */
  public Object get ( String key )
  {
    if ( key == null ) return null;

    if ( key.compareTo(SOLID_TYPE) == 0 )
      return solidTypeParam;
    if ( key.compareTo(TEXTURE_TYPE) == 0 )
      return textureTypeParam;

    return null;
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "SimpleGLGraphics";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "GLGraphicsDrawingSimpleScene";

  /** Object description. */
  private final static String DESCRIPTION = "Generate simple GL graphics";

  /** Object category. */
  protected final static String CATEGORY = C_3D + '.' + C_RENDER;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug( PL_DATA, IFACE + "GLGraphics" );
        // Property:
      t.propBegin( SOLID_TYPE, TYPE_INTEGER, "Solid type", true );
        t.propManipulator( MANIPULATOR_COMBO );
        t.propEnum( "Box",    SOLID_BOX,    "Draws siple box" );
        t.propEnum( "Sphere", SOLID_SPHERE, "Draws siple sphere" );
        t.propEnum( "Teapot", SOLID_TEAPOT, "Draws build-in teapot" );
      t.propEnd();
      t.propBegin( TEXTURE_TYPE, TYPE_INTEGER, "Texture type", true );
        t.propManipulator( MANIPULATOR_COMBO );
        t.propEnum( "2D - normal",              TEXTURE_TYPE_1, "Type 1" );
        t.propEnum( "1D - contures",            TEXTURE_TYPE_2, "Type 2" );
        t.propEnum( "1D - eye plane",           TEXTURE_TYPE_3, "Type 3" );
        t.propEnum( "2D - environment",         TEXTURE_TYPE_4, "Type 4" );
        t.propEnum( "2D - environment spheric", TEXTURE_TYPE_5, "Type 5" );
      t.propEnd();
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }
}
