package cz.cuni.jagrlib.worker;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.piece.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Worker: alpha blending test composition.
 *
 * @version 0.26 $Rev: 466 $ $Date: 2007-05-26 07:12:19 +0200 (so, 26 V 2007) $ $Author: pepca $
 * @since   0.25
 * @see     <a href="../../../../../cz/cuni/jagrlib/worker/AlphaWorker.java">AlphaWorker.java</a>
 */
public class AlphaWorker extends Piece implements Worker
{
  //==========================================================================
  //  Interface Worker:

  /**
   * Executive routine of the working thread.
   */
  public void run ()
  {
    final Trigger        genT    = (Trigger)       getInterface( PL_OUTPUT,    IFACE+"Trigger" );
    final Property       genP    = (Property)      getInterface( PL_PROPERTY,  IFACE+"Property" );
    final SolidBrush     brush   = (SolidBrush)    getInterface( PL_ALPHAMASK, IFACE+"SolidBrush" );
    final GraphicsViewer preview = (GraphicsViewer)getInterface( PL_RASTER,    IFACE+"GraphicsViewer" );
    final DataFileFormat bak     = (DataFileFormat)getInterface( PL_TRIGGER,   IFACE+"DataFileFormat" );

    if ( preview != null )
    {
      GraphicsViewer.PreviewThread runIt = new GraphicsViewer.PreviewThread( preview );
      runIt.safeStart();
    }

    if ( genP  == null ||
         genT  == null ||
         brush == null ) return;

    int[] color = new int[] { 255, 255, 255, 255 };

      // generate the test pattern (the 1st stage):
    genT.fire( AlphaGenerator.PATTERN_WAVES );
      // random color:
    color[0] = 54 + (int)(Math.random() * 200.0);
    color[1] = 54 + (int)(Math.random() * 200.0);
    color[2] = 54 + (int)(Math.random() * 200.0);
    brush.setColor( color );
    brush.fill();
    if ( pl != null ) pl.progress( 1L, 3L );
    if ( userBreak ) return;

    if ( preview != null )
    {
      preview.repaintAll();
      preview.set( GraphicsViewer.WINDOW_TITLE, "After the first stage" );
      try
      {
        Thread.sleep( 4000L );
      }
      catch ( InterruptedException e )
      {}
    }

      // the 2nd stage:
    genP.set( AlphaGenerator.PERIOD, 0 );
    genT.fire( AlphaGenerator.PATTERN_TRANS_LEFT );

      // random color:
    color[0] = 54 + (int)(Math.random() * 200.0);
    color[1] = 54 + (int)(Math.random() * 200.0);
    color[2] = 54 + (int)(Math.random() * 200.0);
    brush.setColor( color );
    brush.fill();
    if ( pl != null ) pl.progress( 2L, 3L );
    if ( userBreak ) return;

    if ( preview != null )
    {
      preview.repaintAll();
      preview.set( GraphicsViewer.WINDOW_TITLE, "After the second stage" );
      try
      {
        Thread.sleep( 4000L );
      }
      catch ( InterruptedException e )
      {}
    }

      // the 3rd stage:
    genT.fire( AlphaGenerator.PATTERN_TRANS_DOWN );

      // random color:
    color[0] = 54 + (int)(Math.random() * 200.0);
    color[1] = 54 + (int)(Math.random() * 200.0);
    color[2] = 54 + (int)(Math.random() * 200.0);
    brush.setColor( color );
    brush.fill();
    if ( pl != null ) pl.progress( 3L, 3L );
    if ( userBreak ) return;

      // finish repainting:
    if ( preview != null )
    {
      preview.set( GraphicsViewer.WINDOW_TITLE, "FINISHED" );
      preview.repaintAll();
      preview.stopRepaintLoop();
    }

      // save the result image in PNG format:
    if ( bak != null )
      try
      {
        bak.saveFile( (String)null, null ); // file-name was specified in constructor
      }
      catch ( Exception e )
      {
        throw new JaGrLibException( "Error writting image!", e );
      }
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "AlphaWorker";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "WorkerForAlpha";

  /** Object description. */
  private final static String DESCRIPTION = "Alpha-blending worker.";

  /** Object category. */
  protected final static String CATEGORY = C_2D + "." + C_DRAW + "." + C_SAMPLE + "." + C_ALPHA + "." + C_WORKER;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newOutputPlug(    PL_OUTPUT,    IFACE+"Trigger" );
      t.newOutputPlug(    PL_ALPHAMASK, IFACE+"SolidBrush" );
      t.newOptOutputPlug( PL_RASTER,    IFACE+"GraphicsViewer" );
      t.newOptOutputPlug( PL_TRIGGER,   IFACE+"DataFileFormat" );
      t.newOutputPlug(    PL_PROPERTY,  IFACE+"Property" );
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
