package cz.cuni.jagrlib.worker;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.RegPiece;

/**
 * Worker: GL graphics drawn in infinite loop.
 *
 * @author  Stuchl, PE
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/worker/GLWorker.java">GLWorker.java</a>
 */
public class GLWorker extends Piece implements Worker
{
  //==========================================================================
  //  Data:

  /** Redraw period in milliseconds (or 0 if no periodic redraw has to be done). */
  protected int period   = 10;

  /** Continue flag for regular redraw loop. */
  protected boolean cont = true;

  /** Accelerator reference to the viewer window. */
  protected GraphicsViewer window;

  //==========================================================================
  //  Executive routine:

  /**
   * Executive routine of the working thread.
   */
  public void run ()
  {
    window = (GraphicsViewer)getInterface( PL_WINDOW, IFACE+"GraphicsViewer" );
    if ( window == null ) return;

    makeBrep();

    Semaphore sem;
    window.set( GraphicsViewer.WINDOW_TITLE, "GL Graphics" );

      // preview thread:
    GraphicsViewer.PreviewThread runIt = new GraphicsViewer.PreviewThread( window );
    runIt.safeStart();

    if ( period > 0 )
    {
      sem = new Semaphore( 0 );
      window.addSemaphore( sem );

        // timer thread:
      RedrawTimer timer = new RedrawTimer();
      timer.startTimer( window, period );

      sem.semWait( 3600000L );

      timer.stopTimer();
    }
  }

  /**
   * Creates simple Brep scene (box).
   */
  private void makeBrep ()
  {
    final Brep brep = (Brep)getInterface( PL_OUTPUT, IFACE + "Brep" );
    if ( brep == null ) return;

    final int context = Brep.CTX_DEFAULT;

      // N=near,F=far,T=top,B=bottom,L=left,R=right
    final int faceN = brep.createFace();
    final int faceF = brep.createFace();
    final int faceT = brep.createFace();
    final int faceB = brep.createFace();
    final int faceL = brep.createFace();
    final int faceR = brep.createFace();

    final int edgeNT = brep.createEdge();
    final int edgeNB = brep.createEdge();
    final int edgeNL = brep.createEdge();
    final int edgeNR = brep.createEdge();
    final int edgeFT = brep.createEdge();
    final int edgeFB = brep.createEdge();
    final int edgeFL = brep.createEdge();
    final int edgeFR = brep.createEdge();
    final int edgeLT = brep.createEdge();
    final int edgeLB = brep.createEdge();
    final int edgeRT = brep.createEdge();
    final int edgeRB = brep.createEdge();

    final int vertexNLT = brep.createVertex();
    final int vertexNLB = brep.createVertex();
    final int vertexNRT = brep.createVertex();
    final int vertexNRB = brep.createVertex();
    final int vertexFLT = brep.createVertex();
    final int vertexFLB = brep.createVertex();
    final int vertexFRT = brep.createVertex();
    final int vertexFRB = brep.createVertex();

    brep.setVertexCoords( context, vertexNLT, new double[] { -1.,  1., -1., 1. } );
    brep.setVertexCoords( context, vertexNLB, new double[] { -1., -1., -1., 1. } );
    brep.setVertexCoords( context, vertexNRT, new double[] {  1.,  1., -1., 1. } );
    brep.setVertexCoords( context, vertexNRB, new double[] {  1., -1., -1., 1. } );
    brep.setVertexCoords( context, vertexFLT, new double[] { -1.,  1.,  1., 1. } );
    brep.setVertexCoords( context, vertexFLB, new double[] { -1., -1.,  1., 1. } );
    brep.setVertexCoords( context, vertexFRT, new double[] {  1.,  1.,  1., 1. } );
    brep.setVertexCoords( context, vertexFRB, new double[] {  1., -1.,  1., 1. } );

    brep.setEdgeVertices( edgeNT, vertexNLT, vertexNRT );
    brep.setEdgeVertices( edgeNB, vertexNLB, vertexNRB );
    brep.setEdgeVertices( edgeNL, vertexNLT, vertexNLB );
    brep.setEdgeVertices( edgeNR, vertexNRT, vertexNRB );
    brep.setEdgeVertices( edgeFT, vertexFLT, vertexFRT );
    brep.setEdgeVertices( edgeFB, vertexFLB, vertexFRB );
    brep.setEdgeVertices( edgeFL, vertexFLT, vertexFLB );
    brep.setEdgeVertices( edgeFR, vertexFRT, vertexFRB );
    brep.setEdgeVertices( edgeLT, vertexNLT, vertexFLT );
    brep.setEdgeVertices( edgeLB, vertexNLB, vertexFLB );
    brep.setEdgeVertices( edgeRT, vertexNRT, vertexFRT );
    brep.setEdgeVertices( edgeRB, vertexNRB, vertexFRB );

    brep.setFaceEdges( faceN, new int[] { edgeNT, edgeNL, edgeNB, edgeNR } );
    brep.setFaceEdges( faceF, new int[] { edgeFT, edgeFL, edgeFB, edgeFR } );
    brep.setFaceEdges( faceL, new int[] { edgeNL, edgeLT, edgeFL, edgeLB } );
    brep.setFaceEdges( faceR, new int[] { edgeNR, edgeRT, edgeFR, edgeRB } );
    brep.setFaceEdges( faceT, new int[] { edgeNT, edgeLT, edgeFT, edgeRT } );
    brep.setFaceEdges( faceB, new int[] { edgeNB, edgeLB, edgeFB, edgeRB } );

    int color = brep.createAttribute( Brep.FACE, context, Brep.COLOR, Brep.ATTR_RGB_3F );

    brep.setAttribute( color, faceN, new float[] { 1.0f, 1.0f, 0.0f } );
    brep.setAttribute( color, faceF, new float[] { 1.0f, 0.0f, 0.0f } );
    brep.setAttribute( color, faceL, new float[] { 0.0f, 1.0f, 0.0f } );
    brep.setAttribute( color, faceR, new float[] { 0.0f, 1.0f, 1.0f } );
    brep.setAttribute( color, faceT, new float[] { 0.0f, 0.0f, 1.0f } );
    brep.setAttribute( color, faceB, new float[] { 1.0f, 0.0f, 1.0f } );

    brep.commit();
  }

  //==========================================================================
  //  Interface Property:

  public final static String PERIOD  = "Redraw period";

  /**
   * Sets the given property.
   *
   * @param  key Key string.
   * @param  value The new value.
   */
  @Override
  public void set ( String key, Object value )
  {
    if ( key == null || value == null ) return;

      // PERIOD:
    if ( key.compareTo(PERIOD) == 0 )
    {
      period = intProperty( value, period, 0, 60000 );
      return;
    }
  }

  /**
   * Gets the given property.
   *
   * @param  key Key string.
   * @return The actual value or {@code null}.
   */
  @Override
  public Object get ( String key )
  {
    if ( key == null ) return null;

    if ( key.compareTo(PERIOD) == 0 )
      return period;

    return null;
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "GLWorker";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "WorkerForGLRendering";

  /** Object description. */
  private final static String DESCRIPTION = "Worker for GL rendering (B-rep rendering).";

  /** Object category. */
  protected final static String CATEGORY = C_3D + '.' + C_RENDER + '.' + C_WORKER;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newOutputPlug(    PL_WINDOW, IFACE+"GraphicsViewer" );
      t.newOptOutputPlug( PL_OUTPUT, IFACE+"Brep" );
        // Property:
      t.propBegin( PERIOD, TYPE_INTEGER, "Auto-redraw period in milliseconds (0 for none)", true );
        t.propDefault( 10 );
        t.propBounds(  0, 60000 );
      t.propEnd();
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
