package cz.cuni.jagrlib.worker;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Worker: interactive projection setup.
 *
 * @version 0.26 $Rev: 701 $ $Date: 2008-01-24 00:19:06 +0100 (čt, 24 I 2008) $ $Author: pepca $
 * @since   0.25
 * @see     <a href="../../../../../cz/cuni/jagrlib/worker/ProjectionWorker.java">ProjectionWorker.java</a>
 */
public class ProjectionWorker extends Piece implements Worker
{
  //==========================================================================
  //  Data:

  /** Redraw period in milliseconds (or 0 if no periodic redraw has to be done). */
  protected int period   = 500;

  /** Continue flag for regular re-draw loop. */
  protected boolean cont = true;

  //==========================================================================
  //  Executive routine:

  /**
   * Executive routine of the working thread.
   */
  public void run ()
  {
    final GraphicsViewer window = (GraphicsViewer)getInterface( PL_WINDOW,  IFACE+"GraphicsViewer" );
    if ( window == null ) return;

    Semaphore sem;
    window.set( GraphicsViewer.WINDOW_TITLE, "Projection matrix setup" );

      // preview thread:
    GraphicsViewer.PreviewThread runIt = new GraphicsViewer.PreviewThread( window );
    runIt.safeStart();

    if ( period > 0 )
    {
      sem = new Semaphore( 0 );
      window.addSemaphore( sem );

        // timer thread:
      RedrawTimer timer = new RedrawTimer();
      timer.startTimer( window, period );

      sem.semWait( 3600000L );

      timer.stopTimer();
    }
  }

  //==========================================================================
  //  Interface Property:

  public final static String PERIOD  = "Redraw period";

  /**
   * Sets the given property.
   *
   * @param  key Key string.
   * @param  value The new value.
   */
  @Override
  public void set ( String key, Object value )
  {
    if ( key == null || value == null ) return;

      // PERIOD:
    if ( key.compareTo(PERIOD) == 0 )
    {
      period = intProperty( value, period, 0, 60000 );
      return;
    }
  }

  /**
   * Gets the given property.
   *
   * @param  key Key string.
   * @return The actual value or {@code null}.
   */
  @Override
  public Object get ( String key )
  {
    if ( key == null ) return null;

    if ( key.compareTo(PERIOD) == 0 )
      return period;

    return null;
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "ProjectionWorker";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "WorkerForInteractiveProjection";

  /** Object description. */
  private final static String DESCRIPTION = "Interactive projection matrix setup.";

  /** Object category. */
  protected final static String CATEGORY = C_3D + '.' + C_RENDER + '.' + C_WORKER;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newOutputPlug( PL_WINDOW, IFACE+"GraphicsViewer" );
        // Property:
      t.propBegin( PERIOD, TYPE_INTEGER, "Auto-redraw period in milliseconds", true );
        t.propDefault( 500 );
        t.propBounds(  0, 60000 );
      t.propEnd();
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
