package cz.cuni.jagrlib.worker;

import java.io.*;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Worker: interactive raster image warping (two-phase-{@link Trigger} warper module).
 *
 * @version 0.26 $Rev: 466 $ $Date: 2007-05-26 07:12:19 +0200 (so, 26 V 2007) $ $Author: pepca $
 * @since   0.25
 * @see     <a href="../../../../../cz/cuni/jagrlib/worker/WarpingWorker.java">WarpingWorker.java</a>
 */
public class WarpingWorker extends Piece implements Worker
{
  //==========================================================================
  //  Interface Worker:

  /**
   * Executive routine of the working thread.
   */
  public void run ()
  {
    final DataFileFormat output   = (DataFileFormat)getInterface( PL_OUTPUT, IFACE+"DataFileFormat" );
    final GraphicsViewer preview2 = (GraphicsViewer)getInterface( "raster2", IFACE+"GraphicsViewer" );
    final Trigger        filter   = (Trigger)       getInterface( PL_DIRECT, IFACE+"Trigger" );

    if ( output == null ||
         filter == null ) return;

      // output image init..
    filter.fire( 0 );

      // attach preview window to the output image & render it:
    if ( preview2 != null )
    {
      preview2.set( GraphicsViewer.WINDOW_TITLE, "OUTPUT" );
      GraphicsViewer.PreviewThread runIt = new GraphicsViewer.PreviewThread( preview2 );
      runIt.safeStart();
    }

      // do the interaction..
    filter.fire( 1 );

      // save the output image:
    try
    {
      output.saveFile( (String)null, null ); // file-name was specified in constructor
    }
    catch ( IOException e )
    {
      throw new JaGrLibException( "Error writting image!", e );
    }
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "WarpingWorker";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "WorkerForImageWarping";

  /** Object description. */
  private final static String DESCRIPTION = "Tests image warpers.";

  /** Object category. */
  protected final static String CATEGORY = C_2D + '.' + C_RASTER + '.' + C_FILTER + '.' + C_WORKER;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newOutputPlug(    PL_OUTPUT, IFACE+"DataFileFormat" );
      t.newOptOutputPlug( "raster2", IFACE+"GraphicsViewer" );
      t.newOutputPlug(    PL_DIRECT, IFACE+"Trigger" );
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
