package cz.cuni.jagrlib.xml;

import java.io.*;
import java.util.*;
import org.w3c.dom.*;
import javax.swing.*;
import javax.xml.parsers.*;
import javax.xml.transform.*;
import javax.xml.transform.stream.*;
import javax.xml.transform.dom.*;

import cz.cuni.jagrlib.gui.*;
import cz.cuni.jagrlib.gui.comp.*;
import cz.cuni.jagrlib.reg.*;
import cz.cuni.jagrlib.Formula;
import cz.cuni.jagrlib.LogFile;

/**
 * Saving and loading of XML files.
 *
 * @author  PE, Jan Kostlivy
 * @version 0.26 $Rev: 430 $ $Date: 2007-04-29 04:27:07 +0200 (ne, 29 IV 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/xml/PlugGUI.java">PlugGUI.java</a>
 */
public class InputOutputXML implements InputOutput
{
  /** File name of comoposition. */
  protected String fileName;

  /** File chooser. */
  JFileChooser chooser = new JFileChooser( Options.pathData );

  /** File filter for file chooser. */
  CommonFileFilter filter = new CommonFileFilter();
  {
    filter.addExtension(   "xml" );
    filter.setDescription( "XML files" );
    chooser.setFileFilter( filter );
  }

  /** XML document. */
  protected Document doc;

  /** Root of data. */
  protected Node root;

  /** Actual node for saving or loading. */
  protected Node actualNode;

  /** Number of backup files. */
  protected final static int maxBackupNumber   = 9;

    // String constants - XML tags:
  protected final static String G_REGISTRY     = "registry";
  protected final static String G_COMPOSITION  = "composition";
  protected final static String G_SHOWMODULES  = "showmodules";
  protected final static String KEY            = "key";
  protected final static String C_INTERFACE    = "interface";
  protected final static String C_MODULEFROM   = "modulefrom";
  protected final static String C_PLUGFROM     = "plugfrom";
  protected final static String C_MODULETO     = "moduleto";
  protected final static String C_PLUGTO       = "plugto";
  protected final static String PA_NAME        = "name";
  protected final static String PA_VALUE       = "value";
  protected final static String PA_VISIBLE     = "visible";
  protected final static String PL_NAME        = "name";
  protected final static String PL_ORIENTATION = "orientation";
  protected final static String PL_VISIBLE     = "visible";

  protected final static String M_CLASS        = "class";
  protected final static String M_PACKAGE      = "package";
  protected final static String M_TEMPLATE     = "template";
  protected final static String M_NAME         = "name";
  protected final static String M_SHAPE        = "shape";
  protected final static String M_MODESHOW     = "mode";
  protected final static String M_EDITABLE     = "editable";
  protected final static String M_MINIMIZABLE  = "minimizable";
  protected final static String M_MAXIMIZABLE  = "maximizable";
  protected final static String M_SELECTED     = "selected";
  protected final static String M_PLUGS        = "plugs";
  protected final static String M_PARAMS       = "params";
  protected final static String M_NEXTINFO     = "nextInfo";

  protected final static String SHAPE_X        = "x";
  protected final static String SHAPE_Y        = "y";
  protected final static String SHAPE_HEIGHT   = "height";
  protected final static String SHAPE_WIDTH    = "width";

  /**
   * Main method for save Composition to XML file.
   *
   * @param  _composition Composition info.
   * @param  type Save type (Save or SaveAs)
   */
  public void save ( String type, InfoGroup _composition )
  throws Exception
  {
    if ( _composition == null )
      throw new Exception( "Invalid Composition" );

    fileName      = _composition.fileName;
    int returnVal = JFileChooser.APPROVE_OPTION;
    if ( type.compareTo( SAVEAS ) == 0 ||
         fileName == null ||
         fileName.length() == 0 )
    {
      if ( fileName == null ||
           fileName.length() == 0 )
        fileName = Options.pathData + "new.xml";

      chooser.setSelectedFile( new File( fileName ) );
      returnVal = chooser.showSaveDialog( MainWindow.mainWindow );
      fileName = chooser.getSelectedFile().getPath();
    }

    if ( returnVal == JFileChooser.APPROVE_OPTION )
    {
      _composition.fileName = fileName;

      if ( _composition.fileName.length() == 0 )
        throw new Exception( "Invalid File Name" );

      doc = DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument();
      Transformer vv = TransformerFactory.newInstance().newTransformer();
      vv.setOutputProperty( OutputKeys.METHOD,               "xml" );
      vv.setOutputProperty( OutputKeys.OMIT_XML_DECLARATION, "no" );
      vv.setOutputProperty( OutputKeys.INDENT,               "yes" );
      vv.setOutputProperty( OutputKeys.ENCODING,             "UTF-8" );
      DOMSource    c = new DOMSource();
      StreamResult b = new StreamResult();
      root           = doc.createElement( InfoGroup.TI_COMPOSITION );
      actualNode     = root;
      saveComposition( _composition );
      c.setNode( root );

      File oldFile = new File( _composition.fileName );
      if ( oldFile.exists() )
        backup( _composition.fileName, oldFile, 1 );

      b.setOutputStream( new FileOutputStream( _composition.fileName ) );
      try
      {
        vv.transform( c, b );
      }
      catch ( Exception e )
      {
        LogFile.exception( e );
      }

      b.getOutputStream().close();
    }
  }

  /**
   * Saves composition.
   *
   * @param _composition Composition info.
   */
  public void saveComposition ( InfoGroup _composition )
  {
    Set< Integer > chKeys = new TreeSet< Integer >( _composition.modules.keySet() );
    for ( Integer s : chKeys )
      if ( _composition.modules.get( s ) instanceof InfoGroup )
        saveGroup( (InfoGroup)_composition.modules.get( s ) );
      else
        if ( _composition.modules.get( s ) instanceof InfoModule )
          saveModule( _composition.modules.get( s ) );

    chKeys.clear();
    chKeys.addAll( _composition.channels.keySet() );
    for ( Integer ch : chKeys )
      saveChannel( _composition.channels.get( ch ) );

    actualNode.appendChild( doc.createTextNode( XMLAction.DELIMITER0 ) );
  }

  /**
   * Saves one group.
   *
   * @param _info Group info.
   */
  public void saveGroup ( InfoGroup _info )
  {
    try
    {
      Node actualNodeNow = actualNode;

      Element sg = (Element)XMLAction.appendChild( doc, actualNode, XMLAction.DELIMITER1, InfoGroup.TI_GROUP );

      if ( _info.registry )
        XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, G_REGISTRY );

      Node pome = XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, G_COMPOSITION );

      if ( _info.infoCompositionGUI.modulesShow )
        XMLAction.appendChild( doc, pome, XMLAction.DELIMITER3, G_SHOWMODULES );

      XMLAction.appendChild( doc, pome, XMLAction.DELIMITER3, SHAPE_HEIGHT, String.valueOf( _info.infoCompositionGUI.height ) );
      XMLAction.appendChild( doc, pome, XMLAction.DELIMITER3, SHAPE_WIDTH,  String.valueOf( _info.infoCompositionGUI.width ) );
      pome.appendChild( doc.createTextNode( XMLAction.DELIMITER2 ) );

      saveModule( sg, _info );
      if ( !_info.registry )
      {
        actualNode = sg;
        saveComposition( _info );
      }
      sg.appendChild( doc.createTextNode( XMLAction.DELIMITER1 ) );

      if ( _info.editRegisty )
      {
        _info.editRegisty = false;
        _info.registry    = false;
        RegDatabaseBasic.tables.registerGroup( _info );
        RegDatabaseBasic.saveRegistryData();
        _info.registry    = true;
      }

      actualNode = actualNodeNow;
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Saves one channel.
   *
   * @param _info Channel info.
   */
  public void saveChannel ( InfoChannel _info )
  {
    try
    {
      Node sg = XMLAction.appendChild( doc, actualNode, XMLAction.DELIMITER1, InfoChannel.TI_CHANNEL );

      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, KEY,         _info.key.toString() );
      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, C_INTERFACE, _info.nameInterface );

      InfoModule it;
      InfoPlug   pl;

      it = _info.plugFrom.owner;
      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, C_MODULEFROM, String.valueOf( it.key ) );
      for ( String s : it.plugs.keySet() )
      {
        pl = it.plugs.get( s );
        if ( _info.plugFrom.equals( pl ) )
          XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, C_PLUGFROM, s );
      }

      it = _info.plugTo.owner;
      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, C_MODULETO, String.valueOf( it.key ) );
      for ( String s : it.plugs.keySet() )
      {
        pl = it.plugs.get( s );
        if ( _info.plugTo.equals( pl ) )
          XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, C_PLUGTO, s );
      }

      if ( _info.nextInfo != null && !_info.nextInfo.isEmpty() )
      {
        sg.appendChild( doc.createTextNode( XMLAction.DELIMITER2 ) );
        sg.appendChild( saveNextInfo( _info.nextInfo ) );
      }

      sg.appendChild( doc.createTextNode( XMLAction.DELIMITER1 ) );
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Saves one parameter.
   *
   * @param _info Parameter info.
   * @param _key Key of parameter for module or group.
   */
  public void saveParam ( InfoParam _info, String _key )
  {
    try
    {
      Node sg = XMLAction.appendChild( doc, actualNode, XMLAction.DELIMITER3, InfoParam.TI_PARAM );

      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER4, PA_NAME,  _key );
      //LogFile.log( "saveParam: key = " + _key + ", value = '" + Formula.stringValue( _info.value ) + "' (" + _info.value.getClass().getName() + ')' );
      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER4, PA_VALUE, Formula.stringValue( _info.value ) );

      if ( _info.infoGUI != null &&
           _info.infoGUI.visible )
        XMLAction.appendChild( doc, sg, XMLAction.DELIMITER4, PA_VISIBLE );

      if ( _info.nextInfo != null &&
          !_info.nextInfo.isEmpty() )
      {
        sg.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
        sg.appendChild( saveNextInfo( _info.nextInfo ) );
      }

      sg.appendChild( doc.createTextNode( XMLAction.DELIMITER3 ) );
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Saves one module.
   *
   * @param _info Module info.
   */
  public void saveModule ( InfoModule _info )
  {
    try
    {
      Node actualNodeNow = actualNode;

      Element sg = (Element)XMLAction.appendChild( doc, actualNode, XMLAction.DELIMITER1, InfoModule.TI_MODULE );
      saveModule( sg, _info );
      sg.appendChild( doc.createTextNode( XMLAction.DELIMITER1 ) );

      actualNode = actualNodeNow;
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Saves module or group info.
   *
   * @param sg Node for saving.
   * @param _info Module info.
   */
  public void saveModule ( Element sg, InfoModule _info )
  {
    try
    {
      if ( _info.key != null )
        XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, KEY, _info.key.toString() );

      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, M_CLASS,    _info.reg.className );
      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, M_PACKAGE,  _info.reg.packageName );
      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, M_TEMPLATE, _info.reg.template );
      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, M_NAME,     _info.reg.name );

      Node pome = XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, M_SHAPE );
      XMLAction.appendChild( doc, pome, XMLAction.DELIMITER3, M_MODESHOW,   _info.infoGUI.modeShow );
      XMLAction.appendChild( doc, pome, XMLAction.DELIMITER3, SHAPE_X,      String.valueOf( _info.infoGUI.x ) );
      XMLAction.appendChild( doc, pome, XMLAction.DELIMITER3, SHAPE_Y,      String.valueOf( _info.infoGUI.y ) );
      XMLAction.appendChild( doc, pome, XMLAction.DELIMITER3, SHAPE_HEIGHT, String.valueOf( _info.infoGUI.height ) );
      XMLAction.appendChild( doc, pome, XMLAction.DELIMITER3, SHAPE_WIDTH,  String.valueOf( _info.infoGUI.width ) );
      pome.appendChild( doc.createTextNode( XMLAction.DELIMITER2 ) );

      if ( _info.infoGUI.selected )
        XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, M_SELECTED );
      if ( _info.infoGUI.editable )
        XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, M_EDITABLE );
      if ( _info.infoGUI.minimizable )
        XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, M_MINIMIZABLE );
      if ( _info.infoGUI.maximizable )
        XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, M_MAXIMIZABLE );

      if ( _info.nextInfo != null && !_info.nextInfo.isEmpty() )
      {
        sg.appendChild( doc.createTextNode( XMLAction.DELIMITER2 ) );
        sg.appendChild( saveNextInfo( _info.nextInfo ) );
      }

      actualNode = XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, M_PLUGS );
      for ( String s : _info.plugs.keySet() )
        savePlug( _info.plugs.get( s ), s );

      if ( _info.plugs.size() > 0 )
        actualNode.appendChild( doc.createTextNode( XMLAction.DELIMITER2 ) );

      actualNode = XMLAction.appendChild( doc, sg, XMLAction.DELIMITER2, M_PARAMS );
      for ( String s : _info.params.keySet() )
        saveParam( _info.params.get( s ), s );

      if ( _info.params.size() > 0 )
        actualNode.appendChild( doc.createTextNode( XMLAction.DELIMITER2 ) );
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Saves one plug.
   *
   * @param _info Plug info.
   * @param _key Key of plug for module or group.
   */
  public void savePlug ( InfoPlug _info, String _key )
  {
    try
    {
      Node sg = XMLAction.appendChild( doc, actualNode, XMLAction.DELIMITER3, InfoPlug.TI_PLUG );

      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER4, KEY,            _key );
      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER4, PL_NAME,        _info.name );
      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER4, PL_ORIENTATION, String.valueOf( _info.infoGUI.orientation ) );
      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER4, SHAPE_X,        String.valueOf( _info.infoGUI.x ) );
      XMLAction.appendChild( doc, sg, XMLAction.DELIMITER4, SHAPE_Y,        String.valueOf( _info.infoGUI.y ) );
      if ( _info.infoGUI.visible )
        XMLAction.appendChild( doc, sg, XMLAction.DELIMITER4, PL_VISIBLE );

      if ( _info.nextInfo != null &&
          !_info.nextInfo.isEmpty() )
      {
        sg.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
        sg.appendChild( saveNextInfo( _info.nextInfo ) );
      }
      sg.appendChild( doc.createTextNode( XMLAction.DELIMITER3 ) );
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Saves nextInfo.
   *
   * @param _nextInfo Next information for anything.
   * @return Node with saved data.
   */
  public Element saveNextInfo ( Map< String, Object > _nextInfo )
  {
    Element pome = doc.createElement( M_NEXTINFO );
    for ( String s : _nextInfo.keySet() )
      XMLAction.appendChild( doc, pome, XMLAction.DELIMITER3, s, _nextInfo.get( s ).toString() );

    if ( _nextInfo.size() > 0 )
      pome.appendChild( doc.createTextNode( XMLAction.DELIMITER2 ) );

    return pome;
  }

  /**
   * Loads composition w/o asking for its file-name.
   * File-name can be stored in _composition.fileName already
   * (in that case fileName argument should be {@code null}).
   */
  public void loadFile ( InfoGroup _composition, String fileName )
  throws Exception
  {
    if ( fileName != null )
      _composition.fileName = fileName;

    if ( _composition.fileName          == null ||
         _composition.fileName.length() == 0 )
      throw new Exception( "Invalid File Name" );

    Transformer  vv = TransformerFactory.newInstance().newTransformer();
    DOMResult    c  = new DOMResult();
    StreamSource b  = new StreamSource();
    b.setInputStream( new FileInputStream( _composition.fileName ) );

    try
    {
      vv.transform( b, c );
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
      return;
    }

    b.getInputStream().close();
    root = c.getNode();
    root.normalize();
    actualNode = XMLAction.getFirstChildElement( root );

    if ( actualNode.getNodeName().equalsIgnoreCase( InfoGroup.TI_COMPOSITION ) )
    {
      _composition.modules.clear();
      _composition.channels.clear();
      loadComposition( _composition );
    }
    else
      throw new Exception( "Invalid File Type" );
  }

  /**
   * Main method for load Composition from XML file.
   *
   * @param _composition Composition info.
   */
  public void load ( InfoGroup _composition )
  throws Exception
  {
    if ( _composition.fileName != null &&
         _composition.fileName.length() > 0 )
      loadFile( _composition, null );

    else
    {
      if ( fileName == null )
        fileName = Options.pathData;

      //LogFile.log( "File to read: " + (fileName == null ? "null" : fileName) );

      chooser.setSelectedFile( new File( fileName ) );
      int returnVal = chooser.showOpenDialog( MainWindow.mainWindow );
      if ( returnVal == JFileChooser.APPROVE_OPTION )
        loadFile( _composition, chooser.getSelectedFile().getPath() );
    }
  }

  /**
   * Loads composition.
   *
   * @param _composition Composition info.
   * @return Information about composition.
   */
  public InfoGroup loadComposition ( InfoGroup _composition )
  throws Exception
  {
    InfoModule  infoM;
    InfoGroup   infoG;
    InfoChannel infoC;

    Node pom = XMLAction.getFirstChildElement( actualNode );
    while ( pom != null )
    {
      actualNode = pom;
      if ( pom.getNodeName().equalsIgnoreCase( InfoModule.TI_MODULE ) )
      {
        try
        {
          infoM       = loadModule( null );
          infoM.owner = _composition;
          _composition.modules.put( infoM.key, infoM );
        }
        catch ( Exception e )
        {
          LogFile.exception( e );
          JOptionPane.showMessageDialog( MainWindow.mainWindow, e.getMessage(),
                                         "Error", JOptionPane.ERROR_MESSAGE );
        }
      }
      if ( pom.getNodeName().equalsIgnoreCase( InfoGroup.TI_GROUP ) )
      {
        try
        {
          infoG       = loadGroup( null );
          infoG.owner = _composition;
          _composition.modules.put( infoG.key, infoG );
        }
        catch ( Exception e )
        {
          LogFile.exception( e );
          JOptionPane.showMessageDialog( MainWindow.mainWindow, e.getMessage(), "Error", JOptionPane.ERROR_MESSAGE );
        }
      }
      if ( pom.getNodeName().equalsIgnoreCase( InfoChannel.TI_CHANNEL ) )
      {
        try
        {
          infoC       = new InfoChannel();
          infoC.owner = _composition;
          loadChannel( infoC );
          _composition.channels.put( infoC.key, infoC );
        }
        catch ( Exception e )
        {
          LogFile.exception( e );
          JOptionPane.showMessageDialog( MainWindow.mainWindow, e.getMessage(),
                                         "Error", JOptionPane.ERROR_MESSAGE );
        }
      }
      pom = XMLAction.getNextSiblingElement( pom );
    }
    return _composition;
  }

  /**
   * Loads group.
   *
   * @param _info Group info.
   * @return Information about group.
   */
  public InfoGroup loadGroup ( InfoGroup _info )
  throws Exception
  {
    Node pom;

    String cn  = XMLAction.getValue( actualNode, M_CLASS );
    String pn  = XMLAction.getValue( actualNode, M_PACKAGE );
    String tn  = XMLAction.getValue( actualNode, M_TEMPLATE );
    boolean br = XMLAction.getBoolLegacy( actualNode, G_REGISTRY );
    if ( br )
    {
      _info = (InfoGroup)RegDatabaseBasic.getInfo( pn, cn, tn );
      if (_info == null )
        throw new Exception( "Unknown Group: '" + pn + "." + cn + "(" + tn + ")'" );
    }
    if ( _info == null )
      _info = new InfoGroup();
    if ( _info.infoGUI == null )
      _info.infoGUI = new InfoGroupGUI();

    _info          = (InfoGroup)loadModuleInfo( _info );
    _info.registry = br;
    Node pomNode = actualNode;
    if ( !br )
    {
      _info = loadComposition( _info );
      _info.init();
    }

    if ( _info.infoCompositionGUI == null )
      _info.infoCompositionGUI = new InfoCompositionGUI();

    actualNode = pomNode;
    pom = XMLAction.getNode( actualNode, G_COMPOSITION );
    if ( pom != null )
    {
      _info.infoCompositionGUI.modulesShow = XMLAction.getBoolLegacy( pom, G_SHOWMODULES );
      _info.infoCompositionGUI.height      = XMLAction.getIntValue(  pom, SHAPE_HEIGHT );
      _info.infoCompositionGUI.width       = XMLAction.getIntValue(  pom, SHAPE_WIDTH );
    }
    loadPlugsParams( _info );

    return _info;
  }

  /**
   * Loads channel.
   *
   * @param _info Channel info.
   * @return Information about channel.
   */
  public InfoChannel loadChannel ( InfoChannel _info )
  throws Exception
  {
    if ( _info.infoGUI == null )
      _info.infoGUI = new InfoChannelGUI();

    HashMapModules mod = _info.owner.modules;

    Integer keymf;
    Integer keymt;
    String  keypf;
    String  keypt;

    _info.key           = XMLAction.getIntegerValue( actualNode, KEY );
    _info.nameInterface = XMLAction.getValue( actualNode, C_INTERFACE );

    keymf = XMLAction.getIntegerValue( actualNode, C_MODULEFROM );
    keymt = XMLAction.getIntegerValue( actualNode, C_MODULETO );

    keypf = XMLAction.getValue( actualNode, C_PLUGFROM );
    keypt = XMLAction.getValue( actualNode, C_PLUGTO );

    InfoModule im = mod.get( keymf );
    if ( im    == null ||
         keymf == null )
      throw new Exception( "Unknown Channel ModuleFrom: '" + _info.key + "'" );

    _info.plugFrom = im.plugs.get( keypf );
    im = mod.get( keymt );
    if ( im    == null ||
         keymf == null )
      throw new Exception( "Unknown Channel ModuleTo: '" + _info.key + "'" );

    _info.plugTo = im.plugs.get( keypt );

    return _info;
  }

  /**
   * Loads parameter.
   *
   * @param _info Parameter info.
   * @param _owner Owner of parameter.
   * @return Information about parameter.
   */
  public InfoParam loadParam ( InfoParam _info, InfoModule _owner )
  throws Exception
  {
    if ( !actualNode.getNodeName().equalsIgnoreCase( InfoParam.TI_PARAM ) )
      return null;

    String _name = XMLAction.getValue( actualNode, PA_NAME );

    _info = _owner.params.get( _name );
    if ( _info == null )
      throw new Exception( "Unknown Param: '" + _name + "'" );

    _info.value = XMLAction.getValue( actualNode, PA_VALUE );

    if ( _info.infoGUI == null )
      _info.infoGUI = new InfoParamGUI();

    _info.infoGUI.visible = XMLAction.getBoolLegacy( actualNode, PA_VISIBLE );

    return _info;
  }

  /**
   * Loads module or group info.
   *
   * @param _info Module info.
   * @return Information about module.
   */
  public InfoModule loadModuleInfo ( InfoModule _info )
  throws Exception
  {
    Node pom;
    String ps;

    _info.key = XMLAction.getIntegerValue( actualNode, KEY );

    ps = XMLAction.getValue( actualNode, M_NAME );
    if ( ps != "" )
      _info.reg.name = ps;

    _info.infoGUI.selected    = XMLAction.getBoolLegacy( actualNode, M_SELECTED );
    _info.infoGUI.editable    = XMLAction.getBoolLegacy( actualNode, M_EDITABLE );
    _info.infoGUI.minimizable = XMLAction.getBoolLegacy( actualNode, M_MINIMIZABLE );
    _info.infoGUI.maximizable = XMLAction.getBoolLegacy( actualNode, M_MAXIMIZABLE );

    pom = XMLAction.getNode( actualNode, M_SHAPE );
    _info.infoGUI.modeShow = XMLAction.getValue(    pom, M_MODESHOW );
    _info.infoGUI.x        = XMLAction.getIntValue( pom, SHAPE_X );
    _info.infoGUI.y        = XMLAction.getIntValue( pom, SHAPE_Y );
    _info.infoGUI.height   = XMLAction.getIntValue( pom, SHAPE_HEIGHT );
    _info.infoGUI.width    = XMLAction.getIntValue( pom, SHAPE_WIDTH );
    return _info;
  }

  /**
   * Loads plugs and params.
   *
   * @param _info Module info.
   */
  public void loadPlugsParams ( InfoModule _info )
  throws Exception
  {
    Node pom;
    Node nodeParam = null;
    Node nodePlugs = null;
    nodePlugs      = XMLAction.getNode( actualNode, M_PLUGS );
    nodeParam      = XMLAction.getNode( actualNode, M_PARAMS );
    if ( nodePlugs != null )
    {
      pom = XMLAction.getFirstChildElement( nodePlugs );
      while ( pom != null )
      {
        actualNode = pom;
        try
        {
          loadPlug( null, _info );
        }
        catch ( Exception e )
        {
          LogFile.exception(e);
          if ( JOptionPane.showConfirmDialog( MainWindow.mainWindow,
                                              "Error '" + e.getMessage() + "' occured.\nDo you want to skip module '" +
                                              _info.reg.name + "'?",
                                              "Confirm", JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION )
            throw new Exception( e.getMessage() );
        }
        pom = XMLAction.getNextSiblingElement( pom );
      }
    }
    if ( nodeParam != null )
    {
      pom = XMLAction.getFirstChildElement( nodeParam );
      while ( pom != null )
      {
        actualNode = pom;
        try
        {
          loadParam( null, _info );
        }
        catch ( Exception e )
        {
          LogFile.exception( e );
          if ( JOptionPane.showConfirmDialog( MainWindow.mainWindow,
                                              "Error '" + e.getMessage() + "' occured.\nDo you want to skip module '" +
                                              _info.reg.name + "'?",
                                              "Confirm", JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION )
            throw new Exception( e.getMessage() );
        }
        pom = XMLAction.getNextSiblingElement( pom );
      }
    }
  }

  /**
   * Loads module.
   *
   * @param _info Module info.
   * @return Information about module.
   */
  public InfoModule loadModule ( InfoModule _info )
  throws Exception
  {
    String cn = XMLAction.getValue( actualNode, M_CLASS );
    String pn = XMLAction.getValue( actualNode, M_PACKAGE );
    String tn = XMLAction.getValue( actualNode, M_TEMPLATE );
    _info = RegDatabaseBasic.getInfo( pn, cn, tn );
    if ( _info == null )
      throw new Exception( "Unknown Module: '" + pn + "." + cn + "(" + tn + ")'" );

    if ( _info.infoGUI == null )
      _info.infoGUI = new InfoModuleGUI();

    _info = loadModuleInfo( _info );
    loadPlugsParams( _info );

    return _info;
  }

  /**
   * Loads plug.
   *
   * @param _info Plug info.
   * @param _owner Owner of plug.
   * @return Information about plug.
   */
  public InfoPlug loadPlug ( InfoPlug _info, InfoModule _owner )
  throws Exception
  {
    if ( !actualNode.getNodeName().equalsIgnoreCase( InfoPlug.TI_PLUG ) )
      return null;

    String _type = XMLAction.getValue( actualNode, KEY );

    _info = _owner.plugs.get( _type );
    if ( _info == null )
      throw new Exception( "Unknown Plug: '" + _type + "'" );

    if ( _info.infoGUI == null )
      _info.infoGUI = new InfoPlugGUI();

    _info.infoGUI.orientation = XMLAction.getIntValue(   actualNode, PL_ORIENTATION );
    _info.infoGUI.x           = XMLAction.getIntValue(   actualNode, SHAPE_X );
    _info.infoGUI.y           = XMLAction.getIntValue(   actualNode, SHAPE_Y );
    _info.infoGUI.visible     = XMLAction.getBoolLegacy( actualNode, PL_VISIBLE );

    return _info;
  }

  /**
   * Renaming of backup files.
   *
   * @param fileName Name of new file.
   * @param oldFile Name of old file.
   * @param order Numerical order of backup file.
   */
  public void backup ( String fileName, File oldFile, int order )
  {
    File backFile = new File( fileName + ".~" + String.valueOf(order) );
    if ( maxBackupNumber == order && backFile.exists() )
      backFile.delete();
    if ( backFile.exists() )
    {
      backup( fileName, backFile, order + 1 );
    }
    oldFile.renameTo( backFile );
  }

}
