package cz.cuni.jagrlib.xml;

import java.io.*;
import java.util.*;
import org.w3c.dom.*;
import javax.swing.*;
import javax.swing.table.AbstractTableModel;
import javax.xml.parsers.*;
import javax.xml.transform.*;
import javax.xml.transform.stream.*;
import javax.xml.transform.dom.*;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.gui.comp.*;
import cz.cuni.jagrlib.gui.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Class for registry data stored in XML file.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.26 $Rev: 431 $ $Date: 2007-04-29 22:42:22 +0200 (ne, 29 IV 2007) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/xml/RegTablesXML.java">RegTablesXML.java</a>
 */
public class RegTablesXML implements RegTables
{
  /** Name of registry file. */
  private String file = RegDatabaseBasic.getRegDataFile();

  /** Root of registry data document. */
  static private Node root;

  /** Root of registry data. */
  static private Node rootDat;

  /** XML document. */
  private Document doc;

    // String constants - XML tags:
  protected final static String MODULE                 = "Module";
  protected final static String MODULE_PACKAGENAME     = "Packagename";
  protected final static String MODULE_CLASSNAME       = "Classname";
  protected final static String MODULE_NAME            = "Name";
  protected final static String MODULE_SHAPE           = "Shape";
  protected final static String MODULE_TEMPLATE        = "Template";
  protected final static String MODULE_KEY             = "Key";
  protected final static String MODULE_PLUGS           = "Plugs";
  protected final static String MODULE_PARAMS          = "Params";

  protected final static String SHAPE_MODE             = "mode";
  protected final static String SHAPE_X                = "x";
  protected final static String SHAPE_Y                = "y";
  protected final static String SHAPE_WIDTH            = "width";
  protected final static String SHAPE_HEIGHT           = "height";

  protected final static String CLASS                  = "Class";
  protected final static String CLASS_MOVED_TO         = "MovedTo";
  protected final static String CLASS_CLASSNAME        = "Classname";

  protected final static String TEMPLATE               = "Template";
  protected final static String TEMPLATE_TEMPLATE_NAME = "TemplateName";
  protected final static String TEMPLATE_NAME          = "Name";
  protected final static String TEMPLATE_CATEGORY      = "Category";
  protected final static String TEMPLATE_DESCRIPTION   = "Description";

  protected final static String PLUG                   = "Plug";
  protected final static String PLUG_NAME              = "Name";           // !!! LEGACY !!!
  protected final static String PLUG_IFACE             = "Iface";
  protected final static String PLUG_TYPE              = "Type";           // !!! LEGACY !!!
  protected final static String PLUG_ID                = "Id";
  protected final static String PLUG_DESCRIPTION       = "Description";
  protected final static String PLUG_VISIBLE           = "Visible";
  protected final static String PLUG_IO                = "IO";
  protected final static String PLUG_INPUT             = "Input";
  protected final static String PLUG_MANDATORY         = "Mandatory";
  protected final static String PLUG_MULTI             = "Multi";

  protected final static String PARAM                  = "Param";
  protected final static String PARAM_NAME             = "Name";
  protected final static String PARAM_TYPE             = "Type";
  protected final static String PARAM_DESCRIPTION      = "Description";
  protected final static String PARAM_VISIBLE          = "Visible";
  protected final static String PARAM_MANIPULATOR      = "Manipulator";
  protected final static String PARAM_DEFAULT          = "Default";

  protected final static String VALUES                 = "Values";
  protected final static String VALUES_ITEM            = "Item";

  protected final static String CHANNEL                = "Channel";
  protected final static String CHANNEL_NAME           = "Name";
  protected final static String CHANNEL_MODULE_FROM    = "ModulFrom";
  protected final static String CHANNEL_MODULE_TO      = "ModulTo";
  protected final static String CHANNEL_PLUG_FROM      = "PlugFrom";
  protected final static String CHANNEL_PLUG_TO        = "PlugTo";

  protected final static String GROUP                  = "GROUP";

  /**
   * Gets information about modules in group.
   *
   * @param nodeClass Node with group.
   * @return HashMapModules.
   */
  public HashMapModules getModules ( Node nodeClass )
  {
    HashMapModules mod = new HashMapModules();
    InfoModule im;
    Node np;
    Node pom = XMLAction.getFirstChildElement( nodeClass );
    while ( pom != null )
    {
      if ( pom.getNodeName().compareTo( MODULE ) == 0 )
      {
        String pn  = XMLAction.getValue( pom, MODULE_PACKAGENAME );
        String cn  = XMLAction.getValue( pom, MODULE_CLASSNAME );
        String tn  = XMLAction.getValue( pom, MODULE_TEMPLATE );
        String key = XMLAction.getValue( pom, MODULE_KEY );
        im = getInfo( pn, cn, tn );
        if ( im.infoGUI == null )
          im.infoGUI = new InfoModuleGUI();
        im.key = new Integer( key );

        String ps = XMLAction.getValue( pom, MODULE_NAME );
        if ( ps != null &&
             ps.length() > 0 )
          im.reg.name = ps;

        np = XMLAction.getNode( pom, MODULE_SHAPE );
        if ( np != null )
          initGroupModuleShape( np, im );

        np = XMLAction.getNode( pom, MODULE_PLUGS );
        if ( np != null )
          initGroupPlugs( np, im );

        np = XMLAction.getNode( pom, MODULE_PARAMS );
        if ( np != null )
          initGroupParams( np, im );

        mod.put( im.key, im );
      }
      pom = XMLAction.getNextSiblingElement( pom );
    }
    return mod;
  }

  /**
   * Read information about plugs of group.
   *
   * @param nodePlugs Node with plugs.
   * @param im Original owner of Plugs.
   */
  public void initGroupPlugs ( Node nodePlugs, InfoModule im )
  {
    Node nPlug = XMLAction.getFirstChildElement( nodePlugs );
    while ( nPlug != null )
    {
      if ( nPlug.getNodeName().compareTo( PLUG ) == 0 &&
           nPlug.getFirstChild() != null )
      {
        InfoPlug ip = im.plugs.get( XMLAction.getValue( nPlug, PLUG_NAME ) );
        if ( ip != null )
        {
          if ( ip.infoGUI == null )
            ip.infoGUI = new InfoPlugGUI();
          ip.infoGUI.visible = XMLAction.getBoolLegacy( nPlug, PLUG_VISIBLE );
        }
      }
      nPlug = XMLAction.getNextSiblingElement( nPlug );
    }
  }

  /**
   * Read information about parameters of group.
   *
   * @param nodeParams Node with parameters.
   * @param im Original owner of parameters.
   */
  public void initGroupParams ( Node nodeParams, InfoModule im )
  {
    Node nParam = XMLAction.getFirstChildElement( nodeParams );
    while ( nParam != null )
    {
      if ( nParam.getNodeName().compareTo( PARAM ) == 0 &&
           nParam.getFirstChild() != null )
      {
        InfoParam ip = im.params.get( XMLAction.getValue( nParam, PARAM_NAME ) );
        if ( ip != null )
        {
          if ( ip.infoGUI == null )
            ip.infoGUI = new InfoParamGUI();
          ip.infoGUI.visible = XMLAction.getBoolLegacy( nParam, PARAM_VISIBLE );
          String str = XMLAction.getValue( nParam, PARAM_DEFAULT );
          if ( str.length() == 0 )
            ip.defaultValue = str;
        }
      }
      nParam = XMLAction.getNextSiblingElement( nParam );
    }
  }

  /**
   * Read information about shape of module.
   *
   * @param nodeShape Node with shape.
   * @param im Original module.
   */
  public void initGroupModuleShape ( Node nodeShape, InfoModule im )
  {
    if ( im.infoGUI == null )
      im.infoGUI = new InfoModuleGUI();
    im.infoGUI.modeShow = XMLAction.getValue(    nodeShape, SHAPE_MODE );
    im.infoGUI.x        = XMLAction.getIntValue( nodeShape, SHAPE_X );
    im.infoGUI.y        = XMLAction.getIntValue( nodeShape, SHAPE_Y );
    im.infoGUI.width    = XMLAction.getIntValue( nodeShape, SHAPE_WIDTH );
    im.infoGUI.height   = XMLAction.getIntValue( nodeShape, SHAPE_HEIGHT );
  }

  /**
   * Gets information about channels in group.
   *
   * @param nodeClass Node with group.
   * @param modules Modules from group.
   * @return HashMapChannels.
   */
  public HashMapChannels getChannels ( HashMapModules modules, Node nodeClass )
  {
    HashMapChannels chan = new HashMapChannels();
    InfoChannel ic;
    int i = 0;
    Node pom = XMLAction.getFirstChildElement( nodeClass );
    while ( pom != null )
    {
      if ( pom.getNodeName().compareTo( CHANNEL ) == 0 )
      {
        ic = new InfoChannel();
        ic.infoGUI = new InfoChannelGUI();
        ic.key = i;
        chan.put( ic.key, ic );
        i++;
        ic.nameInterface = XMLAction.getValue( pom, CHANNEL_NAME );
        String mf        = XMLAction.getValue( pom, CHANNEL_MODULE_FROM );
        String mt        = XMLAction.getValue( pom, CHANNEL_MODULE_TO );
        String pf        = XMLAction.getValue( pom, CHANNEL_PLUG_FROM );
        String pt        = XMLAction.getValue( pom, CHANNEL_PLUG_TO );

        ic.plugFrom      = modules.get( mf ).plugs.get( pf );
        ic.plugTo        = modules.get( mt ).plugs.get( pt );
      }
      pom = XMLAction.getNextSiblingElement( pom );
    }
    return chan;
  }

  /**
   * Add node with module into package node.
   *
   * @param _package Name of package.
   * @param _class Name of class.
   * @param _template Name of template.
   * @param _nodeTemp node with template template.
   */
  protected void addClass ( String _package, String _class, String _template, Node _nodeTemp )
  {
    _nodeTemp.appendChild( doc.createTextNode( XMLAction.DELIMITER2 ) );

      // package node:
    Node packageNode = getPackage( _package );
    if ( packageNode == null )
    {                                     // create new (empty) package node
      packageNode = newElement( _package );
      packageNode.appendChild( doc.createTextNode( XMLAction.DELIMITER0 ) );
      rootDat.appendChild( packageNode );
      rootDat.appendChild( doc.createTextNode( XMLAction.DELIMITER0 ) );
    }

      // we are going to insert a new (or replace the old) <Class> element:
    Node classNode = getClass( packageNode, _class );

    if ( classNode == null )              // brand new class..
    {
      Node newClassNode = newElement( CLASS );
      newClassNode.appendChild( doc.createTextNode( XMLAction.DELIMITER2 ) );
      newClassNode.appendChild( newElement( CLASS_CLASSNAME, _class ) );
      newClassNode.appendChild( doc.createTextNode( XMLAction.DELIMITER2 ) );
      newClassNode.appendChild( _nodeTemp );
      newClassNode.appendChild( doc.createTextNode( XMLAction.DELIMITER1 ) );

      packageNode.appendChild( doc.createTextNode( "\t" ) );
      packageNode.appendChild( newClassNode );
      packageNode.appendChild( doc.createTextNode( XMLAction.DELIMITER0 ) );
      return;
    }

      // Is the given template present?
    Node templateNode = getTemplate( classNode, _template );

    if ( templateNode == null )
    {
      classNode.appendChild( doc.createTextNode( "\t" ) );
      classNode.appendChild( _nodeTemp );
      classNode.appendChild( doc.createTextNode( XMLAction.DELIMITER1 ) );
      return;
    }

    if ( JOptionPane.showConfirmDialog( MainWindow.mainWindow, "Module '" +
                                        _package + "." + _class + " (" + _template +
                                        ")' is already registered.\nDo you want to re-registry it?",
                                        "Confirm", JOptionPane.YES_NO_OPTION ) == JOptionPane.YES_OPTION )
      classNode.replaceChild( _nodeTemp, templateNode );
  }

  /**
   * Creates new Element.
   *
   * @param _name Name of Element.
   * @return New element.
   */
  protected Element newElement ( String _name )
  {
    return doc.createElement( _name );
  }

  /**
   * Creates new Element with value.
   *
   * @param _name Name of Element.
   * @param _value Value of element.
   * @return New element.
   */
  protected Element newElement ( String _name, String _value )
  {
    Element pom = newElement( _name );
    pom.appendChild( doc.createTextNode( _value ) );
    return pom;
  }

  /**
   * Finds node with the given package.
   *
   * @param _package Name of package.
   * @return Node package.
   */
  public Node getPackage ( String _package )
  {
    Node pom = XMLAction.getFirstChildElement( rootDat );
    while ( pom != null )
    {
      if ( pom.getNodeName().compareTo( _package ) == 0 )
        return pom;
      pom = XMLAction.getNextSiblingElement( pom );
    }

    return null;
  }

  /**
   * Finds node with the given class.
   *
   * @param _package Node with package.
   * @param _class Name of class.
   */
  public Node getClass ( Node _package, String _class )
  {
    Node pom = XMLAction.getFirstChildElement( _package );
    Node nodeClass;
    while ( pom != null )
    {
      if ( pom.getNodeName().compareTo( CLASS ) == 0 )
      {
        nodeClass = XMLAction.getFirstChildElement( pom );
        while ( nodeClass != null )
        {
          if ( nodeClass.getNodeName().compareTo( CLASS_CLASSNAME ) == 0 )
          {
            if ( nodeClass.getFirstChild() != null &&
                 nodeClass.getFirstChild().getNodeValue().compareTo( _class ) == 0 ||
                 _class == "" )
              return pom;
          }
          nodeClass = XMLAction.getNextSiblingElement( nodeClass );
        }
      }
      pom = XMLAction.getNextSiblingElement( pom );
    }

    return null;
  }

  /**
   * Finds node with the given template within the given class.
   *
   * @param _class Node with class.
   * @param _template Name of template.
   */
  public Node getTemplate ( Node _class, String _template )
  {
    Node pom = XMLAction.getFirstChildElement( _class );
    Node nodeTemp;
    while ( pom != null )
    {
      if ( pom.getNodeName().compareTo( TEMPLATE ) == 0 )
      {
        if ( _template.length() == 0 )
          return pom;
        nodeTemp = XMLAction.getFirstChildElement( pom );
        while ( nodeTemp != null )
        {
          if ( nodeTemp.getNodeName().compareTo( TEMPLATE_TEMPLATE_NAME ) == 0 &&
               nodeTemp.getFirstChild() != null &&
               nodeTemp.getFirstChild().getNodeValue().compareTo( _template ) == 0 )
            return pom;
          nodeTemp = XMLAction.getNextSiblingElement( nodeTemp );
        }
      }
      pom = XMLAction.getNextSiblingElement( pom );
    }
    return null;
  }

  /**
   * Gets values of parameter.
   *
   * @param _class Node with template.
   * @return values of parameter.
   */
  public Vector< Map< String, Object > > getParamValues ( Node _class )
  {
    Vector< Map< String, Object > > pv = new Vector< Map< String, Object > >();
    Node pom2;
    Map< String, Object > h;

    Node pom = XMLAction.getFirstChildElement( _class );
    while ( pom != null )
    {
      if ( pom.getNodeName().compareTo( VALUES ) == 0 )
      {
        pom2 = XMLAction.getFirstChildElement( pom );
        while ( pom2 != null )
        {
          if ( pom2.getNodeName().compareTo( VALUES_ITEM ) == 0 )
          {
            h = new HashMap< String, Object >();
            h.put( InfoParam.IP_STRING, XMLAction.getValue( pom2, InfoParam.IP_STRING ) );
            h.put( InfoParam.IP_VALUE,  XMLAction.getValue( pom2, InfoParam.IP_VALUE ) );
            h.put( InfoParam.IP_TYPE,   XMLAction.getValue( pom2, InfoParam.IP_TYPE ) );
            pv.add( h );
          }
          pom2 = XMLAction.getNextSiblingElement( pom2 );
        }
        return pv;
      }
      pom = XMLAction.getNextSiblingElement( pom );
    }
    return pv;
  }

  /**
   * Gets information about parameters.
   *
   * @param nodeTemp Node with template.
   * @param _owner Owner of parameters.
   */
  public LinkedHashMap< String, InfoParam > getParams ( Node nodeTemp, InfoModule _owner )
  {
    LinkedHashMap< String, InfoParam > p = new LinkedHashMap< String, InfoParam >();
    InfoParam par;

    Node nodePar = XMLAction.getFirstChildElement( nodeTemp );
    while ( nodePar != null )
    {
      if ( nodePar.getNodeName().compareTo( PARAM ) == 0 )
      {
        par = new InfoParam();
        par.owner           = _owner;
        par.name            = XMLAction.getValue( nodePar, PARAM_NAME );
        par.propManipClass  = XMLAction.getValue( nodePar, PARAM_MANIPULATOR );
        par.type            = XMLAction.getValue( nodePar, PARAM_TYPE );
        par.values          = getParamValues(     nodePar );
        par.defaultValue    = XMLAction.getValue( nodePar, PARAM_DEFAULT );
        par.description     = XMLAction.getValue( nodePar, PARAM_DESCRIPTION );
        par.visible         = XMLAction.getFlag(  nodePar, PARAM_VISIBLE );
        p.put( par.name, par );
      }
      nodePar = XMLAction.getNextSiblingElement( nodePar );
    }
    return p;
  }

  /**
   * Gets information about plugs.
   *
   * @param nodeTemp Node with template.
   * @param _owner Owner of plugs.
   */
  public Map< String, InfoPlug > getPlugs ( Node nodeTemp, InfoModule _owner )
  {
    Map< String, InfoPlug > p = new LinkedHashMap< String, InfoPlug >();

    Node nodeplug = XMLAction.getFirstChildElement( nodeTemp );
    while ( nodeplug != null )
    {
      if ( nodeplug.getNodeName().compareTo( PLUG ) == 0 )
      {
        InfoPlug ip    = new InfoPlug();
        ip.owner       = _owner;
        ip.name        = XMLAction.getValue( nodeplug, PLUG_IFACE );       // !!! LEGACY !!!
        if ( ip.name.length() == 0 )
          ip.name      = XMLAction.getValue( nodeplug, PLUG_NAME );
        ip.type        = XMLAction.getValue( nodeplug, PLUG_ID );
        if ( ip.type.length() == 0 )
          ip.type      = XMLAction.getValue( nodeplug, PLUG_TYPE );
        String io      = XMLAction.getValue( nodeplug, PLUG_IO );          // !!! LEGACY !!!
        if ( io.length() > 0 )
          ip.input = io.equals( "Input" );
        else
          ip.input     = XMLAction.getBoolLegacy( nodeplug, PLUG_INPUT );
        ip.mandatory   = !ip.input &&
                         XMLAction.getBoolLegacy( nodeplug, PLUG_MANDATORY );
        ip.multi       = XMLAction.getBoolLegacy( nodeplug, PLUG_MULTI );
        ip.description = XMLAction.getValue(      nodeplug, PLUG_DESCRIPTION );
        p.put( ip.type, ip );
      }
      nodeplug = XMLAction.getNextSiblingElement( nodeplug );
    }

    return p;
  }

  /**
   * Default constructor.
   */
  public RegTablesXML ()
  {
    try
    {
      jbInit();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Component initialization.
   */
  private void jbInit ()
  throws Exception
  {
    try
    {
      Transformer  vv = TransformerFactory.newInstance().newTransformer();
      DOMResult    c  = new DOMResult();
      StreamSource b  = new StreamSource();

      File oldFile = new File( file );
      if ( oldFile.exists() )             // read reg database from regular disk file
      {
        FileInputStream inputs = new FileInputStream( file );
        b.setInputStream( inputs );
      }
      else                                // try default database from URL or create a new (empty) one
      {
        InputStream is = Options.getResource( Options.FILE_NAME_REG );
        if ( is == null )                 // create empty registration database..
        {
          root    = DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument();
          doc     = (Document)root;
          rootDat = root.appendChild( newElement( "RegData" ) );
          return;
        }

        b.setInputStream( is );
      }

      vv.transform( b, c );
      b.getInputStream().close();
      root = c.getNode();
      root.normalize();
      doc = (Document)root;
      rootDat = root.getFirstChild();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  //==========================================================================
  //  Methods RegTables:

  /**
   * Gets information about module or group.
   *
   * @param _package Name of package.
   * @param _class Name of class.
   * @param _template Name of template.
   * @return information about module or group.
   */
  public InfoModule getInfo ( String _package, String _class, String _template )
  {
    if ( _package  == null ||
         _class    == null ||
         _template == null )
      return null;

    InfoModule info;
    if ( _package.compareTo( GROUP ) == 0 )
    {
      info = new InfoGroup();
      if ( info.infoGUI == null )
        info.infoGUI = new InfoGroupGUI();
    }
    else
      info = new InfoModule( new RegPiece() );

    Node nodePackage = getPackage( _package );
    if ( nodePackage == null )
    {
      LogFile.warning( "RegTablesXML.getInfo() - Unknown parameter _package: " + _package );
      return null;
    }

    Node nodeClass = getClass( nodePackage, _class );
    if ( nodeClass == null )
    {
      LogFile.warning( "RegTablesXML.getInfo() - Unknown parameter _class: " + _class );
      return null;
    }

    String newpack = XMLAction.getValue( nodeClass, CLASS_MOVED_TO );
    while ( newpack.length() > 0 )
    {
      nodePackage = getPackage( newpack );
      if ( nodePackage == null )
      {
        LogFile.warning( "RegTablesXML.getInfo() - Unknown parameter _package: " + _package );
        return null;
      }
      nodeClass = getClass( nodePackage, _class );
      _package = newpack;
      newpack = XMLAction.getValue( nodeClass, CLASS_MOVED_TO );
    }

    Node nodeTemp = getTemplate( nodeClass, _template );
    if ( nodeTemp == null )
    {
      LogFile.warning( "RegTablesXML.getInfo() - Unknown parameter _template:" + _template );
      return null;
    }

    info.reg.className   = _class;
    info.reg.packageName = _package;
    info.reg.template    = _template;

    info.reg.name        = XMLAction.getValue( nodeTemp, TEMPLATE_NAME );
    info.reg.category    = XMLAction.getValue( nodeTemp, TEMPLATE_CATEGORY );
    info.reg.description = XMLAction.getValue( nodeTemp, TEMPLATE_DESCRIPTION );

    if ( _package.compareTo( GROUP ) == 0 ) // Group
    {
      InputOutputXML ioXML = new InputOutputXML();
      ioXML.actualNode = XMLAction.getNode( nodeTemp, InfoGroup.TI_GROUP );
      try
      {
        ioXML.loadGroup( (InfoGroup)info );
        ((InfoGroup)info).registry = true;
      }
      catch ( Exception e )
      {
        LogFile.exception( e );
      }
//      ((InfoGroup)info).modules  = getModules( nodeTemp );
//      ((InfoGroup)info).channels = getChannels( ((InfoGroup)info).modules, nodeTemp );
      ((InfoGroup)info).init();
    }
    else                                  // Atomic module
    {
      info.plugs  = getPlugs(  nodeTemp, info );
      info.params = getParams( nodeTemp, info );

      Piece ip = null;
      try
      {
        ip = RegDatabaseBasic.newPieceInstance( info );
      }
      catch ( ClassNotFoundException e )
      {
        LogFile.warning( "'" + info.reg.fullClassName() + "' code is not available" );
      }
      catch ( Exception e )
      {
        LogFile.exception( e );
      }

      if ( ip == null )
      {
        if ( JOptionPane.showConfirmDialog ( MainWindow.mainWindow,
                                             "Code for the '" + info.reg.fullClassName() +
                                             "' module is not available!\nIgnore and continue?",
                                             "Error", JOptionPane.YES_NO_OPTION ) == JOptionPane.NO_OPTION )
          return null;
      }
      else
        if ( ip instanceof Worker )
        {
          if ( info.infoGUI == null )
            info.infoGUI = new InfoModuleGUI();
          if ( info.infoGUI.nextInfo == null )
            info.infoGUI.nextInfo = new HashMap< String, Object >();
          info.infoGUI.nextInfo.put( InfoModuleGUI.MS_ICON, InfoModuleGUI.iconRunable );
        }
    }

    return info;
  }

  /**
   * Move module to diferent package.
   *
   * @param _info Information about module.
   * @param newPackageName new package.
   */
  public void moveModule ( InfoModule _info, String newPackageName )
  {
    Node packageNode = getPackage( _info.reg.packageName );
    if ( packageNode == null )
    {
      LogFile.error( "RegTablesXML.moveModule(): incorrect package name: " + _info.reg.packageName );
      return;
    }
    Node classNode = getClass( packageNode, _info.reg.className );
    if ( classNode == null )
    {
      LogFile.error( "RegTablesXML.moveModule(): incorrect class name: " + _info.reg.className );
      return;
    }
    packageNode.removeChild( classNode );

    classNode = newElement( CLASS );
    classNode.appendChild( doc.createTextNode( XMLAction.DELIMITER2 ) );
    classNode.appendChild( newElement( CLASS_CLASSNAME, _info.reg.className ) );
    classNode.appendChild( doc.createTextNode( XMLAction.DELIMITER2 ) );
    classNode.appendChild( newElement( CLASS_MOVED_TO, newPackageName ) );
    classNode.appendChild( doc.createTextNode( XMLAction.DELIMITER1 ) );

    packageNode.appendChild( doc.createTextNode( XMLAction.DELIMITER1 ) );
    packageNode.appendChild( classNode );
    packageNode.appendChild( doc.createTextNode( XMLAction.DELIMITER0 ) );
  }

  /**
   * Registration of Piece into registry data.
   *
   * @param _info Information about module.
   */
  public void registerModule ( InfoModule _info )
  {
    Element templateNode = newElement( TEMPLATE );
    templateNode.appendChild( doc.createTextNode( XMLAction.DELIMITER3 ) );
    templateNode.appendChild( newElement( TEMPLATE_TEMPLATE_NAME, _info.reg.template ) );
    templateNode.appendChild( doc.createTextNode( XMLAction.DELIMITER3 ) );
    templateNode.appendChild( newElement( TEMPLATE_CATEGORY, _info.reg.category ) );
    templateNode.appendChild( doc.createTextNode( XMLAction.DELIMITER3 ) );
    templateNode.appendChild( newElement( TEMPLATE_NAME, _info.reg.name ) );
    templateNode.appendChild( doc.createTextNode( XMLAction.DELIMITER3 ) );
    templateNode.appendChild( newElement( TEMPLATE_DESCRIPTION, _info.reg.description ) );

    Node pNode;
    for ( InfoPlug ip : _info.plugs.values() )
    {
      pNode = newElement( PLUG );
      pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
      pNode.appendChild( newElement( PLUG_IFACE, ip.name ) );
      pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
      pNode.appendChild( newElement( PLUG_ID, ip.type ) );
      if ( ip.input )
      {
        pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
        pNode.appendChild( newElement( PLUG_INPUT ) );
      }
      else
        if ( ip.mandatory )
        {
          pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
          pNode.appendChild( newElement( PLUG_MANDATORY ) );
        }
      if ( ip.multi )
      {
        pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
        pNode.appendChild( newElement( PLUG_MULTI ) );
      }
      if ( ip.description != null &&
           ip.description.length() > 0 )
      {
        pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
        pNode.appendChild( newElement( PLUG_DESCRIPTION, ip.description ) );
      }
      pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER3 ) );
      templateNode.appendChild( doc.createTextNode( XMLAction.DELIMITER3 ) );
      templateNode.appendChild( pNode );
    }

    InfoParam ipa;
    Node nodeVal;
    Node itemNode;
    Map< String, Object > m;
    Object o;
    for ( String s : _info.params.keySet() )
    {
      pNode = newElement( PARAM );
      ipa   = _info.params.get( s );
      pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
      pNode.appendChild( newElement( PARAM_NAME, ipa.name ) );
      pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
      pNode.appendChild( newElement( PARAM_TYPE, ipa.type ) );
      if ( ipa.defaultValue != null )
      {
        pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
        pNode.appendChild( newElement( PARAM_DEFAULT, ipa.defaultValue.toString() ) );
      }
      if ( ipa.description != null &&
           ipa.description.length() > 0 )
      {
        pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
        pNode.appendChild( newElement( PARAM_DESCRIPTION, ipa.description ) );
      }
      if ( ipa.visible )
      {
        pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
        pNode.appendChild( newElement( PARAM_VISIBLE ) );
      }
      if ( ipa.propManipClass != null &&
           ipa.propManipClass.length() > 0 )
      {
        pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
        pNode.appendChild( newElement( PARAM_MANIPULATOR, ipa.propManipClass ) );
      }

      nodeVal = newElement( VALUES );
      for ( int j = 0; j < ipa.values.size(); j++ )
      {
        itemNode = newElement( VALUES_ITEM );
        m = (Map< String, Object >)ipa.values.get( j );
        o = m.get( InfoParam.IP_STRING );
        if ( o != null )
        {
          itemNode.appendChild( doc.createTextNode( XMLAction.DELIMITER6 ) );
          itemNode.appendChild( newElement( InfoParam.IP_STRING, o.toString() ) );
        }
        o = m.get( InfoParam.IP_VALUE );
        if ( o != null )
        {
          itemNode.appendChild( doc.createTextNode( XMLAction.DELIMITER6 ) );
          itemNode.appendChild( newElement( InfoParam.IP_VALUE, o.toString() ) );
        }
        o = m.get( InfoParam.IP_TYPE );
        if ( o != null )
        {
          itemNode.appendChild( doc.createTextNode( XMLAction.DELIMITER6 ) );
          itemNode.appendChild( newElement( InfoParam.IP_TYPE, o.toString() ) );
        }
        o = m.get( InfoParam.IP_DESCR );
        if ( o != null )
        {
          itemNode.appendChild( doc.createTextNode( XMLAction.DELIMITER6 ) );
          itemNode.appendChild( newElement( InfoParam.IP_DESCR, o.toString() ) );
        }

        o = m.get( InfoParam.IP_MINVALUE );
        if ( o != null )
        {
          nodeVal.appendChild( doc.createTextNode( XMLAction.DELIMITER5 ) );
          nodeVal.appendChild( newElement( InfoParam.IP_MINVALUE, o.toString() ) );
        }
        o = m.get( InfoParam.IP_MAXVALUE );
        if ( o != null )
        {
          nodeVal.appendChild( doc.createTextNode( XMLAction.DELIMITER5 ) );
          nodeVal.appendChild( newElement( InfoParam.IP_MAXVALUE, o.toString() ) );
        }

        if ( itemNode.hasChildNodes() )
        {
          itemNode.appendChild( doc.createTextNode( XMLAction.DELIMITER5 ) );
          nodeVal.appendChild( doc.createTextNode( XMLAction.DELIMITER5 ) );
          nodeVal.appendChild( itemNode );
        }
      }

      if ( nodeVal.hasChildNodes() )
      {
        nodeVal.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
        pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER4 ) );
        pNode.appendChild( nodeVal );
      }

      pNode.appendChild( doc.createTextNode( XMLAction.DELIMITER3 ) );
      templateNode.appendChild( doc.createTextNode( XMLAction.DELIMITER3 ) );
      templateNode.appendChild( pNode );
    }

    addClass( _info.reg.packageName, _info.reg.className, _info.reg.template, templateNode );
  }

  /**
   * Registration of group into registry data.
   *
   * @param _info Information about group.
   */
  public void registerGroup ( InfoGroup _info )
  {
    Element templateNode = newElement( TEMPLATE );
    templateNode.appendChild( doc.createTextNode( XMLAction.DELIMITER3 )  );
    templateNode.appendChild( newElement( TEMPLATE_TEMPLATE_NAME, _info.reg.template ) );
    templateNode.appendChild( doc.createTextNode( XMLAction.DELIMITER3 ) );
    templateNode.appendChild( newElement( TEMPLATE_CATEGORY, _info.reg.category ) );
    templateNode.appendChild( doc.createTextNode( XMLAction.DELIMITER3 ) );
    templateNode.appendChild( newElement( TEMPLATE_DESCRIPTION, _info.reg.description ) );

    InputOutputXML ioXML = new InputOutputXML();
    ioXML.actualNode = templateNode;
    ioXML.doc = doc;
    ioXML.saveGroup( _info );

    addClass( _info.reg.packageName, _info.reg.className, _info.reg.template, templateNode );
  }

  /**
   * Unregistration of Piece into registry data.
   *
   * @param _info Information about module.
   */
  public void unregister ( InfoModule _info )
  {
    Node packageNode = getPackage( _info.reg.packageName );
    if ( packageNode == null )
      return;

    Node classNode = getClass( packageNode, _info.reg.className );
    if ( classNode == null )
      return;

    Node templateNode = getTemplate( classNode, _info.reg.template );
    if ( templateNode == null )
      return;

    classNode.removeChild( templateNode );
    if ( XMLAction.getNode( classNode, TEMPLATE ) == null )
      packageNode.removeChild( classNode );
  }

  /** Saves registry data into XML file. */
  public void save ()
  {
    try
    {
      Transformer vv = TransformerFactory.newInstance().newTransformer();
      vv.setOutputProperty( OutputKeys.METHOD,               "xml" );
      vv.setOutputProperty( OutputKeys.OMIT_XML_DECLARATION, "no" );
      vv.setOutputProperty( OutputKeys.INDENT,               "yes" );
      vv.setOutputProperty( OutputKeys.ENCODING,             "UTF-8" );
      DOMSource    c = new DOMSource();
      StreamResult b = new StreamResult();
      c.setNode( root );

      File outFile = new File( file );
      if ( !outFile.exists() )
      {
        File parent = outFile.getParentFile();
        if ( !parent.exists() )
          parent.mkdirs();
        outFile.createNewFile();
      }
      b.setOutputStream( new FileOutputStream( outFile ) );

      vv.transform( c, b );
      b.getOutputStream().close();
    }
    catch ( Exception e )
    {
      LogFile.exception( e );
    }
  }

  /**
   * Gets TableModel for table of modules.
   *
   * @param _filter Filter.
   * @return table.
   */
  public AbstractTableModel getTableModelModule ( SelectFilter _filter )
  {
    String[] cul = new String[]
                   { "Package",
                     "Class",
                     "Template",
                     "Category",
                     "Name",
                     "Description"
                   };
    Object[][] rdata = {};
    MyTableModel tm = new MyTableModel( rdata, cul );

    boolean group = true;
    if ( _filter != null )
      group = _filter.getShowGroup();

    Node nodePackage = XMLAction.getFirstChildElement( rootDat );
    while ( nodePackage != null )
    {
      if ( group || nodePackage.getNodeName().compareTo( GROUP ) != 0 )
      {
        Node nodeClass = getClass( nodePackage, "" );
        while ( nodeClass != null )
        {
          Node nodeTemp = getTemplate( nodeClass, "" );
          while ( nodeTemp != null )
          {
            InfoModule im = getInfo( nodePackage.getNodeName(),
                                     XMLAction.getValue( nodeClass, CLASS_CLASSNAME ),
                                     XMLAction.getValue( nodeTemp, TEMPLATE_TEMPLATE_NAME ) );
            if ( im != null && (_filter == null || _filter.filter( im )) )
              tm.addRow( new String[]
                {
                  im.reg.packageName,
                  im.reg.className,
                  im.reg.template,
                  im.reg.category,
                  im.reg.name,
                  im.reg.description
                } );

            nodeTemp = XMLAction.getNextSiblingElement( nodeTemp );
          }
          nodeClass = XMLAction.getNextSiblingElement( nodeClass );
        }
      }
      nodePackage = XMLAction.getNextSiblingElement( nodePackage );
    }

    return tm;
  }

  /**
   * Gets TableModel for table of plugs.
   *
   * @param _package Name of package.
   * @param _class Name of class.
   * @param _template Name of template.
   * @return table.
   */
  public AbstractTableModel getTableModelPlug ( String _package, String _class,
                                                String _template )
  {
    String[] cul = new String[]
                   { "Name",
                     "Type",
                     "IO",
                     "Mandatory",
                     "Multi",
                     "Description"
                   };
    Object[][] rdata = {};
    MyTableModel tm = new MyTableModel( rdata, cul );

    if ( _package.equals( GROUP ) )
    {
      InfoModule im = getInfo( _package, _class, _template );
      for ( InfoPlug ip : im.plugs.values() )
        tm.addRow( new String[]
          {
            ip.type,
            ip.name,
            ip.inputOutput(),
            String.valueOf( ip.mandatory ),
            String.valueOf( ip.multi ),
            ip.description
          } );

      return tm;
    }

    Node nodePackage = getPackage( _package );
    if ( nodePackage == null )
      return tm;

    Node nodeClass = getClass( nodePackage, _class );
    if ( nodeClass == null )
      return tm;

    Node nodeTemp = getTemplate( nodeClass, _template );
    if ( nodeTemp == null )
      return tm;

    Node nodePlug = XMLAction.getFirstChildElement( nodeTemp );
    while ( nodePlug != null )
    {
      if ( nodePlug.getNodeName().compareTo( PLUG ) == 0 )
      {
        String id = XMLAction.getValue( nodePlug, PLUG_ID );               // !!! LEGACY !!!
        if ( id.length() == 0 )
          id = XMLAction.getValue( nodePlug, PLUG_TYPE );

        String iface = XMLAction.getValue( nodePlug, PLUG_IFACE );         // !!! LEGACY !!!
        if ( iface.length() == 0 )
          XMLAction.getValue( nodePlug, PLUG_NAME );

        String io = XMLAction.getValue( nodePlug, PLUG_IO );               // !!! LEGACY !!!
        if ( io.length() == 0 )
          io = XMLAction.getBoolLegacy( nodePlug, PLUG_INPUT ) ? "Input" : "Output";

        String mandatory = XMLAction.getValue( nodePlug, PLUG_MANDATORY ); // !!! LEGACY !!!
        if ( mandatory.length() == 0 )
          mandatory = String.valueOf( XMLAction.getBoolLegacy( nodePlug, PLUG_MANDATORY ) );

        String multi = XMLAction.getValue( nodePlug, PLUG_MULTI );         // !!! LEGACY !!!
        if ( multi.length() == 0 )
          multi = String.valueOf( XMLAction.getBoolLegacy( nodePlug, PLUG_MULTI ) );

        tm.addRow( new String[]
          {
            id,
            iface,
            io,
            mandatory,
            multi,
            XMLAction.getValue( nodePlug, PLUG_DESCRIPTION )
          } );
      }

      nodePlug = XMLAction.getNextSiblingElement( nodePlug );
    }
    return tm;
  }

  /**
   * Gets TableModel for table of parameters.
   *
   * @param _package Name of package.
   * @param _class Name of class.
   * @param _template Name of template.
   * @return table.
   */
  public AbstractTableModel getTableModelParam ( String _package, String _class,
                                                 String _template )
  {
    String[] cul = new String[]
                   {
                     "Name",
                     "Type",
                     "Description"
                   };
    Object[][] rdata = {};
    MyTableModel tm = new MyTableModel( rdata, cul );

    if ( _package.compareTo( GROUP ) == 0 )
    {
      InfoModule im = getInfo( _package, _class, _template );
      for ( InfoParam ip : im.params.values() )
        tm.addRow( new String[]
          {
            ip.name,
            ip.type,
            ip.description
          } );

      return tm;
    }

    Node nodePackage = getPackage( _package );
    if ( nodePackage == null )
      return tm;

    Node nodeClass = getClass( nodePackage, _class );
    if ( nodeClass == null )
      return tm;

    Node nodeTemp = getTemplate( nodeClass, _template );
    if ( nodeTemp == null )
      return tm;

    Node nodeParam = XMLAction.getFirstChildElement( nodeTemp );
    while ( nodeParam != null )
    {
      if ( nodeParam.getNodeName().compareTo( PARAM ) == 0 )
        tm.addRow( new String[]
        {
          XMLAction.getValue( nodeParam, PARAM_NAME ),
          XMLAction.getValue( nodeParam, PARAM_TYPE ),
          XMLAction.getValue( nodeParam, PARAM_DESCRIPTION )
        } );
      nodeParam = XMLAction.getNextSiblingElement( nodeParam );
    }

    return tm;
  }

  /** Returns set of all used interfaces (Plug types). */
  public Set< String > getInterfaces ()
  {
    Set< String > ifaces = new TreeSet< String >();

    Node nodePackage = XMLAction.getFirstChildElement( rootDat );
    while ( nodePackage != null )
    {
      if ( nodePackage.getNodeName().compareTo( GROUP ) != 0 )
      {
        Node nodeClass = getClass( nodePackage, "" );
        while ( nodeClass != null )
        {
          Node nodeTemp = getTemplate( nodeClass, "" );
          while ( nodeTemp != null )
          {
            Map< String, InfoPlug > plugs = getPlugs( nodeTemp, null );
            for ( InfoPlug ip : plugs.values() )
              ifaces.add( ip.name );
            nodeTemp = XMLAction.getNextSiblingElement( nodeTemp );
          }
          nodeClass = XMLAction.getNextSiblingElement( nodeClass );
        }
      }
      nodePackage = XMLAction.getNextSiblingElement( nodePackage );
    }

    return ifaces;
  }
}
