package cz.cuni.jagrlib.xml;

import org.w3c.dom.*;

/**
 * Support class for XML output.
 *
 * @author  Jan Kostlivy, PE
 * @version 0.25 $Rev: 381 $ $Date: 2007-01-02 15:51:44 +0100 (út, 02 I 2007) $ $Author: pepca $
 * @since   0.23
 * @see     <a href="../../../../../cz/cuni/jagrlib/xml/XMLAction.java">XMLAction.java</a>
 */
public class XMLAction
{
  public final static String DELIMITER0 = "\n";
  public final static String DELIMITER1 = "\n\t";
  public final static String DELIMITER2 = "\n\t\t";
  public final static String DELIMITER3 = "\n\t\t\t";
  public final static String DELIMITER4 = "\n\t\t\t\t";
  public final static String DELIMITER5 = "\n\t\t\t\t\t";
  public final static String DELIMITER6 = "\n\t\t\t\t\t\t";

  //==========================================================================
  //  Methods:

  /**
   * Returns first child Element.
   *
   * @param _parent branch of data.
   */
  public static Node getFirstChildElement ( Node _parent )
  {
    Node pom = _parent.getFirstChild();
    while ( pom != null )
    {
      if ( pom.getNodeType() == Node.ELEMENT_NODE )
        return pom;
      pom = pom.getNextSibling();
    }

    return null;
  }

  /**
   * Returns next sibling Element.
   *
   * @param _node branch of data.
   */
  public static Node getNextSiblingElement ( Node _node )
  {
    Node pom = _node.getNextSibling();
    while ( pom != null )
    {
      if ( pom.getNodeType() == Node.ELEMENT_NODE )
        return pom;
      pom = pom.getNextSibling();
    }

    return null;
  }

  /**
   * Returns value of node from branch.
   *
   * @param _node branch of data.
   * @param _name name of node.
   */
  public static String getValue ( Node _node, String _name )
  {
    Node pom = getFirstChildElement( _node );
    while ( pom != null )
    {
      if ( pom.getNodeName().compareTo( _name ) == 0 )
      {
        if ( pom.getFirstChild() != null )
          return pom.getFirstChild().getNodeValue();
        else
          return "";
      }
      pom = getNextSiblingElement( pom );
    }

    return "";
  }

  /**
   * Returns boolean flag (presence of the given tag, the shortest
   * variant is {@code name}).
   *
   * @param _node Data node.
   * @param _name Tag name to be looked for.
   * @return true if the given tag was found.
   */
  public static boolean getFlag ( Node _node, String _name )
  {
    Node pom = getFirstChildElement( _node );
    while ( pom != null )
    {
      if ( pom.getNodeName().compareTo( _name ) == 0 )
        return true;

      pom = getNextSiblingElement( pom );
    }

    return false;
  }

  /**
   * Returns value of node from branch as boolean.
   * Will be replaced by {@link #getFlag} code after a while..
   *
   * @param _node branch of data.
   * @param _name name of node.
   */
  public static boolean getBoolLegacy ( Node _node, String _name )
  {
    Node pom = getFirstChildElement( _node );
    while ( pom != null )
    {
      if ( pom.getNodeName().equals( _name ) )
      {
        if ( pom.getFirstChild() == null )
          return true;

        return !pom.getFirstChild().getNodeValue().equalsIgnoreCase( "false" );
      }
      pom = getNextSiblingElement( pom );
    }

    return false;
  }

  /**
   * Returns value of node from branch as integer.
   *
   * @param _node branch of data.
   * @param _name name of node.
   */
  public static int getIntValue ( Node _node, String _name )
  {
    String ps = XMLAction.getValue( _node, _name );
    if ( ps == "" )
      return 0;

    return Integer.parseInt( ps );
  }

  /**
   * Returns value of node from branch as Integer.
   *
   * @param _node branch of data.
   * @param _name name of node.
   */
  public static Integer getIntegerValue ( Node _node, String _name )
  {
    String ps = XMLAction.getValue( _node, _name );
    if ( ps == "" )
      return null;

    return Integer.valueOf( ps );
  }

  /**
   * Returns node from branch.
   *
   * @param _node branch of data.
   * @param _name name of node.
   */
  public static Node getNode ( Node _node, String _name )
  {
    Node pom = getFirstChildElement( _node );
    while ( pom != null )
    {
      if ( pom.getNodeName().compareTo( _name ) == 0 )
        return pom;

      pom = getNextSiblingElement( pom );
    }

    return null;
  }

  /**
   * Appends child to node.
   *
   * @param doc Document.
   * @param nodeTo branch for new node.
   * @param delimiter For formating XML document - Human readable.
   */
  public static Node appendChild ( Document doc, Node nodeTo, String delimiter,
                                   String nodeName, String nodeValue )
  {
    if ( delimiter != null )
      nodeTo.appendChild( doc.createTextNode( delimiter ) );
    Element pom = doc.createElement( nodeName );
    pom.appendChild( doc.createTextNode( nodeValue ) );
    nodeTo.appendChild( pom );
    return nodeTo;
  }

  /**
   * Appends child to node.
   *
   * @param doc Document.
   * @param nodeTo branch for new node.
   * @param delimiter For formating XML document - Human readable.
   */
  public static Node appendChild ( Document doc, Node nodeTo, String delimiter,
                                   String nodeName )
  {
    if ( delimiter != null )
      nodeTo.appendChild( doc.createTextNode( delimiter ) );
    Element newNode = doc.createElement( nodeName );
    nodeTo.appendChild( newNode );
    return newNode;
  }

}
