package cz.cuni.jagrlib.gui;

import cz.cuni.jagrlib.reg.*;

/**
 * Class with actual skin.
 *
 * @author  Jan Kostlivy
 * @version 0.25 $Rev: 375 $ $Date: 2006-12-23 15:23:15 +0100 (so, 23 XII 2006) $ $Author: pepca $
 * @since   0.24
 * @see     <a href="../../../../../cz/cuni/jagrlib/gui/InstanceGUI.java">InstanceGUI.java</a>
 */
public class InstanceGUI
{
  //==========================================================================
  //  Methods:

  //----------WorkSpace
  /**
   * Creates new instance of WorkSpace.
   *
   * @return Instance of Composition.
   */
  static public WorkSpaceGUI newWorkSpaceInstance ()
  {
    return new WorkSpaceGUIBasic();
  }

  //----------Module
  /**
   * Creates new instance of module with info.
   *
   * @param _info Information about module.
   * @return Instance of module.
   */
  static public ModuleGUI newModuleInstance ( InfoModule _info )
  {
    return new ModuleGUIImproved( _info );
  }

  //----------Plug
  /**
   * Creates new instance of Plug with info.
   *
   * @param _infoP Information about Plug.
   * @return Instance of Plug.
   */
  static public PlugGUI newPlugInstance ( InfoPlug _infoP )
  {
    return new PlugGUIImproved( _infoP );
  }

  //----------Channel
  /**
   * Creates new instance of Channel and connecting Modules and Plugs.
   *
   * @param _info Information about channel.
   * @return Instance of Channel.
   */
  static public ChannelGUI newChannelInstance ( InfoChannel _info )
  {
    return new ChannelGUIImproved( _info );
  }

  //----------Group
  /**
   * Creates new instance of Group.
   *
   * @param _info Information about group.
   * @return Instance of Group.
   */
  static public ModuleGUI newGroupInstance ( InfoGroup _info )
  {
    return new GroupGUIImproved( _info );
  }

  //----------Composition
  /**
   * Creates new instance of Composition.
   *
   * @return Instance of Composition.
   */
  static public CompositionGUI newCompositionInstance ()
  {
    return new CompositionGUIBasic();
  }

  //----------Params
  static public ParamGUI newParamCombo ()
  {
    return new ParamCombo();
  }

  static public ParamGUI newParamInteger ()
  {
    return new ParamInteger();
  }

  static public ParamGUI newParamLong ()
  {
    return new ParamLong();
  }

  static public ParamGUI newParamFloat ()
  {
    return new ParamFloat();
  }

  static public ParamGUI newParamDouble ()
  {
    return new ParamDouble();
  }

  static public ParamGUI newParamString ()
  {
    return new ParamString();
  }

  static public ParamGUI newParamText ()
  {
    return new ParamText();
  }

  static public ParamGUI newParamBoolean ()
  {
    return new ParamBoolean();
  }

  static public ParamGUI newParamSpec ()
  {
    return new ParamSpec();
  }

  /**
   * Creates new parameter instance.
   *
   * @param ip Information about parameter.
   * @return Instance of Parameter.
   */
  static public ParamGUI newParam ( InfoParam ip )
  {
    ParamGUI ret = null;

    if ( InfoParam.IP_TYPE_COMBO.compareTo( ip.type ) == 0 )
    {
      ret = newParamCombo();
      ret.setInfo( ip );
      return ret;
    }

    if ( InfoParam.IP_TYPE_STRING.compareTo( ip.type ) == 0 )
    {
      ret = newParamString();
      ret.setInfo( ip );
      return ret;
    }

    if ( InfoParam.IP_TYPE_MULTILINE.compareTo( ip.type ) == 0 )
    {
      ret = newParamText();
      ret.setInfo( ip );
      return ret;
    }

    if ( InfoParam.IP_TYPE_INTEGER.compareTo( ip.type ) == 0 )
    {
      ret = newParamInteger();
      ret.setInfo( ip );
      return ret;
    }

    if ( InfoParam.IP_TYPE_LONG.compareTo( ip.type ) == 0 )
    {
      ret = newParamLong();
      ret.setInfo( ip );
      return ret;
    }

    if ( InfoParam.IP_TYPE_FLOAT.compareTo( ip.type ) == 0 )
    {
      ret = newParamFloat();
      ret.setInfo( ip );
      return ret;
    }

    if ( InfoParam.IP_TYPE_DOUBLE.compareTo( ip.type ) == 0 )
    {
      ret = newParamDouble();
      ret.setInfo( ip );
      return ret;
    }

    if ( InfoParam.IP_TYPE_BOOLEAN.compareTo( ip.type ) == 0 )
    {
      ret = newParamBoolean();
      ret.setInfo( ip );
      return ret;
    }

    if ( InfoParam.IP_TYPE_SPEC.compareTo( ip.type ) == 0 )
    {
      ret = newParamSpec();
      ret.setInfo( ip );
      return ret;
    }

    return ret;
  }

  //----------Zoom
  /**
   * Creates new instance of zoom window.
   *
   * @return Instance of zoom window.
   */
  static public ZoomWindow newZoomInstance ()
  {
    return new ZoomImproved();
  }

}
